@@ -16,7 +16,7 @@ SUBROUTINE CASPT2_UDL(PSI,F,NAO,NMO,CMO,ONEINT,TWOINT)
   ! to the upper and lower triangular blocks Q of U and L by means of the
   ! exponential operator exp(Q).
 
-  USE ISO_FORTRAN_ENV
+  USE ISO_FORTRAN_ENV, ONLY: REAL64
   USE SECOND_QUANTIZATION
   USE WAVEFUNCTION
   USE DENSITY
@@ -49,13 +49,11 @@ SUBROUTINE CASPT2_UDL(PSI,F,NAO,NMO,CMO,ONEINT,TWOINT)
 
   INTEGER, ALLOCATABLE :: IPIV(:)
 
-  INTEGER :: A, B, I, J, T, U, P, Q, R, S, IA, IB
+  INTEGER :: A, I, T, P, Q, R, S, IA, IB
   INTEGER :: DETA, DETB, TMPA, TMPB
   INTEGER, ALLOCATABLE :: IDXA(:), IDXB(:), ADET(:), BDET(:)
 
-  REAL(REAL64), EXTERNAL :: DNRM2, DDOT
-
-  INTEGER :: ICNT
+  REAL(REAL64), EXTERNAL :: DNRM2_, DDOT_
 
   ! get appropriate orbital space dimensions from the supplied Fock matrix
   NI=SIZE(F%II,1)
@@ -235,8 +233,8 @@ SUBROUTINE CASPT2_UDL(PSI,F,NAO,NMO,CMO,ONEINT,TWOINT)
           PSI1%COEF=0.0D0
           CALL WFN_PSD(NI,NA,NS,SGM,PSI1)
 
-          IF (DNRM2(PSI1%NDET,PSI1%COEF,1).NE.0.0D0) THEN
-            VPQRS(P,Q,R,S)=DDOT(PSI1%NDET,PSI1%COEF,1,TAU%COEF,1)
+          IF (DNRM2_(PSI1%NDET,PSI1%COEF,1).NE.0.0D0) THEN
+            VPQRS(P,Q,R,S)=DDOT_(PSI1%NDET,PSI1%COEF,1,TAU%COEF,1)
             NSD=NSD+1
           END IF
 
@@ -299,7 +297,7 @@ SUBROUTINE CASPT2_UDL(PSI,F,NAO,NMO,CMO,ONEINT,TWOINT)
           PSI1%COEF=0.0D0
           CALL WFN_PSD(NI,NA,NS,SGM,PSI1)
 
-          IF (DNRM2(PSI1%NDET,PSI1%COEF,1).NE.0.0D0) THEN
+          IF (DNRM2_(PSI1%NDET,PSI1%COEF,1).NE.0.0D0) THEN
             ISD=ISD+1
             ! put |i> = E_pqrs |0> into PSI1BRA and PSI1KET
             PSI1BRA(ISD,:,:) = PSI1%COEF
@@ -330,11 +328,11 @@ SUBROUTINE CASPT2_UDL(PSI,F,NAO,NMO,CMO,ONEINT,TWOINT)
     END DO
   END DO
 
-  CALL DGEMM('N','N',NSD,NSD,PSI1%NDET,1.0D0, &
+  CALL DGEMM_('N','N',NSD,NSD,PSI1%NDET,1.0D0, &
        & PSI1BRA,NSD,PSI1KET,PSI1%NDET, &
        & 0.0D0,S0,NSD)
 
-  CALL DGEMM('N','N',NSD,NSD,PSI1%NDET,1.0D0, &
+  CALL DGEMM_('N','N',NSD,NSD,PSI1%NDET,1.0D0, &
        & PSI1BRA,NSD,FOCKKET,PSI1%NDET, &
        & 0.0D0,H0,NSD)
 
@@ -343,7 +341,7 @@ SUBROUTINE CASPT2_UDL(PSI,F,NAO,NMO,CMO,ONEINT,TWOINT)
   ! orthogonal basis, and transform X, S0, H0 and V0 accordingly
 
   ALLOCATE(U0(NSD,NSD))
-  U0=S0
+  U0(:,:)=S0
 
   NWORK=NSD**2
   ALLOCATE(WORK(NWORK))
@@ -373,12 +371,12 @@ SUBROUTINE CASPT2_UDL(PSI,F,NAO,NMO,CMO,ONEINT,TWOINT)
   DEALLOCATE(U0)
 
   ALLOCATE(X(NSD))
-  X=-V0
+  X(:)=-V0
 
   ! compute RHS = Sum_i X_i |i>
   RHS%COEF=0.0D0
   DO ISD=1,NSD
-    RHS%COEF=RHS%COEF+X(ISD)*PSI1KET(:,:,ISD)
+    RHS%COEF(:,:)=RHS%COEF+X(ISD)*PSI1KET(:,:,ISD)
   END DO
 
   ! apply first series of operators exp(-Q_IA) exp(-Q_AS) exp(-Q_IS)
@@ -390,13 +388,13 @@ SUBROUTINE CASPT2_UDL(PSI,F,NAO,NMO,CMO,ONEINT,TWOINT)
       CALL WFN_EX1(-F%IS(I,A),I,NI+NA+A,RHS,SGM)
     END DO
   END DO
-  PSI1%COEF=SGM%COEF
+  PSI1%COEF(:,:)=SGM%COEF
   DO A=1,NS
     DO I=1,NI
       CALL WFN_EX1(-0.5D0*F%IS(I,A),I,NI+NA+A,PSI1,SGM)
     END DO
   END DO
-  RHS%COEF=RHS%COEF+SGM%COEF
+  RHS%COEF(:,:)=RHS%COEF+SGM%COEF
 
   ! exp(-Q_AS) = 1 - Sum_AS Q_AS E_AS + ...
   SGM%COEF=0.0D0
@@ -405,13 +403,13 @@ SUBROUTINE CASPT2_UDL(PSI,F,NAO,NMO,CMO,ONEINT,TWOINT)
       CALL WFN_EX1(-F%AS(T,A),NI+T,NI+NA+A,RHS,SGM)
     END DO
   END DO
-  PSI1%COEF=SGM%COEF
+  PSI1%COEF(:,:)=SGM%COEF
   DO A=1,NS
     DO T=1,NA
       CALL WFN_EX1(-0.5D0*F%AS(T,A),NI+T,NI+NA+A,PSI1,SGM)
     END DO
   END DO
-  RHS%COEF=RHS%COEF+SGM%COEF
+  RHS%COEF(:,:)=RHS%COEF+SGM%COEF
 
   ! exp(-Q_IA) = 1 - Sum_IA Q_IA E_IA + ...
   SGM%COEF=0.0D0
@@ -428,13 +426,13 @@ SUBROUTINE CASPT2_UDL(PSI,F,NAO,NMO,CMO,ONEINT,TWOINT)
       CALL WFN_EX1(-0.5D0*F%IA(I,T),I,NI+T,PSI1,SGM)
     END DO
   END DO
-  RHS%COEF=RHS%COEF+SGM%COEF
+  RHS%COEF(:,:)=RHS%COEF+SGM%COEF
 
   ! contract into X_i = <i|exp(-Q_IA)|RHS> and
   ! transform to adapt for the overcomplete basis
   CALL DGEMV_('N',NSD,PSI1%NDET,1.0D0, &
        & PSI1BRA,NSD,RHS%COEF,1,0.0D0,X,1)
-  X = MATMUL(MATMUL(T0,TRANSPOSE(T0)),X)
+  X(:) = MATMUL(MATMUL(T0,TRANSPOSE(T0)),X)
 
 
   ! apply diagonal inverse, e.g. solve H0' XNEW = XOLD
@@ -455,14 +453,14 @@ SUBROUTINE CASPT2_UDL(PSI,F,NAO,NMO,CMO,ONEINT,TWOINT)
 
   DEALLOCATE(IPIV)
 
-  X=MATMUL(T0,X(1:MSD))
+  X(:)=MATMUL(T0,X(1:MSD))
 
   ! Now, continue with the transformation steps for L
 
   ! compute new RHS = Sum_i X_i |i>
   RHS%COEF=0.0D0
   DO ISD=1,NSD
-    RHS%COEF=RHS%COEF+X(ISD)*PSI1KET(:,:,ISD)
+    RHS%COEF(:,:)=RHS%COEF+X(ISD)*PSI1KET(:,:,ISD)
   END DO
 
   ! apply second series of operators exp(-Q_SI) exp(-Q_SA) exp(-Q_SI)
@@ -474,13 +472,13 @@ SUBROUTINE CASPT2_UDL(PSI,F,NAO,NMO,CMO,ONEINT,TWOINT)
       CALL WFN_EX1(-F%AI(T,I),NI+T,I,RHS,SGM)
     END DO
   END DO
-  PSI1%COEF=SGM%COEF
+  PSI1%COEF(:,:)=SGM%COEF
   DO I=1,NI
     DO T=1,NA
       CALL WFN_EX1(-0.5D0*F%AI(T,I),NI+T,I,PSI1,SGM)
     END DO
   END DO
-  RHS%COEF=RHS%COEF+SGM%COEF
+  RHS%COEF(:,:)=RHS%COEF+SGM%COEF
 
   ! exp(-Q_SA) = 1 - Sum_SA Q_SA E_SA + ...
   SGM%COEF=0.0D0
@@ -489,13 +487,13 @@ SUBROUTINE CASPT2_UDL(PSI,F,NAO,NMO,CMO,ONEINT,TWOINT)
       CALL WFN_EX1(-F%SA(A,T),NI+NA+A,NI+T,RHS,SGM)
     END DO
   END DO
-  PSI1%COEF=SGM%COEF
+  PSI1%COEF(:,:)=SGM%COEF
   DO T=1,NA
     DO A=1,NS
       CALL WFN_EX1(-0.5D0*F%SA(A,T),NI+NA+A,NI+T,PSI1,SGM)
     END DO
   END DO
-  RHS%COEF=RHS%COEF+SGM%COEF
+  RHS%COEF(:,:)=RHS%COEF+SGM%COEF
 
   ! exp(-Q_SI) = 1 - Sum_SI Q_SI E_SI + ...
   SGM%COEF=0.0D0
@@ -504,40 +502,40 @@ SUBROUTINE CASPT2_UDL(PSI,F,NAO,NMO,CMO,ONEINT,TWOINT)
       CALL WFN_EX1(-F%SI(A,I),NI+NA+A,I,RHS,SGM)
     END DO
   END DO
-  PSI1%COEF=SGM%COEF
+  PSI1%COEF(:,:)=SGM%COEF
   DO I=1,NI
     DO A=1,NS
       CALL WFN_EX1(-0.5D0*F%SI(A,I),NI+NA+A,I,PSI1,SGM)
     END DO
   END DO
-  RHS%COEF=RHS%COEF+SGM%COEF
+  RHS%COEF(:,:)=RHS%COEF+SGM%COEF
 
   ! contract into X_i = <i|exp(-Q_IA)|RHS> and
   ! transform to adapt for the overcomplete basis
   CALL DGEMV_('N',NSD,PSI1%NDET,1.0D0, &
        & PSI1BRA,NSD,RHS%COEF,1,0.0D0,X,1)
-  X = MATMUL(MATMUL(T0,TRANSPOSE(T0)),X)
+  X(:) = MATMUL(MATMUL(T0,TRANSPOSE(T0)),X)
 
 
 
   ! compute the energy
 
   ! method 1: E2 = <V0|X>
-  E2 = DDOT(NSD,V0,1,X,1)
+  E2 = DDOT_(NSD,V0,1,X,1)
   WRITE(*,'(1X,A32,F21.14)') 'E2 as <V0|X> = ', E2
 
   ! method 2: E2 = <0|Ĥ|Psi1>
   ! first, form the first-order wavefunction |Psi1>
   PSI1%COEF=0.0D0
   DO ISD=1,NSD
-    PSI1%COEF=PSI1%COEF+X(ISD)*PSI1KET(:,:,ISD)
+    PSI1%COEF(:,:)=PSI1%COEF+X(ISD)*PSI1KET(:,:,ISD)
   END DO
 
   !WRITE(*,*) 'Final first-order wavefunction from UDL method:'
   !CALL WFN_PRINT(PSI1,1.0D-8)
 
   ! TAU still contains Ĥ|0>, so contract with |Psi1>
-  E2 = DDOT(PSI1%NDET,PSI1%COEF,1,TAU%COEF,1)
+  E2 = DDOT_(PSI1%NDET,PSI1%COEF,1,TAU%COEF,1)
   WRITE(*,'(1X,A32,F21.14)') 'E2 as <Psi1|H|0> = ', E2
 
   DEALLOCATE(H0)
@@ -664,7 +662,7 @@ SUBROUTINE CASPT2_UDL(PSI,F,NAO,NMO,CMO,ONEINT,TWOINT)
   END DO
 
   ! set RHS to -<i|H|0>
-  RHS%COEF=-RHS%COEF
+  RHS%COEF(:,:)=-RHS%COEF
 
   ! series of deexcitation operators exp(-Q_IA) exp(-Q_AS) exp(-Q_IS)
 
@@ -675,13 +673,13 @@ SUBROUTINE CASPT2_UDL(PSI,F,NAO,NMO,CMO,ONEINT,TWOINT)
       CALL WFN_EX1(-F%IS(I,A),I,NI+NA+A,RHS,SGM)
     END DO
   END DO
-  PSI1%COEF=SGM%COEF
+  PSI1%COEF(:,:)=SGM%COEF
   DO A=1,NS
     DO I=1,NI
       CALL WFN_EX1(-0.5D0*F%IS(I,A),I,NI+NA+A,PSI1,SGM)
     END DO
   END DO
-  RHS%COEF=RHS%COEF+SGM%COEF
+  RHS%COEF(:,:)=RHS%COEF+SGM%COEF
 
   ! exp(-Q_AS) = 1 - Sum_AS Q_AS E_AS + ...
   SGM%COEF=0.0D0
@@ -690,13 +688,13 @@ SUBROUTINE CASPT2_UDL(PSI,F,NAO,NMO,CMO,ONEINT,TWOINT)
       CALL WFN_EX1(-F%AS(T,A),NI+T,NI+NA+A,RHS,SGM)
     END DO
   END DO
-  PSI1%COEF=SGM%COEF
+  PSI1%COEF(:,:)=SGM%COEF
   DO A=1,NS
     DO T=1,NA
       CALL WFN_EX1(-0.5D0*F%AS(T,A),NI+T,NI+NA+A,PSI1,SGM)
     END DO
   END DO
-  RHS%COEF=RHS%COEF+SGM%COEF
+  RHS%COEF(:,:)=RHS%COEF+SGM%COEF
 
   ! exp(-Q_IA) = 1 - Sum_IA Q_IA E_IA + ...
   SGM%COEF=0.0D0
@@ -705,13 +703,13 @@ SUBROUTINE CASPT2_UDL(PSI,F,NAO,NMO,CMO,ONEINT,TWOINT)
       CALL WFN_EX1(-F%IA(I,T),I,NI+T,RHS,SGM)
     END DO
   END DO
-  PSI1%COEF=SGM%COEF
+  PSI1%COEF(:,:)=SGM%COEF
   DO T=1,NA
     DO I=1,NI
       CALL WFN_EX1(-0.5D0*F%IA(I,T),I,NI+T,PSI1,SGM)
     END DO
   END DO
-  RHS%COEF=RHS%COEF+SGM%COEF
+  RHS%COEF(:,:)=RHS%COEF+SGM%COEF
 
   ALLOCATE(X(NSD))
 
@@ -771,13 +769,13 @@ SUBROUTINE CASPT2_UDL(PSI,F,NAO,NMO,CMO,ONEINT,TWOINT)
       CALL WFN_EX1(-F%AI(T,I),NI+T,I,RHS,SGM)
     END DO
   END DO
-  PSI1%COEF=SGM%COEF
+  PSI1%COEF(:,:)=SGM%COEF
   DO I=1,NI
     DO T=1,NA
       CALL WFN_EX1(-0.5D0*F%AI(T,I),NI+T,I,PSI1,SGM)
     END DO
   END DO
-  RHS%COEF=RHS%COEF+SGM%COEF
+  RHS%COEF(:,:)=RHS%COEF+SGM%COEF
 
   ! exp(-Q_SA) = 1 - Sum_SA Q_SA E_SA + ...
   SGM%COEF=0.0D0
@@ -786,13 +784,13 @@ SUBROUTINE CASPT2_UDL(PSI,F,NAO,NMO,CMO,ONEINT,TWOINT)
       CALL WFN_EX1(-F%SA(A,T),NI+NA+A,NI+T,RHS,SGM)
     END DO
   END DO
-  PSI1%COEF=SGM%COEF
+  PSI1%COEF(:,:)=SGM%COEF
   DO T=1,NA
     DO A=1,NS
       CALL WFN_EX1(-0.5D0*F%SA(A,T),NI+NA+A,NI+T,PSI1,SGM)
     END DO
   END DO
-  RHS%COEF=RHS%COEF+SGM%COEF
+  RHS%COEF(:,:)=RHS%COEF+SGM%COEF
 
   ! exp(-Q_SI) = 1 - Sum_SI Q_SI E_SI + ...
   SGM%COEF=0.0D0
@@ -801,13 +799,13 @@ SUBROUTINE CASPT2_UDL(PSI,F,NAO,NMO,CMO,ONEINT,TWOINT)
       CALL WFN_EX1(-F%SI(A,I),NI+NA+A,I,RHS,SGM)
     END DO
   END DO
-  PSI1%COEF=SGM%COEF
+  PSI1%COEF(:,:)=SGM%COEF
   DO I=1,NI
     DO A=1,NS
       CALL WFN_EX1(-0.5D0*F%SI(A,I),NI+NA+A,I,PSI1,SGM)
     END DO
   END DO
-  RHS%COEF=RHS%COEF+SGM%COEF
+  RHS%COEF(:,:)=RHS%COEF+SGM%COEF
 
   ! contract into X_i = <i|exp(-Q_IA)|RHS> and
   ! transform to adapt for the overcomplete basis
@@ -821,7 +819,7 @@ SUBROUTINE CASPT2_UDL(PSI,F,NAO,NMO,CMO,ONEINT,TWOINT)
   ! compute the energy
 
   ! method 1: E2 = <V0|X>
-  E2 = DDOT(NSD,V0,1,X,1)
+  E2 = DDOT_(NSD,V0,1,X,1)
   WRITE(*,'(1X,A32,F21.14)') 'E2 as <V0|X> = ', E2
 
   ! method 2: E2 = <0|Ĥ|Psi1>
@@ -837,7 +835,7 @@ SUBROUTINE CASPT2_UDL(PSI,F,NAO,NMO,CMO,ONEINT,TWOINT)
   !CALL WFN_PRINT(PSI1,1.0D-8)
 
   ! TAU still contains Ĥ|0>, so contract with |Psi1>
-  E2 = DDOT(PSI1%NDET,PSI1%COEF,1,TAU%COEF,1)
+  E2 = DDOT_(PSI1%NDET,PSI1%COEF,1,TAU%COEF,1)
   WRITE(*,'(1X,A32,F21.14)') 'E2 as <Psi1|H|0> = ', E2
 
 END SUBROUTINE CASPT2_UDL
