@@ -11,10 +11,18 @@
 
 ! This is just an encapsulation of the interface in
 ! src/Include/stdalloc.fh
+! and data in src/Include/WrkSpc.fh
 ! into a module.
 
       module stdalloc
       implicit none
+      private
+      public :: mma_allocate, mma_deallocate, mxMem
+
 #include "stdalloc.fh"
+      integer, parameter :: iWorkLen = 8
+      real*8 :: Work(1:iWorkLen)
+      integer :: mxMem
+      common /WrkSpc/ Work, mxMem
       save
       end module stdalloc
