@@ -19,20 +19,6 @@
 *                                                                      *
 *          Alaska is a derivative code of Seward 3.1.                  *
 *                                                                      *
-* Called from: None                                                    *
-*                                                                      *
-* Calling    : QEnter                                                  *
-*              XuFlow (IBM)                                            *
-*              SetUp0                                                  *
-*              GetMem                                                  *
-*              GetInf                                                  *
-*              Inputg                                                  *
-*              DrvN1                                                   *
-*              Drvh1                                                   *
-*              PrepP                                                   *
-*              Drvg1                                                   *
-*              CloseP                                                  *
-*                                                                      *
 *  Author: Roland Lindh, IBM Almaden Research Center, San Jose, CA     *
 *          July '89 - May '90                                          *
 *                                                                      *
@@ -40,13 +26,16 @@
 *          Lund, SWEDEN. Modified to gradient calculations September   *
 *          1991 - February 1992.                                       *
 ************************************************************************
+      use Alaska_Info
       use Real_Spherical
+      use Basis_Info
+      use Temporary_Parameters
+      use RICD_Info, only: Do_RI, Cholesky
       Implicit Real*8 (A-H,O-Z)
       External RF_On
+#include "Molcas.fh"
 #include "real.fh"
-#include "itmax.fh"
-#include "info.fh"
-#include "WrkSpc.fh"
+#include "stdalloc.fh"
 #include "print.fh"
 #include "disp.fh"
 #include "rctfld.fh"
@@ -57,8 +46,10 @@
 #include "alaska_root.fh"
 #include "para_info.fh"
       Logical OldTst, DoRys, RF_On, Found
-      Logical Do_OFemb,KEonly,OFE_first
       Character(Len=180) Label
+      Real*8, Allocatable:: Grad(:), Temp(:), Tmp(:), Rlx(:,:), CSFG(:)
+
+      Logical Do_OFemb,KEonly,OFE_first
       COMMON  / OFembed_L / Do_OFemb,KEonly,OFE_first
 ************ columbus interface ****************************************
         Integer  Columbus, colgradmode
@@ -68,6 +59,8 @@
         Integer iatom,icen,j
 *                                                                      *
 ************************************************************************
+*                                                                      *
+*     Call Alaska_banner()
       npelem=3
 *                                                                      *
       Call CWTime(TCpu1,TWall1)
@@ -84,7 +77,6 @@
 *                                                                      *
 *     Print program header
 *
-      Call qEnter('Alaska')
 *                                                                      *
 ************************************************************************
 *                                                                      *
@@ -92,7 +84,7 @@
 *
       nDiff=1
       DoRys=.True.
-      Call IniSew(Info,DoRys,nDiff)
+      Call IniSew(DoRys,nDiff)
       If (RF_On()) Then
          If (NonEq_Ref) Then
             Call WarningMessage(2,'Error in Alaska')
@@ -115,10 +107,10 @@
 *
       iPrint=nPrint(iRout)
 
-      If (iPrint.ge.99) Call GetMem(' LIST ','LIST','REAL',iDum,iDum)
-      Call GetMem('Grad','Allo','Real',ipGrad,lDisp(0))
-      Call GetMem('Temp','Allo','Real',ipTemp,lDisp(0))
-      call dcopy_(lDisp(0),[Zero],0,Work(ipGrad),1)
+
+      Call mma_allocate(Grad,lDisp(0),Label='Grad')
+      Call mma_allocate(Temp,lDisp(0),Label='Temp')
+      Grad(:)=Zero
 *
 *     remove LuSpool
 *
@@ -147,10 +139,10 @@
        If (NO_NUC .or. (Columbus.eq.1 .and. colgradmode.eq.3)) then
          write(6,*) 'Skipping Nuclear Charge Contribution'
        Else
-         Call DrvN1(Work(ipGrad),Work(ipTemp),lDisp(0))
+         Call DrvN1(Grad,Temp,lDisp(0))
          If (iPrint.ge.15) Then
             Lab=' Total Nuclear Contribution'
-            Call PrGrad(Lab,Work(ipGrad),lDisp(0),lIrrep,ChDisp,iPrint)
+            Call PrGrad(Lab,Grad,lDisp(0),ChDisp,iPrint)
          End If
        End If
       End If
@@ -161,7 +153,7 @@
 *                                                                      *
       If (Do_OFemb) Then
 * RepNuc term to the Orbital-Free Embedding gradient
-         Call DrvN1_EMB(Work(ipGrad),Work(ipTemp),lDisp(0))
+         Call DrvN1_EMB(Grad,Temp,lDisp(0))
       EndIf
 *                                                                      *
 ************************************************************************
@@ -175,20 +167,20 @@
 *     normalization.
 *
       If (.Not.(nProcs.gt.1).or.Onenly) Then
-         Call Drvh1(Work(ipGrad),Work(ipTemp),lDisp(0))
+         Call Drvh1(Grad,Temp,lDisp(0))
       End If ! .Not.(nProcs.gt.1).or.Onenly
       If (Do_OFemb) Then
 * NucAtt term to the Orbital-Free Embedding gradient
-         Call Drvh1_EMB(Work(ipGrad),Work(ipTemp),lDisp(0))
+         Call Drvh1_EMB(Grad,Temp,lDisp(0))
       EndIf
 !         Lab='Nuc + One-electron Contribution'
-!         Call PrGrad(Lab,Work(ipGrad),lDisp(0),lIrrep,ChDisp,iPrint)
+!         Call PrGrad(Lab,Grad,lDisp(0),ChDisp,iPrint)
 *                                                                      *
 ************************************************************************
 *                                                                      *
 *     Compute the DFT contribution to the gradient
 *
-      Call DrvDFTg(Work(ipGrad),Work(ipTemp),lDisp(0))
+      Call DrvDFTg(Grad,Temp,lDisp(0))
 *                                                                      *
 ************************************************************************
 *                                                                      *
@@ -198,46 +190,38 @@
 *                                                                      *
 *     DFT-type Orbital-Free Embedding term to the gradient
 *
-      If (Do_OFemb) Call DrvEMBg(Work(ipGrad),Work(ipTemp),lDisp(0))
+      If (Do_OFemb) Call DrvEMBg(Grad,Temp,lDisp(0))
 *                                                                      *
 ************************************************************************
 *                                                                      *
 *-----Compute contribution due to 2-electron integrals.
 *
-      Call GetMem('MemHid','ALLO','REAL',idum,MemHid)
-*
-*                                                                      *
-************************************************************************
-*                                                                      *
       If (Cholesky.or.Do_RI) Then
          If (Cholesky) Then
             If (iPrint.ge.6) Write (6,*) 'Cholesky-ERI gradients!'
          Else
             If (iPrint.ge.6) Write (6,*) 'RI-ERI gradients!'
          End If
-         Call Drvg1_RI (Work(ipGrad),Work(ipTemp),lDisp(0))
+         Call Drvg1_RI (Grad,Temp,lDisp(0))
       Else
          If (iPrint.ge.6) Write (6,*) 'Conventional ERI gradients!'
-         Call Drvg1    (Work(ipGrad),Work(ipTemp),lDisp(0))
+         Call Drvg1    (Grad,Temp,lDisp(0))
       End If
 *
-      Call DScal_(lDisp(0),Half,Work(ipTemp),1)
+      Call DScal_(lDisp(0),Half,Temp,1)
       If (iPrint.ge.15) Then
          Lab=' Two-electron Contribution'
-         Call PrGrad(Lab,Work(ipTemp),lDisp(0),lIrrep,ChDisp,iPrint)
+         Call PrGrad(Lab,Temp,lDisp(0),ChDisp,iPrint)
       End If
 *
 *-----Accumulate contribution to the gradient
 *
-      Call GR_DArray(Work(ipGrad),lDisp(0))
-      Call DaXpY_(lDisp(0),One,Work(ipTemp),1,
-     &                        Work(ipGrad),1)
+      Call GR_DArray(Grad,lDisp(0))
+      Call DaXpY_(lDisp(0),One,Temp,1,Grad,1)
 *
 *                                                                      *
 ************************************************************************
 *                                                                      *
-*
-      Call GetMem('MemHid','Free','REAL',idum,MemHid)
  998  Continue
 *                                                                      *
 ************************************************************************
@@ -254,17 +238,16 @@
          If (iPrint.ge.99) Then
             Call PrGrad(
      &       ' Molecular gradients (no TR) ',
-     &           Work(ipGrad),lDisp(0),lIrrep,ChDisp,iPrint)
-            Call RecPrt(' The A matrix',' ',Work(ipAm),
-     &                  lDisp(0),lDisp(0))
+     &           Grad,lDisp(0),ChDisp,iPrint)
+            Call RecPrt(' The A matrix',' ',Am,lDisp(0),lDisp(0))
          End If
-         call dcopy_(lDisp(0),Work(ipGrad),1,Work(ipTemp),1)
+         call dcopy_(lDisp(0),Grad,1,Temp,1)
 
          Call dGeMV_('N',lDisp(0),lDisp(0),
-     &              One,Work(ipAm),lDisp(0),
-     &              Work(ipTemp),1,
-     &              Zero,Work(ipGrad),1)
-         Call GetMem('AMtrx','Free','Real',ipAm,lDisp(0)**2)
+     &              One,Am,lDisp(0),
+     &              Temp,1,
+     &              Zero,Grad,1)
+         Call mma_deallocate(Am)
       End If ! TRSymm
 *                                                                      *
 ************************************************************************
@@ -273,8 +256,7 @@
 *
       If (lEq) Then
          Do i = 1, lDisp(0)
-            If (IndxEq(i).ne.i) Work(ipGrad-1+i) =
-     &         Work(ipGrad-1+IndxEq(i))
+            If (IndxEq(i).ne.i) Grad(i) = Grad(IndxEq(i))
          End Do
       End If ! lEq
 *                                                                      *
@@ -286,10 +268,9 @@
 *                                                                      *
       nCnttp_Valence=0
       Do iCnttp = 1, nCnttp
-         If (AuxCnttp(iCnttp)) Go To 1999
+         If (dbsc(iCnttp)%Aux) Exit
          nCnttp_Valence = nCnttp_Valence+1
       End Do
- 1999 Continue
 *
 *     f^AB is the "total derivative coupling"
 *     h^AB is the "CI derivative coupling"
@@ -302,49 +283,45 @@
 *
       If (isNAC) Then
         Call PrGrad('CI derivative coupling ',
-     &                 Work(ipGrad),lDisp(0),lIrrep,ChDisp,iPrint)
+     &                 Grad,lDisp(0),ChDisp,iPrint)
         EDiff_s = Max(One, Ten**(-Floor(Log10(Abs(EDiff)))-4))
         EDiff_f = EDiff*EDiff_s
         If (DoCSF) Then
-          Call Allocate_Work(ipCSFG,lDisp(0))
-          Call CSFGrad(Work(ipCSFG),lDisp(0))
+          Call mma_Allocate(CSFG,lDisp(0),Label='CSFG')
+          Call CSFGrad(CSFG,lDisp(0))
           Call PrGrad('CSF derivative coupling ',
-     &                   Work(ipCSFG),lDisp(0),lIrrep,ChDisp,iPrint)
-          Call daxpy_(lDisp(0),EDiff_f,Work(ipCSFG),1,Work(ipGrad),1)
-          Call Free_Work(ipCSFG)
+     &                  CSFG,lDisp(0),ChDisp,iPrint)
+          Call daxpy_(lDisp(0),EDiff_f,CSFG,1,Grad,1)
+          Call mma_deallocate(CSFG)
         End If
         write(6,'(15X,A,ES13.6)') 'Energy difference: ',EDiff
         Label = ''
         If (EDiff_s.gt.One)
      &      Write(Label,'(A,ES8.1,A)') ' (divided by',EDiff_s,')'
         Label = 'Total derivative coupling'//Trim(Label)
-        Call Allocate_Work(ipTmp,lDisp(0))
-        call dcopy_(lDisp(0),Work(ipGrad),1,Work(ipTmp),1)
-        call dscal_(lDisp(0),One/EDiff_f,Work(ipTmp),1)
-        Call PrGrad(Trim(Label),
-     &              Work(ipTmp),lDisp(0),lIrrep,ChDisp,iPrint)
-        write(6,'(15X,A,F12.4)') 'norm: ',dnrm2_(lDisp(0),Work(ipTmp),1)
-        Call Free_Work(ipTmp)
+        Call mma_allocate(Tmp,lDisp(0),Label='Tmp')
+        Tmp(:)=Grad(:)/EDiff_f
+        Call PrGrad(Trim(Label),Tmp,lDisp(0),ChDisp,iPrint)
+        write(6,'(15X,A,F12.4)') 'norm: ',dnrm2_(lDisp(0),Tmp,1)
+        Call mma_deallocate(Tmp)
       ElseIf (iPrint.ge.4) then
          If (HF_Force) Then
             Call PrGrad('Hellmann-Feynman Forces ',
-     &                 Work(ipGrad),lDisp(0),lIrrep,ChDisp,iPrint)
+     &                 Grad,lDisp(0),ChDisp,iPrint)
          Else
             Call PrGrad(' Molecular gradients',
-     &                    Work(ipGrad),lDisp(0),lIrrep,ChDisp,iPrint)
+     &                    Grad,lDisp(0),ChDisp,iPrint)
          End If
       End If
       If (isNAC) Then
-*        For NAC, the sign is undefined (because the wave functions can change sign),
-*        check only absolute values
-         Call Allocate_Work(ipTmp,lDisp(0))
-         Do i=0,lDisp(0)-1
-            Work(ipTmp+i)=Abs(Work(ipGrad+i))
-         End Do
-         Call Add_Info('Grad',Work(ipTmp),lDisp(0),6)
-         Call Free_Work(ipTmp)
+*        For NAC, the sign is undefined (because the wave functions can
+*        change sign), check only absolute values
+         Call mma_allocate(Tmp,lDisp(0),Label='Tmp')
+         Tmp(:)=ABS(Grad(:))
+         Call Add_Info('Grad',Tmp,lDisp(0),6)
+         Call mma_deallocate(Tmp)
       Else
-         Call Add_Info('Grad',Work(ipGrad),lDisp(0),6)
+         Call Add_Info('Grad',Grad,lDisp(0),6)
       End If
 *
 *---- Molcas format
@@ -356,30 +333,29 @@
 
       Call Get_iScalar('Unique atoms',nsAtom)
       l1 = 3*nsAtom
-      Call GetMem('RELAX','Allo','Real',ipRlx,l1)
+      Call mma_allocate(Rlx,3,nsAtom,Label='Rlx')
       mdc = 0
       ndc = 0
       Do iCnttp = 1, nCnttp_Valence
 *
 *        Skip gradients for pseudo atoms
 *
-         If (pChrg(iCnttp).or.nFragType(iCnttp).gt.0.or.
-     &       FragCnttp(iCnttp)) Then
-            mdc=mdc+nCntr(iCnttp)
+         If (dbsc(iCnttp)%pChrg.or.dbsc(iCnttp)%nFragType.gt.0.or.
+     &       dbsc(iCnttp)%Frag) Then
+            mdc=mdc+dbsc(iCnttp)%nCntr
          Else
-            Do iCnt = 1, nCntr(iCnttp)
+            Do iCnt = 1, dbsc(iCnttp)%nCntr
                mdc=mdc+1
                ndc=ndc+1
                Do iCar = 1, 3
                   If (InxDsp(mdc,iCar).ne.0) Then
-                     temp = Work(ipGrad-1+InxDsp(mdc,iCar))
-                     Work(ipRlx-1+(ndc-1)*3+iCar) = temp
+                     Rlx(iCar,ndc) = Grad(InxDsp(mdc,iCar))
                   Else
 *
 *                    Put in explicit zero if gradient is zero
 *                    by symmetry.
 *
-                     Work(ipRlx-1+(ndc-1)*3+iCar) = Zero
+                     Rlx(iCar,ndc) = Zero
                   End If
                End Do
             End Do
@@ -387,13 +363,13 @@
       End Do
 *
       If (HF_Force) Then
-         Call Put_dArray('HF-forces',Work(ipRlx),l1)
+         Call Put_dArray('HF-forces',Rlx,l1)
       Elseif (Columbus.eq.1) then
-         Call Put_nadc(colgradmode,Work(ipRlx),l1)
+         Call Put_nadc(colgradmode,Rlx,l1)
       Else
-         Call Put_Grad(Work(ipRlx),l1)
+         Call Put_Grad(Rlx,l1)
       End If
-      Call GetMem('RELAX','Free','Real',ipRlx,l1)
+      Call mma_deallocate(Rlx)
 
 
 ************ columbus interface ****************************************
@@ -404,7 +380,7 @@
 *     Real*8 Cgrad(3,mxatom)
 *     Character CNames(MxAtom)*9
 *     Integer lcartgrd, iatom,icen,j
-      Call TrGrd_Alaska_(CGrad,CNames,Work(ipGrad),lDisp(0),iCen)
+      Call TrGrd_Alaska_(CGrad,CNames,Grad,lDisp(0),iCen)
       lcartgrd=60
       lcartgrd=isFreeUnit(lcartgrd)
       Call Molcas_Open(lcartgrd,'cartgrd')
@@ -419,21 +395,17 @@
 *-----At the end of the calculation free all memory to check for
 *     corruption of the memory.
 *
-      Call GetMem('Temp','Free','Real',ipTemp,lDisp(0))
-      Call GetMem('Grad','Free','Real',ipGrad,lDisp(0))
-*
-      If (iPrint.ge.99) Then
-         Call GetMem(' LIST ','LIST','REAL',iDum,iDum)
-      End If
+      Call mma_deallocate(Temp)
+      Call mma_deallocate(Grad)
 *
 *     Restore iRlxRoot if changed as set by the RASSCF module.
 *
       Call qpg_iScalar('Relax CASSCF root',Found)
       If (Found) Then
          Call Get_iScalar('Relax CASSCF root',irlxroot1)
-         Call qpg_iScalar('Relax Original ro',Found)
+         Call qpg_iScalar('Relax Original root',Found)
          If (Found) Then
-            Call Get_iScalar('Relax Original ro',irlxroot2)
+            Call Get_iScalar('Relax Original root',irlxroot2)
             If (iRlxRoot1.ne.iRlxRoot2) Then
                Call Put_iScalar('Relax CASSCF root',irlxroot2)
                Call Put_iScalar('NumGradRoot',irlxroot2)
@@ -443,11 +415,9 @@
 *
 *     Epilogue
 *
-      Call ClsSew
-      Call qExit('Alaska')
+      Call ClsSew()
 *
       If (iPrint.ge.6) Then
-         Call qStat(' ')
          Call FastIO('STATUS')
       End If
 *
