@@ -15,55 +15,51 @@
 *                                                                      *
 * Object: input module for the gradient code                           *
 *                                                                      *
-* Called from: Alaska                                                  *
-*                                                                      *
-* Calling    : QEnter                                                  *
-*              GetMem                                                  *
-*              DCopy   (ESSL)                                          *
-*              RecPrt                                                  *
-*              DaXpY   (ESSL)                                          *
-*              DDot_   (ESSL)                                          *
-*              DScal   (ESSL)                                          *
-*              DGEMM_  (ESSL)                                          *
-*              QExit                                                   *
-*                                                                      *
 *     Author: Roland Lindh, Dept. of Theoretical Chemistry,            *
 *             University of Lund, SWEDEN                               *
 *             September '91                                            *
 *                                                                      *
 *             Modified to complement GetInf, January '92.              *
 ************************************************************************
+      use Alaska_Info, only: Am
+      use Basis_Info
+      use Center_Info
+      use Symmetry_Info, only: nIrrep, iChTbl, iOper, lIrrep, lBsFnc
+      use Temporary_Parameters
+      use Real_Info, only: CutInt
       Implicit Real*8 (A-H,O-Z)
 #include "itmax.fh"
-#include "info.fh"
+#include "Molcas.fh"
 #include "print.fh"
 #include "real.fh"
 #include "disp.fh"
 #include "iavec.fh"
-#include "WrkSpc.fh"
+#include "stdalloc.fh"
 #include "columbus_gamma.fh"
 #include "exterm.fh"
 #include "nac.fh"
 #include "alaska_root.fh"
       Logical TstFnc, Type, Slct, T_Only, No_Input_OK
-      Character*1 xyz(0:2)
-      Character KWord*80, Key*80
-      Integer iSym(3), iTemp(3*mxdc)
+      Real*8, Allocatable:: Tmp(:), C(:,:), Scr(:,:), Temp(:,:)
+      Integer, Allocatable:: IndCar(:)
+
+      Character(LEN=1) :: xyz(0:2)=['x','y','z']
+      Character(LEN=80) KWord, Key
+      Integer iSym(3), iTemp(3*MxAtom)
       Logical timings,Reduce_Prt
       External Reduce_Prt
-      Data xyz/'x','y','z'/
       COMMON /CHOTIME / timings
+
       Logical Do_OFemb,KEonly,OFE_first
       COMMON  / OFembed_L / Do_OFemb,KEonly,OFE_first
+
       COMMON  / OFembed_R1/ Xsigma
       COMMON  / OFembed_R2/ dFMD
       Character*16  OFE_KSDFT
       COMMON  / OFembed_C / OFE_KSDFT
-*
 *
       iRout = 99
       iPrint = nPrint(iRout)
-*     Call qEnter('Inputg')
       Do i = 1, nRout
          nPrint(i) = 5
       End Do
@@ -71,7 +67,6 @@
       DoCSF  = .True.
       isCSF  = .False.
       Auto   = .False.
-      Onenly = .False.
       Test   = .False.
       T_Only = .False.
       TRSymm = .False.
@@ -115,15 +110,10 @@
 *     Second CutInt should now locally for Alaska be reset to the value
 *     of CutInt/100!
       CutInt=CutGrd*1.0D-2
-c..   debug
-c      onenly=.true.
-c      nprint(112)=99
-c      nprint(133)=99
-c      nprint(26)=99
-      Do 109 i = 1, 3*mxdc
+      Do 109 i = 1, 3*MxAtom
          IndxEq(i) = i
  109  Continue
-      Do 1500 ldsp = 1, 3*mxdc
+      Do 1500 ldsp = 1, 3*MxAtom
          Direct(ldsp) = .True.
  1500 Continue
 *                                                                      *
@@ -139,13 +129,12 @@ c      nprint(26)=99
       KWord = Key
       Call UpCase(KWord)
       If (KWord(1:1).eq.'*')    Go To 998
-      If (KWord.eq.BLine)       Go To 998
+      If (KWord.eq.'')       Go To 998
       If (KWord(1:4).eq.'VERB') Go To 912
       If (KWord(1:4).eq.'PRIN') Go To 930
       If (KWord(1:4).eq.'EQUI') Go To 935
       If (KWord(1:4).eq.'CUTO') Go To 942
       If (KWord(1:4).eq.'HF-F') Go To 993
-      If (KWord(1:4).eq.'MEMO') Go To 951
       If (KWord(1:4).eq.'NOIN') Go To 953
       If (KWord(1:4).eq.'SELE') Go To 960
       If (KWord(1:4).eq.'2DOP') Go To 965
@@ -192,12 +181,12 @@ c      nprint(26)=99
 *
  930  Read(LuSpool,'(A)',Err=988) KWord
       If (KWord(1:1).eq.'*') Go To 930
-      If (KWord.eq.BLine)    Go To 930
+      If (KWord.eq.'')    Go To 930
       Read(KWord,*,Err=988) n
       Do 931 i = 1, n
  9301    Read(LuSpool,'(A)',Err=988) KWord
          If (KWord(1:1).eq.'*') Go To 9301
-         If (KWord.eq.BLine)    Go To 9301
+         If (KWord.eq.'')    Go To 9301
          Read(KWord,*,Err=988) jRout, iPrint
          nPrint(jRout)=iPrint
  931  Continue
@@ -210,18 +199,18 @@ c      nprint(26)=99
  935  Continue
       If (T_Only) Then
          Call WarningMessage(2,'Error in InputG')
-         Write (LuWr,*)'EQUI option does not work with RF calculations!'
+         Write (LuWr,*)'EQUI option does not ork with RF calculations!'
          Call Quit_OnUserError()
       End If
       lEq=.True.
  936  Read(LuSpool,'(A)',Err=988) KWord
       If (KWord(1:1).eq.'*') Go To 936
-      If (KWord.eq.BLine)    Go To 936
+      If (KWord.eq.'')    Go To 936
       Read(KWord,*) nGroup
       Do 937 iGroup = 1, nGroup
  938     Read(LuSpool,'(A)',Err=988) KWord
          If (KWord(1:1).eq.'*') Go To 938
-         If (KWord.eq.BLine)    Go To 938
+         If (KWord.eq.'')    Go To 938
          Read(KWord,*) nElem,(iTemp(iElem),iElem=1,nElem)
          Do 939 iElem=2,nElem
             IndxEq(iTemp(iElem)) = iTemp(1)
@@ -236,25 +225,13 @@ c      nprint(26)=99
 *
  942  Read(LuSpool,'(A)',Err=988) KWord
       If (KWord(1:1).eq.'*') Go To 942
-      If (KWord.eq.BLine)    Go To 942
+      If (KWord.eq.'')    Go To 942
       Read(KWord,*,Err=988) CutGrd
       CutGrd = Abs(CutGrd)
       Go To 998
 *                                                                      *
 ************************************************************************
 *                                                                      *
-*     Screen off memory
-*
- 951  Read(LuSpool,'(A)',Err=988) KWord
-      If (KWord(1:1).eq.'*') Go To 951
-      If (KWord.eq.BLine)    Go To 951
-      Read(KWord,*,Err=988) MemHid
-      If (MemHid.le.0) MemHid = 1
-      Go To 998
-*                                                                      *
-************************************************************************
-*                                                                      *
-*
 *     Disable the utilization of translational and
 *     rotational invariance of the energy in the
 *     computation of the molecular gradient.
@@ -280,17 +257,17 @@ c      nprint(26)=99
      &                  ' Equivalence option to work together.'
          Call Quit_OnUserError()
       End If
-      Do 961 i = 1, 3*mxdc
+      Do 961 i = 1, 3*MxAtom
          Direct(i) = .False.
  961  Continue
  962  Read(LuSpool,'(A)',Err=988) KWord
       If (KWord(1:1).eq.'*') Go To 962
-      If (KWord.eq.BLine)    Go To 962
+      If (KWord.eq.'')    Go To 962
       Read(KWord,*) nSlct
 *
  963  Read(LuSpool,'(A)',Err=988) KWord
       If (KWord(1:1).eq.'*') Go To 963
-      If (KWord.eq.BLine)    Go To 963
+      If (KWord.eq.'')    Go To 963
       Read(KWord,*) (iTemp(iElem),iElem=1,nSlct)
       Do 964 iElem=1,nSlct
          Direct(iTemp(iElem)) = .True.
@@ -412,7 +389,7 @@ c      nprint(26)=99
 *
  973  Read(LuSpool,'(A)',Err=988) KWord
       If (KWord(1:1).eq.'*') Go To 973
-      If (KWord.eq.BLine)    Go To 973
+      If (KWord.eq.'')    Go To 973
       Call UpCase(KWord)
       Call LeftAd(KWord)
       Read(KWord,'(A)') OFE_KSDFT
@@ -433,7 +410,7 @@ c      nprint(26)=99
 *
  975  Read(LuSpool,'(A)',Err=988) KWord
       If (KWord(1:1).eq.'*') Go To 975
-      If (KWord.eq.BLine)    Go To 975
+      If (KWord.eq.'')    Go To 975
       Read(KWord,*) dFMD, Xsigma
       Go To 998
 *                                                                      *
@@ -444,7 +421,7 @@ c      nprint(26)=99
 *
  976  Read(LuSpool,'(A)',Err=988) KWord
       If (KWord(1:1).eq.'*') Go To 976
-      If (KWord.eq.BLine)    Go To 976
+      If (KWord.eq.'')    Go To 976
       Read(KWord,*) iRoot
       Go To 998
 *                                                                      *
@@ -456,7 +433,7 @@ c      nprint(26)=99
  977  Read(LuSpool,'(A)',Err=988) KWord
       isNAC=.True.
       If (KWord(1:1).eq.'*') Go To 977
-      If (KWord.eq.BLine)    Go To 977
+      If (KWord.eq.'')    Go To 977
       Read(KWord,*) NACstates(1),NACstates(2)
       Go To 998
 *                                                                      *
@@ -490,18 +467,17 @@ c      nprint(26)=99
          No_Nuc=.True.
 *Get the state energies
          Call Get_iScalar('Number of roots',nRoots)
-         Call Allocate_Work(ipTmp,nRoots)
-         Call Get_dArray('Last energies',Work(ipTmp),nRoots)
-         Ediff=Work(ipTmp+NACstates(1)-1)-Work(ipTmp+NACstates(2)-1)
-         Call Free_Work(ipTmp)
+         Call mma_Allocate(Tmp,nRoots,Label='Tmp')
+         Call Get_dArray('Last energies',Tmp,nRoots)
+         Ediff=Tmp(NACstates(1))-Tmp(NACstates(2))
+         Call mma_deallocate(Tmp)
       End If
 *
       nCnttp_Valence=0
       Do iCnttp = 1, nCnttp
-         If (AuxCnttp(iCnttp)) Go To 999
+         If (dbsc(iCnttp)%Aux) Exit
          nCnttp_Valence = nCnttp_Valence+1
       End Do
- 999  Continue
 *
       If (lEq)  TRSymm=.False.
       If (Slct) TRSymm=.False.
@@ -516,16 +492,16 @@ c      nprint(26)=99
       mDisp = 0
       mdc = 0
       Do 10 iCnttp = 1, nCnttp_Valence
-         If (pChrg(iCnttp)) Then
+         If (dbsc(iCnttp)%pChrg) Then
              TRSymm=.False.
-             mdc = mdc + nCntr(iCnttp)
+             mdc = mdc + dbsc(iCnttp)%nCntr
              Go To 10
-         Else If(nFragType(iCnttp).gt.0.or.FragCnttp(iCnttp)) Then
+         Else If(dbsc(iCnttp)%nFragType.gt.0.or.dbsc(iCnttp)%Frag) Then
            TRSymm = .false.
          End If
-         Do 20 iCnt = 1, nCntr(iCnttp)
+         Do 20 iCnt = 1, dbsc(iCnttp)%nCntr
             mdc = mdc + 1
-            mDisp = mDisp + 3*(nIrrep/nStab(mdc))
+            mDisp = mDisp + 3*(nIrrep/dc(mdc)%nStab)
  20      Continue
  10   Continue
 *
@@ -559,10 +535,10 @@ c      nprint(26)=99
          Write (LuWr,*)
       End If
 *
-      Call ICopy(mxdc*8,[0],0,IndDsp,1)
-      Call ICopy(mxdc*3,[0],0,InxDsp,1)
-      call dcopy_(3*MxSym*mxdc,[One],0,Disp_Fac,1)
-      Call ICopy(3*mxdc,[1],0,mult_Disp,1)
+      Call ICopy(MxAtom*8,[0],0,IndDsp,1)
+      Call ICopy(MxAtom*3,[0],0,InxDsp,1)
+      call dcopy_(3*MxSym*MxAtom,[One],0,Disp_Fac,1)
+      Call ICopy(3*MxAtom,[1],0,mult_Disp,1)
       nDisp = 0
       Do iIrrep = 0, nIrrep-1
          lDisp(iIrrep) = 0
@@ -572,20 +548,19 @@ c      nprint(26)=99
          mc = 1
          Do iCnttp = 1, nCnttp_Valence
 *           Loop over unique centers associated with this basis set.
-            Do iCnt = 1, nCntr(iCnttp)
+            Do iCnt = 1, dbsc(iCnttp)%nCntr
                mdc = mdc + 1
                IndDsp(mdc,iIrrep) = nDisp
 *              Loop over the cartesian components
                Do iCar = 0, 2
                   iComp = 2**iCar
-                  If ( TstFnc(iOper,nIrrep,iCoSet(0,0,mdc),
-     &                nIrrep/nStab(mdc),iChTbl,iIrrep,
-     &                iComp,nStab(mdc)) .and.
-     &                .Not.pChrg(iCnttp) ) Then
+                  If ( TstFnc(dc(mdc)%iCoSet,
+     &                iIrrep,iComp,dc(mdc)%nStab) .and.
+     &                .Not.dbsc(iCnttp)%pChrg ) Then
                       nDisp = nDisp + 1
                       If (iIrrep.eq.0) InxDsp(mdc,iCar+1) = nDisp
                       lDisp(iIrrep) = lDisp(iIrrep) + 1
-                      mult_Disp(nDisp)=nIrrep/nStab(mdc)
+                      mult_Disp(nDisp)=nIrrep/dc(mdc)%nStab
                       If (Type) Then
       If (Show.and.iPrint.ge.6) then
                          Write (LuWr,*)
@@ -610,19 +585,18 @@ c      nprint(26)=99
                       End If
       If (Show.and.iPrint.ge.6) Then
                       Write (LuWr,'(I4,3X,A8,5X,A1,7X,8(I3,4X,I2,4X))')
-     &                      nDisp,LblCnt(mdc),xyz(iCar),
-     &                      (mc+iCo,iPrmt(NrOpr(iCoSet(iCo,0,mdc),
-     &                      iOper,nIrrep),iComp)*
-     &                      iChTbl(iIrrep,NrOpr(iCoSet(iCo,0,mdc),
-     &                      iOper,nIrrep)),
-     &                      iCo=0,nIrrep/nStab(mdc)-1 )
+     &                      nDisp,dc(mdc)%LblCnt,xyz(iCar),
+     &                      (mc+iCo,iPrmt(
+     &                      NrOpr(dc(mdc)%iCoSet(iCo,0)),iComp)*
+     &                      iChTbl(iIrrep,NrOpr(dc(mdc)%iCoSet(iCo,0))),
+     &                      iCo=0,nIrrep/dc(mdc)%nStab-1 )
       End If
       Write (ChDisp(nDisp),'(A,1X,A1)')
-     &      LblCnt(mdc),xyz(iCar)
+     &      dc(mdc)%LblCnt,xyz(iCar)
                   End If
 *
                End Do
-               mc = mc + nIrrep/nStab(mdc)
+               mc = mc + nIrrep/dc(mdc)%nStab
             End Do
          End Do
 *
@@ -672,13 +646,13 @@ c      nprint(26)=99
             Go To 9876
          End If
          If (iPrint.ge.99) Write (LuWr,*) ' nTR=',nTR
-         Call GetMem('Amtrx','Allo','Real',ipAm,lDisp(0)**2)
-         Call GetMem('Temp ','Allo','Real',ipTmp,nTR**2)
-         Call GetMem('Coor ','Allo','Real',ipC,lDisp(0)*4)
-         Call GetMem('Car  ','Allo','Inte',ipCar,lDisp(0))
+         Call mma_allocate(Am,nTR,lDisp(0),Label='Am')
+         Call mma_allocate(Temp,nTR,nTR,Label='Temp')
+         Call mma_allocate(C,4,lDisp(0),Label='C')
+         Call mma_allocate(IndCar,lDisp(0),Label='IndCar')
 *
-         call dcopy_(nTR*lDisp(0),[Zero],0,Work(ipAm),1)
-         call dcopy_(4*lDisp(0),[Zero],0,Work(ipC),1)
+         Am(:,:)=Zero
+         C(:,:)=Zero
 *
 *        Generate temporary information of the symmetrical
 *        displacements.
@@ -687,43 +661,43 @@ c      nprint(26)=99
          mdc = 0
          iIrrep = 0
          Do 2100 iCnttp = 1, nCnttp_Valence
-            jxyz = ipCntr(iCnttp)
-            Do 2200 iCnt = 1, nCntr(iCnttp)
+            Do 2200 iCnt = 1, dbsc(iCnttp)%nCntr
                mdc = mdc + 1
-*              Call RecPrt(' Coordinates',' ',Work(jxyz),1,3)
+*              Call RecPrt(' Coordinates',' ',
+*    &                     dbsc(iCnttp)%Coor(1,iCnt),1,3)
                Fact = Zero
                iComp = 0
-               If (Work(jxyz  ).ne.Zero) iComp = iOr(iComp,1)
-               If (Work(jxyz+1).ne.Zero) iComp = iOr(iComp,2)
-               If (Work(jxyz+2).ne.Zero) iComp = iOr(iComp,4)
+               If (dbsc(iCnttp)%Coor(1,iCnt).ne.Zero)
+     &             iComp = iOr(iComp,1)
+               If (dbsc(iCnttp)%Coor(2,iCnt).ne.Zero)
+     &             iComp = iOr(iComp,2)
+               If (dbsc(iCnttp)%Coor(3,iCnt).ne.Zero)
+     &             iComp = iOr(iComp,4)
                Do jIrrep = 0, nIrrep-1
-                  If ( TstFnc(iOper,nIrrep,iCoSet(0,0,mdc),
-     &                  nIrrep/nStab(mdc),iChTbl,jIrrep,
-     &                  iComp,nStab(mdc)) ) Then
+                  If ( TstFnc(dc(mdc)%iCoSet,
+     &                  jIrrep,iComp,dc(mdc)%nStab) ) Then
                      Fact = Fact + One
                   End If
                End Do
-               Do iCar = 0, 2
-                  iComp = 2**iCar
-                  If ( TstFnc(iOper,nIrrep,iCoSet(0,0,mdc),
-     &                  nIrrep/nStab(mdc),iChTbl,iIrrep,
-     &                  iComp,nStab(mdc)) ) Then
+               Do iCar = 1, 3
+                  iComp = 2**(iCar-1)
+                  If ( TstFnc(dc(mdc)%iCoSet,
+     &                  iIrrep,iComp,dc(mdc)%nStab) ) Then
                      ldsp = ldsp + 1
                      Direct(lDsp)=.True.
 *--------------------Transfer the coordinates
-                     ip = 4*(ldsp-1) + ipC
-                     call dcopy_(3,Work(jxyz),1,Work(ip),1)
+                     call dcopy_(3,dbsc(iCnttp)%Coor(1:3,iCnt),1,
+     &                           C(1,ldsp),1)
 *--------------------Transfer the multiplicity factor
-                     Work(ip+3) = Fact
-                     iWork(ipCar-1+ldsp) = iCar + 1
+                     C(4,ldsp)= Fact
+                     IndCar(ldsp) = iCar
                   End If
                 End Do
-               jxyz = jxyz + 3
  2200       Continue
  2100    Continue
          If (iPrint.ge.99) Then
-            Call RecPrt(' Information',' ',Work(ipC),4,lDisp(0))
-            Write (LuWr,*) (iWork(i),i=ipCar,ipCar+lDisp(0)-1)
+            Call RecPrt(' Information',' ',C,4,lDisp(0))
+            Write (LuWr,*) (IndCar(i),i=1,lDisp(0))
          End If
 *
 *--------Set up coefficient for the translational equations
@@ -733,10 +707,8 @@ c      nprint(26)=99
             If (iSym(i).eq.0) Then
                iTR = iTR + 1
                Do ldsp = 1, lDisp(0)
-                  If (iWork(ipCar+ldsp-1).eq.i) Then
-                     ipOut= ipC + 4*(ldsp-1) + 3
-                     ipIn = nTR*(ldsp-1) + iTR + ipAm - 1
-                     Work(ipIn) = Work(ipOut)
+                  If (IndCar(ldsp).eq.i) Then
+                     Am(iTR,ldsp) = C(4,ldsp)
                   End If
                End Do
             End If
@@ -754,21 +726,19 @@ c      nprint(26)=99
                If (ijSym.ne.0) Go To 1210
                iTR = iTR + 1
                Do ldsp = 1, lDisp(0)
-                  ipIn = nTR*(ldsp-1) + iTR + ipAm - 1
-                  ipOut = ipC + 4*(ldsp-1)
-                  If (iWork(ipCar+ldsp-1).eq.j) Then
-                     Fact = Work(ipOut+3) * Work(ipOut+k-1)
-                     Work(ipIn) = Fact
-                  Else If (iWork(ipCar+ldsp-1).eq.k) Then
-                     Fact = Work(ipOut+3) * Work(ipOut+j-1)
-                     Work(ipIn) = -Fact
+                  If (IndCar(ldsp).eq.j) Then
+                     Fact = C(4,ldsp) * C(k,ldsp)
+                     Am(iTR,ldsp) = Fact
+                  Else If (IndCar(ldsp).eq.k) Then
+                     Fact =-C(4,ldsp) * C(j,ldsp)
+                     Am(iTR,ldsp) = Fact
                   End If
                End Do
  1210          Continue
             End Do
          End If
          If (iPrint.ge.99)
-     &      Call RecPrt(' The A matrix',' ',Work(ipAm),nTR,lDisp(0))
+     &      Call RecPrt(' The A matrix',' ',Am,nTR,lDisp(0))
 *
 *--------Now, transfer the coefficient of those gradients which will
 *        not be computed directly.
@@ -786,19 +756,16 @@ c      nprint(26)=99
                   If (iTemp(jTR).eq.ldsp) Go To 1231
                End Do
 *              Write (LuWr,*) ' Checking vector #', ldsp
-               ipNew = ipAm + nTR*(ldsp-1)
-               ipIn = ipTmp + nTR*(iTR-1)
-               call dcopy_(nTR,Work(ipNew),1,Work(ipIn),1)
-*              Call RecPrt(' Vector',' ',Work(ipIn),nTR,1)
+               call dcopy_(nTR,Am(1,ldsp),1,Temp(1,iTR),1)
+*              Call RecPrt(' Vector',' ',Temp(1,iTR),nTR,1)
 *--------------Gram-Schmidt orthonormalize against accepted vectors
                Do lTR = 1, iTR-1
-                  ipOld = ipTmp + nTR*(lTR-1)
-                  alpha = DDot_(nTR,Work(ipIn),1,Work(ipOld),1)
+                  alpha = DDot_(nTR,Temp(1,iTR),1,Temp(1,lTR),1)
 *                 Write (LuWr,*) ' <x|y> =', alpha
-                  Call DaXpY_(nTR,-alpha,Work(ipOld),1,Work(ipIn),1)
+                  Call DaXpY_(nTR,-alpha,Temp(1,lTR),1,Temp(1,iTR),1)
                End Do
-*              Call RecPrt(' Remainings',' ',Work(ipIn),nTR,1)
-               alpha = DDot_(nTR,Work(ipIn),1,Work(ipIn),1)
+*              Call RecPrt(' Remainings',' ',Temp(1,iTR),nTR,1)
+               alpha = DDot_(nTR,Temp(1,iTR),1,Temp(1,iTR),1)
 *              Write (LuWr,*) ' Remaining overlap =', alpha
 *--------------Check the remaining magnitude of vector after Gram-Schmidt
                If (alpha.gt.ovlp) Then
@@ -817,64 +784,59 @@ c      nprint(26)=99
             End If
 *           Write (LuWr,*) ' Selecting vector #', kTR
 *-----------Pick up the "best" vector
-            ipNew = ipAm + nTR*(kTR-1)
-            ipIn = ipTmp + nTR*(iTR-1)
-            call dcopy_(nTR,Work(ipNew),1,Work(ipIn),1)
+            call dcopy_(nTR,Am(1,kTR),1,Temp(1,iTR),1)
             Do lTR = 1, iTR-1
-               ipOld = ipTmp + nTR*(lTR-1)
-               alpha = DDot_(nTR,Work(ipIn),1,Work(ipOld),1)
-               Call DaXpY_(nTR,-alpha,Work(ipOld),1,Work(ipIn),1)
+               alpha = DDot_(nTR,Temp(1,iTR),1,Temp(1,lTR),1)
+               Call DaXpY_(nTR,-alpha,Temp(1,lTR),1,Temp(1,iTR),1)
             End Do
-            alpha = DDot_(nTR,Work(ipIn),1,Work(ipIn),1)
-            Call DScal_(nTR,One/Sqrt(alpha),Work(ipIn),1)
+            alpha = DDot_(nTR,Temp(1,iTR),1,Temp(1,iTR),1)
+            Call DScal_(nTR,One/Sqrt(alpha),Temp(1,iTR),1)
             iTemp(iTR) = kTR
          End Do
          Do iTR = 1, nTR
-            ipNew = ipAm + nTR*(iTemp(iTR)-1)
-            ipIn  = ipTmp + nTR*(iTR-1)
-            call dcopy_(nTR,Work(ipNew),1,Work(ipIn),1)
-            call dcopy_(nTR,[Zero],0,Work(ipNew),1)
+            call dcopy_(nTR,Am(1,iTemp(iTR)),1,Temp(1,iTR),1)
+            Am(:,iTemp(iTR))=Zero
          End Do
          If (iPrint.ge.99) Then
-            Call RecPrt(' The A matrix',' ',Work(ipAm),nTR,lDisp(0))
-            Call RecPrt(' The T matrix',' ',Work(ipTmp),nTR,nTR)
+            Call RecPrt(' The A matrix',' ',Am,nTR,lDisp(0))
+            Call RecPrt(' The T matrix',' ',Temp,nTR,nTR)
             Write (LuWr,*) (iTemp(iTR),iTR=1,nTR)
          End If
 *
 *        Compute the inverse of the T matrix
 *
-         Call MatInvert(Work(ipTmp),nTR)
+         Call MatInvert(Temp,nTR)
          If (IPrint.ge.99)
-     &      Call RecPrt(' The T-1 matrix',' ',Work(ipTmp),nTR,nTR)
-         Call DScal_(nTR**2,-One,Work(ipTmp),1)
+     &      Call RecPrt(' The T-1 matrix',' ',Temp,nTR,nTR)
+         Call DScal_(nTR**2,-One,Temp,1)
 *
 *        Generate the complete matrix
 *
-         Call GetMem(' Temp2','Allo','Real',ipScr,nTR*lDisp(0))
+         Call mma_allocate(Scr,nTR,lDisp(0),Label='Scr')
          Call DGEMM_('N','N',
      &               nTR,lDisp(0),nTR,
-     &               1.0d0,Work(ipTmp),nTR,
-     &               Work(ipAm),nTR,
-     &               0.0d0,Work(ipScr),nTR)
-         If (IPrint.ge.99)
-     &      Call RecPrt(' A-1*A',' ',Work(ipScr),nTR,lDisp(0))
-         call dcopy_(lDisp(0)**2,[Zero],0,Work(ipAm),1)
-         call dcopy_(lDisp(0),[One],0,Work(ipAm),lDisp(0)+1)
+     &               1.0d0,Temp,nTR,
+     &               Am,nTR,
+     &               0.0d0,Scr,nTR)
+         If (IPrint.ge.99) Call RecPrt(' A-1*A',' ',Scr,nTR,lDisp(0))
+         Call mma_deallocate(Am)
+         Call mma_allocate(Am,lDisp(0),lDisp(0),Label='Am')
+         Am(:,:)=Zero
+         Do i = 1, lDisp(0)
+            Am(i,i)=One
+         End Do
          Do 1250 iTR = 1, nTR
             ldsp = iTemp(iTR)
-            ipOut = ipScr + iTR - 1
-            ipIn  = ipAM  + ldsp - 1
-            call dcopy_(lDisp(0),Work(ipOut),nTR,Work(ipIn),lDisp(0))
+            call dcopy_(lDisp(0),Scr(1,iTR),nTR,Am(1,lDisp),lDisp(0))
  1250    Continue
          If (iPrint.ge.99)
-     &      Call RecPrt('Final A matrix',' ',
-     &                  Work(ipAm),lDisp(0),lDisp(0))
+     &      Call RecPrt('Final A matrix',' ',Am,lDisp(0),lDisp(0))
 *
 *
-         Call GetMem(' Temp2','Free','Real',ipScr,nTR*lDisp(0))
-         Call GetMem('Car  ','Free','Inte',ipCar,lDisp(0))
-         Call GetMem('Coor ','Free','Real',ipC,lDisp(0)*4)
-         Call GetMem('Temp ','Free','Real',ipTmp,nTR**2)
+         Call mma_deallocate(Scr)
+         Call mma_deallocate(IndCar)
+         Call mma_deallocate(C)
+         Call mma_deallocate(Temp)
          Do 1501 iTR = 1, nTR
             ldsp = iTemp(iTR)
             Direct(ldsp)=.False.
@@ -938,6 +900,5 @@ c      nprint(26)=99
 *
       Onenly = HF_Force
 *
-*     Call qExit('Inputg')
       Return
       End
