@@ -20,13 +20,6 @@
 *         matrix and the latter will be contracted with the generalized*
 *         Fock matrix.                                                 *
 *                                                                      *
-* Called from: Alaska                                                  *
-*                                                                      *
-* Calling    : QEnter                                                  *
-*              GetMem                                                  *
-*              OneEl                                                   *
-*              QExit                                                   *
-*                                                                      *
 *     Author: Roland Lindh, Dept. of Theoretical Chemistry,            *
 *             University of Lund, SWEDEN                               *
 *             October '91                                              *
@@ -38,16 +31,19 @@
 *             gradients, April '95. R. Lindh                           *
 *             Modified to Self Consistent Reaction Fields, May '95     *
 ************************************************************************
+      use PCM_arrays, only: PCM_SQ
+      use External_Centers
+      use Basis_Info, only: nCnttp, dbsc, nBas
+      use Symmetry_Info, only: nIrrep
       Implicit Real*8 (A-H,O-Z)
       External OvrGrd, KneGrd, NAGrd, PrjGrd, M1Grd, M2Grd, SROGrd,
      &         WelGrd, XFdGrd, RFGrd, PCMGrd, PPGrd, COSGrd, FragPGrd
       External OvrMmG, KneMmG, NAMmG, PrjMmG, M1MmG, M2MmG, SROMmG,
      &         WelMmg, XFdMmg, RFMmg, PCMMmg, PPMmG, FragPMmG
-#include "itmax.fh"
-#include "info.fh"
+#include "Molcas.fh"
 #include "print.fh"
 #include "real.fh"
-#include "WrkSpc.fh"
+#include "stdalloc.fh"
 #include "disp.fh"
 #include "wldata.fh"
 #include "rctfld.fh"
@@ -58,8 +54,10 @@
       common /finfld/force
       character*30 fldname
       External MltGrd,MltMmG
+      Real*8, Allocatable:: Coor(:,:), Fock(:), D_Var(:)
+      Integer, Allocatable:: lOper(:), lOperf(:)
 CAOM>
-      Logical DiffOp
+      Logical DiffOp, lECP, lPP, lFAIEMP
 *
 *-----Statement function
 *
@@ -69,7 +67,6 @@ CAOM>
       iRout = 131
       iPrint = nPrint(iRout)
       Call CWTime(TCpu1,TWall1)
-      Call qEnter('Drvh1')
       Call StatusLine(' Alaska:',' Computing 1-electron gradients')
 *
 *---- Allocate memory for density and Fock matrices
@@ -80,6 +77,14 @@ CAOM>
          nFock = nFock + nBas(iIrrep)*(nBas(iIrrep)+1)/2
          nDens = nDens + nBas(iIrrep)*(nBas(iIrrep)+1)/2
       End Do
+      lECP=.False.
+      lPP =.False.
+      lFAIEMP =.False.
+      Do i = 1, nCnttp
+         lECP = lECP .or. dbsc(i)%ECP
+         lPP  = lPP  .or. dbsc(i)%nPP.ne.0
+         lFAIEMP = LFAIEMP .or. dbsc(i)%Frag
+      End Do
 *
 *
 *...  Get the method label
@@ -90,19 +95,14 @@ CAOM>
 *...  density matrix in AO/SO basis
 *     print *,' Read density matrix'
 
-      Call Get_D1ao_Var(ipD_var,Length)
-      If ( length.ne.nDens ) Then
-         Call WarningMessage(2,'Error in Drvh1')
-         Write (6,*) 'Drvh1: length.ne.nDens'
-         Write (6,*) 'length,nDens=',length,nDens
-         Call Abend()
-      End If
+      Call mma_allocate(D_Var,nDens,Label='D_Var')
+      Call Get_D1ao_Var(D_Var,nDens)
       If (iPrint.ge.99) then
          Write(6,*) 'variational 1st order density matrix'
-         ii=ipD_Var
+         ii=1
          Do iIrrep = 0, nIrrep - 1
             Write(Label,*) 'symmetry block',iIrrep
-            Call TriPrt(Label,' ',Work(ii),nBas(iIrrep))
+            Call TriPrt(Label,' ',D_Var(ii),nBas(iIrrep))
             ii = ii + nBas(iIrrep)*(nBas(iIrrep)+1)/2
          End Do
       End If
@@ -111,20 +111,14 @@ CAOM>
 *...  Fock matrix in AO/SO basis
 *     print *,' Read Fock matrix'
       If (.Not.HF_Force) Then
-         Call Get_Fock_Occ(ipFock,Length)
-         If ( length.ne.nDens ) Then
-            Call WarningMessage(2,'Error in Drvh1')
-            Write (6,*) 'Drvh1: length.ne.nDens'
-            Write (6,*) 'length,nDens=',length,nDens
-            Call Abend()
-         End If
-!         iprint=100
+         Call mma_allocate(Fock,nDens,Label='Fock')
+         Call Get_Fock_Occ(Fock,nDens)
          If (iPrint.ge.99) then
             Write(6,*) 'generalized Fock matrix'
-            ii=ipFock
+            ii=1
             Do iIrrep = 0, nIrrep - 1
                Write(Label,*) 'symmetry block',iIrrep
-               Call TriPrt(Label,' ',Work(ii),nBas(iIrrep))
+               Call TriPrt(Label,' ',Fock(ii),nBas(iIrrep))
                ii = ii + nBas(iIrrep)*(nBas(iIrrep)+1)/2
             End Do
          End If
@@ -133,14 +127,14 @@ CAOM>
 ************************************************************************
 *                                                                      *
 *     nOrdOp: order/rank of the operator
-*     Work(ip1): lOper of each component of the operator
+*     lOper: lOper of each component of the operator
 *
       nOrdOp=0
       nComp = nElem(nOrdOp)
-      Call GetMem('Coor','Allo','Real',ipC,3*nComp)
-      Call GetMem('lOper','Allo','Inte',ip1,nComp)
-      call dcopy_(nComp*3,[Zero],0,Work(ipC),1)
-      iWork(ip1) = 1
+      Call mma_allocate(Coor,3,nComp,Label='Coor')
+      Call mma_allocate(lOper,nComp,Label='lOper')
+      Coor(:,:)=Zero
+      lOper(1)=1
       If (HF_Force) Go To 1003
 ************************************************************************
 *1)                                                                    *
@@ -151,8 +145,8 @@ CAOM>
 *
       DiffOp = .False.
       Label  = ' The Renormalization Contribution'
-      Call OneEl_g(OvrGrd,OvrMmG,Temp,nGrad,DiffOp,Work(ipC),
-     &           Work(ipFock),nFock,iWork(ip1),nComp,nOrdOp,Label)
+      Call OneEl_g(OvrGrd,OvrMmG,Temp,nGrad,DiffOp,Coor,
+     &             Fock,nFock,lOper,nComp,nOrdOp,Label)
       Call DaXpY_(nGrad,-One,Temp,1,Grad,1)
 *
 ************************************************************************
@@ -164,8 +158,8 @@ CAOM>
 *
       DiffOp = .False.
       Label  = ' The Kinetic Energy Contribution'
-      Call OneEl_g(KneGrd,KneMmG,Temp,nGrad,DiffOp,Work(ipC),
-     &           Work(ipD_Var),nDens,iWork(ip1),nComp,nOrdOp,Label)
+      Call OneEl_g(KneGrd,KneMmG,Temp,nGrad,DiffOp,Coor,
+     &             D_Var,nDens,lOper,nComp,nOrdOp,Label)
       Call DaXpY_(nGrad,One,Temp,1,Grad,1)
 CAOM<
 C... Check finite field operators...
@@ -186,16 +180,14 @@ C... Check finite field operators...
            Write(6,*) 'Wrong number of components in FF grad'
            Call Quit_OnUserError()
         endif
-        Call GetMem('lOperf','Allo','Inte',ip1f,nCompf)
-        do ii=1,ncompf
-          iwork(ip1f+ii-1)=1
-        enddo
+        Call mma_allocate(lOperf,nCompf,Label='lOperf')
+        lOperf(:)=1
         DiffOp=.False.
         if(nOrdOpf.gt.0) DiffOp=.True.
-        Call OneEl_g(MltGrd,MltMmG,Temp,nGrad,DiffOp,Work(ipC),
-     &           Work(ipD_Var),nDens,iWork(ip1f),nCompf,nOrdOpf,Label)
+        Call OneEl_g(MltGrd,MltMmG,Temp,nGrad,DiffOp,Coor,
+     &               D_Var,nDens,lOperf,nCompf,nOrdOpf,Label)
         Call MltGrdNuc(Temp,nGrad,nOrdOpf)
-        Call GetMem('lOperf','Free','Inte',ip1f,nCompf)
+        Call mma_deallocate(lOperf)
         Call DaXpY_(nGrad,-One,Temp,1,Grad,1)
         goto 1100
       endif
@@ -211,11 +203,11 @@ CAOM>
  1003 Continue
       DiffOp = .True.
       Label = ' The Nuclear Attraction Contribution'
-      Call OneEl_g(NAGrd,NAMmG,Temp,nGrad,DiffOp,Work(ipC),
-     &           Work(ipD_Var),nDens,iWork(ip1),nComp,nOrdOp,Label)
+      Call OneEl_g(NAGrd,NAMmG,Temp,nGrad,DiffOp,Coor,
+     &             D_Var,nDens,lOper,nComp,nOrdOp,Label)
       Call DaXpY_(nGrad,One,Temp,1,Grad,1)
       If (HF_Force) Then
-         If (lECP.or.nWel.ne.0.or.lXF.or.lRF) Then
+         If (lECP.or.nWel.ne.0.or.Allocated(XF).or.lRF) Then
             Call WarningMessage(2,'Error in Drvh1')
             Write (6,*) 'HF forces not implemented yet for this case!'
             Call Quit_OnUserError()
@@ -233,29 +225,29 @@ CAOM>
       If (lECP) Then
          DiffOp = .True.
          Label = ' The Projection Operator Contribution'
-         Call OneEl_g(PrjGrd,PrjMmG,Temp,nGrad,DiffOp,Work(ipC),
-     &              Work(ipD_Var),nDens,iWork(ip1),nComp,nOrdOp,Label)
+         Call OneEl_g(PrjGrd,PrjMmG,Temp,nGrad,DiffOp,Coor,
+     &                D_Var,nDens,lOper,nComp,nOrdOp,Label)
          Call DaXpY_(nGrad,One,Temp,1,Grad,1)
 *
          Label = ' The M1 Operator Contribution'
-         Call OneEl_g( M1Grd, M1MmG,Temp,nGrad,DiffOp,Work(ipC),
-     &              Work(ipD_Var),nDens,iWork(ip1),nComp,nOrdOp,Label)
+         Call OneEl_g( M1Grd, M1MmG,Temp,nGrad,DiffOp,Coor,
+     &                D_Var,nDens,lOper,nComp,nOrdOp,Label)
          Call DaXpY_(nGrad,One,Temp,1,Grad,1)
 *
          Label = ' The M2 Operator Contribution'
-         Call OneEl_g( M2Grd, M2MmG,Temp,nGrad,DiffOp,Work(ipC),
-     &              Work(ipD_Var),nDens,iWork(ip1),nComp,nOrdOp,Label)
+         Call OneEl_g( M2Grd, M2MmG,Temp,nGrad,DiffOp,Coor,
+     &                D_Var,nDens,lOper,nComp,nOrdOp,Label)
          Call DaXpY_(nGrad,One,Temp,1,Grad,1)
 *
          Label = ' The SR Operator Contribution'
-         Call OneEl_g(SROGrd,SROMmG,Temp,nGrad,DiffOp,Work(ipC),
-     &              Work(ipD_Var),nDens,iWork(ip1),nComp,nOrdOp,Label)
+         Call OneEl_g(SROGrd,SROMmG,Temp,nGrad,DiffOp,Coor,
+     &              D_Var,nDens,lOper,nComp,nOrdOp,Label)
          Call DaXpY_(nGrad,One,Temp,1,Grad,1)
       End If
       If (lPP) Then
          Label = ' The Pseudo Potential Contribution'
-         Call OneEl_g(PPGrd,PPMmG,Temp,nGrad,DiffOp,Work(ipC),
-     &              Work(ipD_Var),nDens,iWork(ip1),nComp,nOrdOp,Label)
+         Call OneEl_g(PPGrd,PPMmG,Temp,nGrad,DiffOp,Coor,
+     &              D_Var,nDens,lOper,nComp,nOrdOp,Label)
          Call DaXpY_(nGrad,One,Temp,1,Grad,1)
       End If
 *
@@ -266,13 +258,13 @@ CAOM>
 *                                                                      *
 ************************************************************************
       DiffOp = .True.
-      Do iWel = 0, nWel-1
-         r0   = Work(ipWel+iWel*3  )
-         ExpB = Work(ipWel+iWel*3+1)
+      Do iWel = 1, nWel
+         r0   = Wel_Info(1,iWel)
+         ExpB = Wel_Info(2,iWel)
          Label = ' The Spherical Well Contribution'
-         Call OneEl_g(WelGrd,WelMmG,Temp,nGrad,DiffOp,Work(ipC),
-     &              Work(ipD_Var),nDens,iWork(ip1),nComp,nOrdOp,Label)
-         Fact = Work(ipWel+iWel*3+2)
+         Call OneEl_g(WelGrd,WelMmG,Temp,nGrad,DiffOp,Coor,
+     &              D_Var,nDens,lOper,nComp,nOrdOp,Label)
+         Fact = Wel_Info(3,iWel)
          Call DaXpY_(nGrad,Fact,Temp,1,Grad,1)
       End Do
 ************************************************************************
@@ -281,11 +273,11 @@ CAOM>
 *     gradient of the external field integrals.                        *
 *                                                                      *
 ************************************************************************
-      If (lXF) Then
+      If (Allocated(XF)) Then
          DiffOp = .True.
          Label = ' The External Field Contribution'
-         Call OneEl_g(XFdGrd,XFdMmG,Temp,nGrad,DiffOp,Work(ipC),
-     &              Work(ipD_Var),nDens,iWork(ip1),nComp,nOrdOp,Label)
+         Call OneEl_g(XFdGrd,XFdMmG,Temp,nGrad,DiffOp,Coor,
+     &              D_Var,nDens,lOper,nComp,nOrdOp,Label)
          Call DaXpY_(nGrad,One,Temp,1,Grad,1)
       End If
 *
@@ -297,18 +289,18 @@ CAOM>
 ************************************************************************
 *
       If (lRF.and..Not.lLangevin.and..Not.PCM) Then
-         Call GetMem('lOper','Free','Inte',ip1,nComp)
-         Call GetMem('Coor','Free','Real',ipC,3*nComp)
+         Call mma_deallocate(lOper)
+         Call mma_deallocate(Coor)
 *
 *------- The Kirkwood model
 *
          nOrdOp=lMax
          nComp=(lMax+1)*(lMax+2)*(lMax+3)/6
-         Call GetMem('lOper','Allo','Inte',ip1,nComp)
+         Call mma_allocate(lOper,nComp,Label='lOper')
 *
 *------- Store permutation symmetry of components of the EF
 *
-         iComp = 0
+         iComp = 1
          Do iMltpl = 0, lMax
             Do ix = iMltpl, 0, -1
                If (Mod(ix,2).eq.0) Then
@@ -331,20 +323,19 @@ CAOM>
                      ixyz=4
                      iSymZ=2**IrrFnc(ixyz)
                   End If
-*                 iWork(ip1+iComp) = MltLbl(iSymX,MltLbl(iSymY,iSymZ,
-*    &                                      nIrrep),nIrrep)
+*                 lOper(iComp) = MltLbl(iSymX,MltLbl(iSymY,iSymZ))
 *-----------------Compute only total symmetric contributions
-                  iWork(ip1+iComp) = 1
+                  lOper(iComp) = 1
                   iComp = iComp + 1
                End Do
             End Do
          End Do
-         Call GetMem('Coor','Allo','Real',ipC,3*nComp)
-         call dcopy_(nComp*3,[Zero],0,Work(ipC),1)
+         Call mma_allocate(Coor,3,nComp,Label='Coor')
+         Coor(:,:)=Zero
          DiffOp = .True.
          Label = ' The Electronic Reaction Field Contribution'
-         Call OneEl_g(RFGrd,RFMmG,Temp,nGrad,DiffOp,Work(ipC),
-     &              Work(ipD_Var),nDens,iWork(ip1),nComp,nOrdOp,Label)
+         Call OneEl_g(RFGrd,RFMmG,Temp,nGrad,DiffOp,Coor,
+     &              D_Var,nDens,lOper,nComp,nOrdOp,Label)
          Call DaXpY_(nGrad,One,Temp,1,Grad,1)
 *
       Else If (lRF.and.PCM) Then
@@ -353,34 +344,33 @@ CAOM>
 *
          If (iCOSMO.le.0) Then
             iPrint=15
-            Call DScal_(nTs*2,One/DBLE(nIrrep),Work(ip_Q),1)
+            Call DScal_(nTs*2,One/DBLE(nIrrep),PCM_SQ,1)
          End If
-*        iWork(ip1) = 255
-         iWork(ip1) = 1
+         lOper(1) = 1
          DiffOp = .True.
          If (iCOSMO.gt.0) Then
             Call dzero(Temp,ngrad)
             Label= ' The Electronic Reaction Field Contribution (COSMO)'
-            Call OneEl_g(COSGrd,PCMMmG,Temp,nGrad,DiffOp,Work(ipC),
-     &                   Work(ipD_Var),nDens,iWork(ip1),nComp,nOrdOp,
+            Call OneEl_g(COSGrd,PCMMmG,Temp,nGrad,DiffOp,Coor,
+     &                   D_Var,nDens,lOper,nComp,nOrdOp,
      &                   Label)
             If (iPrint.ge.15) Then
                Label=' Reaction Field (COSMO) Contribution'
-               Call PrGrad(Label,Temp,nGrad,lIrrep,ChDisp,5)
+               Call PrGrad(Label,Temp,nGrad,ChDisp,5)
             End If
          Else
             Label = ' The Electronic Reaction Field Contribution (PCM)'
-            Call OneEl_g(PCMGrd,PCMMmG,Temp,nGrad,DiffOp,Work(ipC),
-     &                   Work(ipD_Var),nDens,iWork(ip1),nComp,nOrdOp,
+            Call OneEl_g(PCMGrd,PCMMmG,Temp,nGrad,DiffOp,Coor,
+     &                   D_Var,nDens,lOper,nComp,nOrdOp,
      &                   Label)
             If (iPrint.ge.15) Then
                Label=' Reaction Field (PCM) Contribution'
-               Call PrGrad(Label,Temp,nGrad,lIrrep,ChDisp,5)
+               Call PrGrad(Label,Temp,nGrad,ChDisp,5)
             End If
          End If
 
          Call DaXpY_(nGrad,One,Temp,1,Grad,1)
-         If (iCOSMO.eq.0) Call DScal_(nTs*2,DBLE(nIrrep),Work(ip_Q),1)
+         If (iCOSMO.eq.0) Call DScal_(nTs*2,DBLE(nIrrep),PCM_SQ,1)
 *
       End If
 *
@@ -394,27 +384,26 @@ CAOM>
       If(lFAIEMP) Then
         DiffOp = .True.
         Label = ' The FAIEMP Projection Operator Contribution'
-        Call OneEl_g(FragPGrd,FragPMmG,Temp,nGrad,DiffOp,Work(ipC),
-     &               Work(ipD_Var),nDens,iWork(ip1),nComp,nOrdOp,Label)
+        Call OneEl_g(FragPGrd,FragPMmG,Temp,nGrad,DiffOp,Coor,
+     &               D_Var,nDens,lOper,nComp,nOrdOp,Label)
         Call DaXpY_(nGrad,One,Temp,1,Grad,1)
         Call DrvG_FAIEMP(Grad,Temp,nGrad)
       End If
 *                                                                      *
 ************************************************************************
 *                                                                      *
-      Call GetMem('lOper','Free','Inte',ip1,nComp)
-      Call GetMem('Coor','Free','Real',ipC,3*nComp)
+      Call mma_deallocate(lOper)
+      Call mma_deallocate(Coor)
 *                                                                      *
 ************************************************************************
 1099  Continue
 *                                                                      *
 *...  Epilogue, end
 *
-      If (.Not.HF_Force) Call GetMem('Fock','Free','Real',ipFock,nFock)
-      Call GetMem('D0  ','Free','Real',ipD_Var,nDens)
+      If (.Not.HF_Force) Call mma_deallocate(Fock)
+      Call mma_deallocate(D_Var)
 *
       Call CWTime(TCpu2,TWall2)
       Call SavTim(3,TCpu2-TCpu1,TWall2-TWall1)
-      Call qExit('Drvh1')
       Return
       End
