@@ -10,26 +10,29 @@
 ************************************************************************
       Subroutine read_formatted_aniso( input_file_name, nss, nstate,
      &                                multiplicity, eso, esfs,
-     &                                U, MM, MS, ML, DM, ANGMOM, EDMOM )
+     &                                U, MM, MS, ML, DM, ANGMOM, EDMOM,
+     &                                AMFI, HSO )
       Implicit None
 #include "stdalloc.fh"
       Integer, Parameter            :: wp=selected_real_kind(p=15,r=307)
       Integer, intent(inout)        :: nss, nstate
       Integer, intent(out)          :: multiplicity(nstate)
-      Real(kind=wp), intent(out)    :: eso(nss), esfs(nstate)
-      Real(kind=wp), intent(out)    ::  edmom(3,nstate,nstate)
-      Real(kind=wp), intent(out)    :: angmom(3,nstate,nstate)
-      Complex(kind=wp), intent(out) :: MM(3,nss,nss)
-      Complex(kind=wp), intent(out) :: MS(3,nss,nss)
-      Complex(kind=wp), intent(out) :: ML(3,nss,nss)
+      Real(kind=8), intent(out)    :: eso(nss), esfs(nstate)
+      Real(kind=8), intent(out)    ::  edmom(3,nstate,nstate)
+      Real(kind=8), intent(out)    :: angmom(3,nstate,nstate)
+      Real(kind=8), intent(out)    ::   amfi(3,nstate,nstate)
+      Complex(kind=8), intent(out) :: MM(3,nss,nss)
+      Complex(kind=8), intent(out) :: MS(3,nss,nss)
+      Complex(kind=8), intent(out) :: ML(3,nss,nss)
 !     electric dipole moment
-      Complex(kind=wp), intent(out) :: DM(3,nss,nss)
-      Complex(kind=wp), intent(out) :: U(nss,nss)
-      Character(180)                :: input_file_name
+      Complex(kind=8), intent(out) :: DM(3,nss,nss)
+      Complex(kind=8), intent(out) ::   U(nss,nss)
+      Complex(kind=8), intent(out) :: HSO(nss,nss)
+      Character(Len=180)            :: input_file_name
       ! local variables:
       Integer       :: l,j,j1,j2,LuAniso,IsFreeUnit
-      Real(kind=wp) :: g_e
-      Real(kind=wp), allocatable :: tmpR(:,:), tmpI(:,:)
+      Real(kind=8) :: g_e
+      Real(kind=8), allocatable :: tmpR(:,:), tmpI(:,:)
       External      :: IsFreeUnit
       logical :: DBG
 
@@ -152,7 +155,27 @@ c compatibility with the present version: of aniso_i.input file
       ! edmom
       Do l=1,3
         Do j1=1,nstate
-          Read(LuAniso,'(5ES24.14)') (edmom(l,j1,j2),j2=1,nstate)
+          Read(LuAniso,*) (edmom(l,j1,j2),j2=1,nstate)
+        End Do
+      End Do
+
+      ! amfi
+      Do l=1,3
+        Do j1=1,nstate
+          Read(LuAniso,*) (amfi(l,j1,j2),j2=1,nstate)
+        End Do
+      End Do
+
+      ! HSO matrix
+      tmpR=0.0_wp
+      tmpI=0.0_wp
+      Do j1=1,nss
+        read(LuAniso,*) ( tmpR(j1,j2), tmpI(j1,j2), j2=1,nss )
+      End Do
+
+      Do j1=1,nss
+        Do j2=1,nss
+          HSO(j1,j2) = cmplx(tmpR(j1,j2),tmpI(j1,j2),wp)
         End Do
       End Do
 
@@ -172,15 +195,15 @@ c compatibility with the present version: of aniso_i.input file
       Integer, Parameter            :: wp=selected_real_kind(p=15,r=307)
       Integer, intent(inout)        :: nss, nstate
       Integer, intent(out)          :: multiplicity(nstate)
-      Real(kind=wp), intent(out)    :: eso(nss)
-      Complex(kind=wp), intent(out) :: MM(3,nss,nss)
-      Complex(kind=wp), intent(out) :: MS(3,nss,nss)
-      Complex(kind=wp), intent(out) :: ML(3,nss,nss)
-      Character(180)                :: input_file_name
+      Real(kind=8), intent(out)    :: eso(nss)
+      Complex(kind=8), intent(out) :: MM(3,nss,nss)
+      Complex(kind=8), intent(out) :: MS(3,nss,nss)
+      Complex(kind=8), intent(out) :: ML(3,nss,nss)
+      Character(Len=180)            :: input_file_name
       ! local variables:
       Integer       :: l,j,j1,j2,LuAniso,IsFreeUnit
-      Real(kind=wp) :: g_e
-      Real(kind=wp), allocatable :: tmpR(:,:), tmpI(:,:)
+      Real(kind=8) :: g_e
+      Real(kind=8), allocatable :: tmpR(:,:), tmpI(:,:)
       External      :: IsFreeUnit
 
       g_e=2.00231930437180_wp
@@ -278,14 +301,14 @@ c      End If
       Integer, Parameter            :: wp=selected_real_kind(p=15,r=307)
       Integer, intent(inout)        :: nss, nstate, nLoc, iReturn
       ! nLoc is the maximal value of the array nss(1:nneq)
-      Real(kind=wp), intent(out)    :: eso(nLoc)
-      Complex(kind=wp), intent(out) :: MM(3,nLoc,nLoc)
-      Complex(kind=wp), intent(out) :: MS(3,nLoc,nLoc)
+      Real(kind=8), intent(out)    :: eso(nLoc)
+      Complex(kind=8), intent(out) :: MM(3,nLoc,nLoc)
+      Complex(kind=8), intent(out) :: MS(3,nLoc,nLoc)
       Character(len=180)            :: input_file_name
       ! local variables:
       Integer       :: l,j,j1,j2,LuAniso,IsFreeUnit
       Integer       :: multiplicity(nLoc)
-      Real(kind=wp), allocatable :: tmpR(:,:), tmpI(:,:)
+      Real(kind=8), allocatable :: tmpR(:,:), tmpI(:,:)
       External      :: IsFreeUnit
 
 c   set to zero all arrays:
@@ -374,18 +397,20 @@ c      End If
 
       Subroutine write_formatted_aniso( nss, nstate, multiplicity, eso,
      &                                  esfs, U, MM, MS, DM, angmom,
-     &                                  edmom )
+     &                                  edmom, amfi, HSO )
 
       Implicit None
       Integer, Parameter           :: wp=selected_real_kind(p=15,r=307)
       Integer, intent(in)          :: nss, nstate, multiplicity(nstate)
-      Real(kind=wp), intent(in)    :: eso(nss), esfs(nstate)
-      Real(kind=wp), intent(in)    :: angmom(3,nstate,nstate)
-      Real(kind=wp), intent(in)    ::  edmom(3,nstate,nstate)
-      Complex(kind=wp), intent(in) :: MM(3,nss,nss)
-      Complex(kind=wp), intent(in) :: MS(3,nss,nss)
-      Complex(kind=wp), intent(in) :: DM(3,nss,nss)
-      Complex(kind=wp), intent(in) :: U(nss,nss)
+      Real(kind=8), intent(in)    :: eso(nss), esfs(nstate)
+      Real(kind=8), intent(in)    :: angmom(3,nstate,nstate)
+      Real(kind=8), intent(in)    ::  edmom(3,nstate,nstate)
+      Real(kind=8), intent(in)    ::   amfi(3,nstate,nstate)
+      Complex(kind=8), intent(in) :: MM(3,nss,nss)
+      Complex(kind=8), intent(in) :: MS(3,nss,nss)
+      Complex(kind=8), intent(in) :: DM(3,nss,nss)
+      Complex(kind=8), intent(in) ::    U(nss,nss)
+      Complex(kind=8), intent(in) ::  HSO(nss,nss)
       ! local stuff
       Integer                      :: l,i,j,LuAniso,IsFreeUnit
       External                     :: IsFreeUnit
@@ -432,6 +457,18 @@ c      End If
         End Do
       End Do
 
+      ! amfi
+      Do l=1,3
+        Do i=1,nstate
+          Write(LuAniso,'(5ES24.14)') (amfi(l,i,j),j=1,nstate)
+        End Do
+      End Do
+
+      ! HSO matrix
+      Do i=1,nss
+         Write(LuAniso,'(5ES24.14)') (HSO(i,j) ,j=1,nss)
+      End Do
+
       Close(LuAniso)
       Return
       End
@@ -445,16 +482,16 @@ c      End If
 #include "stdalloc.fh"
       Integer, Parameter            :: wp=selected_real_kind(p=15,r=307)
       Integer, intent(in)           :: nss
-      Real(kind=wp), intent(out)    :: eso(nss)
-      Complex(kind=wp), intent(out) :: MM(3,nss,nss)
-      Complex(kind=wp), intent(out) :: MS(3,nss,nss)
-      Complex(kind=wp), intent(out) :: ML(3,nss,nss)
-      Character(180)                :: input_file_name
+      Real(kind=8), intent(out)    :: eso(nss)
+      Complex(kind=8), intent(out) :: MM(3,nss,nss)
+      Complex(kind=8), intent(out) :: MS(3,nss,nss)
+      Complex(kind=8), intent(out) :: ML(3,nss,nss)
+      Character(Len=180)            :: input_file_name
       ! local variables:
       Integer       :: itmp, nss_local, nstate_local
       Integer       :: l,j,j1,j2,LuAniso,IsFreeUnit
-      Real(kind=wp) :: g_e
-      Real(kind=wp), allocatable :: tmpR(:,:), tmpI(:,:), tmp(:)
+      Real(kind=8) :: g_e
+      Real(kind=8), allocatable :: tmpR(:,:), tmpI(:,:), tmp(:)
       External      :: IsFreeUnit
 !     in this subroutine nss is input data
 
@@ -542,9 +579,9 @@ c compatibility with the present version: of aniso_i.input file
       Implicit None
       Integer, Parameter           :: wp=selected_real_kind(p=15,r=307)
       Integer, intent(in)          :: nss
-      Real(kind=wp), intent(in)    :: eso(nss)
-      Complex(kind=wp), intent(in) :: MM(3,nss,nss)
-      Complex(kind=wp), intent(in) :: MS(3,nss,nss)
+      Real(kind=8), intent(in)    :: eso(nss)
+      Complex(kind=8), intent(in) :: MM(3,nss,nss)
+      Complex(kind=8), intent(in) :: MS(3,nss,nss)
       Character(len=180), intent(in):: filename
       ! local stuff
       Integer                      :: l,i,j,LuAniso,IsFreeUnit
