@@ -13,18 +13,17 @@
       Implicit None
 #include "stdalloc.fh"
 #include "mh5.fh"
-      Character(180),intent(in) ::    file_h5
+      Character(Len=180),intent(in) ::    file_h5
       Integer, intent(out)      ::    nstate,nss
       ! local variables:
       Integer                   ::    i,fileid
       Character                 ::    tmp*256, sFile*128
-      Character(180)            ::    tmp2
+      Character(Len=180)        ::    tmp2
       Integer, allocatable      ::    spin_mult(:)
-      Character(5)              ::    molcas_module_kind
+      Character(Len=5)          ::    molcas_module_kind
       Logical                   ::    Exist
       Logical                   ::    DBG
 
-      Call qEnter('read_hdf5_init')
       DBG=.false.
 
       WRITE (6,'(A,A)') 'Read data from rassi.h5 file ',trim(file_h5)
@@ -92,7 +91,6 @@
       ! close the file
       Call mh5_close_file(fileid)
 
-      Call qExit('read_hdf5_init')
       RETURN
       END SUBROUTINE read_hdf5_init
 
@@ -112,41 +110,40 @@
       Integer, intent(in)           :: nstate,nss
       Integer, intent(out)          :: multiplicity(nstate)
 
-      Real(kind=wp), intent(out)    :: esfs(nstate)
-      Real(kind=wp), intent(out)    :: eso(nss)
-      Real(kind=wp), intent(out)    ::  edmom(3,nstate,nstate)
-      Real(kind=wp), intent(out)    ::   amfi(3,nstate,nstate)
-      Real(kind=wp), intent(out)    :: angmom(3,nstate,nstate)
-      Complex(kind=wp), intent(out) :: MM(3,nss,nss)
-      Complex(kind=wp), intent(out) :: MS(3,nss,nss)
-      Complex(kind=wp), intent(out) :: ML(3,nss,nss)
+      Real(kind=8), intent(out)    :: esfs(nstate)
+      Real(kind=8), intent(out)    :: eso(nss)
+      Real(kind=8), intent(out)    ::  edmom(3,nstate,nstate)
+      Real(kind=8), intent(out)    ::   amfi(3,nstate,nstate)
+      Real(kind=8), intent(out)    :: angmom(3,nstate,nstate)
+      Complex(kind=8), intent(out) :: MM(3,nss,nss)
+      Complex(kind=8), intent(out) :: MS(3,nss,nss)
+      Complex(kind=8), intent(out) :: ML(3,nss,nss)
 !     electric dipole moment
-      Complex(kind=wp), intent(out) :: DM(3,nss,nss)
-      Complex(kind=wp), intent(out) :: U(nss,nss)
-      Complex(kind=wp), intent(out) :: HSO(nss,nss)
+      Complex(kind=8), intent(out) :: DM(3,nss,nss)
+      Complex(kind=8), intent(out) :: U(nss,nss)
+      Complex(kind=8), intent(out) :: HSO(nss,nss)
 
-      Real(kind=wp)                 :: AU2CM
-      Real(kind=wp), allocatable    :: etmp(:)
-      Real(kind=wp), allocatable    :: RR(:,:), RI(:,:)
-      Real(kind=wp), allocatable    :: AL(:,:,:)
+      Real(kind=8)                 :: AU2CM
+      Real(kind=8), allocatable    :: etmp(:)
+      Real(kind=8), allocatable    :: RR(:,:), RI(:,:)
+      Real(kind=8), allocatable    :: AL(:,:,:)
       Integer                       :: fileid,jend,INRM
-      Character(180)                :: file_h5
-      Real(kind=wp)                 :: RNRM
-      Real(kind=wp), external       :: dnrm2_, dznrm2_
-      Complex(kind=wp), external    :: spin
+      Character(Len=180)            :: file_h5
+      Real(kind=8)                 :: RNRM
+      Real(kind=8), external       :: dnrm2_, dznrm2_
+      Complex(kind=8), external    :: spin
       ! local variables:
       Integer       :: iss, ibas(nstate,-50:50)
       Integer       :: i, j, i1, j1, ist, jst, mult, multI, multJ
       Integer       :: l, ipar
-      Real(kind=wp) :: g_e
-      Complex(kind=wp), allocatable    :: tmp(:,:)
+      Real(kind=8) :: g_e
+      Complex(kind=8), allocatable    :: tmp(:,:)
 
 !      Logical :: Exist
       Logical :: found_edmom, found_angmom, found_hso, found_amfi,
      &           found_sos_coeff, found_eso, found_esfs, found_mult
       Logical :: DBG
 
-      Call qEnter('read_hdf5_all')
       DBG  =.false.
       AU2CM=219474.6313702_wp
       g_e=2.00231930437180_wp
@@ -571,7 +568,6 @@ c----- expand the spin free basis to the spin-orbit basis:
       ! close the file
       Call mh5_close_file(fileid)
 
-      Call qExit('read_hdf5_all')
       RETURN
       END SUBROUTINE read_hdf5_all
 
@@ -591,41 +587,40 @@ c----- expand the spin free basis to the spin-orbit basis:
       Integer                       :: multiplicity(nstate)
       Integer                       :: iReturn
 
-!      Real(kind=wp), intent(out)    :: esfs(nstate)
-      Real(kind=wp), intent(out)    :: eso(nss)
-!      Real(kind=wp), intent(out)    ::  edmom(3,nstate,nstate)
-!      Real(kind=wp), intent(out)    ::   amfi(3,nstate,nstate)
-      Real(kind=wp)                 :: angmom(3,nstate,nstate)
-      Complex(kind=wp)  :: MM(3,nss,nss)
-      Complex(kind=wp)  :: MS(3,nss,nss)
-!      Complex(kind=wp), intent(out) :: ML(3,nss,nss)
-!      Complex(kind=wp), intent(out) :: DM(3,nss,nss) ! electric dipole moment
-!      Complex(kind=wp)              :: U(nLoc,nLoc)
-!      Complex(kind=wp), intent(out) :: HSO(nss,nss)
+!      Real(kind=8), intent(out)    :: esfs(nstate)
+      Real(kind=8), intent(out)    :: eso(nss)
+!      Real(kind=8), intent(out)    ::  edmom(3,nstate,nstate)
+!      Real(kind=8), intent(out)    ::   amfi(3,nstate,nstate)
+      Real(kind=8)                 :: angmom(3,nstate,nstate)
+      Complex(kind=8)  :: MM(3,nss,nss)
+      Complex(kind=8)  :: MS(3,nss,nss)
+!      Complex(kind=8), intent(out) :: ML(3,nss,nss)
+!      Complex(kind=8), intent(out) :: DM(3,nss,nss) ! electric dipole moment
+!      Complex(kind=8)              :: U(nLoc,nLoc)
+!      Complex(kind=8), intent(out) :: HSO(nss,nss)
 
-      Real(kind=wp)                 :: AU2CM
-      Real(kind=wp), allocatable    :: etmp(:)
-      Real(kind=wp), allocatable    :: RR(:,:), RI(:,:)
-      Real(kind=wp), allocatable    :: AL(:,:,:)
-      Complex(kind=wp), allocatable :: U(:,:)
+      Real(kind=8)                 :: AU2CM
+      Real(kind=8), allocatable    :: etmp(:)
+      Real(kind=8), allocatable    :: RR(:,:), RI(:,:)
+      Real(kind=8), allocatable    :: AL(:,:,:)
+      Complex(kind=8), allocatable :: U(:,:)
       Integer                       :: fileid,jend,INRM
-      Character(180)                :: file_h5
-      Real(kind=wp)                 :: RNRM
-      Real(kind=wp), external       :: dnrm2_, dznrm2_
-      Complex(kind=wp), external    :: spin
+      Character(Len=180)            :: file_h5
+      Real(kind=8)                 :: RNRM
+      Real(kind=8), external       :: dnrm2_, dznrm2_
+      Complex(kind=8), external    :: spin
       ! local variables:
       Integer       :: iss, ibas(nstate,-50:50)
       Integer       :: i, j, i1, j1, ist, jst, mult, multI, multJ
       Integer       :: l, ipar
-      Real(kind=wp) :: g_e
-      Complex(kind=wp), allocatable    :: tmp(:,:)
+      Real(kind=8) :: g_e
+      Complex(kind=8), allocatable    :: tmp(:,:)
 
 !      Logical :: Exist
       Logical :: found_edmom, found_angmom, found_hso, found_amfi,
      &           found_sos_coeff, found_eso, found_esfs, found_mult
       Logical :: DBG
 
-      Call qEnter('read_hdf5_poly')
       DBG  =.false.
       AU2CM=219474.6313702_wp
       g_e=2.00231930437180_wp
@@ -1056,7 +1051,6 @@ c----- expand the spin free basis to the spin-orbit basis:
       ! close the file
       Call mh5_close_file(fileid)
 
-      Call qExit('read_hdf5_poly')
       RETURN
       END  SUBROUTINE read_hdf5_poly
 
