@@ -13,11 +13,11 @@
       Implicit None
       Integer, parameter         :: wp=SELECTED_REAL_KIND(p=15,r=307)
       Integer, intent(in)        :: N ! size of the array
-      Real(kind=wp), intent(in)  :: A(N) ! input
-      Real(kind=wp), intent(out) :: B(N) ! output
+      Real(kind=8), intent(in)  :: A(N) ! input
+      Real(kind=8), intent(out) :: B(N) ! output
       ! local variables
       Integer       :: i
-      Real(kind=wp) :: AS
+      Real(kind=8) :: AS
       AS=0.0_wp
       Call dcopy_(N,[0.0_wp],0, B,1)
       !compute the equal-weighted average
