@@ -29,7 +29,6 @@ C Set up B matrices for cases 1..13.
 
 #include "SysDef.fh"
 
-      CALL QENTER('MKBMAT')
 
       IF(IPRGLB.GE.VERBOSE) THEN
         WRITE(6,*)
@@ -94,7 +93,6 @@ C looping, etc in the rest  of the routines.
         END DO
       END DO
 
-      CALL QEXIT('MKBMAT')
 
       RETURN
       END
@@ -1761,7 +1759,6 @@ C where A= EASUM= sum over active w of (Ew*Dww).
 C    BBP(tu,xy)=BB(tu,xy)+BB(tu,yx)
 C    BBM(tu,xy)=BB(tu,xy)-BB(tu,yx)
 
-      CALL QENTER('MKBB')
 
 C Loop over superindex symmetry.
       DO ISYM=1,NSYM
@@ -1949,7 +1946,6 @@ CGG End
  1000 CONTINUE
       END DO
 
-      CALL QEXIT('MKBB')
 
       RETURN
       END
@@ -1978,7 +1974,6 @@ C    BD(tu2,xy2)=
 C       -Fxtuy - (Ex+Et-A)*Gxtuy + 2*dxt (Fuy + (Ex-A)*Duy)
 C where A=EASUM=Sum(w) of (Ew*Dww)
 
-      CALL QENTER('MKBD')
 
 C Loop over superindex symmetry.
       DO ISYM=1,NSYM
@@ -2071,7 +2066,6 @@ CGG End
  1000 CONTINUE
       END DO
 
-      CALL QEXIT('MKBD')
 
       RETURN
       END
@@ -2094,7 +2088,6 @@ C Formula used:
 C    BE(t,x)=-Ftx + (EASUM-Ex-Et)*Dtx
 C            + 2dtx Ex
 
-      CALL QENTER('MKBE')
 
       DO ISYM=1,NSYM
         NINP=NINDEP(ISYM,6)
@@ -2158,7 +2151,6 @@ CGG End
  1000 CONTINUE
       END DO
 
-      CALL QEXIT('MKBE')
 
       RETURN
       END
@@ -2183,7 +2175,6 @@ C    BF(tu,xy)= 2*(Ftxuy - EASUM*Gtxuy)
 C    BFP(tu,xy)=BF(tu,xy)+BF(tu,yx)
 C    BFM(tu,xy)=BF(tu,xy)-BF(tu,yx)
 
-      CALL QENTER('MKBF')
 
 C Loop over superindex symmetry.
       DO ISYM=1,NSYM
@@ -2326,7 +2317,6 @@ CGG End
  1000 CONTINUE
       END DO
 
-      CALL QEXIT('MKBF')
 
       RETURN
       END
@@ -2348,7 +2338,6 @@ C     Set up the matrix BG(t,x)
 C     Formula used:
 C     BG(t,x)= Ftx -EASUM*Dtx
 
-      CALL QENTER('MKBG')
 
       DO ISYM=1,NSYM
         NINP=NINDEP(ISYM,10)
@@ -2408,7 +2397,6 @@ CGG End
  1000 CONTINUE
       END DO
 
-      CALL QEXIT('MKBG')
 
       RETURN
       END
