@@ -93,18 +93,17 @@ C
       ! which is set to nbuf1 later, i.e. a maximum of nlev2 <= mxlev**2
 *     REAL*8 BUFR(MXLEV**2)
 
-      CALL QENTER('MKFG3DM')
 
 C Put in zeroes. Recognize special cases:
       IF(nlev.EQ.0) GOTO 999
 
-      CALL DCOPY_(NG1,0.0D0,0,G1,1)
-      CALL DCOPY_(NG2,0.0D0,0,G2,1)
-      CALL DCOPY_(NG3,0.0D0,0,G3,1)
+      CALL DCOPY_(NG1,[0.0D0],0,G1,1)
+      CALL DCOPY_(NG2,[0.0D0],0,G2,1)
+      CALL DCOPY_(NG3,[0.0D0],0,G3,1)
       IF(IFF.ne.0) THEN
-       CALL DCOPY_(NG1,0.0D0,0,F1,1)
-       CALL DCOPY_(NG2,0.0D0,0,F2,1)
-       CALL DCOPY_(NG3,0.0D0,0,F3,1)
+        CALL DCOPY_(NG1,[0.0D0],0,F1,1)
+        CALL DCOPY_(NG2,[0.0D0],0,F2,1)
+        CALL DCOPY_(NG3,[0.0D0],0,F3,1)
       END IF
 
       IF(NACTEL.EQ.0) GOTO 999
@@ -573,7 +572,6 @@ C     so make sure that the _total_ fingerprint is computed
       ENDIF
 
  999  continue
-      CALL QEXIT('MKFG3DM')
       RETURN
       END
 #elif defined (NAGFOR)
