@@ -14,9 +14,9 @@
       Implicit None
 CSVC: this module contains a data structure to keep all input variables.
 C Note that I use the standard 'allocate' here against the appropriate
-C Molcas practices. The reason is that these are (i) very small, and (ii)
-C there is need for allocating complex things such as derived types, which
-C are not supported with stdalloc. Hence, the infraction.
+C Molcas practices. The reason is that these are (i) very small, and
+C (ii) there is need for allocating complex things such as derived
+C types, which are not supported with stdalloc. Hence, the infraction.
 
 #include "compiler_features.h"
 
@@ -39,6 +39,11 @@ C are not supported with stdalloc. Hence, the infraction.
       Integer :: nXMulState = 0
       Type(States) :: XMulGroup
       Logical :: AllXMult = .False.
+!     DWMS      use dynamical weighting to construct Fock
+      Logical :: DWMS = .False.
+      Integer :: ZETA = 50
+!     EFOC      uses rotated E_0 energies with DWMS
+      Logical :: EFOC = .False.
 !     LROO      compute only a single root, mutually exclusive
 !               with both MULT or XMUL
       Logical :: LROO = .False.
@@ -210,7 +215,6 @@ C is nSym, as some input lines assume knowledge of the number of irreps.
 #endif
 
 
-      CALL QENTER('READIN')
 *
       Rewind(LuIn)
       Call RdNLst(LuIn,'CASPT2')
@@ -303,6 +307,15 @@ C end of input
       End Do
       dealloc_dline
 
+
+      Case('DWMS')
+      Input % DWMS = .True.
+      If(.NOT.next_non_comment(LuIn,Line)) GoTo 9910
+      Read(Line,*,Err=9920,End=9920) Input % ZETA
+
+      Case('EFOC')
+      Input % EFOC = .True.
+
       Case('LROO')
       Input % LROO = .True.
       If(.NOT.next_non_comment(LuIn,Line)) GoTo 9910
@@ -619,7 +632,6 @@ c      call Quit_OnInstError
       GoTo 10
 
 9000  CONTINUE
-      CALL QEXIT('Readin_CASPT2')
 
 #ifdef _ENABLE_CHEMPS2_DMRG_
 ! Check if nState>1
