@@ -28,7 +28,6 @@
 #include "eqsolv.fh"
 #include "para_info.fh"
 
-      Call QEnter('RHSOD')
 
       IF (IPRGLB.GE.VERBOSE) THEN
         WRITE(6,'(1X,A)') ' Using RHS on-demand algorithm'
@@ -50,7 +49,7 @@
       CALL RHSOD_G(IVEC)
       CALL RHSOD_H(IVEC)
 
-#ifdef _DEBUG_
+#ifdef _DEBUGPRINT_
 * compute and print RHS fingerprints
       WRITE(6,'(1X,A4,1X,A3,1X,A18)') 'Case','Sym','Fingerprint'
       WRITE(6,'(1X,A4,1X,A3,1X,A18)') '====','===','==========='
@@ -68,7 +67,6 @@
       END DO
 #endif
 
-      Call QExit('RHSOD')
 
       END
 
