@@ -26,7 +26,6 @@
 #include "SysDef.fh"
 #include "para_info.fh"
 
-      CALL QENTER('SBDIAG')
 
       IF(IPRGLB.GE.VERBOSE) THEN
         WRITE(6,*)
@@ -96,7 +95,6 @@ C usually print info on the total number of parameters
         WRITE(6,'(a,i12)')'   After  reduction:',IPAR1
       ENDIF
 
-      CALL QEXIT('SBDIAG')
 
       RETURN
       END
@@ -183,7 +181,7 @@ C Extremely small values give scale factor exactly zero.
 * Small variations of the scale factor were beneficial
           WORK(LSCA-1+I)=(1.0D00+DBLE(I)*3.0D-6)/SQRT(SD)
         ELSE
-          WORK(LSCA-1+I)=0.0D00
+          WORK(LSCA-1+I)=0.0D0
         END IF
       END DO
       IJ=0
@@ -350,7 +348,7 @@ C TRANSFORM B. NEW B WILL OVERWRITE AND DESTROY WORK(LVEC)
       CALL GETMEM('LXBX','ALLO','REAL',LXBX,NAS)
       DO J=NIN,1,-1
         LVSTA=LVEC+NAS*(J-1)
-        CALL DCOPY_(NAS,[0.0D00],0,WORK(LBX),1)
+        CALL DCOPY_(NAS,[0.0D0],0,WORK(LBX),1)
 #ifdef _CRAY_C90_
         CALL SSPMV('U',NAS,1.0D+00,WORK(LB),WORK(LVSTA),1,
      &                           1.0D+00,WORK(LBX),1)
@@ -361,7 +359,7 @@ C TRANSFORM B. NEW B WILL OVERWRITE AND DESTROY WORK(LVEC)
      &                           1.0D+00,WORK(LBX),1)
 #endif
 C WORK(LBX): B * Vector number J.
-        CALL DCOPY_(J,[0.0D00],0,WORK(LXBX),1)
+        CALL DCOPY_(J,[0.0D0],0,WORK(LXBX),1)
         CALL DGEMM_('T','N',
      &              J,1,NAS,
      &              1.0d0,WORK(LVEC),NAS,
@@ -478,7 +476,7 @@ C      utilities.
       IDS=IDSMAT(ISYM,ICASE)
       CALL DDAFILE(LUSBT,2,WORK(LS),NS,IDS)
       CALL GETMEM('LST','ALLO','REAL',LST,NAS*NIN)
-      CALL DCOPY_(NAS*NIN,[0.0D00],0,WORK(LST),1)
+      CALL DCOPY_(NAS*NIN,[0.0D0],0,WORK(LST),1)
       CALL TRIMUL(NAS,NIN,1.0D00,WORK(LS),WORK(LTRANS),
      &            NAS,WORK(LST),NAS)
       CALL GETMEM('LS','FREE','REAL',LS,NS)
@@ -517,7 +515,7 @@ C-SVC20100902: global arrays header files
       DIMENSION WGRONK(2)
 #endif
       LOGICAL bSTAT
-      CHARACTER(2) cSYM,cCASE
+      CHARACTER(LEN=2) cSYM,cCASE
       LOGICAL KING
 
 C On entry, the DRA metafiles contain the matrices S and B for cases A
@@ -584,7 +582,7 @@ C full parallelization of use of S matrices is achieved.
 C Save the diagonal elements from the S matrix for easy access later on.
 C FIXME: nicer way to do this?
       CALL GETMEM('SD','ALLO','REAL',LSD,NAS)
-      CALL DCOPY_(NAS,[0.0D00],0,WORK(LSD),1)
+      CALL DCOPY_(NAS,[0.0D0],0,WORK(LSD),1)
       myRank = GA_NodeID()
       call GA_Distribution (lg_S, myRank, iLo, iHi, jLo, jHi)
       ISTA=MAX(ILO,JLO)
@@ -605,7 +603,7 @@ C Calculate the scaling factors and store them in array LSCA.
         IF(SD.GT.THRSHN) THEN
           WORK(LSCA-1+I)=(1.0D00+DBLE(I)*3.0D-6)/SQRT(SD)
         ELSE
-          WORK(LSCA-1+I)=0.0D00
+          WORK(LSCA-1+I)=0.0D0
         END IF
       END DO
 
@@ -684,7 +682,7 @@ C eigenvectors back to a global array.  Then distribute the eigenvalues.
       CPU=CPU+CPU2-CPU1
 
       CALL GETMEM('COND','ALLO','REAL',LCOND,NIN)
-      CALL DCOPY_(NIN,[0.0D00],0,WORK(LCOND),1)
+      CALL DCOPY_(NIN,[0.0D0],0,WORK(LCOND),1)
 C Form orthonormal transformation vectors by scaling the eigenvectors.
       call GA_Sync()
       myRank = GA_NodeID()
@@ -769,7 +767,7 @@ C eigenvalues would go in ordinary CASPT2.
         CALL PSBMAT_GETMEM ('B',lg_B,NAS)
         CALL PSBMAT_READ ('B',iCase,iSym,lg_B,NAS)
         CALL GETMEM('BD','ALLO','REAL',LBD,NAS)
-        CALL DCOPY_(NAS,[0.0D00],0,WORK(LBD),1)
+        CALL DCOPY_(NAS,[0.0D0],0,WORK(LBD),1)
         myRank = GA_NodeID()
         call GA_Distribution (lg_B, myRank, iLo, iHi, jLo, jHi)
         ISTA=MAX(ILO,JLO)
