@@ -34,9 +34,8 @@ C Compute |JVEC> := BETA* |JVEC> + ALPHA* (H0-E0)* |IVEC>
 C where the vectors are represented in transformed basis and
 C are  stored at positions IVEC and JVEC on the LUSOLV unit.
 
-      CALL QENTER('SIGMA')
 
-#ifdef _DEBUG_
+#ifdef _DEBUGPRINT_
       WRITE(6,*)' Entering SIGMA.'
       WRITE(6,*)
      &' Compute |JVEC> := Beta*|JVEC> + Alpha*(H0-E0)|IVEC>'
@@ -92,7 +91,7 @@ C Flop counts:
 C First compute diagonal block contributions:
 CTEST      WRITE(6,*)' First, do it for (H0(diag)-E0).'
       CALL PSGMDIA(ALPHA,BETA,IVEC,JVEC)
-      IF(ALPHA.EQ.0.0D00) GOTO 99
+      IF(ALPHA.EQ.0.0D0) GOTO 99
 CTEST      WRITE(6,*)
 CTEST     & ' From now on, scaling with BETA is already done.'
 CTEST      WRITE(6,*)' Test print  after SGMDIA call in SIGMA:'
@@ -148,15 +147,15 @@ C SVC: add transposed fock matrix blocks
 C Loop over types and symmetry block of sigma vector:
       DO 300 ICASE1=1,11
 *     DO 300 ICASE1=1,NCASES
-        DO 300 ISYM1=1,NSYM
-          IF(NINDEP(ISYM1,ICASE1).EQ.0) GOTO 300
+        DO 301 ISYM1=1,NSYM
+          IF(NINDEP(ISYM1,ICASE1).EQ.0) GOTO 301
           NIS1=NISUP(ISYM1,ICASE1)
           NAS1=NASUP(ISYM1,ICASE1)
           NSGM2=NIS1*NAS1
-          IF(NSGM2.EQ.0) GOTO 300
+          IF(NSGM2.EQ.0) GOTO 301
 
           CALL GETMEM('SGM2','ALLO','REAL',LSGM2,NSGM2)
-          CALL DCOPY_(NSGM2,[0.0D00],0,WORK(LSGM2),1)
+          CALL DCOPY_(NSGM2,[0.0D0],0,WORK(LSGM2),1)
 
           NSGM1=0
           LSGM1=1
@@ -169,7 +168,7 @@ C Loop over types and symmetry block of sigma vector:
           END IF
           IF(NSGM1.GT.0) THEN
             CALL GETMEM('SGM1','ALLO','REAL',LSGM1,NSGM1)
-            CALL DCOPY_(NSGM1,[0.0D00],0,WORK(LSGM1),1)
+            CALL DCOPY_(NSGM1,[0.0D0],0,WORK(LSGM1),1)
           END IF
 
           IMLTOP=0
@@ -203,7 +202,7 @@ C the SGM subroutines
                 GOTO 999
               END IF
 
-#ifdef _DEBUG_
+#ifdef _DEBUGPRINT_
               WRITE(6,*)' ISYM1,ICASE1:',ISYM1,ICASE1
               WRITE(6,*)' ISYM2,ICASE2:',ISYM2,ICASE2
               WRITE(6,*)' SIGMA calling SGM with IMLTOP=',IMLTOP
@@ -254,7 +253,7 @@ C-SVC: sum the replicate arrays:
           END IF
 
 C       XTST2=DDOT_(NSGM2,WORK(LSGM2),1,WORK(LSGM2),1)
-C       XTST1=0.0D00
+C       XTST1=0.0D0
 C       IF(NSGM1.GT.0)XTST1=DDOT_(NSGM1,WORK(LSGM1),1,WORK(LSGM1),1)
 C       WRITE(6,'(1x,a,a,i2,2f16.6)')
 C    & 'Contr. SGM2, SGM1, ',cases(icase1),isym1,xtst2,xtst1
@@ -318,18 +317,19 @@ C Add to sigma array. Multiply by S to  lower index.
 C Write SGMX to disk.
           CALL RHS_SAVE (NAS1,NIS1,lg_SGMX,ICASE1,ISYM1,JVEC)
           CALL RHS_FREE (NAS1,NIS1,lg_SGMX)
+ 301    CONTINUE
  300  CONTINUE
 
       IMLTOP=1
 C Loop over types and symmetry block of CX vector:
       DO 600 ICASE1=1,11
 *     DO 600 ICASE1=1,NCASES
-        DO 600 ISYM1=1,NSYM
-          IF(NINDEP(ISYM1,ICASE1).EQ.0) GOTO 600
+        DO 601 ISYM1=1,NSYM
+          IF(NINDEP(ISYM1,ICASE1).EQ.0) GOTO 601
           NIS1=NISUP(ISYM1,ICASE1)
           NAS1=NASUP(ISYM1,ICASE1)
           ND2=NIS1*NAS1
-          IF(ND2.EQ.0) GOTO 600
+          IF(ND2.EQ.0) GOTO 601
 
           CALL RHS_ALLO (NAS1,NIS1,lg_D2)
           CALL RHS_SCAL (NAS1,NIS1,lg_D2,0.0D0)
@@ -372,7 +372,7 @@ CPAM Sanity check:
             ND1=NASH(ISYM1)*NISH(ISYM1)
             IF(ND1.GT.0) THEN
               CALL GETMEM('D1','ALLO','REAL',LD1,ND1)
-              CALL DCOPY_(ND1,[0.0D00],0,WORK(LD1),1)
+              CALL DCOPY_(ND1,[0.0D0],0,WORK(LD1),1)
               CALL SPEC1A(IMLTOP,FACT,ISYM1,WORK(LD2),
      &                    WORK(LD1))
             END IF
@@ -380,7 +380,7 @@ CPAM Sanity check:
             ND1=NASH(ISYM1)*NSSH(ISYM1)
             IF(ND1.GT.0) THEN
               CALL GETMEM('D1','ALLO','REAL',LD1,ND1)
-              CALL DCOPY_(ND1,[0.0D00],0,WORK(LD1),1)
+              CALL DCOPY_(ND1,[0.0D0],0,WORK(LD1),1)
               CALL SPEC1C(IMLTOP,FACT,ISYM1,WORK(LD2),
      &                    WORK(LD1))
             END IF
@@ -388,7 +388,7 @@ CPAM Sanity check:
             ND1=NIS1
             IF(ND1.GT.0) THEN
               CALL GETMEM('D1','ALLO','REAL',LD1,ND1)
-              CALL DCOPY_(ND1,[0.0D00],0,WORK(LD1),1)
+              CALL DCOPY_(ND1,[0.0D0],0,WORK(LD1),1)
               CALL SPEC1D(IMLTOP,FACT,WORK(LD2),WORK(LD1))
             END IF
           END IF
@@ -419,7 +419,7 @@ CPAM Sanity check:
                 LSGMX=lg_SGMX
               ELSE
                 CALL GETMEM('SGMX','ALLO','REAL',LSGMX,NSGMX)
-                CALL DCOPY_(NSGMX,[0.0D00],0,WORK(LSGMX),1)
+                CALL DCOPY_(NSGMX,[0.0D0],0,WORK(LSGMX),1)
               END IF
 
 * SVC: this array is just zero....
@@ -432,7 +432,7 @@ CPAM Sanity check:
 *               GOTO 999
 *             END IF
 
-#ifdef _DEBUG_
+#ifdef _DEBUGPRINT_
               WRITE(6,*)' ISYM1,ICASE1:',ISYM1,ICASE1
               WRITE(6,*)' ISYM2,ICASE2:',ISYM2,ICASE2
               WRITE(6,*)' SIGMA calling SGM with IMLTOP=',IMLTOP
@@ -474,13 +474,14 @@ C-SVC: no need for the replicate arrays any more, fall back to one array
  500      CONTINUE
           CALL GETMEM('D2','FREE','REAL',LD2,ND2)
           IF(ND1.GT.0) CALL GETMEM('D1','FREE','REAL',LD1,ND1)
+ 601    CONTINUE
  600  CONTINUE
 
       CALL TIMING(CPU1,CPU,TIO1,TIO)
       CPUSGM=CPUSGM+(CPU1-CPU0)
       TIOSGM=TIOSGM+(TIO1-TIO0)
 
-#ifdef _DEBUG_
+#ifdef _DEBUGPRINT_
       WRITE(6,*)' End of SIGMA. Flop counts:'
       WRITE(6,'(a,i12)')' In MLTSCA:',NFSCA
       WRITE(6,'(a,i12)')' In MLTDXP:',NFDXP
@@ -502,7 +503,6 @@ C Transform covar. sigma to eigenbasis of H0(diag):
       CALL PTRTOSR(0,JVEC,JVEC)
 
   99  CONTINUE
-      CALL QEXIT('SIGMA')
       RETURN
 
  999  CONTINUE
