@@ -192,7 +192,7 @@ C     -------------
       THR_PRESCREEN = -1.0d9 ! diag. prescreen threshold (neg=>generic)
       CHO_SIMRI = .FALSE.    ! simulate RI
       THR_SIMRI = -1.0D9     ! threshold for qualifying diags. in RI sim
-#if defined (_DEBUG_)
+#if defined (_DEBUGPRINT_)
       CHO_INTCHK = .TRUE.  ! check integrals after decomposition
       CHO_MINCHK = .TRUE.  ! minimal integral check
       CHO_TRCNEG = .TRUE.  ! tracing of negative diagonals
@@ -861,21 +861,20 @@ C     ------------
 
  9999 CALL CHO_QUIT('Error in '//SECNAM,IRC)
       END
-***********************************************************************
-*                                                                     *
-***********************************************************************
+************************************************************************
+*                                                                      *
+************************************************************************
       Subroutine Put_thr_Cho(ThrCom)
+      use RICD_Info, only: Do_RI, Thrshld_CD
       Implicit Real*8 (a-h,o-z)
-#include "itmax.fh"
-#include "info.fh"
 *
       If (.not. Do_RI) Thrshld_CD = ThrCom
 *
       Return
       End
-***********************************************************************
-*                                                                     *
-***********************************************************************
+************************************************************************
+*                                                                      *
+************************************************************************
       SubRoutine Cho_Inp_SetDecAlg(ForceParallel)
       Implicit None
       Logical ForceParallel
