@@ -9,13 +9,11 @@
 * LICENSE or in <http://www.gnu.org/licenses/>.                        *
 ************************************************************************
       SubRoutine Cho_PreScr(Thr1,Thr2)
+      use Real_Info, only: ThrInt, CutInt
 C
 C     Purpose: read integral prescreening thresholds from common block.
 C
-      Implicit Real*8 (a-h,o-z)
-#include "itmax.fh"
-#include "info.fh"
-
+      Real*8 Thr1, Thr2
       Thr1 = CutInt
       Thr2 = ThrInt
 
