@@ -27,10 +27,10 @@
 *      Author:Per Ake Malmqvist, Department of Theoretical Chemistry,  *
 *             University of Lund, SWEDEN. December 2005                *
 ************************************************************************
+      use KSDFT_Info, only: tmpB
       Implicit Real*8 (A-H,O-Z)
 #include "real.fh"
 #include "nq_index.fh"
-#include "WrkSpc.fh"
 #include "ksdft.fh"
       Real*8 Rho(nRho,mGrid),dF_dRho(ndF_dRho,mGrid),F_xc(mGrid)
 cGLM     &       F_xca(mGrid),F_xcb(mGrid),tmpB(mGrid)
@@ -114,7 +114,7 @@ cGLM     &       F_xca(mGrid),F_xcb(mGrid),tmpB(mGrid)
          zeta_in=(rhoa-rhob)/rho_in
          call cpbe_(idord,rho_in,grdrho_in,zeta_in,func0,func1,func2)
          F_xc(iGrid)=F_xc(iGrid)+Coeff*func0
-         Work(ip_tmpB+iGrid-1)=F_xc(iGrid)-Work(ip_tmpB+iGrid-1)
+         tmpB(iGrid)=F_xc(iGrid)-tmpB(iGrid)
 * dF_drhoa:
          dF_dRho(ipRa,iGrid)=dF_dRho(ipRa,iGrid)+
      &            Coeff*(func1(1)+(2.0D0*func1(3))*(rhob/rho_in**2))
