@@ -10,11 +10,7 @@
 *                                                                      *
 * Copyright (C) Ben Swerts                                             *
 ************************************************************************
-CStart Molcas
       SubRoutine Drvg_FAIEMP(Grad,Temp,nGrad)
-celse
-c;      SubRoutine Drvg_FAIEMP(Grad,Temp,nGrad,fock,fock1,d1ao,d1ao1)
-cend
 ************************************************************************
 *                                                                      *
 *  Object: driver for the derivatives of central-fragment              *
@@ -24,32 +20,24 @@ cend
 *          list of symmetry distinct centers that do have basis func-  *
 *          tions of the requested type.                                *
 *                                                                      *
-* Called from: Alaska                                                  *
-*                                                                      *
-* Calling    : QEnter                                                  *
-*              SetUp_Ints                                              *
-*              GetMem                                                  *
-*              DCopy   (ESSL)                                          *
-*              Swap                                                    *
-*              MemRg1                                                  *
-*              PSOAO1                                                  *
-*              PGet0                                                   *
-*              TwoEl                                                   *
-*              QExit                                                   *
-*                                                                      *
 *     Author: Ben Swerts                                               *
 *                                                                      *
 *     based on Drvg1                                                   *
-*                                                                      *
 ************************************************************************
       use k2_setup
       use iSD_data
+      use k2_arrays, only: ipZeta, ipiZet, Mem_DBLE, Aux, Sew_Scr
+      use Basis_Info
+      use Sizes_of_Seward, only:S
+      use Real_Info, only: CutInt
+      use Symmetry_Info, only: nIrrep
       Implicit None
       External King, Rsv_GTList, MPP
-#include "real.fh"
 #include "itmax.fh"
-#include "info.fh"
+#include "Molcas.fh"
+#include "real.fh"
 #include "WrkSpc.fh"
+#include "stdalloc.fh"
 #include "print.fh"
 #include "disp.fh"
 #include "nsd.fh"
@@ -74,13 +62,13 @@ cend
 *
       Integer  iRout,iPrint,nBT,nBVT,idum,idum1,i,j,iAng,iBasi,iBasn
       Integer  iS,jS,iBasAO,iBsInc,iCar,ijklA,ijS,Indij,iOpt,ijMax
-      Integer  ip_ij,ipEI,ipEta,ipiEta,ipCffi,ipMem1,ipMem2,ipP,ipQ
+      Integer  ip_ij,ipEI,ipEta,ipiEta,ipMem1,ipMem2,ipP,ipQ
       Integer  iPrem,iPren,ipxA,ipxB,ipxG,ipxD,ipZi,Mem1,Mem2,iPrimi
-      Integer  iPrInc,ipTMax,jAng,iSh,jBasAO,jBasj,jBasn,jBsInc,jpCffj
+      Integer  iPrInc,ipTMax,jAng,iSh,jBasAO,jBasj,jBasn,jBsInc
       Integer  jPrInc,k2ij,k2kl,jPrimj,kBasAO,kBasn,kBask,kBsInc
-      Integer  kBtch,klS,kpCffk,kPrimk,kPrInc,kS,lBasAO,lBasl,lBasn
-      Integer  lBsInc,lpCffl,lPriml,lPrInc,mBtch,lS,mdci,mdcj,mdck,mdcl
-      Integer  MemPSO,MxPrm,nab,ncd,nDCRR,nDCRS,nEta,nHmab,nHmcd,nHrrab
+      Integer  kBtch,klS,kPrimk,kPrInc,kS,lBasAO,lBasl,lBasn
+      Integer  lBsInc,lPriml,lPrInc,mBtch,lS,mdci,mdcj,mdck,mdcl
+      Integer  MemPSO,nab,ncd,nDCRR,nDCRS,nEta,nHmab,nHmcd,nHrrab
       Integer  nij,nijkl,nPairs,nQuad,nRys,nSkal,nSkal_Fragments
       Integer  nSkal_Valence,nSO,nZeta,nBtch
       Real*8   TMax,PMax,ExFac,CoulFac,Aint,Count,P_Eff,Prem,Pren
@@ -105,7 +93,6 @@ cend
       idum1=0
       ExFac=One
       CoulFac=One
-      Call QEnter('Drvg_FAIEMP')
 *
 *     Handle both the valence and the fragment basis set
 *
@@ -149,8 +136,8 @@ cend
 ************************************************************************
 *                                                                      *
       MxPrm = 0
-      Do iAng = 0, iAngMx
-         MxPrm = Max(MxPrm,MaxPrm(iAng))
+      Do iAng = 0, S%iAngMx
+         MxPrm = Max(MxPrm,S%MaxPrm(iAng))
       End Do
       nZeta = MxPrm * MxPrm
       nEta  = MxPrm * MxPrm
@@ -189,7 +176,7 @@ cend
 *                                                                      *
 *-------Compute FLOP's for the transfer equation.
 *
-        Do iAng = 0, iAngMx
+        Do iAng = 0, S%iAngMx
            Do jAng = 0, iAng
               nHrrab = 0
               Do i = 0, iAng+1
@@ -215,12 +202,13 @@ cend
       iOpt=0
       call dcopy_(nGrad,[Zero],0,Temp,1)
       If (iPrint.ge.15) Call PrGrad(' In Drvg_FAIEMP: Total Grad (1)',
-     &                              Grad,nGrad,lIrrep,ChDisp,iprint)
+     &                              Grad,nGrad,ChDisp,iprint)
 *                                                                      *
 ************************************************************************
 *                                                                      *
-      Call GetMem('MemMax','Max','Real',iDum,MemMax)
-      Call GetMem('MemMax','Allo','Real',ipMem1,MemMax)
+      Call mma_MaxDBLE(MemMax)
+      Call mma_allocate(Sew_Scr,MemMax,Label='Sew_Scr')
+      ipMem1=1
 *                                                                      *
 ************************************************************************
 *                                                                      *
@@ -260,7 +248,7 @@ cend
 ************************************************************************
 *                                                                      *
          Call Gen_iSD4(iS, jS, kS, lS,iSD,nSD,iSD4)
-         Call Size_SO_block_g(iSD4,nSD,Petite,nSO,No_batch)
+         Call Size_SO_block_g(iSD4,nSD,nSO,No_batch)
          If (No_batch) Go To 140
 *
          Call Int_Prep_g(iSD4,nSD,Coor,Shijij,iAOV,iStabs)
@@ -299,7 +287,6 @@ cend
 
          Call SOAO_g(iSD4,nSD,nSO,
      &               MemPrm, MemMax,
-     &               nExp,nBasis,MxShll,
      &               iBsInc,jBsInc,kBsInc,lBsInc,
      &               iPrInc,jPrInc,kPrInc,lPrInc,
      &               ipMem1,ipMem2, Mem1,  Mem2,
@@ -314,8 +301,6 @@ cend
          Call Int_Parm_g(iSD4,nSD,iAnga,
      &                 iCmpa,iShlla,iShela,
      &                 iPrimi,jPrimj,kPrimk,lPriml,
-     &                 ipCffi,jpCffj,kpCffk,lpCffl,
-     &                 nExp,ipExp,ipCff,MxShll,
      &                 indij,k2ij,nDCRR,k2kl,nDCRS,
      &                 mdci,mdcj,mdck,mdcl,AeqB,CeqD,
      &                 nZeta,nEta,ipZeta,ipZI,
@@ -356,12 +341,12 @@ cend
 *----------Get the 2nd order density matrix in SO basis.
 *
            nijkl = iBasn*jBasn*kBasn*lBasn
-           Call PGet0(iCmpa,iShela,
+           Call PGet0(iCmpa,
      &                iBasn,jBasn,kBasn,lBasn,Shijij,
-     &                iAOV,iAOst,nijkl,Work(ipMem1),nSO,
+     &                iAOV,iAOst,nijkl,Sew_Scr(ipMem1),nSO,
      &                iFnc(1)*iBasn,iFnc(2)*jBasn,
      &                iFnc(3)*kBasn,iFnc(4)*lBasn,MemPSO,
-     &                ipMem2,iS,jS,kS,lS,nQuad,PMax)
+     &                Sew_Scr(ipMem2),Mem2,iS,jS,kS,lS,nQuad,PMax)
            If (AInt*PMax.lt.CutInt) Go To 430
 *
 *----------Compute gradients of shell quadruplet
@@ -373,20 +358,21 @@ cend
      &          Data_k2(k2kl),ncd,nHmcd,nDCRS,Pren,Prem,
      &          iPrimi,iPrInc,jPrimj,jPrInc,
      &          kPrimk,kPrInc,lPriml,lPrInc,
-     &          Work(ipCffi+(iBasAO-1)*iPrimi),iBasn,
-     &          Work(jpCffj+(jBasAO-1)*jPrimj),jBasn,
-     &          Work(kpCffk+(kBasAO-1)*kPrimk),kBasn,
-     &          Work(lpCffl+(lBasAO-1)*lPriml),lBasn,
-     &          Work(ipZeta),Work(ipZI),Work(ipP),nZeta,
-     &          Work(ipEta), Work(ipEI),Work(ipQ),nEta,
-     &          Work(ipxA),Work(ipxB),Work(ipxG),Work(ipxD),Temp,nGrad,
-     &          JfGrad,JndGrd,Work(ipMem1), nSO,Work(ipMem2),Mem2,
-     &          Work(ipAux),nAux,Shijij)
+     &          Shells(iSD4(0,1))%pCff(iPrimi,iBasAO),iBasn,
+     &          Shells(iSD4(0,2))%pCff(jPrimj,jBasAO),jBasn,
+     &          Shells(iSD4(0,3))%pCff(kPrimk,kBasAO),kBasn,
+     &          Shells(iSD4(0,4))%pCff(lPriml,lBasAO),lBasn,
+     &          Mem_DBLE(ipZeta),Mem_DBLE(ipZI),Mem_DBLE(ipP),nZeta,
+     &          Mem_DBLE(ipEta), Mem_DBLE(ipEI),Mem_DBLE(ipQ),nEta,
+     &          Mem_DBLE(ipxA),Mem_DBLE(ipxB),
+     &          Mem_DBLE(ipxG),Mem_DBLE(ipxD),Temp,nGrad,
+     &          JfGrad,JndGrd,Sew_Scr(ipMem1), nSO,Sew_Scr(ipMem2),Mem2,
+     &          Aux,nAux,Shijij)
 *
 *
             If (iPrint.ge.15)
      &         Call PrGrad(' In Drvg_FAIEMP: Grad',
-     &                  Temp,nGrad,lIrrep,ChDisp,iPrint)
+     &                  Temp,nGrad,ChDisp,iPrint)
 *
  430     Continue
  420     Continue
@@ -425,7 +411,7 @@ cend
 *                                                                      *
 ************************************************************************
 *                                                                      *
-      Call GetMem('MemMax','Free','Real',ipMem1,MemMax)
+      Call mma_deallocate(Sew_Scr)
       Call Free_GTList
       Call Free_PPList
       Call Free_TList
@@ -454,13 +440,12 @@ cend
 * Accumulate the final results
       Call DScal_(nGrad,Half,Temp,1)
       If(iPrint.ge.15) Call PrGrad('The FAIEMP 2-electron Contribution',
-     &                             Temp,nGrad,lIrrep,ChDisp,iPrint)
+     &                             Temp,nGrad,ChDisp,iPrint)
       call daxpy_(nGrad,One,Temp,1,Grad,1)
 *
       Call Free_iSD()
 *                                                                      *
 ************************************************************************
 *                                                                      *
-      Call QExit('Drvg_FAIEMP')
       Return
       End
