@@ -11,31 +11,15 @@
 * Copyright (C) Ben Swerts                                             *
 *               2016, Liviu Ungur                                      *
 ************************************************************************
-      SubRoutine FragPInt(Alpha,nAlpha,Beta, nBeta,Zeta,ZInv,rKappa,P,
-     &                    Final,nZeta,nIC,nComp,la,lb,A,RB,nRys,
-     &                    Array,nArr,Ccoor,nOrdOp,lOper,iChO,
-     &                    iStabM,nStabM,
-     &                    PtChrg,nGrid,iAddPot)
+      SubRoutine FragPInt(
+#define _CALLING_
+#include "int_interface.fh"
+     &                    )
 ************************************************************************
 *                                                                      *
 * Object: kernel routine for the computation of Fragment AIEMP         *
 *         projection integrals                                         *
 *                                                                      *
-* Called from: OneEl                                                   *
-*                                                                      *
-* Calling    : QEnter                                                  *
-*              RecPrt                                                  *
-*              DCopy   (ESSL)                                          *
-*              ZXia                                                    *
-*              SetUp1                                                  *
-*              MltPrm                                                  *
-*              DGeTMO  (ESSL)                                          *
-*              DGEMM_  (ESSL)                                          *
-*              DScal   (ESSL)                                          *
-*              DGEMM_  (ESSL)                                          *
-*              GetMem                                                  *
-*              QExit                                                   *
-*                                                                      *
 *      Alpha : exponents of bra gaussians                              *
 *      nAlpha: number of primitives (exponents) of bra gaussians       *
 *      Beta  : as Alpha but for ket gaussians                          *
@@ -78,38 +62,39 @@
 ************************************************************************
       use Real_Spherical
       use iSD_data
+      use Basis_Info
+      use Center_Info
+      use Symmetry_Info, only: nIrrep, iChTbl
       Implicit None
 #include "real.fh"
-#include "itmax.fh"
-#include "info.fh"
-#include "WrkSpc.fh"
 #include "print.fh"
 #include "nsd.fh"
 #include "setup.fh"
 #include "para_info.fh"
-      Integer nZeta,la,lb,nIC,nArr,nComp,nAlpha,nBeta,nRys,nOrdOp,
-     &        nStabM
-      Real*8  Final(nZeta,(la+1)*(la+2)/2,(lb+1)*(lb+2)/2,nIC),
-     &        Zeta(nZeta), ZInv(nZeta), Alpha(nAlpha), Beta(nBeta),
-     &        rKappa(nZeta), P(nZeta,3), A(3), RB(3),
-     &        Array(nZeta*nArr), Ccoor(3), C(3), TC(3), B(3), TB(3)
-      Integer iStabM(0:nStabM-1), lOper(nComp), iDCRT(0:7),iTwoj(0:7),
-     &        iChO(nComp),iAddPot
+
+#include "int_interface.fh"
+
+*     Local variables
+      Real*8  C(3), TC(3), B(3), TB(3)
+      Integer iDCRT(0:7),iTwoj(0:7)
       Logical EnergyWeight
-c      Character*80 Label
+!#define _DEBUGPRINT_
+#ifdef _DEBUGPRINT_
       Character*24 Label
+      Integer ia, ib
+#endif
       Data    iTwoj/1,2,4,8,16,32,64,128/
 *
       Integer i,j,ixyz,nElem,iTri,nGrid,
-     &        iRout,iPrint,ia,iAng,ib,iBas,iAO,iCff,iCmp,iCnttp,iComp,
-     &        iCurCenter,iCurCnttp,iCurMdc,iExp,iIC,iIrrep,iLoc,iPrim,
+     &        iAng,iBas,iAO,iCmp,iCnttp,iComp,
+     &        iCurCenter,iCurCnttp,iCurMdc,iIC,iIrrep,iLoc,iPrim,
      &        ip,ipF1,ipF2,ipIJ,ipK1,ipK2,ipP1,ipP2,ipTmp,ipZ1,ipZ2,
      &        ipZI1,ipZI2,iS,iSbasis,iSend,iShell,iShll,iSize,iSlocal,
-     &        iSstart,iStemp,jAng,jAO,jBas,jCff,jCmp,jCnttp,jExp,jPrim,
-     &        jS,jShell,jShll,jSize,jSlocal,jxyz,lDCRT,llOper,LmbdT,
-     &        mArr,maxDensSize,mdci,mdcj,nac,ncb,nDCRT,nHer,nOp,nSkal,
-     &        jSbasis
-      Real*8  Fact,Factor,PtChrg,Xg
+     &        iSstart,iStemp,jAng,jAO,jBas,jCmp,jCnttp,jPrim,
+     &        jS,jShell,jShll,jSize,jSlocal,lDCRT,llOper,LmbdT,
+     &        mArr,maxDensSize,mdci,mdcj,nac,ncb,nDCRT,nOp,nSkal,
+     &        jSbasis,iCnt,jCnt
+      Real*8  Fact,Factor,Xg
 * external functions:
       Integer NrOpr
       Real*8  DNRM2_
@@ -120,42 +105,39 @@ c      Character*80 Label
       nElem(ixyz) = (ixyz+1)*(ixyz+2)/2
       iTri(i,j) = Max(i,j)*(Max(i,j)-1)/2 + Min(i,j)
 *
-      iRout = 202
-      iPrint = nPrint(iRout)
-*
-      If (iPrint.ge.49) Then
-c data for individual fragments:
-         Write (6,*) ' In FragPInt:    nCnttp          = ',nCnttp
-         Write (6,*) ' In FragPInt: mdciCnttp(nCnttp)  = ',
-     &                                    (mdciCnttp(i),i=1,nCnttp)
-         Write (6,*) ' In FragPInt:     nCntr(nCnttp)  = ',
-     &                                        (nCntr(i),i=1,nCnttp)
-         Write (6,*) ' In FragPInt: nFragType(nCnttp)  = ',
-     &                                    (nFragType(i),i=1,nCnttp)
-         Write (6,*) ' In FragPInt: nFragCoor(nCnttp)  = ',
-     &                                    (nFragCoor(i),i=1,nCnttp)
-         Write (6,*) ' In FragPInt: nFragDens(nCnttp)  = ',
-     &                                    (nFragDens(i),i=1,nCnttp)
-         Write (6,*) ' In FragPInt: nFragDens(nCnttp)  = ',
-     &                                    (nFragDens(i),i=1,nCnttp)
+#ifdef _DEBUGPRINT_
+c     data for individual fragments:
+      Write (6,*) ' In FragPInt:    nCnttp          = ',nCnttp
+      Write (6,*) ' In FragPInt: dbsc(nCnttp)%mdci  = ',
+     &                                 (dbsc(i)%mdci,i=1,nCnttp)
+      Write (6,*) ' In FragPInt:     dbsc(nCnttp)%nCntr  = ',
+     &                                     (dbsc(i)%nCntr,i=1,nCnttp)
+      Write (6,*) ' In FragPInt: nFragType(nCnttp)  = ',
+     &                                 (dbsc(i)%nFragType,i=1,nCnttp)
+      Write (6,*) ' In FragPInt: nFragCoor(nCnttp)  = ',
+     &                                 (dbsc(i)%nFragCoor,i=1,nCnttp)
+      Write (6,*) ' In FragPInt: nFragDens(nCnttp)  = ',
+     &                                 (dbsc(i)%nFragDens,i=1,nCnttp)
+      Write (6,*) ' In FragPInt: nFragDens(nCnttp)  = ',
+     &                                 (dbsc(i)%nFragDens,i=1,nCnttp)
 c
-         Write (6,*) ' In FragPInt: nAlpha,nBeta=',' ',nAlpha,nBeta
-         Write (6,*) ' In FragPInt: Alpha=',' ',Alpha
-         Write (6,*) ' In FragPInt: Beta=',' ',Beta
+      Write (6,*) ' In FragPInt: nAlpha,nBeta=',' ',nAlpha,nBeta
+      Write (6,*) ' In FragPInt: Alpha=',' ',Alpha
+      Write (6,*) ' In FragPInt: Beta=',' ',Beta
 c
-         Write (6,*) ' In FragPInt: nZeta=',' ',nZeta
-         Write (6,*) ' In FragPInt:  nArr=',' ',nArr
-         Write (6,*) ' In FragPInt:   nIC=',' ',nIC
-         Write (6,*) ' In FragPInt: la,lb=',' ',la,lb
-         Write (6,*) ' In FragPInt: nElem(la)=',' ',nElem(la)
-         Write (6,*) ' In FragPInt: nElem(lb)=',' ',nElem(lb)
-c         Call RecPrt(' In FragPInt: A     ',' ',A     ,1,3)
-         Call RecPrt(' In FragPInt: RB    ',' ',RB    ,1,3)
-         Call RecPrt(' In FragPInt: Ccoor ',' ',Ccoor ,1,3)
-c         Call RecPrt(' In FragPInt: P     ',' ',P     ,nZeta,3)
-c         Call RecPrt(' In FragPInt: Array ',' ',Array,nZeta,nArr)
-c         Call TrcPrt(' In FragPInt: Array ',' ',Array,nZeta,nArr)
-      End If
+      Write (6,*) ' In FragPInt: nZeta=',' ',nZeta
+      Write (6,*) ' In FragPInt:  nArr=',' ',nArr
+      Write (6,*) ' In FragPInt:   nIC=',' ',nIC
+      Write (6,*) ' In FragPInt: la,lb=',' ',la,lb
+      Write (6,*) ' In FragPInt: nElem(la)=',' ',nElem(la)
+      Write (6,*) ' In FragPInt: nElem(lb)=',' ',nElem(lb)
+      Call RecPrt(' In FragPInt: A     ',' ',A     ,1,3)
+      Call RecPrt(' In FragPInt: RB    ',' ',RB    ,1,3)
+      Call RecPrt(' In FragPInt: Ccoor ',' ',Ccoor ,1,3)
+      Call RecPrt(' In FragPInt: P     ',' ',P     ,nZeta,3)
+      Call RecPrt(' In FragPInt: Array ',' ',Array,nZeta,nArr)
+      Call TrcPrt(' In FragPInt: Array ',' ',Array,nZeta,nArr)
+#endif
 *
       Call dcopy_(nZeta*nElem(la)*nElem(lb)*nIC,[Zero],0,Final,1)
 *                                                                      *
@@ -167,8 +149,9 @@ c         Call TrcPrt(' In FragPInt: Array ',' ',Array,nZeta,nArr)
       Call Set_Basis_Mode('Fragments')
       Call SetUp_iSD
       Call Nr_Shells(nSkal)
-      If (iPrint.ge.49) print *, 'nSkal_Fragment,nAlpha,nBeta = ',
-     &                              nSkal,nAlpha,nBeta
+#ifdef _DEBUGPRINT_
+      Write(6,*)'nSkal_Fragment,nAlpha,nBeta = ',nSkal,nAlpha,nBeta
+#endif
 *                                                                      *
 ************************************************************************
 *                                                                      *
@@ -176,11 +159,13 @@ c         Call TrcPrt(' In FragPInt: Array ',' ',Array,nZeta,nArr)
 * density matrix and one combination of shells of it.
       maxDensSize = 0
       Do iCnttp = 1, nCnttp
-        If(nFragType(iCnttp).gt.0) then
-        maxDensSize = Max( maxDensSize,
-     &                     nFragDens(iCnttp)*(nFragDens(iCnttp)+1)/2)
-c        write(6,'(A,i2,A,i6)') 'nFragDens(',iCnttp,')=',
-c     &                                              nFragDens(iCnttp)
+        If(dbsc(iCnttp)%nFragType.gt.0) then
+        maxDensSize = Max( maxDensSize,dbsc(iCnttp)%nFragDens
+     &                               *(dbsc(iCnttp)%nFragDens+1)/2)
+#ifdef _DEBUGPRINT_
+        write(6,'(A,i2,A,i6)') 'nFragDens(',iCnttp,')=',
+     &                                           dbsc(iCnttp)%nFragDens
+#endif
         endif
       End Do
 *                                                                      *
@@ -207,42 +192,41 @@ c     ! The basis function index relative to the start of the fragment
         iAng   = iSD( 1,iS)
         iCmp   = iSD( 2,iS)
         iBas   = iSD( 3,iS)
-        iCff   = iSD( 4,iS)
         iPrim  = iSD( 5,iS)
-        iExp   = iSD( 6,iS)
         iAO    = iSD( 7,iS)
-        ixyz   = iSD( 8,iS)
         mdci   = iSD(10,iS)
         iShell = iSD(11,iS)
         iCnttp = iSD(13,iS)
+        iCnt   = iSD(14,iS)
         iSize = nElem(iAng)
+        C(1:3)=dbsc(iCnttp)%Coor(1:3,iCnt)
 c some printouts:
-c      If (iPrint.ge.49) Then
-c        print *, 'In FragPInt: iS=',iS,' iShll =',iShll
-c        print *, 'In FragPInt: iS=',iS,' iAng  =',iAng
-c        print *, 'In FragPInt: iS=',iS,' iCmp  =',iCmp
-c        print *, 'In FragPInt: iS=',iS,' iBas  =',iBas
-c        print *, 'In FragPInt: iS=',iS,' iCff  =',iCff
-c        print *, 'In FragPInt: iS=',iS,' iPrim =',iPrim
-c        print *, 'In FragPInt: iS=',iS,' iExp  =',iExp
-c        print *, 'In FragPInt: iS=',iS,' iAO   =',iAO
-c        print *, 'In FragPInt: iS=',iS,' ixyz  =',ixyz
-c        print *, 'In FragPInt: iS=',iS,' mdci  =',mdci
-c        print *, 'In FragPInt: iS=',iS,' iShell=',iShell
-c        print *, 'In FragPInt: iS=',iS,' iCnttp=',iCnttp
-c        print *, 'In FragPInt: iS=',iS,' iSize =',iSize
-c        print *, 'In FragPInt: iS=',iS,' iCurMdc =',iCurMdc
-c        print *, 'In FragPInt: nFragCoor(',mdci,') =',nFragCoor(mdci)
-c      End If
+#ifdef _DEBUGPRINT_
+        Write(6,*) 'In FragPInt: iS=',iS,' iShll =',iShll
+        Write(6,*) 'In FragPInt: iS=',iS,' iAng  =',iAng
+        Write(6,*) 'In FragPInt: iS=',iS,' iCmp  =',iCmp
+        Write(6,*) 'In FragPInt: iS=',iS,' iBas  =',iBas
+        Write(6,*) 'In FragPInt: iS=',iS,' iPrim =',iPrim
+        Write(6,*) 'In FragPInt: iS=',iS,' iAO   =',iAO
+        Write(6,*) 'In FragPInt: iS=',iS,' ixyz  =',ixyz
+        Write(6,*) 'In FragPInt: iS=',iS,' mdci  =',mdci
+        Write(6,*) 'In FragPInt: iS=',iS,' iShell=',iShell
+        Write(6,*) 'In FragPInt: iS=',iS,' iCnttp=',iCnttp
+        Write(6,*) 'In FragPInt: iS=',iS,' iSize =',iSize
+        Write(6,*) 'In FragPInt: iS=',iS,' iCurMdc =',iCurMdc
+        Write(6,*) 'In FragPInt: nFragCoor(',iCnttp,') =',
+     &            dbsc(iCnttp)%nFragCoor
+#endif
 
-        If(Transf(iShll).and.Prjct(iShll)) iSize = 2*iAng+1
-        If(nFragCoor(mdci).ne.iCurMdc) Then
+        If(Shells(iShll)%Transf.and.
+     &     Shells(iShll)%Prjct ) iSize = 2*iAng+1
+        If(Abs(dbsc(iCnttp)%nFragCoor).ne.iCurMdc) Then
 * update fragment related quantities
-          iCurMdc = nFragCoor(mdci)
+          iCurMdc = Abs(dbsc(iCnttp)%nFragCoor)
           iSstart = iS
           iSend = nSkal
           Do iStemp = iSstart + 1,nSkal
-            If(nFragCoor(iSD(10,iStemp)).ne.iCurMdc) Then
+            If(Abs(dbsc(iSD(13,iStemp))%nFragCoor).ne.iCurMdc) Then
               iSend = iStemp - 1
               goto 101
             End If
@@ -251,16 +235,16 @@ c      End If
           iSbasis= 1
           iCurCenter = iCurCenter + 1
 
-      If (iPrint.ge.49) Then
-         write(6,*) 'start of new fragment encountered'
-         write(6,*) 'iSstart,iSend,iCurCnttp,iCurCenter =',
-     &               iSstart,iSend,iCurCnttp,iCurCenter
-      End If
+#ifdef _DEBUGPRINT_
+      write(6,*) 'start of new fragment encountered'
+      write(6,*) 'iSstart,iSend,iCurCnttp,iCurCenter =',
+     &            iSstart,iSend,iCurCnttp,iCurCenter
+#endif
 
-          If(iCurCenter.gt.nCntr(iCurCnttp)) Then
+          If(iCurCenter.gt.dbsc(iCurCnttp)%nCntr) Then
             iCurCenter = 1
             Do jCnttp = iCurCnttp+1, nCnttp
-              If(nFragType(jCnttp).gt.0) Then
+              If(dbsc(jCnttp)%nFragType.gt.0) Then
                 iCurCnttp = jCnttp
                 goto 102
               End If
@@ -269,75 +253,74 @@ c      End If
  102        Continue
 * update the energy weighted density matrix of the current fragment
             EnergyWeight = .true.
-c            write(6,*) 'Calling MakeDens 1: iCurCnttp=',iCurCnttp
-c            write(6,*) 'nFragDens(iCurCnttp)=',nFragDens(iCurCnttp)
-c            write(6,*) 'nFragEner(iCurCnttp)=',nFragEner(iCurCnttp)
-c           Call MakeDens(                nBas,                nOrb,
-c                                     Cff,                      OrbEn,
-c             EnergyWeight, Dens)
-            Call MakeDens(nFragDens(iCurCnttp),nFragEner(iCurCnttp),
-     &        Work(ipFragCoef(iCurCnttp)),Work(ipFragEner(iCurCnttp)),
-     &        EnergyWeight,Array)
-            If(iPrint.ge.49) Call TriPrt('Energy weighted fragment dens'
-     &                                  ,' ',Array,nFragDens(iCurCnttp))
+            Call MakeDens(dbsc(iCurCnttp)%nFragDens,
+     &                    dbsc(iCurCnttp)%nFragEner,
+     &                    dbsc(iCurCnttp)%FragCoef,
+     &                    dbsc(iCurCnttp)%FragEner,
+     &                    EnergyWeight,Array)
+#ifdef _DEBUGPRINT_
+            Call TriPrt('Energy weighted fragment dens',' ',
+     &                   Array,dbsc(iCurCnttp)%nFragDens)
+#endif
 * include the minus sign of -2eta_i
-            Call DScal_(nFragDens(iCurCnttp)*(nFragDens(iCurCnttp)+1)/2,
-     &                 -One,Array,1)
-            If(iPrint.ge.49)
-     &                    Call TriPrt('-1 Energy weighted fragment dens'
-     &                                  ,' ',Array,nFragDens(iCurCnttp))
-            If(maxDensSize.lt.nFragDens(iCurCnttp)*
-     &         (nFragDens(iCurCnttp)+1)/2) Call Abend !'maxIJSize'
+            Call DScal_(dbsc(iCurCnttp)%nFragDens
+     &                *(dbsc(iCurCnttp)%nFragDens+1)/2,-One,Array,1)
+#ifdef _DEBUGPRINT_
+            Call TriPrt('-1 Energy weighted fragment dens',' ',
+     &                  Array,dbsc(iCurCnttp)%nFragDens)
+#endif
+            If (maxDensSize.lt.dbsc(iCurCnttp)%nFragDens*
+     &                        (dbsc(iCurCnttp)%nFragDens+1)/2)
+     &         Call Abend !'maxIJSize'
           End If
         End If
-        call dcopy_(3,Work(ixyz),1,C,1)
-c       write(*,*) '  iShll,iAng,mdci,iShell,iCnttp,iCurMdc,iCurCnttp',
-c    &              iShll,iAng,mdci,iShell,iCnttp,iCurMdc,iCurCnttp
-c       write(*,*) '  iPrim,iBas =',iPrim,iBas
+#ifdef _DEBUGPRINT_
+       write(6,*) '  iShll,iAng,mdci,iShell,iCnttp,iCurMdc,iCurCnttp',
+     &              iShll,iAng,mdci,iShell,iCnttp,iCurMdc,iCurCnttp
+       write(6,*) '  iPrim,iBas =',iPrim,iBas
+#endif
 *                                                                      *
 ************************************************************************
 *                                                                      *
 * Loop over all other shells belonging to the same fragment
         jSbasis = 1
-      If (iPrint.ge.49) Then
+#ifdef _DEBUGPRINT_
       write(6,'(3(A,i4))') 'iS = ',iS,' iSstart=',iSstart,' iSEnd=',
      &                      iSend
-      End If
+#endif
         Do jS = iSstart, iSend
           jShll  = iSD( 0,jS)
           jAng   = iSD( 1,jS)
           jCmp   = iSD( 2,jS)
           jBas   = iSD( 3,jS)
-          jCff   = iSD( 4,jS)
           jPrim  = iSD( 5,jS)
-          jExp   = iSD( 6,jS)
           jAO    = iSD( 7,iS)
-          jxyz   = iSD( 8,jS)
           mdcj   = iSD(10,jS)
           jShell = iSD(11,jS)
           jCnttp = iSD(13,jS)
+          jCnt   = iSD(14,jS)
           jSize = nElem(jAng)
-      If (iPrint.ge.49) Then
+          B(1:3) = dbsc(jCnttp)%Coor(1:3,jCnt)
+#ifdef _DEBUGPRINT_
         write(6,'(A,i6,A,i16)') 'In FragPInt: jS=',jS,' jShll =',jShll
         write(6,'(A,i6,A,i16)') 'In FragPInt: jS=',jS,' jAng  =',jAng
         write(6,'(A,i6,A,i16)') 'In FragPInt: jS=',jS,' jCmp  =',jCmp
         write(6,'(A,i6,A,i16)') 'In FragPInt: jS=',jS,' jBas  =',jBas
-        write(6,'(A,i6,A,i16)') 'In FragPInt: jS=',jS,' jCff  =',jCff
         write(6,'(A,i6,A,i16)') 'In FragPInt: jS=',jS,' jPrim =',jPrim
-        write(6,'(A,i6,A,i16)') 'In FragPInt: jS=',jS,' jExp  =',jExp
         write(6,'(A,i6,A,i16)') 'In FragPInt: jS=',jS,' jAO   =',jAO
-        write(6,'(A,i6,A,i16)') 'In FragPInt: jS=',jS,' jxyz  =',jxyz
         write(6,'(A,i6,A,i16)') 'In FragPInt: jS=',jS,' mdcj  =',mdcj
         write(6,'(A,i6,A,i16)') 'In FragPInt: jS=',jS,' jShell=',jShell
         write(6,'(A,i6,A,i16)') 'In FragPInt: jS=',jS,' jCnttp=',jCnttp
         write(6,'(A,i6,A,i16)') 'In FragPInt: jS=',jS,' jSize =',jSize
-       End If
+#endif
 
-          if(Transf(jShll).and.Prjct(jShll)) jSize = 2*jAng+1
-          call dcopy_(3,Work(jxyz),1,B,1)
-c         write(*,*) '    jShll,jAng,mdcj,jShell,jCnttp =',
-c     &                    jShll,jAng,mdcj,jShell,jCnttp
-c         write(*,*) '    jPrim,jBas =',jPrim,jBas
+          if(Shells(jShll)%Transf.and.
+     &       Shells(jShll)%Prjct ) jSize = 2*jAng+1
+#ifdef _DEBUGPRINT_
+         write(6,*) '    jShll,jAng,mdcj,jShell,jCnttp =',
+     &                    jShll,jAng,mdcj,jShell,jCnttp
+         write(6,*) '    jPrim,jBas =',jPrim,jBas
+#endif
 *                                                                      *
 ************************************************************************
 *                                                                      *
@@ -346,33 +329,39 @@ c         write(*,*) '    jPrim,jBas =',jPrim,jBas
 * contains values from iSbasis to iSbasis + iBas*nElem(iAng) - 1
 *             and from jSbasis to jSbasis + jBas*nElem(jAng) - 1
            ipIJ = 1 + maxDensSize
-c          write(6,*) '    ipIJ=',ipIJ
-c          write(6,*) '    extracting values from',iSbasis,' to',iSbasis
-c     &                + iBas*iSize - 1,', and from',jSbasis,' to',
-c     &                jSbasis + jBas*jSize - 1
+#ifdef _DEBUGPRINT_
+           write(6,*) '    ipIJ=',ipIJ
+           write(6,*) '    extracting values from',iSbasis,' to',iSbasis
+     &                + iBas*iSize - 1,', and from',jSbasis,' to',
+     &                jSbasis + jBas*jSize - 1
+#endif
            Do iSlocal = iSbasis, iSbasis + iBas*iSize - 1
              Do jSlocal = jSbasis, jSbasis + jBas*jSize - 1
                iLoc = ipIJ + (jSlocal-jSbasis)*iBas*iSize + iSlocal
      &                - iSbasis
-c               write(6,'(A,i3,A,i3,A,i4,A,i8)')
-c     &         'iTri(',iSlocal,',',jSlocal,')=',iTri(iSlocal,jSlocal),
-c     &        ' iLoc=',iLoc
+#ifdef _DEBUGPRINT_
+                write(6,'(A,i3,A,i3,A,i4,A,i8)')
+     &         'iTri(',iSlocal,',',jSlocal,')=',iTri(iSlocal,jSlocal),
+     &        ' iLoc=',iLoc
+#endif
                Array(iLoc) = Array(iTri(iSlocal,jSlocal))
                If(iSlocal.ne.jSlocal) Array(iLoc) = Array(iLoc)/Two
-c              write(*,*) 'Filling (',iSlocal-iSbasis+1,',',
-c    &           jSlocal-jSbasis+1,') from (',iSlocal,',',jSlocal,')'
+#ifdef _DEBUGPRINT_
+               write(6,*) 'Filling (',iSlocal-iSbasis+1,',',
+     &           jSlocal-jSbasis+1,') from (',iSlocal,',',jSlocal,')'
+#endif
              End Do
            End Do
-           If(iPrint.ge.99) Call RecPrt('W(KC,LD)',
-     &        ' ',Array(ipIJ),iBas*iSize,jBas*jSize)
-
+#ifdef _DEBUGPRINT_
+           Call RecPrt('W(KC,LD)',' ',Array(ipIJ),iBas*iSize,jBas*jSize)
+#endif
 *                                                                      *
 ************************************************************************
 *                                                                      *
 * DCR stuff (iS and jS have always the same symmetry character)
 *
-          Call DCR(LmbdT,iOper,nIrrep,iStabM,nStabM,
-     &             jStab(0,mdci),nStab(mdci),iDCRT,nDCRT)
+          Call DCR(LmbdT,iStabM,nStabM,
+     &                   dc(mdci)%iStab,dc(mdci)%nStab,iDCRT,nDCRT)
           Fact = DBLE(nStabM) / DBLE(LmbdT)
 *                                                                      *
 ************************************************************************
@@ -380,12 +369,8 @@ c    &           jSlocal-jSbasis+1,') from (',iSlocal,',',jSlocal,')'
 * Loop over symmetry operations acting on the basis.
 *
           Do lDCRT = 0, nDCRT-1
-            TC(1) = iPhase(1,iDCRT(lDCRT))*C(1)
-            TC(2) = iPhase(2,iDCRT(lDCRT))*C(2)
-            TC(3) = iPhase(3,iDCRT(lDCRT))*C(3)
-            TB(1) = iPhase(1,iDCRT(lDCRT))*B(1)
-            TB(2) = iPhase(2,iDCRT(lDCRT))*B(2)
-            TB(3) = iPhase(3,iDCRT(lDCRT))*B(3)
+            Call OA(iDCRT(lDCRT),C,TC)
+            Call OA(iDCRT(lDCRT),B,TB)
 
 *                                                                      *
 ************************************************************************
@@ -411,19 +396,21 @@ c    &           jSlocal-jSbasis+1,') from (',iSlocal,',',jSlocal,')'
             mArr = (nArr*nZeta-(ip-1))/nZeta
 *
             Call ZXia(Array(ipZ1),Array(ipZI1),nAlpha,iPrim,
-     &                Alpha,Work(iExp))
-            Call SetUp1(Alpha,nAlpha,Work(iExp),iPrim,
+     &                Alpha,Shells(iShll)%Exp)
+            Call SetUp1(Alpha,nAlpha,Shells(iShll)%Exp,iPrim,
      &                  A,TC,Array(ipK1),Array(ipP1),Array(ipZI1))
 *
             nHer = (la+iAng+2)/2
-            Call MltPrm(Alpha,nAlpha,Work(iExp),iPrim,
+            Call MltPrm(Alpha,nAlpha,Shells(iShll)%Exp,iPrim,
      &                Array(ipZ1),Array(ipZI1),
      &                Array(ipK1),Array(ipP1),
      &                Array(ipF1),nAlpha*iPrim,iComp,
      &              la,iAng,A,TC,nHer,Array(ip),
      &              mArr,CCoor,nOrdOp)
-            If(iPrint.ge.99) Call RecPrt('<alpha|iS> (aBas x X)',
+#ifdef _DEBUGPRINT_
+            Call RecPrt('<alpha|iS> (aBas x X)',
      &        ' ',Array(ipF1),nAlpha*iPrim,nac)
+#endif
 *                                                                      *
 ************************************************************************
 *                                                                      *
@@ -448,12 +435,12 @@ c    &           jSlocal-jSbasis+1,') from (',iSlocal,',',jSlocal,')'
             mArr = (nArr*nZeta-(ip-1))/nZeta
 *
             Call ZXia(Array(ipZ2),Array(ipZI2),jPrim,nBeta,
-     &                Work(jExp),Beta)
-            Call SetUp1(Work(jExp),jPrim,Beta,nBeta,
+     &                Shells(jShll)%Exp,Beta)
+            Call SetUp1(Shells(jShll)%Exp,jPrim,Beta,nBeta,
      &                 TB,RB,Array(ipK2),Array(ipP2),Array(ipZI2))
 *
             nHer = (jAng+lb+2)/2
-            Call MltPrm(Work(jExp),jPrim,Beta,nBeta,
+            Call MltPrm(Shells(jShll)%Exp,jPrim,Beta,nBeta,
      &                Array(ipZ2),Array(ipZI2),
      &                Array(ipK2),Array(ipP2),
      &                Array(ipF2),jPrim*nBeta,iComp,
@@ -467,8 +454,10 @@ c    &           jSlocal-jSbasis+1,') from (',iSlocal,',',jSlocal,')'
                Write (6,*) '  ip-1.gt.nArr*nZeta(3) in FragPInt'
                Call Abend
             End If
-            If(iPrint.ge.99) Call RecPrt('<jS|beta> (bBas x Y)',
+#ifdef _DEBUGPRINT_
+            Call RecPrt('<jS|beta> (bBas x Y)',
      &        ' ',Array(ipF2),nBeta*jPrim,ncb)
+#endif
             If((ipTmp-ipF2).lt.nBeta*jPrim*ncb) stop 'sizetest 1'
 *                                                                      *
 ************************************************************************
@@ -494,24 +483,26 @@ c    &           jSlocal-jSbasis+1,') from (',iSlocal,',',jSlocal,')'
 *
             Call DgeTMo(Array(ipF1),nAlpha,nAlpha,
      &                  iPrim*nac,Array(ipTmp),iPrim*nac)
-            If(iPrint.ge.99) Call RecPrt('<alpha|iS>^T (X x aBas)',
+#ifdef _DEBUGPRINT_
+            Call RecPrt('<alpha|iS>^T (X x aBas)',
      &        ' ',Array(ipTmp),iPrim*nac,nAlpha)
+#endif
             If((ip-ipTmp).lt.nAlpha*iPrim*nac) stop 'sizetest 2'
 *
 *-----------2) aciK =  k,aci * k,K
 *
             Call DGEMM_('T','N', nac*nAlpha, iBas, iPrim,
      &                  1.0d0, Array(ipTmp),       iPrim,
-     &                          Work(iCff ),       iPrim,
+     &                         Shells(iShll)%pCff, iPrim,
      &                  0.0d0, Array(ipF1 ),  nAlpha*nac  )
-            If(iPrint.ge.99) Then
-              Call RecPrt('<alpha|iS>(regrouped, X x iPrim)',' ',
+#ifdef _DEBUGPRINT_
+             Call RecPrt('<alpha|iS>(regrouped, X x iPrim)',' ',
      &                    Array(ipTmp),nAlpha*nac,iPrim)
-              Call RecPrt('Coeffs of iS (iPrim x iBas)',' ',Work(iCff),
-     &                    iPrim,iBas)
+             Call RecPrt('Coeffs of iS (iPrim x iBas)',' ',
+     &                    Shells(iShll)%pCff,iPrim,iBas)
              Call RecPrt('<alpha|iS>(re) * Coeffs of iS (X x iBas)',' ',
      &                   Array(ipF1),nAlpha*nac,iBas)
-            End If
+#endif
             If((ipF2-ipF1).lt.nAlpha*iBas*nac) stop 'sizetest 3'
 *
 *-----------4) a,ciK -> ciKa
@@ -520,31 +511,32 @@ c    &           jSlocal-jSbasis+1,') from (',iSlocal,',',jSlocal,')'
      &                  nElem(iAng)*nAlpha*iBas,
      &                  Array(ipTmp),
      &                  nElem(iAng)*nAlpha*iBas)
-            If(iPrint.ge.99) Then
-              Call RecPrt('result (regrouped, nElem(la) x X)',' ',
-     &                  Array(ipF1),nElem(la),nElem(iAng)*nAlpha*iBas)
-              Call RecPrt('transpose of result (X x nElem(la))',' ',
-     &                  Array(ipTmp),nElem(iAng)*nAlpha*iBas,nElem(la))
-            End If
+#ifdef _DEBUGPRINT_
+            Call RecPrt('result (regrouped, nElem(la) x X)',' ',
+     &                Array(ipF1),nElem(la),nElem(iAng)*nAlpha*iBas)
+            Call RecPrt('transpose of result (X x nElem(la))',' ',
+     &                Array(ipTmp),nElem(iAng)*nAlpha*iBas,nElem(la))
+#endif
             If((ip-ipTmp).lt.nAlpha*iBas*nElem(iAng)*nElem(la))
      &        stop 'sizetest 6'
 *
 *-----------5) iKa,C = c,iKa * c,C
 *
-            If(Transf(iShll).and.Prjct(iShll)) Then
+            If(Shells(iShll)%Transf.and.
+     &         Shells(iShll)%Prjct ) Then
               Call DGEMM_('T','N',
      &                    iBas*nElem(la)*nAlpha,iSize,nElem(iAng),
      &                    1.0d0,Array(ipTmp),nElem(iAng),
      &                    RSph(ipSph(iAng)),nElem(iAng),
      &                    0.0d0,Array(ipF1),nAlpha*iBas*nElem(la))
-              If(iPrint.ge.99) Then
-                Call RecPrt('result (regrouped, X x nElem(iAng))',' ',
-     &                   Array(ipTmp),nElem(la)*nAlpha*iBas,nElem(iAng))
-                Call RecPrt('Spher of iS (nElem(iAng) x (2*iAng+1))',' '
-     &                      ,RSph(ipSph(iAng)),nElem(iAng),(2*iAng+1))
-                Call RecPrt('result in spherical gaussians (X x iSize',
-     &                    ' ',Array(ipF1),nAlpha*iBas*nElem(la),iSize)
-              End If
+#ifdef _DEBUGPRINT_
+              Call RecPrt('result (regrouped, X x nElem(iAng))',' ',
+     &                 Array(ipTmp),nElem(la)*nAlpha*iBas,nElem(iAng))
+              Call RecPrt('Spher of iS (nElem(iAng) x (2*iAng+1))',' '
+     &                    ,RSph(ipSph(iAng)),nElem(iAng),(2*iAng+1))
+              Call RecPrt('result in spherical gaussians (X x iSize',
+     &                  ' ',Array(ipF1),nAlpha*iBas*nElem(la),iSize)
+#endif
             Else
 * in this case nElem(iAng) = iSize
               Call DgeTMo(Array(ipTmp),nElem(iAng),nElem(iAng),
@@ -561,17 +553,16 @@ c    &           jSlocal-jSbasis+1,') from (',iSlocal,',',jSlocal,')'
             Call DGEMM_('T','N',
      &                  nBeta*ncb,jBas,jPrim,
      &                  1.0d0,Array(ipF2),jPrim,
-     &                  Work(jCff),jPrim,
+     &                        Shells(jShll)%pCff,jPrim,
      &                  0.0d0,Array(ipTmp),nBeta*ncb)
-            If(iPrint.ge.99) Then
-              Call RecPrt('<jS|beta>(regrouped, X x jPrim)',' ',
-     &                    Array(ipF2),nBeta*ncb,jPrim)
-              Call RecPrt('Coeffs of jS (jPrim x jBas)',' ',Work(jCff),
-     &                    jPrim,jBas)
-              Call RecPrt('<jS|beta>(re) * Coeffs of jS (Y x jBas)',' ',
-     &                   Array(ipTmp),nBeta*ncb,jBas)
-
-            End If
+#ifdef _DEBUGPRINT_
+            Call RecPrt('<jS|beta>(regrouped, X x jPrim)',' ',
+     &                  Array(ipF2),nBeta*ncb,jPrim)
+            Call RecPrt('Coeffs of jS (jPrim x jBas)',' ',
+     &                   Shells(jShll)%pCff,jPrim,jBas)
+            Call RecPrt('<jS|beta>(re) * Coeffs of jS (Y x jBas)',' ',
+     &                 Array(ipTmp),nBeta*ncb,jBas)
+#endif
             If((ip-ipTmp).lt.nBeta*jBas*ncb) stop 'sizetest 8'
 *
 *-----------2)  j,dbL -> dbL,j
@@ -579,21 +570,25 @@ c    &           jSlocal-jSbasis+1,') from (',iSlocal,',',jSlocal,')'
             Call DgeTMo(Array(ipTmp),nBeta,nBeta,
      &                  jBas*ncb,Array(ipF2),
      &                  jBas*ncb)
-            If(iPrint.ge.99) Call RecPrt('transposed right 1 (Y x bBas)'
-     &        ,' ',Array(ipF2),jBas*ncb,nBeta)
+#ifdef _DEBUGPRINT_
+            Call RecPrt('transposed right 1 (Y x bBas)',
+     &         ' ',Array(ipF2),jBas*ncb,nBeta)
+#endif
             If((ipTmp-ipF2).lt.nBeta*jBas*ncb) stop 'sizetest 9'
 *
 *-----------3) bLj,D = d,bLj * d,D
 *
-            If(Transf(jShll).and.Prjct(jShll)) Then
+            If(Shells(jShll)%Transf.and.
+     &         Shells(jShll)%Prjct ) Then
               Call DGEMM_('T','N',
      &                    nElem(lb)*jBas*nBeta,jSize,nElem(jAng),
      &                    1.0d0,Array(ipF2),nElem(jAng),
      &                    RSph(ipSph(jAng)),nElem(jAng),
      &                    0.0d0,Array(ipTmp),nElem(lb)*jBas*nBeta)
-              If(iPrint.ge.99)
-     &          Call RecPrt('multiply right 2 (Y x jSize)',' ',
-     &                      Array(ipTmp),nBeta*jBas*nElem(lb),jSize)
+#ifdef _DEBUGPRINT_
+              Call RecPrt('multiply right 2 (Y x jSize)',' ',
+     &                    Array(ipTmp),nBeta*jBas*nElem(lb),jSize)
+#endif
             Else
 * in this case nElem(jAng) = jSize
               Call DgeTMo(Array(ipF2),nElem(jAng),nElem(jAng),
@@ -609,10 +604,10 @@ c    &           jSlocal-jSbasis+1,') from (',iSlocal,',',jSlocal,')'
             Call DgeTMo(Array(ipTmp),nElem(lb),nElem(lb),
      &                  jBas*nBeta*jSize,Array(ipF2),
      &                  jBas*nBeta*jSize)
-            If(iPrint.ge.99) Then
-              Call RecPrt('transposed right 2 (Y x nElem(lb)',' ',
-     &                    Array(ipF2),jBas*nBeta*jSize,nElem(lb))
-            End If
+#ifdef _DEBUGPRINT_
+            Call RecPrt('transposed right 2 (Y x nElem(lb)',' ',
+     &                  Array(ipF2),jBas*nBeta*jSize,nElem(lb))
+#endif
 
             If((ipTmp-ipF2).lt.nBeta*jBas*nElem(lb)*jSize)
      &        stop 'sizetest 11'
@@ -631,22 +626,22 @@ c    &           jSlocal-jSbasis+1,') from (',iSlocal,',',jSlocal,')'
 *               ipF2 = nBeta*nElem(lb)  * jBas*jSize                (jBas,   nBeta, jSize,     nElem(lb))
 *                  W = iBas*iSize * jBas*jSize                      (iBas,   iSize, jBas,      jSize)
 *
-            If(iPrint.ge.100) Then
-              Write (6,*) ' Current contents of Final():'
-              Do ia = 1, nElem(la)
-                Do ib = 1, nElem(lb)
-                  Write (Label,'(A,I2,A,I2,A)') ' Final(',ia,',',ib,')'
-                  Call RecPrt(Label,' ',Final(:,ia,ib,:),nAlpha,nBeta)
-                End Do
+#ifdef _DEBUGPRINT_
+            Write (6,*) ' Current contents of Final():'
+            Do ia = 1, nElem(la)
+              Do ib = 1, nElem(lb)
+                Write (Label,'(A,I2,A,I2,A)') ' Final(',ia,',',ib,')'
+                Call RecPrt(Label,' ',Final(:,ia,ib,:),nAlpha,nBeta)
               End Do
-            End If
+            End Do
+#endif
 
             iIC = 0
             Do iIrrep = 0, nIrrep - 1
               If (iAnd(llOper,iTwoj(iIrrep)).ne.0) Then
                 iIC = iIC + 1
-                nOp = NrOpr(iDCRT(lDCRT),iOper,nIrrep)
-                Xg=rChTbl(iIrrep,nOp)
+                nOp = NrOpr(iDCRT(lDCRT))
+                Xg=DBLE(iChTbl(iIrrep,nOp))
 * Half is needed because we do a complete loop over iS,jS
                 Factor=Xg*Fact*Half
                 ! write(6,'(A,i24)') 'FragPInt:  ipIJ=', ipIJ
@@ -661,15 +656,15 @@ c     &                         Array(ipIJ), Final(1,1,1,iIC), Factor)
             End Do
             If(iIC.ne.nIC) stop 'iIC.ne.nIC'
 
-            If(iPrint.ge.99) Then
-              Write (6,*) ' After contraction:'
-              Do ia = 1, nElem(la)
-                Do ib = 1, nElem(lb)
-                  Write (Label,'(A,I2,A,I2,A)') ' Final(',ia,',',ib,')'
-                  Call RecPrt(Label,' ',Final(:,ia,ib,:),nAlpha,nBeta)
-                End Do
+#ifdef _DEBUGPRINT_
+            Write (6,*) ' After contraction:'
+            Do ia = 1, nElem(la)
+              Do ib = 1, nElem(lb)
+                Write (Label,'(A,I2,A,I2,A)') ' Final(',ia,',',ib,')'
+                Call RecPrt(Label,' ',Final(:,ia,ib,:),nAlpha,nBeta)
               End Do
-            End If
+            End Do
+#endif
 *
           End Do ! end loop over lDCR
 *
@@ -681,17 +676,15 @@ c     &                         Array(ipIJ), Final(1,1,1,iIC), Factor)
       End Do ! end loop over iS
       Call xFlush(6)
 *
-      If (iPrint.ge.49) Then
-         Write (6,*) ' Result in FragPInt'
-         Do ia = 1, nElem(la)
-            Do ib = 1, nElem(lb)
-               Write (Label,'(A,I2,A,I2,A)') ' Final(',ia,',',ib,')'
-               Call RecPrt(Label,' ',Final(:,ia,ib,:),nAlpha,nBeta)
-               Call xFlush(6)
-c               Call Add_Info(Label,Final(1,ia,ib,1),nAlpha*nBeta,5)
-            End Do
+#ifdef _DEBUGPRINT_
+      Write (6,*) ' Result in FragPInt'
+      Do ia = 1, nElem(la)
+         Do ib = 1, nElem(lb)
+            Write (Label,'(A,I2,A,I2,A)') ' Final(',ia,',',ib,')'
+            Call RecPrt(Label,' ',Final(:,ia,ib,:),nAlpha,nBeta)
          End Do
-      End If
+      End Do
+#endif
 c add some verification data
 !      this check is to ensure that Add_Info is called only on the Master node
 !      The reason being that the execution of this Kernel routine is split on
@@ -724,9 +717,9 @@ c Avoid unused argument warnings
         Call Unused_real_array(ZInv)
         Call Unused_real_array(rKappa)
         Call Unused_real_array(P)
-        Call Unused_integer(nRys)
+        Call Unused_integer(nHer)
         Call Unused_integer_array(iCho)
-        Call Unused_real(PtChrg)
+        Call Unused_real_array(PtChrg)
         Call Unused_integer(nGrid)
         Call Unused_integer(iAddPot)
       End If
