@@ -81,14 +81,13 @@ C
       nDimRS(i,j) = iWork(ip_nDimRS-1+nSym*(j-1)+i)
 ************************************************************************
 
-#ifdef _DEBUG_
+#ifdef _DEBUGPRINT_
 c      Debug=.true.
       Debug=.false.! to avoid double printing in CASSCF-debug
 #else
       Debug=.false.
 #endif
 
-      Call QEnter(SECNAM)
 
       DoRead  = .false.
       DoReord = .false.
@@ -258,14 +257,12 @@ C ------------------------------------------------------------------
 
             if (nVrs.lt.0) then
                Write(6,*)SECNAM//': Cho_X_nVecRS returned nVrs<0. STOP!'
-               call qtrace()
                call abend()
             endif
 
             Call Cho_X_SetRed(irc,iLoc,JRED) !set index arrays at iLoc
             if(irc.ne.0)then
               Write(6,*)SECNAM //' cho_X_setred non-zero rc (',irc,').'
-              call qtrace()
               call abend()
             endif
 
@@ -298,7 +295,6 @@ C ------------------------------------------------------------------
                WRITE(6,*) 'read in ',mNeed1,' and transform to ',mTvec
                WRITE(6,*) 'of jsym= ',jsym,' and JRED= ',JRED
                rc = 33
-               CALL QTrace()
                CALL Abend()
                nBatch = -9999  ! dummy assignment
             End If
@@ -422,7 +418,7 @@ C --- Set pointers to the half-transformed Cholesky vectors
      &                         nAorb(iSymp),nChM(iSymp))*JNUM
      &                  + nnA(iSymp,iSymb)*JNUM
 
-#ifdef _DEBUG_
+#ifdef _DEBUGPRINT_
             write(6,*)'JRED,iBatch,nBatch= ',jred,iBatch,nBatch
             write(6,*)'JSYM,iSymp,iSymb,lChot= ',JSYM,iSymp,iSymb,lChot
             write(6,*)'Lxb starts in= ',ipLab(iSymp,3)
@@ -451,7 +447,7 @@ C *********************** INACTIVE HALF-TRANSFORMATION  ****************
                tread(1) = tread(1) + (TCR4 - TCR3)
                tread(2) = tread(2) + (TWR4 - TWR3)
 
-#ifdef _DEBUG_
+#ifdef _DEBUGPRINT_
        write(6,*) 'Half-transformation in the Inactive space'
        write(6,*) 'Total allocated :     ',mTvec*nVec,' at ',ipChoT
        write(6,*) 'Mem pointers ipLab :  ',(ipLab(i,1),i=1,nSym)
@@ -845,7 +841,7 @@ C --- free memory
 
 
 c Print the Fock-matrix
-#ifdef _DEBUG_
+#ifdef _DEBUGPRINT_
 
       if(Debug) then !to avoid double printing in CASSCF-debug
 
@@ -892,7 +888,6 @@ c Print the Fock-matrix
 
       rc  = 0
 
-      CAll QExit(SECNAM)
 
       Return
       END
