@@ -74,14 +74,13 @@ C
 **************************************************
 
 
-#ifdef _DEBUG_
+#ifdef _DEBUGPRINT_
 c      Debug=.true.
       Debug=.false.! to avoid double printing in CASSCF-debug
 #else
       Debug=.false.
 #endif
 
-      Call QEnter(SECNAM)
 
       DoReord = .false.
       IREDC = -1  ! unknown reduced set in core
@@ -201,7 +200,6 @@ C ------------------------------------------------------------------
 
             if (nVrs.lt.0) then
                Write(6,*)SECNAM//': Cho_X_nVecRS returned nVrs<0. STOP!'
-               call qtrace()
                call abend()
             endif
 
@@ -209,7 +207,6 @@ C ------------------------------------------------------------------
             if(irc.ne.0)then
               Write(6,*)SECNAM//'cho_X_setred non-zero return code.',
      &                        '   rc= ',irc
-              call qtrace()
               call abend()
             endif
 
@@ -235,7 +232,6 @@ C ------------------------------------------------------------------
                WRITE(6,*) 'min. mem. need= ',nRS+mTvec
                WRITE(6,*) 'jsym= ',jsym
                rc = 33
-               CALL QTrace()
                CALL Abend()
                nBatch = -9999  ! dummy assignment
             End If
@@ -574,7 +570,7 @@ C --- free memory
 
 
 c Print the Fock-matrix
-#ifdef _DEBUG_
+#ifdef _DEBUGPRINT_
 
       if(Debug) then !to avoid double printing in RASSI-debug
 
@@ -596,7 +592,6 @@ c Print the Fock-matrix
 
       rc  = 0
 
-      CAll QExit(SECNAM)
 
       Return
       END
@@ -677,7 +672,6 @@ c Print the Fock-matrix
 
          write(6,*)'Wrong input parameter. mode = ',mode
          irc = 66
-         Call Qtrace()
          Call abend()
 
       EndIf
