@@ -13,7 +13,7 @@
       SUBROUTINE CHO_FOCKTWO_RED(rc,nBas,nDen,DoCoulomb,DoExchange,
      &           FactC,FactX,ipDLT,ipDSQ,ipFLT,ipFSQ,ipNocc,MinMem)
 
-**********************************************************************
+************************************************************************
 *  Author : F. Aquilante
 *
 *  Purpose:
@@ -63,7 +63,7 @@
 *  MinMem(nSym) : minimum amount of memory required to read
 *                 a single Cholesky vector in full storage
 *
-***********************************************************************
+************************************************************************
 
       Implicit Real*8 (a-h,o-z)
 
@@ -97,7 +97,7 @@
 **************************************************
 
 
-#ifdef _DEBUG_
+#ifdef _DEBUGPRINT_
 c      Debug=.true.
       Debug=.false.! to avoid double printing in SCF-debug
 #else
@@ -174,7 +174,6 @@ C ------------------
 C         ***QUIT*** bad initialization
          WRITE(6,*) 'Cho_FockTwo_RED: bad initialization'
          rc=99
-         CALL QTrace()
          CALL Abend()
          nVec = -9999  ! dummy assignment - avoid compiler warnings
       End If
@@ -192,7 +191,6 @@ C         ***QUIT*** insufficient memory
          WRITE(6,*) 'NumCho= ',NumCho(jsym)
          WRITE(6,*) 'jsym= ',jsym
          rc = 205
-         CALL QTrace()
          CALL Abend()
          nBatch = -9999  ! dummy assignment
       End If
@@ -281,7 +279,7 @@ C --- Reading of the vectors is done in Reduced sets
        tread(1) = tread(1) + (TCR2 - TCR1)
        tread(2) = tread(2) + (TWR2 - TWR1)
 
-#ifdef _DEBUG_
+#ifdef _DEBUGPRINT_
        write(6,*) 'Batch ',iBatch,' of   ',nBatch,': NumV = ',NumV
        write(6,*) 'Total allocated :     ',kTOT,' at ',kWab
        write(6,*) 'Memory pointers KSQ1: ',(KSQ1(i),i=1,nSym)
@@ -607,7 +605,7 @@ C --- Free the memory
 
 
 c Print the Fock-matrix
-#ifdef _DEBUG_
+#ifdef _DEBUGPRINT_
 
       if(Debug) then !to avoid double printing in SCF-debug
 
