@@ -41,43 +41,7 @@
 *          nTInt               : dimension of TInt                     *
 *          iTOffs              : iTOffs holds symmetry block offsets   *
 *                                                                      *
-*     nShi,nShj,          Dimensions used for blocks in Tint (input)   *
-*     nshk,nshl:          Symmetry block isym,jsym,ksym,lsym for       *
-*                         shells iS,jS,kS,lS starts at                 *
-*                         iTOffs(ksym,jsym,isym)+1 and is dimensioned  *
-*                         [nshl(lsym),nshk(ksym),nshj(jsym,nshi(isym)] *
-*                         Note that l runs fastest! The dimensions     *
-*                         must be larger or equal to the number of     *
-*                         SAOs in the specified shells and symmetries, *
-*                         otherwise chaos!!                            *
-*                                                                      *
-*     nShOffi,nShOffj,    Offsets of Integral symmetry blocks (input)  *
-*     nShOffk,nShOffl:    An Integral (lso,kso|jso,iso) is placed at   *
-*                         [lb,kb,jb,ib] where lb=lso-nShOffl(lsym),    *
-*                         kb=kso-nShOffk(ksym) etc. Here lso,kso etc   *
-*                         are the SAO labels within their symmetry.    *
-*                         More explicitly, the Integral is stored in   *
-*                         in Tint(ijkl), where                         *
-*                                                                      *
-*                         ijkl = iTOffs(ksym,jsym,isym)                *
-*                           + (ib-1)*nshj(jsym)*nshk(ksym)*nshl(lsym)  *
-*                           + (jb-1)*nshk(ksym)*nshl(lsym)             *
-*                           + (kb-1)*nshl(lsym)                        *
-*                           +  lb                                      *
-* Called from:                                                         *
-*                                                                      *
-* Calling    : QEnter,QExit                                            *
-*              GetMem                                                  *
-*              Int_Setup                                               *
-*              Dens_Info                                               *
-*              MemRys                                                  *
-*              PSOAO0                                                  *
-*              Picky_                                                  *
-*              TwoEl_NoSym                                             *
-*              TwoEl_Sym                                               *
-*              Integ_Proc                                              *
-*                                                                      *
-*             Roland Lindh / Martin Schuetz,                           *
+*     Author: Roland Lindh / Martin Schuetz,                           *
 *             Dept. of Theoretical Chemistry, University of Lund,      *
 *             SWEDEN.                                                  *
 *             Modified for k2 loop. August '91                         *
@@ -88,16 +52,19 @@
 *             Total rehack May '99                                     *
 ************************************************************************
       use k2_setup
+      use k2_arrays
       use iSD_data
+      use Basis_Info
+      use Real_Info, only: CutInt
+      use Symmetry_Info, only: nIrrep
       Implicit Real*8 (A-H,O-Z)
       External Integ_Proc
 *
 *     Dummy definitions
 *
-      Parameter (lDens=1,nDens=1,nInd=1)
-      Real*8  Fock(lDens,nDens),Dens(lDens,nDens), ExFac(nDens)
+      Parameter (nDens=1, lDens=1)
+      Real*8 Fock(lDens), Dens(lDens), ExFac(nDens)
       Logical FckNoClmb(nDens), FckNoExch(nDens)
-      Integer Ind(nInd,nInd,2)
 #include "iTOffs.fh"
 *
 *     subroutine parameters
@@ -108,11 +75,8 @@
 *
 #include "ndarray.fh"
 #include "real.fh"
-#include "itmax.fh"
-#include "info.fh"
-#include "WrkSpc.fh"
+#include "stdalloc.fh"
 #include "print.fh"
-#include "k2.fh"
 #include "setup.fh"
 #include "status.fh"
 *
@@ -129,7 +93,6 @@
 *     other local variables
       Integer iAOst(4), iPrimi,jPrimj,kPrimk,lPriml,
      &        iBasi,jBasj,kBask,lBasl,
-     &  ipCffi,jpCffj,kpCffk,lpCffl,
      &  iBasn,jBasn,kBasn,lBasn,
      &  k2ij,nDCRR,k2kl,nDCRS, ipTmp,
      &  mDij,mDik,mDjk,mDkl,mDil,mDjl,
@@ -149,14 +112,8 @@
       iTri(i,j) = Max(i,j)*(Max(i,j)-1)/2 + Min(i,j)
       nabSz(ixyz) = (ixyz+1)*(ixyz+2)*(ixyz+3)/6  - 1
 *
-      ipDDij=ip_Dummy
       mDCRij=1
-      ipDDkl=ip_Dummy
       mDCRkl=1
-      ipDDik=ip_Dummy
-      ipDDil=ip_Dummy
-      ipDDjk=ip_Dummy
-      ipDDjl=ip_Dummy
 *                                                                      *
 ************************************************************************
 *                                                                      *
@@ -181,7 +138,6 @@
       Quad_ijkl=0.0D0
       DoIntegrals=.True.
       DoFock=.False.
-      ExFac(1)=1.0D0
       FckNoClmb(1)=.False.
       FckNoExch(1)=.False.
 *                                                                      *
@@ -189,15 +145,16 @@
 *                                                                      *
 *     If memory not allocated already at this point allocate!          *
 *                                                                      *
-      If (MemMax_int.eq.0) Then
-        Call GetMem('MaxMem','Max','Real',iDum,MemMax)
-        Call GetMem('MaxMem','Allo','Real',ipMem1,MemMax)
-        MemMax_int=MemMax
-        ipMem_int =ipMem1
+      If (.Not.Allocated(Sew_Scr)) Then
+C        Write (*,*) 'Eval_ints: Allocate memory'
+         Call mma_MaxDBLE(MemMax)
+         Call mma_allocate(Sew_Scr,MemMax,Label='Sew_Scr')
       Else
-        MemMax=MemMax_int
-        ipMem1=ipMem_int
+C        Write (*,*) 'Eval_ints: Memory already allocated'
+         MemMax=SIZE(Sew_Scr)
       End If
+C     Write (*,*) 'Eval_ints: MemMax=',MemMax
+      ipMem1=1
 *
       Map4(1)=1
       Map4(2)=2
@@ -221,26 +178,21 @@
 *                                                                      *
 ************************************************************************
 *                                                                      *
-      Call Int_Setup(iSD,mSkal,iS_,jS_,kS_,lS_,
-     &               Coor,Shijij,
+      Call Int_Setup(iSD,mSkal,iS_,jS_,kS_,lS_,Coor,Shijij,
      &               iAngV,iCmpV,iShelV,iShllV,iAOV,iStabs)
 *                                                                      *
 ************************************************************************
 *                                                                      *
-      iPrimi   = nExp(iShllV(1))
-      jPrimj   = nExp(iShllV(2))
-      kPrimk   = nExp(iShllV(3))
-      lPriml   = nExp(iShllV(4))
-      iBasi    = nBasis(iShllV(1))
-      jBasj    = nBasis(iShllV(2))
-      kBask    = nBasis(iShllV(3))
-      lBasl    = nBasis(iShllV(4))
-      ipCffi   = ipCff(iShllV(1))
-      jpCffj   = ipCff(iShllV(2))
-      kpCffk   = ipCff(iShllV(3))
-      lpCffl   = ipCff(iShllV(4))
-      nZeta = iPrimi * jPrimj
-      nEta = kPrimk * lPriml
+      iPrimi   = Shells(iShllV(1))%nExp
+      jPrimj   = Shells(iShllV(2))%nExp
+      kPrimk   = Shells(iShllV(3))%nExp
+      lPriml   = Shells(iShllV(4))%nExp
+      iBasi    = Shells(iShllV(1))%nBasis
+      jBasj    = Shells(iShllV(2))%nBasis
+      kBask    = Shells(iShllV(3))%nBasis
+      lBasl    = Shells(iShllV(4))%nBasis
+      nZeta    = iPrimi * jPrimj
+      nEta     = kPrimk * lPriml
       mDij=nZeta+1 ! Dummy initialize
       mDkl=nEta+1  ! Dummy initialize
 *
@@ -280,10 +232,10 @@
 *     No SO block in direct construction of the Fock matrix.
       nSO = MemSO2(iAngV(1),iAngV(2),iAngV(3),iAngV(4),
      &             iCmpV(1),iCmpV(2),iCmpV(3),iCmpV(4),
-     &             iShelV(1),iShelV(2),iShelV(3),iShelV(4))
+     &             iShelV(1),iShelV(2),iShelV(3),iShelV(4),
+     &             iAOV(1),iAOV(2),iAOV(3),iAOV(4))
       If (nSO.eq.0) Then
         Return
-*       Call GetMem('0Exit_DrvTwo0','Check','Real',iDum,iDum)
       End If
       If (.Not.DoIntegrals) nSO = 0
 *
@@ -408,7 +360,7 @@ c    &                ipDij,ipDkl,ipDik,ipDil,ipDjk,ipDjl
                Call Picky_(iBasi,iBsInc,iPrimi,iBasAO,iBasn,
      &                     jBasj,jBsInc,jPrimj,jBasAO,jBasn,
      &                     iCmpV(1),iCmpV(2),iShelV(1),iShelV(2),
-     &                     mDCRij,ipDij,ipDDij,mDij,nIrrep)
+     &                     mDCRij,ipDij,ipDDij,mDij,DeDe,nDeDe)
             End If
 *
             Do kBasAO = 1, kBask, kBsInc
@@ -419,14 +371,14 @@ c    &                ipDij,ipDkl,ipDik,ipDil,ipDjk,ipDjl
                   Call Picky_(iBasi,iBsInc,iPrimi,iBasAO,iBasn,
      &                        kBask,kBsInc,kPrimk,kBasAO,kBasn,
      &                        iCmpV(1),iCmpV(3),iShelV(1),iShelV(3),
-     &                        mDCRik,ipDik,ipDDik,mDik,nIrrep)
+     &                        mDCRik,ipDik,ipDDik,mDik,DeDe,nDeDe)
                End If
 *
                If (DoFock) Then
                   Call Picky_(jBasj,jBsInc,jPrimj,jBasAO,jBasn,
      &                        kBask,kBsInc,kPrimk,kBasAO,kBasn,
      &                        iCmpV(2),iCmpV(3),iShelV(2),iShelV(3),
-     &                        mDCRjk,ipDjk,ipDDjk,mDjk,nIrrep)
+     &                        mDCRjk,ipDjk,ipDDjk,mDjk,DeDe,nDeDe)
                End If
 *
                 Do lBasAO = 1, lBasl, lBsInc
@@ -437,21 +389,21 @@ c    &                ipDij,ipDkl,ipDik,ipDil,ipDjk,ipDjl
                       Call Picky_(kBask,kBsInc,kPrimk,kBasAO,kBasn,
      &                            lBasl,lBsInc,lPriml,lBasAO,lBasn,
      &                            iCmpV(3),iCmpV(4),iShelV(3),iShelV(4),
-     &                            mDCRkl,ipDkl,ipDDkl,mDkl,nIrrep)
+     &                            mDCRkl,ipDkl,ipDDkl,mDkl,DeDe,nDeDe)
                    End If
 *
                    If (DoFock) Then
                       Call Picky_(iBasi,iBsInc,iPrimi,iBasAO,iBasn,
      &                            lBasl,lBsInc,lPriml,lBasAO,lBasn,
      &                            iCmpV(1),iCmpV(4),iShelV(1),iShelV(4),
-     &                            mDCRil,ipDil,ipDDil,mDil,nIrrep)
+     &                            mDCRil,ipDil,ipDDil,mDil,DeDe,nDeDe)
                    End If
 *
                    If (DoFock) Then
                       Call Picky_(jBasj,jBsInc,jPrimj,jBasAO,jBasn,
      &                            lBasl,lBsInc,lPriml,lBasAO,lBasn,
      &                            iCmpV(2),iCmpV(4),iShelV(2),iShelV(4),
-     &                            mDCRjl,ipDjl,ipDDjl,mDjl,nIrrep)
+     &                            mDCRjl,ipDjl,ipDDjl,mDjl,DeDe,nDeDe)
                    End If
 *                                                                      *
 ************************************************************************
@@ -471,19 +423,23 @@ c    &                ipDij,ipDkl,ipDik,ipDil,ipDjk,ipDjl
      &                            Data_k2(k2ij),mData1,nDCRR,
      *                            Data_k2(k2kl),mData2,nDCRS,
      &                            IJeqKL,kOp,Disc_Mx,Disc,Thize,
-     &                            Work(ipDDij),mDij,mDCRij,
-     &                            Work(ipDDkl),mDkl,mDCRkl,
-     & Work(ipDDik),mDik,mDCRik,Work(ipDDil),mDil,mDCRil,Work(ipDDjk),
-     & mDjk,mDCRjk, Work(ipDDjl),mDjl,mDCRjl,Fock,Dens,lDens,
-     &                            Work(ipCffi+(iBasAO-1)*iPrimi),iBasn,
-     &                            Work(jpCffj+(jBasAO-1)*jPrimj),jBasn,
-     &                            Work(kpCffk+(kBasAO-1)*kPrimk),kBasn,
-     & Work(lpCffl+(lBasAO-1)*lPriml),lBasn, Work(ipFT),nFT,
-     &Work(ipZeta),Work(ipZI),iWork(ipiZet),Work(ipKab),Work(ipP),nZeta,
-     &Work(ipEta), Work(ipEI),iWork(ipiEta),Work(ipKcd),Work(ipQ),nEta,
-     & Work(ipMem1),nSO,Work(ipMem2),Mem2,
+     &                            DeDe(ipDDij),mDij,mDCRij,
+     &                            DeDe(ipDDkl),mDkl,mDCRkl,
+     & DeDe(ipDDik),mDik,mDCRik,DeDe(ipDDil),mDil,mDCRil,
+     & DeDe(ipDDjk),mDjk,mDCRjk,DeDe(ipDDjl),mDjl,mDCRjl,
+     &           Fock,Dens,lDens,
+     &                  Shells(iShllV(1))%pCff(1,iBasAO),iBasn,
+     &                  Shells(iShllV(2))%pCff(1,jBasAO),jBasn,
+     &                  Shells(iShllV(3))%pCff(1,kBasAO),kBasn,
+     &                  Shells(iShllV(4))%pCff(1,lBasAO),lBasn,
+     &                  FT,nFT,
+     & Mem_DBLE(ipZeta),Mem_DBLE(ipZI),Mem_INT(ipiZet),Mem_DBLE(ipKab),
+     & Mem_DBLE(ipP),nZeta,
+     & Mem_DBLE(ipEta), Mem_DBLE(ipEI),Mem_INT(ipiEta),Mem_DBLE(ipKcd),
+     & Mem_DBLE(ipQ),nEta,
+     & Sew_Scr(ipMem1),nSO,Sew_Scr(ipMem2),Mem2,
      & Shijij,W2Disc,PreSch,Quad_ijkl,nHRRAB,nHRRCD,
-     & DoIntegrals,DoFock,FckNoClmb(1),FckNoExch(1),Work(ipAux),nAux,
+     & DoIntegrals,DoFock,FckNoClmb(1),FckNoExch(1),Aux,nAux,
      & ExFac(1))
 *
                   Else
@@ -500,19 +456,23 @@ c    &                ipDij,ipDkl,ipDik,ipDil,ipDjk,ipDjl
      &                            Data_k2(k2ij),mData1,nDCRR,
      &                            Data_k2(k2kl),mData2,nDCRS,
      &                            IJeqKL,kOp,Disc_Mx,Disc,Thize,
-     &                            Work(ipDDij),mDij,mDCRij,
-     &                            Work(ipDDkl),mDkl,mDCRkl,
-     & Work(ipDDik),mDik,mDCRik,Work(ipDDil),mDil,mDCRil,Work(ipDDjk),
-     & mDjk,mDCRjk, Work(ipDDjl),mDjl,mDCRjl,Fock,Dens,lDens,
-     &                            Work(ipCffi+(iBasAO-1)*iPrimi),iBasn,
-     &                            Work(jpCffj+(jBasAO-1)*jPrimj),jBasn,
-     &                            Work(kpCffk+(kBasAO-1)*kPrimk),kBasn,
-     & Work(lpCffl+(lBasAO-1)*lPriml),lBasn, Work(ipFT),nFT,
-     &Work(ipZeta),Work(ipZI),iWork(ipiZet),Work(ipKab),Work(ipP),nZeta,
-     &Work(ipEta), Work(ipEI),iWork(ipiEta),Work(ipKcd),Work(ipQ),nEta,
-     & Work(ipMem1),nSO,Work(ipMem2),Mem2,
+     &                            DeDe(ipDDij),mDij,mDCRij,
+     &                            DeDe(ipDDkl),mDkl,mDCRkl,
+     & DeDe(ipDDik),mDik,mDCRik,DeDe(ipDDil),mDil,mDCRil,
+     & DeDe(ipDDjk),mDjk,mDCRjk,DeDe(ipDDjl),mDjl,mDCRjl,
+     &           Fock,Dens,lDens,
+     &                  Shells(iShllV(1))%pCff(1,iBasAO),iBasn,
+     &                  Shells(iShllV(2))%pCff(1,jBasAO),jBasn,
+     &                  Shells(iShllV(3))%pCff(1,kBasAO),kBasn,
+     &                  Shells(iShllV(4))%pCff(1,lBasAO),lBasn,
+     &                            FT,nFT,
+     & Mem_DBLE(ipZeta),Mem_DBLE(ipZI),Mem_INT(ipiZet),Mem_DBLE(ipKab),
+     & Mem_DBLE(ipP),nZeta,
+     & Mem_DBLE(ipEta), Mem_DBLE(ipEI),Mem_INT(ipiEta),Mem_DBLE(ipKcd),
+     & Mem_DBLE(ipQ),nEta,
+     & Sew_Scr(ipMem1),nSO,Sew_Scr(ipMem2),Mem2,
      & Shijij,W2Disc,PreSch,Quad_ijkl,nHRRAB,nHRRCD,
-     & DoIntegrals,DoFock,FckNoClmb(1),FckNoExch(1),Work(ipAux),nAux,
+     & DoIntegrals,DoFock,FckNoClmb(1),FckNoExch(1),Aux,nAux,
      & ExFac(1))
 *
                   End If
@@ -524,7 +484,7 @@ c    &                ipDij,ipDkl,ipDik,ipDil,ipDjk,ipDjl
                   nijkl=iBasn*jBasn*kBasn*lBasn
                   If (DoIntegrals.and..Not.NoInts) Then
 *                    Get max AO/SO integrals
-                     If (Petite) Then
+                     If (nIrrep.eq.1) Then
                         n=nijkl*iCmpV(1)*iCmpV(2)*iCmpV(3)*iCmpV(4)
                         ip=ipMem2
                      Else
@@ -532,19 +492,16 @@ c    &                ipDij,ipDkl,ipDik,ipDil,ipDjk,ipDjl
                         ip=ipMem1
                      End If
                      Tmax=max(Tmax,
-     &                        abs(Work(ip+iDAMax_(n,Work(ip),1)-1)))
+     &                        abs(Sew_Scr(ip+
+     &                            iDAMax_(n,Sew_Scr(ip),1)-1)))
                      If (Tmax.gt.CutInt) Then
                         Call Integ_Proc(iCmpV,iShelV,Map4,
      &                                  iBasn,jBasn,kBasn,lBasn,kOp,
      &                                  Shijij,IJeqKL,iAOV,iAOst,nijkl,
-     &                                  Work(ipMem2),Work(ipMem1),nSO,
-     &                                  iWork(ipiSOSym),mSkal,nSOs,
-     &                                  TInt,nTInt,FacInt,
-     &                                  iTOffs,nIrrep,
-     &                                  nShi,nShj,nShk,nShl,
-     &                                  nShOffi,nShOffj,nShOffk,nShOffl,
-     &                                  Dens,Fock,lDens,ExFac,nDens,
-     &                                  Ind,nInd,FckNoClmb,FckNoExch)
+     &                                  Sew_Scr(ipMem2),
+     &                                  Sew_Scr(ipMem1),nSO,
+     &                                  iSOSym,mSkal,nSOs,
+     &                                  TInt,nTInt,iTOffs,nIrrep)
                      Else
                         Tmax=Zero
                      End If
