@@ -27,13 +27,18 @@
 *
       use Real_Spherical
       use iSD_data
+      use Basis_Info
+      use Center_Info
+      use Sizes_of_Seward, only:S
+      use Logical_Info, only: FNMC
+      use Symmetry_Info, only: nIrrep
       Implicit Real*8 (a-h,o-z)
-      External Kernel, KrnlMm
+*     External Kernel, KrnlMm
+      External KrnlMm
 #include "angtp.fh"
-#include "info.fh"
+#include "Molcas.fh"
 #include "real.fh"
 #include "rmat_option.fh"
-#include "WrkSpc.fh"
 #include "nsd.fh"
 #include "setup.fh"
 #include "property_label.fh"
@@ -54,19 +59,33 @@
       nElem(ixyz) = (ixyz+1)*(ixyz+2)/2
 *                                                                      *
 ************************************************************************
+*                                                                      *
+      Interface
+      Subroutine Kernel(
+#define _CALLING_
+#include "int_interface.fh"
+     &                 )
+#include "int_interface.fh"
+      End Subroutine Kernel
+      End Interface
+*                                                                      *
+************************************************************************
 *                                                                      *
 *     Kamal Sharkas  01/29/2015
       If (Label(1:4).eq.'PSOI') Then !  PSO Integrals
       iCmp   = iSD( 2,iS)
       iBas   = iSD( 3,iS)
+      iAO    = iSD( 7,iS)
       iShell = iSD(11,iS)
       jCmp   = iSD( 2,jS)
       jBas   = iSD( 3,jS)
+      jAO    = iSD( 7,jS)
       jShell = iSD(11,jS)
       nSO=0
+      B(:)=Zero
       Do iComp = 1, nComp
          iSmLbl=lOper(iComp)
-         nSO=nSO+MemSO1(iSmLbl,iCmp,jCmp,iShell,jShell)
+         nSO=nSO+MemSO1(iSmLbl,iCmp,jCmp,iShell,jShell,iAO,jAO)
       End Do
       If (iPrint.ge.29) Write (6,*) ' nSO=',nSO
       If (nSO.lt.1) Return
@@ -78,53 +97,46 @@
       Call dCopy_(nSO*iBas*jBas,[Zero],0,SOInt,1)
       iShll  = iSD( 0,iS)
       iAng   = iSD( 1,iS)
-      iCff   = iSD( 4,iS)
       iPrim  = iSD( 5,iS)
-      iExp   = iSD( 6,iS)
-      iAO    = iSD( 7,iS)
-      ixyz   = iSD( 8,iS)
       mdci   = iSD(10,iS)
       iCnttp = iSD(13,iS)
-      Call DCopy_(3,Work(ixyz),1,A,1)
-      dbas= LblCnt(mdci)(1:LENIN)
+      iCnt   = iSD(14,iS)
+      A(1:3) = dbsc(iCnttp)%Coor(1:3,iCnt)
+      dbas= dc(mdci)%LblCnt(1:LENIN)
       Call UpCase(dbas)
       jShll  = iSD( 0,jS)
       jAng   = iSD( 1,jS)
-      jCff   = iSD( 4,jS)
       jPrim  = iSD( 5,jS)
-      jExp   = iSD( 6,jS)
-      jAO    = iSD( 7,jS)
-      jxyz   = iSD( 8,jS)
       mdcj   = iSD(10,jS)
       jCnttp = iSD(13,jS)
+      jCnt   = iSD(14,jS)
+      B(1:3) = dbsc(jCnttp)%Coor(1:3,jCnt)
        if (iPrint.ge.19) Then
         write(6,*) "interacted Ato.Fun "
           Write (6,'(A,A,A,A,A)')
      &   ' ***** (',AngTp(iAng),',',AngTp(jAng),') *****'
        endif
-      lFinal = nIC*MaxPrm(iAng)*MaxPrm(jAng)*nElem(iAng)*nElem(jAng)
+      lFinal = nIC*S%MaxPrm(iAng)*S%MaxPrm(jAng)*nElem(iAng)*nElem(jAng)
       If (lFinal.gt.nFinal) Then
          Call WarningMessage(2,'lFinal.gt.nFinal')
          Call Abend()
       End If
       Call dCopy_(lFinal,[Zero],0,Final,1)
-      Call DCR(LmbdR,iOper,nIrrep,jStab(0,mdci),
-     &         nStab(mdci),jStab(0,mdcj),
-     &         nStab(mdcj),iDCRR,nDCRR)
-      Call Inter(jStab(0,mdci),nStab(mdci),
-     &           jStab(0,mdcj),nStab(mdcj),
+      Call DCR(LmbdR,dc(mdci)%iStab,dc(mdci)%nStab,
+     &               dc(mdcj)%iStab,dc(mdcj)%nStab,iDCRR,nDCRR)
+      Call Inter(dc(mdci)%iStab,dc(mdci)%nStab,
+     &           dc(mdcj)%iStab,dc(mdcj)%nStab,
      &           iStabM,nStabM)
-      Call DCR(LambdT,iOper,nIrrep,iStabM,nStabM,iStabO,nStabO,
-     &         iDCRT,nDCRT)
+      Call DCR(LambdT,iStabM,nStabM,iStabO,nStabO,iDCRT,nDCRT)
       If (iPrint.ge.19) Then
          Write (6,*)
          Write (6,*) ' g      =',nIrrep
-         Write (6,*) ' u      =',nStab(mdci)
-         Write (6,'(9A)') '(U)=',(ChOper(jStab(ii,mdci)),
-     &         ii = 0, nStab(mdci)-1)
-         Write (6,*) ' v      =',nStab(mdcj)
-         Write (6,'(9A)') '(V)=',(ChOper(jStab(ii,mdcj)),
-     &         ii = 0, nStab(mdcj)-1)
+         Write (6,*) ' u      =',dc(mdci)%nStab
+         Write (6,'(9A)') '(U)=',(ChOper(dc(mdci)%iStab(ii)),
+     &         ii = 0, dc(mdci)%nStab-1)
+         Write (6,*) ' v      =',dc(mdcj)%nStab
+         Write (6,'(9A)') '(V)=',(ChOper(dc(mdcj)%iStab(ii)),
+     &         ii = 0, dc(mdcj)%nStab-1)
          Write (6,*) ' LambdaR=**',LmbdR
          Write (6,*) ' r      =',nDCRR
          Write (6,'(9A)') '(R)=',(ChOper(iDCRR(ii)),
@@ -133,13 +145,11 @@
          Write (6,'(9A)') '(M)=',(ChOper(iStabM(ii)),
      &         ii = 0, nStabM-1)
       End If
-       nOp(1) = NrOpr(0,iOper,nIrrep)
+       nOp(1) = NrOpr(0)
       If (nDCRR.ge.1) Then
          Do lDCRR = 0, nDCRR-1
-            RB(1) = DBLE(iPhase(1,iDCRR(lDCRR)))*B(1)
-            RB(2) = DBLE(iPhase(2,iDCRR(lDCRR)))*B(2)
-            RB(3) = DBLE(iPhase(3,iDCRR(lDCRR)))*B(3)
-            nOp(2) = NrOpr(iDCRR(lDCRR),iOper,nIrrep)
+            Call OA(iDCRR(lDCRR),B,RB)
+            nOp(2) = NrOpr(iDCRR(lDCRR))
                If (iPrint.ge.49) Then
                Write (6,'(A,3F6.2,2X,3F6.2)') '*',
      &                                        (A(i),i=1,3),(RB(i),i=1,3)
@@ -148,7 +158,6 @@
         Call Get_nAtoms_All(nAtoms)
         l_Coord=3*nAtoms
         Call Get_dArray('Bfn Coordinates',Coord,l_Coord)
-        ! write(6,*) "nPSOI", nPSOI
          NATEST=.false.
         if (nAtoms.eq.2) then
          nAtoms=nAtoms+1
@@ -158,10 +167,12 @@
         call test_f90mod_sgto_pso(iShell,jShell,iCmp,jCmp,
      &                                     iBas,jBas,iAng,jAng,
      &                                     iPrim,jPrim,mdci,mdcj,
-     &                                     Work(iExp),Work(jExp),
-     &                                     Work(iCff+iPrim*iBas),
-     &                         Work(jCff+jPrim*jBas),nAtoms,NATEST,
-     &                         Coord,nPSOI,Final)
+     &                                     Shells(iShll)%Exp,
+     &                                     Shells(jShll)%Exp,
+     &                                     Shells(iShll)%Cff_c(1,1,2),
+     &                                     Shells(jShll)%Cff_c(1,1,2),
+     &                                     nAtoms,NATEST,
+     &                                     Coord,nPSOI,Final)
 #else
          Call WarningMessage(2,
      &   'OneEl_IJ: NO Gen1int interface available!')
@@ -172,7 +183,7 @@
             iIC = 1
             Do iComp = 1, nComp
                iSmLbl=lOper(iComp)
-               mSO=MemSO1(iSmLbl,iCmp,jCmp,iShell,jShell)
+               mSO=MemSO1(iSmLbl,iCmp,jCmp,iShell,jShell,iAO,jAO)
                If (mSO.eq.0) Then
                   Do iIrrep = 0, nIrrep-1
                      If (iAnd(lOper(iComp),iTwoj(iIrrep)).ne.0)
@@ -181,7 +192,8 @@
                Else
                  !write(6,*) "Symmetry adapt component"
                   Call SymAd1(iSmLbl,iAng,jAng,iCmp,jCmp,
-     &                        iShell,jShell,iShll,jShll,Final,
+     &                        iShell,jShell,iShll,jShll,
+     &                        iAO,jAO,Final,
      &                        iBas,jBas,nIC,iIC,SOInt(iSOBlk),mSO,nOp)
                   iSOBlk = iSOBlk + mSO*iBas*jBas
                End If
@@ -200,14 +212,16 @@
 *
       iCmp   = iSD( 2,iS)
       iBas   = iSD( 3,iS)
+      iAO    = iSD( 7,iS)
       iShell = iSD(11,iS)
       jCmp   = iSD( 2,jS)
       jBas   = iSD( 3,jS)
+      jAO    = iSD( 7,jS)
       jShell = iSD(11,jS)
       nSO=0
       Do iComp = 1, nComp
          iSmLbl=lOper(iComp)
-         nSO=nSO+MemSO1(iSmLbl,iCmp,jCmp,iShell,jShell)
+         nSO=nSO+MemSO1(iSmLbl,iCmp,jCmp,iShell,jShell,iAO,jAO)
       End Do
       If (iPrint.ge.29) Write (6,*) ' nSO=',nSO
       If (nSO.lt.1) Return
@@ -222,26 +236,21 @@
 *
       iShll  = iSD( 0,iS)
       iAng   = iSD( 1,iS)
-      iCff   = iSD( 4,iS)
       iPrim  = iSD( 5,iS)
-      iExp   = iSD( 6,iS)
-      iAO    = iSD( 7,iS)
-      ixyz   = iSD( 8,iS)
       mdci   = iSD(10,iS)
       iCnttp = iSD(13,iS)
-      call dcopy_(3,Work(ixyz),1,A,1)
-      dbas= LblCnt(mdci)(1:LENIN)
+      iCnt   = iSD(14,iS)
+      A(1:3)=dbsc(iCnttp)%Coor(1:3,iCnt)
+      dbas= dc(mdci)%LblCnt(1:LENIN)
       Call UpCase(dbas)
 
       jShll  = iSD( 0,jS)
       jAng   = iSD( 1,jS)
-      jCff   = iSD( 4,jS)
       jPrim  = iSD( 5,jS)
-      jExp   = iSD( 6,jS)
-      jAO    = iSD( 7,jS)
-      jxyz   = iSD( 8,jS)
       mdcj   = iSD(10,jS)
       jCnttp = iSD(13,jS)
+      jCnt   = iSD(14,jS)
+      B(1:3)=dbsc(jCnttp)%Coor(1:3,jCnt)
 *
 *---- Identify if shell doublet should be computed with special
 *     R-Matrix code.
@@ -257,7 +266,6 @@
       Else
          RMat_type_integrals=.False.
       End If
-      call dcopy_(3,Work(jxyz),1,B,1)
 *                                                                      *
 ************************************************************************
 *                                                                      *
@@ -343,35 +351,34 @@
 *     At this point we can compute Zeta.
 *     This is now computed in the ij or ji order.
 *
-      Call ZXia(xZeta,xZI,iPrim,jPrim,Work(iExp),Work(jExp))
+      Call ZXia(xZeta,xZI,iPrim,jPrim,Shells(iShll)%Exp,
+     &                                Shells(jShll)%Exp)
 *                                                                      *
 ************************************************************************
 *                                                                      *
 *     Find the DCR for A and B
 *
-      Call DCR(LmbdR,iOper,nIrrep,jStab(0,mdci),
-     &         nStab(mdci),jStab(0,mdcj),
-     &         nStab(mdcj),iDCRR,nDCRR)
+      Call DCR(LmbdR,dc(mdci)%iStab,dc(mdci)%nStab,
+     &               dc(mdcj)%iStab,dc(mdcj)%nStab,iDCRR,nDCRR)
 *
 *     Find the stabilizer for A and B
 *
-      Call Inter(jStab(0,mdci),nStab(mdci),
-     &           jStab(0,mdcj),nStab(mdcj),
+      Call Inter(dc(mdci)%iStab,dc(mdci)%nStab,
+     &           dc(mdcj)%iStab,dc(mdcj)%nStab,
      &           iStabM,nStabM)
 *
-      Call DCR(LambdT,iOper,nIrrep,iStabM,nStabM,iStabO,nStabO,
-     &         iDCRT,nDCRT)
+      Call DCR(LambdT,iStabM,nStabM,iStabO,nStabO,iDCRT,nDCRT)
 *
-#ifdef _DEBUG_
+#ifdef _DEBUGPRINT_
       If (iPrint.ge.19) Then
          Write (6,*)
          Write (6,*) ' g      =',nIrrep
-         Write (6,*) ' u      =',nStab(mdci)
-         Write (6,'(9A)') '(U)=',(ChOper(jStab(ii,mdci)),
-     &         ii = 0, nStab(mdci)-1)
-         Write (6,*) ' v      =',nStab(mdcj)
-         Write (6,'(9A)') '(V)=',(ChOper(jStab(ii,mdcj)),
-     &         ii = 0, nStab(mdcj)-1)
+         Write (6,*) ' u      =',dc(mdci)%nStab
+         Write (6,'(9A)') '(U)=',(ChOper(dc(mdci)%iStab(ii)),
+     &         ii = 0, dc(mdci)%nStab-1)
+         Write (6,*) ' v      =',dc(mdcj)%nStab
+         Write (6,'(9A)') '(V)=',(ChOper(dc(mdcj)%iStab(ii)),
+     &         ii = 0, dc(mdcj)%nStab-1)
          Write (6,*) ' LambdaR=**',LmbdR
          Write (6,*) ' r      =',nDCRR
          Write (6,'(9A)') '(R)=',(ChOper(iDCRR(ii)),
@@ -386,7 +393,7 @@
 *                                                                      *
 *     Compute normalization factor
 *
-      iuv = nStab(mdci)*nStab(mdcj)
+      iuv = dc(mdci)%nStab*dc(mdcj)%nStab
       If (MolWgh.eq.1) Then
          Fact = DBLE(nStabO) / DBLE(LambdT)
       Else If (MolWgh.eq.0) Then
@@ -400,13 +407,11 @@
 *                                                                      *
 *     Loops over symmetry operations acting on the basis.
 *
-       nOp(1) = NrOpr(0,iOper,nIrrep)
+       nOp(1) = NrOpr(0)
       If (nDCRR.ge.1) Then
          Do lDCRR = 0, nDCRR-1
-            RB(1) = DBLE(iPhase(1,iDCRR(lDCRR)))*B(1)
-            RB(2) = DBLE(iPhase(2,iDCRR(lDCRR)))*B(2)
-            RB(3) = DBLE(iPhase(3,iDCRR(lDCRR)))*B(3)
-            nOp(2) = NrOpr(iDCRR(lDCRR),iOper,nIrrep)
+            Call OA(iDCRR(lDCRR),B,RB)
+            nOp(2) = NrOpr(iDCRR(lDCRR))
              If (iPrint.ge.49) Then
                Write (6,'(A,3F6.2,2X,3F6.2)') '*',
      &                                        (A(i),i=1,3),(RB(i),i=1,3)
@@ -414,12 +419,14 @@
 *
 *           Compute kappa and P.
 *
-            Call Setup1(Work(iExp),iPrim,Work(jExp),jPrim,
+            Call Setup1(Shells(iShll)%Exp,iPrim,
+     &                  Shells(jShll)%Exp,jPrim,
      &                  A,RB,xKappa,xPCoor,xZI)
 *
 *           Compute primitive integrals. Result is ordered ij,ab.
 *
-            Call Kernel(Work(iExp),iPrim,Work(jExp),jPrim,
+            Call Kernel(Shells(iShll)%Exp,iPrim,
+     &                  Shells(jShll)%Exp,jPrim,
      &                  xZeta,xZI,
      &                  xKappa,xPCoor,
      &                  Final,iPrim*jPrim,nIC,nComp,
@@ -437,9 +444,9 @@
 *
            If (iPrint.ge.99) Then
                 Call RecPrt(' Left side contraction',' ',
-     &                        Work(iCff+iPrim*iBas),iPrim,iBas)
+     &                        Shells(iShll)%pCff,iPrim,iBas)
                 Call RecPrt(' Right side contraction',' ',
-     &                        Work(jCff+jPrim*jBas),jPrim,jBas)
+     &                        Shells(jShll)%pCff,jPrim,jBas)
 *
             End If
 *
@@ -448,13 +455,13 @@
             Call DGEMM_('T','N',
      &                  jPrim*kk*nIC,iBas,iPrim,
      &                  1.0d0,Final,iPrim,
-     &                  Work(iCff),iPrim,
+     &                        Shells(iShll)%pCff,iPrim,
      &                  0.0d0,Scrtch,jPrim*kk*nIC)
 *           Transform j,abxI to abxI,J
             Call DGEMM_('T','N',
      &                  kk*nIC*iBas,jBas,jPrim,
      &                  1.0d0,Scrtch,jPrim,
-     &                  Work(jCff),jPrim,
+     &                        Shells(jShll)%pCff,jPrim,
      &                  0.0d0,ScrSph,kk*nIC*iBas)
 *
             If (iPrint.ge.99) Then
@@ -465,13 +472,17 @@
 *           Transform to spherical gaussians if needed.
 *
 
-            If (Transf(iShll).or.Transf(jShll)) Then
+            If (Shells(iShll)%Transf.or.Shells(jShll)%Transf) Then
 *              Result comes back as xIJAB or xIJAb
                Call CarSph(ScrSph,kk,iBas*jBas*nIC,
-     &                     Final,lScrSph,RSph(ipSph(iAng)),
-     &                     iAng,Transf(iShll),Prjct(iShll),
-     &                     RSph(ipSph(jAng)),jAng,Transf(jShll),
-     &                     Prjct(jShll),Scrtch,iCmp*jCmp)
+     &                     Final,lScrSph,
+     &                     RSph(ipSph(iAng)),
+     &                     iAng,Shells(iShll)%Transf,
+     &                          Shells(iShll)%Prjct,
+     &                     RSph(ipSph(jAng)),
+     &                     jAng,Shells(jShll)%Transf,
+     &                          Shells(jShll)%Prjct,
+     &                     Scrtch,iCmp*jCmp)
                Call DGeTmO(Scrtch,nIC,nIC,iBas*jBas*iCmp*jCmp,
      &                     Final,iBas*jBas*iCmp*jCmp)
             Else
@@ -515,8 +526,7 @@
 *              multiply with 1/m, where m is the mass of an electron
 *              or muon.
 *
-               xfactor=One/fmass(iCnttp)
-*              Write (*,*) 'fmass(iCnttp)=',fmass(iCnttp)
+               xfactor=One/dbsc(iCnttp)%fMass
 *
 *              Add the Finite Nuclear Mass Correction if activated
 *
@@ -524,10 +534,10 @@
      &             A(1).eq.RB(1) .AND.
      &             A(2).eq.RB(2) .AND.
      &             A(3).eq.RB(3)) .AND.
-     &             Charge(iCnttp).ne.Zero) Then
-                     iAtom=iAtmNr(iCnttp)
+     &             dbsc(iCnttp)%Charge.ne.Zero) Then
+                     iAtom=dbsc(iCnttp)%AtmNr
 *                    Get the atom mass in au (me=1)
-                     xMass=CntMass(iCnttp)
+                     xMass=dbsc(iCnttp)%CntMass
 *                    Substract the electron mass to get the nuclear
 *                    mass.
                      xMass=xMass-DBLE(iAtom)
@@ -552,7 +562,7 @@
             iIC = 1
             Do iComp = 1, nComp
                iSmLbl=lOper(iComp)
-               mSO=MemSO1(iSmLbl,iCmp,jCmp,iShell,jShell)
+               mSO=MemSO1(iSmLbl,iCmp,jCmp,iShell,jShell,iAO,jAO)
                If (mSO.eq.0) Then
                   Do iIrrep = 0, nIrrep-1
                      If (iAnd(lOper(iComp),iTwoj(iIrrep)).ne.0)
@@ -560,7 +570,8 @@
                   End Do
                Else
                   Call SymAd1(iSmLbl,iAng,jAng,iCmp,jCmp,
-     &                        iShell,jShell,iShll,jShll,Final,
+     &                        iShell,jShell,iShll,jShll,
+     &                        iAO,jAO,Final,
      &                        iBas,jBas,nIC,iIC,SOInt(iSOBlk),mSO,nOp)
                   iSOBlk = iSOBlk + mSO*iBas*jBas
                End If
