@@ -15,31 +15,22 @@
 *                                                                      *
 * Object: to set up the handling of the 2nd order density matrix.      *
 *                                                                      *
-* Called from: Alaska                                                  *
-*                                                                      *
-* Calling    : QEnter                                                  *
-*              OpnOne                                                  *
-*              GetMem                                                  *
-*              RdOne                                                   *
-*              PrMtrx                                                  *
-*              ClsOne                                                  *
-*              ErrOne                                                  *
-*              QExit                                                   *
-*                                                                      *
 *     Author: Roland Lindh, Dept. of Theoretical Chemistry,            *
 *             University of Lund, SWEDEN                               *
 *             January '92                                              *
 ************************************************************************
       use iSD_data
+      use aces_stuff
+      use pso_stuff
+      use index_arrays, only: iSO2Sh
+      use Basis_Info, only: nBas
+      use Sizes_of_Seward, only: S
+      use Symmetry_Info, only: nIrrep
       Implicit Real*8 (A-H,O-Z)
-#include "itmax.fh"
-#include "info.fh"
 #include "print.fh"
 #include "real.fh"
-#include "WrkSpc.fh"
-#include "pso.fh"
+#include "stdalloc.fh"
 #include "etwas.fh"
-#include "aces_gamma.fh"
 #include "mp2alaska.fh"
 #include "nsd.fh"
 #include "dmrginfo_mclr.fh"
@@ -51,7 +42,6 @@
 ************ columbus interface ****************************************
 #include "columbus_gamma.fh"
 #include "setup.fh"
-#include "shinf.fh"
 ************************************************************************
       Integer nFro(0:7)
       Integer Columbus
@@ -60,13 +50,13 @@
       Logical DoCholesky
       Real*8 CoefX,CoefR
       Character*80 Fmt*60
+      Real*8, Allocatable:: D1ao(:), D1AV(:), Tmp(:,:)
 *
 *...  Prologue
 
       iRout = 250
       iPrint = nPrint(iRout)
       lPrint=iPrint.ge.6
-      Call qEnter('PrepP')
 #ifdef _CD_TIMING_
       Call CWTIME(PreppCPU1,PreppWall1)
 #endif
@@ -83,7 +73,6 @@
       Case_2C=.False.
       Case_3C=.False.
       Case_mp2=.False.
-*      ip_Z_p_k=ip_Dummy
 
       nDens = 0
       Do 1 iIrrep = 0, nIrrep - 1
@@ -94,8 +83,8 @@
 *...  Get the method label
       Call Get_cArray('Relax Method',Method,8)
       Call Get_iScalar('Columbus',columbus)
-      nCMo = n2Tot
-      mCMo = n2Tot
+      nCMo = S%n2Tot
+      mCMo = S%n2Tot
       If (Method.eq. 'KS-DFT  ' .or.
      &    Method.eq. 'MCPDFT  ' .or.
      &    Method.eq. 'CASDFT  ' ) Then
@@ -169,7 +158,7 @@
 
 *---- Allocate Table Of Content for half sorted gammas.
 *
-      Call GetMem('G_Toc','Allo','Real',ipG_Toc,nQuad+2)
+      Call mma_Allocate(G_Toc,nQuad+2,Label='G_Toc')
 
 *  find free unit number
         lgtoc=61
@@ -177,22 +166,16 @@
         idisk=0
 *  read table of contents of half-sorted gamma file
          Call DaName(lgtoc,'gtoc')
-         Call ddafile(lgtoc,2,Work(ipg_toc),nQuad+2,idisk)
+         Call ddafile(lgtoc,2,G_Toc,nQuad+2,idisk)
          Call Daclos(lgtoc)
-         n=int(Work(ipg_toc+nQuad))
-         lbin=int(Work(ipg_toc+nQuad+1))
+         n=int(G_Toc(nQuad+1))
+         lbin=int(G_Toc(nQuad+2))
          if (n.ne.nQuad) then
            Call WarningMessage(2,'n.ne.nQuad')
            Write (6,*) 'n,nQuad=',n,nQuad
            Call Abend()
          endif
 
-c       open(unit=lgtoc,file='gtoc',form='unformatted')
-c        read(lgtoc) n
-c        if (n.ne.nquad) stop 'quad error'
-c        call read_lgtoc(lgtoc,Work(ipg_toc),n)
-c        read(lgtoc) lbin
-c       close (lgtoc)
         Gamma_On=.True.
         Gamma_mrcisd=.TRUE.
 *       open gamma file
@@ -201,10 +184,10 @@ c       close (lgtoc)
 *        closed in closep
          Call DaName_MF(LuGamma,'GAMMA')
 *  allocate space for bins
-         Call GetMem('Bin','Allo','Real',ipBin,2*lBin)
+         Call mma_Allocate(Bin,2,lBin,Label='Bin')
 *  compute SO2cI array
-         Call GetMem('SO2cI','Allo','Inte',ipSO2cI,2*nSOs)
-         call so2ci(iWork(ipSO2cI),iWork(ipSOsh),nsos)
+         Call mma_Allocate(SO2cI,2,nSOs,Label='SO2cI')
+         call Mk_SO2cI(SO2cI,iSO2Sh,nsos)
 *                                                                      *
 ************************************************************************
 *                                                                      *
@@ -279,40 +262,26 @@ c       close (lgtoc)
          If (lsa) nsa=4
          If ( Method.eq.'MCPDFT  ') nsa=4
 !AMS modification: add a fifth density slot
-         Call GetMem('D0   ','Allo','Real',ipD0,nDens*nsa+nDens)
-         call dcopy_(nDens*nsa+nDens,[0.0d0],0,Work(ipD0),1)
-         Call GetMem('DVar ','Allo','Real',ipDVar,nDens*nsa)
-         if (.not.gamma_mrcisd) then
-         Call Get_D1ao(ipD1ao,length)
-         If ( length.ne.nDens ) Then
-            Call WarningMessage(2,'PrepP: length.ne.nDens')
-            Write (6,*) 'length=',length
-            Write (6,*) 'nDens=',nDens
-            Call Abend()
-         End If
-         call dcopy_(nDens,Work(ipD1ao),1,Work(ipD0),1)
-         Call Free_Work(ipD1ao)
-         endif
+         mDens=nsa+1
+         Call mma_allocate(D0,nDens,mDens,Label='D0')
+         D0(:,:)=Zero
+         Call mma_allocate(DVar,nDens,nsa,Label='DVar')
+         if (.not.gamma_mrcisd) Call Get_D1ao(D0(1,1),nDens)
 *
 
-         Call Get_D1ao_Var(ipD1ao_Var,length)
-         call dcopy_(nDens,Work(ipD1ao_Var),1,Work(ipDVar),1)
-*        if (gamma_mrcisd) then
-*         call dcopy_(nDens,Work(ipD1ao_Var),1,Work(ipD0),1)
-*        endif
-         Call Free_Work(ipD1ao_Var)
+         Call Get_D1ao_Var(DVar,nDens)
 *
+         Call mma_Allocate(DS,nDens,Label='DS')
+         Call mma_Allocate(DSVar,nDens,Label='DSVar')
          If (Method.eq.'UHF-SCF ' .or.
      &       Method.eq.'ROHF    ' .or.
      &    (Method.eq.'KS-DFT  '.and.iSpin.ne.1) .or.
      &       Method.eq.'Corr. WF' ) Then
-            Call Get_D1sao(ipDS,Length)
-            Call Get_D1sao_Var(ipDSVar,Length)
+            Call Get_D1sao(DS,nDens)
+            Call Get_D1sao_Var(DSVar,nDens)
          Else
-            Call GetMem('DS   ','Allo','Real',ipDS,nDens)
-            Call GetMem('DSVar','Allo','Real',ipDSVar,nDens)
-            Call FZero(Work(ipDS),nDens)
-            Call FZero(Work(ipDSVar),nDens)
+            DS   (:)=Zero
+            DSVar(:)=Zero
          End If
 *
 *   This is necessary for the ci-lag
@@ -328,10 +297,10 @@ c       close (lgtoc)
          Do 11 iBas = 1, nBas(iIrrep)
             Do 12 jBas = 1, iBas-1
                ij = ij + 1
-               Work(ipDVar +ij) = Half*Work(ipDVar +ij)
-               Work(ipD0   +ij) = Half*Work(ipD0   +ij)
-               Work(ipDS   +ij) = Half*Work(ipDS   +ij)
-               Work(ipDSVar+ij) = Half*Work(ipDSVar+ij)
+               D0   (1+ij,1) = Half*D0   (1+ij,1)
+               DVar (1+ij,1) = Half*DVar (1+ij,1)
+               DS   (1+ij) = Half*DS   (1+ij)
+               DSVar(1+ij) = Half*DSVar(1+ij)
  12         Continue
             ij = ij + 1
  11      Continue
@@ -340,13 +309,13 @@ c       close (lgtoc)
 
       If (iPrint.ge.99) Then
          RlxLbl='D1AO    '
-         Call PrMtrx(RlxLbl,[iD0Lbl],iComp,[ipD0],Work)
+         Call PrMtrx(RlxLbl,[iD0Lbl],iComp,[1],D0)
          RlxLbl='D1AO-Var'
-         Call PrMtrx(RlxLbl,[iD0Lbl],iComp,[ipDVar],Work)
+         Call PrMtrx(RlxLbl,[iD0Lbl],iComp,[1],DVar)
          RlxLbl='DSAO    '
-         Call PrMtrx(RlxLbl,[iD0Lbl],iComp,[ipDS],Work)
+         Call PrMtrx(RlxLbl,[iD0Lbl],iComp,[1],DS)
          RlxLbl='DSAO-Var'
-         Call PrMtrx(RlxLbl,[iD0Lbl],iComp,[ipDSVar],Work)
+         Call PrMtrx(RlxLbl,[iD0Lbl],iComp,[1],DSVar)
       End If
 
 *
@@ -364,17 +333,14 @@ c       close (lgtoc)
             nsa=1
             If (lsa) nsa=2
          End If
-         Call GetMem('CMO','Allo','Real',ipCMO,nsa*mCMO)
-         ipCMOa=ipCMO
-         ipCMOb=ipCMO+(nsa-1)*mCMO
-         Call Get_CMO(ipTemp,nTemp)
-         call dcopy_(nTemp,Work(ipTemp),1,Work(ipCMO),1)
-         Call Free_Work(ipTemp)
+         kCMO=nsa
+         Call mma_allocate(CMO,mCMO,kCMO,Label='CMO')
+         Call Get_CMO(CMO(:,1),mCMO)
          If (iPrint.ge.99) Then
-            ipTmp1 = ipCMO
+            ipTmp1 = 1
             Do iIrrep = 0, nIrrep-1
                Call RecPrt(' CMO''s',' ',
-     &                     Work(ipTmp1),nBas(iIrrep),
+     &                     CMO(ipTmp1,1),nBas(iIrrep),
      &                     nBas(iIrrep))
                ipTmp1 = ipTmp1 + nBas(iIrrep)**2
             End Do
@@ -414,42 +380,38 @@ c       close (lgtoc)
          nG1 = nAct*(nAct+1)/2
          nsa=1
          If (lsa) nsa=0
-         Call GetMem(' G1 ','Allo','Real',ipG1,nG1*nsa)
+         mG1=nsa
+         Call mma_allocate(G1,nG1,mG1,Label='G1')
          If (nsa.gt.0) Then
-            Call Get_D1MO(ipTemp,nTemp)
-            call dcopy_(nTemp,Work(ipTemp),1,Work(ipG1),1)
-            Call Free_Work(ipTemp)
-            If (iPrint.ge.99) Call TriPrt(' G1',' ',Work(ipG1),nAct)
+            Call Get_D1MO(G1(:,1),nG1)
+            If (iPrint.ge.99) Call TriPrt(' G1',' ',G1(:,1),nAct)
          End If
 *
 *...  Get the two body density for the active orbitals
          nG2 = nG1*(nG1+1)/2
          nsa=1
          if (lsa) nsa=2
-         Call GetMem(' G2 ','Allo','Real',ipG2,nG2*nsa)
+         mG2=nsa
+         Call mma_allocate(G2,nG2,mG2,Label='G2')
 !       write(*,*) 'got the 2rdm, Ithink.'
          if(Method.eq.'MCPDFT  ') then
-           Call Get_P2MOt(ipTemp,nTemp)!PDFT-modified 2-RDM
+           Call Get_P2MOt(G2,nG2)!PDFT-modified 2-RDM
          else
-           Call Get_P2MO(ipTemp,nTemp)
+           Call Get_P2MO(G2,nG2)
          end if
-         call dcopy_(nTemp,Work(ipTemp),1,Work(ipG2),1)
-         Call Free_Work(ipTemp)
-         If (iPrint.ge.99) Call TriPrt(' G2',' ',Work(ipG2),nG1)
+         If (iPrint.ge.99) Call TriPrt(' G2',' ',G2(1,1),nG1)
          If (lsa) Then
 
 *  CMO1 Ordinary CMOs
 *
 *  CMO2 CMO*Kappa
 *
-           Call Get_LCMO(ipLCMO,Length)
-           call dcopy_(Length,Work(ipLCMO),1,Work(ipCMO+mcmo),1)
-           Call Free_Work(ipLCMO)
+           Call Get_LCMO(CMO(:,2),mCMO)
            If (iPrint.ge.99) Then
-            ipTmp1 = ipCMO+mcmo
+            ipTmp1 = 1
             Do iIrrep = 0, nIrrep-1
                Call RecPrt('LCMO''s',' ',
-     &                     Work(ipTmp1),nBas(iIrrep),
+     &                     CMO(ipTmp1,2),nBas(iIrrep),
      &                     nBas(iIrrep))
                ipTmp1 = ipTmp1 + nBas(iIrrep)**2
             End Do
@@ -460,8 +422,7 @@ c       close (lgtoc)
 *   P1=<i|e_pqrs|i> + sum_i <i|e_pqrs|i>+<i|e_pqrs|i>
 *   P2=sum_i <i|e_pqrs|i>
 *
-           Call Get_PLMO(ipPLMO,Length)
-           call dcopy_(Length,Work(ipPLMO),1,Work(ipG2+ng2),1)
+           Call Get_PLMO(G2(:,2),nG2)
            ndim1=0
            if(doDMRG)then
              ndim0=0  !yma
@@ -471,30 +432,15 @@ c       close (lgtoc)
              ndim1=(ndim0+1)*ndim0/2
              ndim2=(ndim1+1)*ndim1/2
              do i=1,ng2
-               if(i.gt.ndim2)then
-                 Work(ipG2+ng2+i-1)=0.0d0
-               end if
+               if(i.gt.ndim2) G2(i,2)=0.0D0
              end do
            end if
-           Call Free_Work(ipPLMO)
-           Call Daxpy_(ng2,One,Work(ipG2+ng2),1,Work(ipG2),1)
-           If(iPrint.ge.99)Call TriPrt(' G2L',' ',Work(ipG2+ng2),nG1)
-           If(iPrint.ge.99)Call TriPrt(' G2T',' ',Work(ipG2),nG1)
+           Call Daxpy_(ng2,One,G2(:,2),1,G2(:,1),1)
+           If(iPrint.ge.99)Call TriPrt(' G2L',' ',G2(:,2),nG1)
+           If(iPrint.ge.99)Call TriPrt(' G2T',' ',G2(:,1),nG1)
 *
-           Call Get_D2AV(ipD2AV,Length)
-           If (ng2.ne.Length) Then
-              Call WarningMessage(2,'Prepp: D2AV, ng2.ne.Length!')
-              Write (6,*) 'ng2,Length=',ng2,Length
-! DMRG with the reduced AS
-              if(doDMRG)then
-                Length=ng2 ! yma
-              else
-                Call Abend()
-              end if
-           End If
-           call dcopy_(Length,Work(ipD2AV),1,Work(ipG2+ng2),1)
-           Call Free_Work(ipD2AV)
-           If (iPrint.ge.99) Call TriPrt('G2A',' ',Work(ipG2+ng2),nG1)
+           Call Get_D2AV(G2(:,2),nG2)
+           If (iPrint.ge.99) Call TriPrt('G2A',' ',G2(:,2),nG1)
 *
 *
 *  Densities are stored as:
@@ -514,84 +460,82 @@ c       close (lgtoc)
 *
 !************************
          RlxLbl='D1AO    '
-!         Call PrMtrx(RlxLbl,iD0Lbl,iComp,ipD0,Work)
+!         Call PrMtrx(RlxLbl,iD0Lbl,iComp,[1],D0)
 
-
-           Call Getmem('TMP','ALLO','REAL',ipT,2*ndens)
-           Call Get_D1I(Work(ipCMO),Work(ipD0+0*ndens),Work(ipT),
-     &                  nish,nbas,nIrrep)
-           Call Getmem('TMP','FREE','REAL',ipT,2*ndens)
+           Call mma_allocate(Tmp,nDens,2,Label='Tmp')
+           Call Get_D1I(CMO(1,1),D0(1,1),Tmp,nIsh,nBas,nIrrep)
+           Call mma_deallocate(Tmp)
 
 !************************
          RlxLbl='D1AO    '
-!         Call PrMtrx(RlxLbl,iD0Lbl,iComp,ipD0,Work)
+!         Call PrMtrx(RlxLbl,iD0Lbl,iComp,[1],D0)
 *
-           Call dcopy_(ndens,Work(ipDVar),1,Work(ipD0+1*ndens),1)
-           If (.not.isNAC) call daxpy_(ndens,-Half,Work(ipD0+0*ndens),1,
-     &                                             Work(ipD0+1*ndens),1)
-!         RlxLbl='D1COMBO  '
-!         Call PrMtrx(RlxLbl,iD0Lbl,iComp,ipD0+1*ndens,Work)
+           Call dcopy_(ndens,DVar,1,D0(1,2),1)
+           If (.not.isNAC) call daxpy_(ndens,-Half,D0(1,1),1,D0(1,2),1)
+!          RlxLbl='D1COMBO  '
+!          Call PrMtrx(RlxLbl,iD0Lbl,iComp,[1],D0(1,2))
 *
 *   This is necessary for the kap-lag
 *
-           Call Get_D1AV(ipD1AV,Length)
            nG1 = nAct*(nAct+1)/2
-           If (ng1.ne.Length) Then
-              Call WarningMessage(2,'PrepP: D1AV, nG1.ne.Length!')
-              Write (6,*) 'nG1,Length=',nG1,Length
-              if(doDMRG)then ! yma
-                If (length.ne.ng1) length=nG1
-              else
-                Call Abend()
-              end if
-              Call Abend()
-           End If
-           Call Get_D1A(Work(ipCMO),Work(ipD1AV),Work(ipD0+2*ndens),
+           Call mma_allocate(D1AV,nG1,Label='D1AV')
+           Call Get_D1AV(D1AV,nG1)
+           Call Get_D1A(CMO(1,1),D1AV,D0(1,3),
      &                 nIrrep,nbas,nish,nash,ndens)
-           Call Free_Work(ipD1AV)
+           Call mma_deallocate(D1AV)
 !************************
-         RlxLbl='D1AOA   '
-!         Call PrMtrx(RlxLbl,iD0Lbl,iComp,ipD0+2*ndens,Work)
+!          RlxLbl='D1AOA   '
+!          Call PrMtrx(RlxLbl,iD0Lbl,iComp,[1],D0(1,3))
 *
-           Call Get_DLAO(ipDLAO,Length)
-           call dcopy_(Length,Work(ipDLAO),1,Work(ipD0+3*ndens),1)
+           Call Get_DLAO(D0(:,4),nDens)
 
 !ANDREW - modify D2: should contain only the correction pieces
 
          If ( Method.eq.'MCPDFT  ') then
-          call daxpy_(ndens,-Half,Work(ipD0+0*ndens),1,
-     &                                             Work(ipD0+1*ndens),1)
-          call daxpy_(ndens,-1.0d0,Work(ipD0+2*ndens),1,
-     &                                             Work(ipD0+1*ndens),1)
-!ANDREW - Generate new D5 piece:
-          call dcopy_(ndens,[0.0d0],0,
-     &                                             Work(ipD0+4*ndens),1)
-          call daxpy_(ndens,0.5d0,Work(ipD0+0*ndens),1,
-     &                                             Work(ipD0+4*ndens),1)
-          call daxpy_(ndens,1.0d0,Work(ipD0+2*ndens),1,
-     &                                             Work(ipD0+4*ndens),1)
+!Get the D_theta piece
+            Call mma_allocate(D1ao,nDens)
+            Call Get_D1ao(D1ao,ndens)
+            ij = 0
+            Do  iIrrep = 0, nIrrep-1
+               Do iBas = 1, nBas(iIrrep)
+                  Do jBas = 1, iBas-1
+                     ij = ij + 1
+                     D1ao(ij) = Half*D1ao(ij)
+                  end do
+                  ij = ij + 1
+                end do
+            end do
+            call daxpy_(ndens,-1d0,D0(1,1),1,D1ao,1)
+!           write(*,*) 'do they match?'
+!           do i=1,ndens
+!             write(*,*) d1ao(i),DO(i,3)
+!           end do
+
+            call daxpy_(ndens,-Half,D0(1,1),1,D0(1,2),1)
+            call daxpy_(ndens,-1.0d0,D1ao,1,D0(1,2),1)
+!ANDREW -   Generate new D5 piece:
+            D0(:,5)=Zero
+            call daxpy_(ndens,0.5d0,D0(1,1),1,D0(1,5),1)
+            call daxpy_(ndens,1.0d0,D1ao,1,D0(1,5),1)
+            Call mma_deallocate(D1ao)
           end if
 
-
-!          call dcopy_(ndens*5,0.0d0,0,
-!     &                                             Work(ipD0),1)
-!          call dcopy_(nG2,0.0d0,0,
-!     &                                             Work(ipG2),1)
+!          call dcopy_(ndens*5,0.0d0,0,D0,1)
+!          call dcopy_(nG2,0.0d0,0,G2,1)
 
 
-           Call Free_Work(ipDLAO)
 !************************
-           !Call dscal_(Length,0.5d0,Work(ipD0+3*ndens),1)
-           !Call dscal_(Length,0.0d0,Work(ipD0+3*ndens),1)
+           !Call dscal_(Length,0.5d0,D0(1,4),1)
+           !Call dscal_(Length,0.0d0,D0(1,4),1)
 
          RlxLbl='DLAO    '
-!         Call PrMtrx(RlxLbl,iD0Lbl,iComp,ipD0+3*ndens,Work)
+!         Call PrMtrx(RlxLbl,iD0Lbl,iComp,[1],D0(1,4))
 ! DMRG with the reduced AS
            if(doDMRG)then
              length=ndim1  !yma
            end if
          End If
-         If (iPrint.ge.99) Call TriPrt(' G2',' ',Work(ipG2),nG1)
+         If (iPrint.ge.99) Call TriPrt(' G2',' ',G2(1,1),nG1)
 *
 *...  Close 'RELAX' file
 1000     Continue
@@ -602,7 +546,6 @@ c       close (lgtoc)
       Prepp_CPU  = PreppCPU2 - PreppCPU1
       Prepp_Wall = PreppWall2 - PreppWall1
 #endif
-      Call qExit('PrepP')
 
       Return
       End
@@ -639,60 +582,52 @@ c       close (lgtoc)
 
       Subroutine Get_D1A(CMO,D1A_MO,D1A_AO,
      &                    nsym,nbas,nish,nash,ndens)
-
-
       Implicit Real*8 (A-H,O-Z)
-
+#include "real.fh"
+#include "stdalloc.fh"
       Dimension CMO(*) , D1A_MO(*) , D1A_AO(*)
       Integer nbas(nsym),nish(nsym),nash(nsym)
+      Real*8, Allocatable:: Scr1(:), Tmp1(:,:), Tmp2(:,:)
 
-#include "WrkSpc.fh"
-#include "real.fh"
       itri(i,j)=Max(i,j)*(Max(i,j)-1)/2+Min(i,j)
 
-      Call qEnter('Get_D1A')
 
-      iOff1 = 1
       iOff2 = 1
       iOff3 = 1
       ii=0
-      Call GetMem('Scr1','Allo','Real',ip1,2*ndens)
+      Call mma_allocate(Scr1,2*nDens,Label='Scr1')
       Do iSym = 1,nSym
         iBas = nBas(iSym)
         iAsh = nAsh(iSym)
         iIsh = nIsh(iSym)
-        Call dCopy_(iBas*iBas,[Zero],0,Work(ip1-1+iOff3),1)
+        Call dCopy_(iBas*iBas,[Zero],0,Scr1(iOff3),1)
         If ( iAsh.ne.0 ) then
-          Call GetMem('Scr1','Allo','Real',iTmp1,iAsh*iAsh)
-          Call GetMem('Scr2','Allo','Real',iTmp2,iAsh*iBas)
-          ij=0
-          Do i=1,iash
-           Do j=1,iash
-            Work(iTmp1+ij)=D1A_MO(itri(i+ii,j+ii))
-            ij=ij+1
+          Call mma_allocate(Tmp1,iAsh,iAsh,Label='Tmp1')
+          Call mma_allocate(Tmp2,iBas,iAsh,Label='Tmp2')
+          Do i=1,iAsh
+           Do j=1,iAsh
+            Tmp1(j,i)=D1A_MO(itri(i+ii,j+ii))
            End do
           End do
           ii=ii+iash
           Call DGEMM_('N','T',
      &                iBas,iAsh,iAsh,
      &                One,CMO(iOff2+iIsh*iBas),iBas,
-     &                Work(iTmp1),iAsh,
-     &                Zero,Work(iTmp2),iBas)
+     &                    Tmp1,iAsh,
+     &               Zero,Tmp2,iBas)
           Call DGEMM_('N','T',
      &                iBas,iBas,iAsh,
-     &                One,Work(iTmp2),iBas,
-     &                CMO(iOff2+iIsh*iBas),iBas,
-     &                Zero,Work(ip1-1+iOff3),iBas)
-          Call GetMem('Scr2','Free','Real',iTmp2,iAsh*iBas)
-          Call GetMem('Scr1','Free','Real',iTmp1,iAsh*iAsh)
+     &                One,Tmp2,iBas,
+     &                    CMO(iOff2+iIsh*iBas),iBas,
+     &               Zero,Scr1(iOff3),iBas)
+          Call mma_deallocate(Tmp2)
+          Call mma_deallocate(Tmp1)
         End If
-        iOff1 = iOff1 + (iAsh*iAsh+iAsh)/2
         iOff2 = iOff2 + iBas*iBas
         iOff3 = iOff3 + iBas*iBas
       End Do
-      Call Fold2(nsym,nBas,work(ip1),D1A_AO)
-      Call GetMem('Scr1','FREE','Real',ip1,ndens)
-      Call qExit('Get_D1A')
+      Call Fold2(nSym,nBas,Scr1,D1A_AO)
+      Call mma_deallocate(Scr1)
       Return
       End
 
