@@ -9,17 +9,21 @@
 * LICENSE or in <http://www.gnu.org/licenses/>.                        *
 ************************************************************************
       subroutine xsetmem_ints(mem)
+      use k2_arrays, only: Sew_Scr
       implicit real*8 (a-h,o-z)
 #include "status.fh"
+#include "stdalloc.fh"
 c
       If (XMem_Status.eq.Active) Then
          Call WarningMessage(2,
      &               'External handling of scratch already active!')
          Call Abend()
       End If
-      Call GetMem('SewMem','ALLONOGARBLE','REAL',ipt,mem)
-      Call SetMem_Ints(ipt,Mem)
+C     Write (6,*) 'xsetmem_ints: External allocate:',Mem
+      Call mma_allocate(Sew_Scr,Mem,Label='Sew_Scr')
       XMem_Status=Active
+C     Call mma_MaxDBLE(nu)
+C     Write (6,*) 'xsetmem_ints: External allocate left to allocate:',nu
 *
       Return
       End
