@@ -34,7 +34,6 @@
       DIMENSION IOCTYP(MXPSTT),IREOSPGP(MXPSTT),ISCR(MXPSTT)
       INTEGER IOCCLS(1),IBASSPC(1)
 *
-      CALL QENTER('STRTY')
       NTESTL = 00
       NTEST = MAX(IPRNT,NTESTL)
 *. As input NCISPC GAS spaces IGSOCCX are given.
@@ -172,7 +171,6 @@ C     END DO
 *.
 *. Occupation classes corresponding to largest CI space
 *
-C     CALL QENTER('OCCLS')
       IBASSPC(1)=0
       CALL OCCLS(         1,    NOCCLS,    IOCCLS,    NACTEL,      NGAS,
      &           IGSOCC(1,1),IGSOCC(1,2),       0,    IBASSPC,   NOBPT)
@@ -607,7 +605,6 @@ C?      CALL IWRTMA(IREOSPGP,1,NSPGP,1,NSPGP)
         END DO
       END IF
 *
-      CALL QEXIT('STRTY')
 *
       RETURN
       END
