@@ -71,7 +71,6 @@
 ************************************************************************
 *                                                                      *
       cpubas=seconds()
-      Call qEnter('MP2_Driver')
       Call Set_Data
 *
 ************************************************
@@ -546,8 +545,6 @@ CGG      DoExch2=.True. ! Do generate Exch-2 integrals (not really used).
       Call GetMem('EOrb  ','Free','Real',mAdEOr,lthEOr)
       Call GetMem('CMO   ','Free','Real',mAdCMO,lthCMO)
 *
-      Call qExit('MP2_Driver')
-      Call qStat(' ')
       ireturn=0
 *                                                                      *
 ************************************************************************
