@@ -12,9 +12,8 @@
 ************************************************************************
       SubRoutine CtrlMO(moip,nAcO)
 *
+      use Symmetry_Info, only: nIrrep
       Implicit Real*8 (a-h,o-z)
-#include "itmax.fh"
-#include "info.fh"
 #include "etwas.fh"
       Integer moip(0:nIrrep-1)
 *
