@@ -24,25 +24,6 @@
 *         b) refer to the components of the cartesian or spherical     *
 *         harmonic gaussians.                                          *
 *                                                                      *
-* Called from: Seward                                                  *
-*                                                                      *
-* Calling    : QEnter                                                  *
-*              GetMem                                                  *
-*              ZXia                                                    *
-*              SetUp1                                                  *
-*              Kernel                                                  *
-*              RecPrt                                                  *
-*              DCopy    (ESSL)                                         *
-*              DGEMM_   (ESSL)                                         *
-*              CarSph                                                  *
-*              DGeTMO   (ESSL)                                         *
-*              DaXpY    (ESSL)                                         *
-*              SOGthr                                                  *
-*              DesymD                                                  *
-*              DScal    (ESSL)                                         *
-*              TriPrt                                                  *
-*              QExit                                                   *
-*                                                                      *
 *     Author: Roland Lindh, IBM Almaden Research Center, San Jose, CA  *
 *             January '90                                              *
 *             Anders Bernhardsson  Dec '94                             *
@@ -56,10 +37,14 @@
 ************************************************************************
       use Real_Spherical
       use iSD_data
+      use Basis_Info
+      use Center_Info
+      use Symmetry_Info, only: nIrrep, iOper
+      use Sizes_of_Seward, only: S
       Implicit Real*8 (A-H,O-Z)
-      External Kernel, KrnlMm
-#include "itmax.fh"
-#include "info.fh"
+*     External Kernel, KrnlMm
+      External KrnlMm
+#include "Molcas.fh"
 #include "real.fh"
 #include "WrkSpc.fh"
 c#include "print.fh"
@@ -77,23 +62,36 @@ c     Character ChOper(0:7)*3
       Logical AeqB, EQ, TstFnc, DiffOp, IfHss(0:1,0:2,0:1,0:2),
      &        TF,Chck,ifgrd(0:2,0:1)
 c     Data ChOper/'E  ','x  ','y  ','xy ','z  ','xz ','yz ','xyz'/
+*                                                                      *
+************************************************************************
+*                                                                      *
+      Interface
+      Subroutine Kernel(
+#define _CALLING_
+#include "hss_interface.fh"
+     &                 )
+#include "hss_interface.fh"
+      End Subroutine Kernel
+      End Interface
+*                                                                      *
+************************************************************************
+*                                                                      *
 *
 *     Statement functions
 *
       nElem(ixyz) = (ixyz+1)*(ixyz+2)/2
       itri(i1,i2)=MAX(i1,i2)*(MAX(i1,i2)-1)/2+MIN(i1,i2)
-      TF(mdc,iIrrep,iComp) = TstFnc(iOper,nIrrep,iCoSet(0,0,mdc),
-     &                       nIrrep/nStab(mdc),iChTbl,iIrrep,iComp,
-     &                       nStab(mdc))
+      TF(mdc,iIrrep,iComp) = TstFnc(dc(mdc)%iCoSet,
+     &                              iIrrep,iComp,dc(mdc)%nStab)
 *
       call dcopy_(nHess,[Zero],0,Hess,1)
 *
 *     Auxiliary memory allocation.
 *
-      Call GetMem('Zeta','ALLO','REAL',iZeta,m2Max)
-      Call GetMem('Zeta','ALLO','REAL',ipZI ,m2Max)
-      Call GetMem('Kappa','ALLO','REAL',iKappa,m2Max)
-      Call GetMem('PCoor','ALLO','REAL',iPCoor,m2Max*3)
+      Call GetMem('Zeta','ALLO','REAL',iZeta,S%m2Max)
+      Call GetMem('Zeta','ALLO','REAL',ipZI ,S%m2Max)
+      Call GetMem('Kappa','ALLO','REAL',iKappa,S%m2Max)
+      Call GetMem('PCoor','ALLO','REAL',iPCoor,S%m2Max*3)
 *                                                                      *
 ************************************************************************
 *                                                                      *
@@ -120,56 +118,56 @@ C     Do iS = 1, nSkal
          iAng   = iSD( 1,iS)
          iCmp   = iSD( 2,iS)
          iBas   = iSD( 3,iS)
-         iCff   = iSD( 4,iS)
          iPrim  = iSD( 5,iS)
-         iExp   = iSD( 6,iS)
          iAO    = iSD( 7,iS)
-         ixyz   = iSD( 8,iS)
          mdci   = iSD(10,iS)
          iShell = iSD(11,iS)
+         iCnttp = iSD(13,iS)
+         iCnt   = iSD(14,iS)
+         A(1:3)=dbsc(iCnttp)%Coor(1:3,iCnt)
 *
 C        Do jS = 1, iS
             jShll  = iSD( 0,jS)
             jAng   = iSD( 1,jS)
             jCmp   = iSD( 2,jS)
             jBas   = iSD( 3,jS)
-            jCff   = iSD( 4,jS)
             jPrim  = iSD( 5,jS)
-            jExp   = iSD( 6,jS)
             jAO    = iSD( 7,jS)
-            jxyz   = iSD( 8,jS)
             mdcj   = iSD(10,jS)
             jShell = iSD(11,jS)
+            jCnttp = iSD(13,jS)
+            jCnt   = iSD(14,jS)
+            B(1:3)=dbsc(jCnttp)%Coor(1:3,jCnt)
 C        write(6,*)
-C    &  'iShll,iAng,iCmp,iBas,iCff,iPrim,iExp,iAO,ixyz,mdci,iShell'
+C    &  'iShll,iAng,iCmp,iBas,iPrim,iAO,ixyz,mdci,iShell'
 C        write(6,*) (iSD(i,iS),i=0,11)
 C        write(6,*)
-C    &  'jShll,jAng,jCmp,jBas,jCff,jPrim,jExp,jAO,jxyz,mdcj,jShell'
+C    &  'jShll,jAng,jCmp,jBas,jPrim,jAO,jxyz,mdcj,jShell'
 C        write(6,*) (iSD(i,jS),i=0,11)
 *
 *       Call kernel routine to get memory requirement.
 *
         nOrdOp = 0  ! not used in this implementation
         Call KrnlMm(nOrder,MemKer,iAng,jAng,nOrdOp)
-        MemKrn=MemKer*m2Max
+        MemKrn=MemKer*S%m2Max
         Call GetMem('Kernel','ALLO','REAL',iKern,MemKrn)
 *
 *       Allocate memory for the final integrals, all in the
 *       primitive basis.
 *
-        lFinal = 21 * MaxPrm(iAng) * MaxPrm(jAng) *
+        lFinal = 21 * S%MaxPrm(iAng) * S%MaxPrm(jAng) *
      &           nElem(iAng)*nElem(jAng)
         Call GetMem('Final','ALLO','REAL',ipFnl,lFinal)
 *
 *       Scratch area for contraction step
 *
-        nScr1 =  MaxPrm(iAng)*MaxPrm(jAng) *
+        nScr1 =  S%MaxPrm(iAng)*S%MaxPrm(jAng) *
      &           nElem(iAng)*nElem(jAng)
         Call GetMem('Scrtch','ALLO','REAL',iScrt1,nScr1)
 *
 *       Scratch area for the transformation to spherical gaussians
 *
-        nScr2=MaxPrm(iAng)*MaxPrm(jAng)*nElem(iAng)*nElem(jAng)
+        nScr2=S%MaxPrm(iAng)*S%MaxPrm(jAng)*nElem(iAng)*nElem(jAng)
         Call GetMem('ScrSph','Allo','Real',iScrt2,nScr2)
 *
           Call GetMem(' DAO ','Allo','Real',ipDAO,
@@ -178,28 +176,24 @@ C        write(6,*) (iSD(i,jS),i=0,11)
 *         At this point we can compute Zeta.
 *
           Call ZXia(Work(iZeta),Work(ipZI),
-     &              iPrim,jPrim,Work(iExp),Work(jExp))
-*
-           call dcopy_(3,Work(ixyz),1,A,1)
-*
-            call dcopy_(3,Work(jxyz),1,B,1)
+     &              iPrim,jPrim,Shells(iShll)%Exp,
+     &                          Shells(jShll)%Exp)
 *
             AeqB = iS.eq.jS
 
 *
 *           Find the DCR for A and B
 *
-            Call DCR(LmbdR,iOper,nIrrep,
-     &               jStab(0,mdci),nStab(mdci),
-     &               jStab(0,mdcj),nStab(mdcj),iDCRR,nDCRR)
+            Call DCR(LmbdR,dc(mdci)%iStab,dc(mdci)%nStab,
+     &                     dc(mdcj)%iStab,dc(mdcj)%nStab,iDCRR,nDCRR)
             If (.Not.DiffOp .and. nDCRR.eq.1 .and. EQ(A,B)) Go To 131
 c           If (iPrint.ge.49) Write (6,'(10A)')
 c    &         ' {R}=(',(ChOper(iDCRR(i)),i=0,nDCRR-1),')'
 *
 *-----------Find the stabilizer for A and B
 *
-            Call Inter(jStab(0,mdci),nStab(mdci),
-     &                 jStab(0,mdcj),nStab(mdcj),
+            Call Inter(dc(mdci)%iStab,dc(mdci)%nStab,
+     &                 dc(mdcj)%iStab,dc(mdcj)%nStab,
      &                 iStabM,nStabM)
 *
 *          Generate all possible (left) CoSet
@@ -244,9 +238,7 @@ c    &         ' {R}=(',(ChOper(iDCRR(i)),i=0,nDCRR-1),')'
                       iComp1=2**iCar
                       iComp2=2**jCar
                       iComp=iEOr(iComp1,iComp2)
-                      Chck=TstFnc(iOper,nIrrep,iCoM,
-     &                       nCoM,iChTbl,0,iComp,
-     &                       nStabM)
+                      Chck=TstFnc(iCoM,0,iComp,nStabM)
                       If (Chck)
      &                  IfHss(iAtom,iCar,jAtom,jCar)=.true.
  430            Continue
@@ -256,7 +248,8 @@ c    &         ' {R}=(',(ChOper(iDCRR(i)),i=0,nDCRR-1),')'
            Call ICopy(nirrep*36,[0],0,Indhss(0,0,0,0,0),1)
            Call ICopy(nirrep*6,[0],0,indgrd,1)
 *
-*          Determine which displacement in all IR's, each center is associated with
+*          Determine which displacement in all IR''s, each center is
+*          associated with.
 *
            nnIrrep=nIrrep
            If (sIrrep) nnIrrep=1
@@ -264,7 +257,7 @@ c    &         ' {R}=(',(ChOper(iDCRR(i)),i=0,nDCRR-1),')'
            Do 200   iIrrep=0,nnIrrep-1
              nDisp1 = IndDsp(mdci,iIrrep)
              nDisp2 = IndDsp(mdcj,iIrrep)
-             Do 200 iCar = 0,2
+             Do 201 iCar = 0,2
               iComp = 2**iCar
               If ( TF(mdci,iIrrep,iComp)) Then
                  nDisp1 = nDisp1 + 1
@@ -283,6 +276,7 @@ c    &         ' {R}=(',(ChOper(iDCRR(i)),i=0,nDCRR-1),')'
                  IndGrd(iCar,1,iIrrep)=0
                  if (iIrrep.eq.0) IfGrd(iCar,1) = .True.
               End If
+ 201         Continue
  200       Continue
 *
 *          Determine index for each 2'nd derivative
@@ -315,7 +309,7 @@ c    &         ' {R}=(',(ChOper(iDCRR(i)),i=0,nDCRR-1),')'
            If (.not.DiffOp) Then
                iAtom=1
                Do 440 iCar=0,2
-               Do 440 jAtom=0,1
+               Do 441 jAtom=0,1
                    If (iAtom.eq.jAtom) Then
                      iStop=iCar
                    Else
@@ -331,6 +325,7 @@ c    &         ' {R}=(',(ChOper(iDCRR(i)),i=0,nDCRR-1),')'
  445                  Continue
                     End If
  460               Continue
+ 441           Continue
  440           Continue
 *
             End If
@@ -339,7 +334,7 @@ c    &         ' {R}=(',(ChOper(iDCRR(i)),i=0,nDCRR-1),')'
 *           pair.
 *
             iSmLbl = 1
-            nSO = MemSO1(iSmLbl,iCmp,jCmp,iShell,jShell)
+            nSO = MemSO1(iSmLbl,iCmp,jCmp,iShell,jShell,iAO,jAO)
             If (nSO.eq.0) Go To 131
             Call GetMem('DSOpr ','ALLO','REAL',ipDSOp,nSO*iPrim*jPrim)
             Call GetMem('DSO ','ALLO','REAL',ipDSO,nSO*iPrim*jPrim)
@@ -350,29 +345,30 @@ c    &         ' {R}=(',(ChOper(iDCRR(i)),i=0,nDCRR-1),')'
 *
             Call SOGthr(Work(ipDSO),iBas,jBas,nSO,FD,
      &                  n2Tri(iSmLbl),iSmLbl,
-     &                  iCmp,jCmp,iShell,jShell,AeqB,iAO,jAO)
+     &                  iCmp,jCmp,iShell,jShell,
+     &                  AeqB,iAO,jAO)
 *
 *           Project the Fock/1st order density matrix in AO
 *           basis on to the primitive basis.
 *
 c           If (iPrint.ge.99) Then
 c              Call RecPrt(' Left side contraction',' ',
-c    &                     Work(iCff),iPrim,iBas)
+c    &                     Shells(iShll)%pCff,iPrim,iBas)
 c              Call RecPrt(' Right side contraction',' ',
-c    &                     Work(jCff),jPrim,jBas)
+c    &                     Shells(jShll)%pCff,jPrim,jBas)
 c           End If
 *
 *           Transform IJ,AB to J,ABi
             Call DGEMM_('T','T',
      &                  jBas*nSO,iPrim,iBas,
      &                  1.0d0,Work(ipDSO),iBas,
-     &                  Work(iCff),iPrim,
+     &                        Shells(iShll)%pCff,iPrim,
      &                  0.0d0,Work(ipDSOp),jBas*nSO)
 *           Transform J,ABi to AB,ij
             Call DGEMM_('T','T',
      &                  nSO*iPrim,jPrim,jBas,
      &                  1.0d0,Work(ipDSOp),jBas,
-     &                  Work(jCff),jPrim,
+     &                        Shells(jShll)%pCff,jPrim,
      &                  0.0d0,Work(ipDSO),nSO*iPrim)
 *           Transpose to ij,AB
             Call DGeTmO(Work(ipDSO),nSO,nSO,iPrim*jPrim,Work(ipDSOp),
@@ -385,13 +381,11 @@ c    &                ' ',Work(ipDSOp),iPrim*jPrim,nSO)
 *
 *           Loops over symmetry operations.
 *
-            nOp(1) = NrOpr(0,iOper,nIrrep)
+            nOp(1) = NrOpr(0)
             if(jBas.lt.-999999) write(6,*) 'gcc overoptimization',nDCRR
             Do 140 lDCRR = 0, nDCRR-1
-               RB(1)  = DBLE(iPhase(1,iDCRR(lDCRR)))*B(1)
-               RB(2)  = DBLE(iPhase(2,iDCRR(lDCRR)))*B(2)
-               RB(3)  = DBLE(iPhase(3,iDCRR(lDCRR)))*B(3)
-               nOp(2) = NrOpr(iDCRR(lDCRR),iOper,nIrrep)
+               Call OA(iDCRR(lDCRR),B,RB)
+               nOp(2) = NrOpr(iDCRR(lDCRR))
                If (EQ(A,RB).and. (.Not.DiffOp)) Go To 140
 *
 c              If (iPrint.ge.49) Then
@@ -404,13 +398,12 @@ c              End If
                   llOper = iOr(llOper,lOper(iComp))
  5000          Continue
                Call SOS(iStabO,nStabO,llOper)
-               Call DCR(LmbdT,iOper,nIrrep,iStabM,nStabM,iStabO,nStabO,
-     &                  iDCRT,nDCRT)
+               Call DCR(LmbdT,iStabM,nStabM,iStabO,nStabO,iDCRT,nDCRT)
 *
 *--------------Compute normalization factor due the DCR symmetrization
 *              of the two basis functions and the operator.
 *
-               iuv = nStab(mdci)*nStab(mdcj)
+               iuv = dc(mdci)%nStab*dc(mdcj)%nStab
                FactNd = DBLE(iuv*nStabO) / DBLE(nIrrep**2 * LmbdT)
                If (MolWgh.eq.1) Then
                   FactNd = FactNd * DBLE(nIrrep)**2 / DBLE(iuv)
@@ -430,14 +423,14 @@ c              End If
 *
                Call DesymD(iSmLbl,iAng,jAng,iCmp,jCmp,
      &                     iShell,jShell,iShll,jShll,
-     &                     Work(ipDAO),iPrim,jPrim,
+     &                     iAO,jAO,Work(ipDAO),iPrim,jPrim,
      &                     Work(ipDSOp),nSO,nOp,FactNd)
 *
 *--------------Project the spherical harmonic space onto the
 *              cartesian space.
 *
                kk = nElem(iAng)*nElem(jAng)
-               If (Transf(iShll).or.Transf(jShll)) Then
+               If (Shells(iShll)%Transf.or.Shells(jShll)%Transf) Then
 *
 *-----------------ij,AB --> AB,ij
                   Call DGeTmO(Work(ipDAO),iPrim*jPrim,iPrim*jPrim,
@@ -445,10 +438,12 @@ c              End If
 *-----------------AB,ij --> ij,ab
                   Call SphCar(Work(iScrt1),iCmp*jCmp,iPrim*jPrim,
      &                        Work(iScrt2),nScr2,
-     &                        RSph(ipSph(iAng)),
-     &                        iAng,Transf(iShll),Prjct(iShll),
-     &                        RSph(ipSph(jAng)),
-     &                        jAng,Transf(jShll),Prjct(jShll),
+     &                        RSph(ipSph(iAng)),iAng,
+     &                        Shells(iShll)%Transf,
+     &                        Shells(iShll)%Prjct,
+     &                        RSph(ipSph(jAng)),jAng,
+     &                        Shells(jShll)%Transf,
+     &                        Shells(jShll)%Prjct,
      &                        Work(ipDAO),kk)
                End If
 c              If (iPrint.ge.99) Call RecPrt(
@@ -457,8 +452,8 @@ c    &                  ' ',Work(ipDAO),iPrim*jPrim,kk)
 *
 *--------------Compute kappa and P.
 *
-c           Call GetMem('OneEl ','CHEC','REAL',iDum,iDum)
-               Call Setup1(Work(iExp),iPrim,Work(jExp),jPrim,
+               Call Setup1(Shells(iShll)%Exp,iPrim,
+     &                     Shells(jShll)%Exp,jPrim,
      &                     A,RB,Work(iKappa),Work(iPCoor),Work(ipZI))
 *
 *--------------Compute gradients of the primitive integrals and
@@ -467,7 +462,8 @@ c           Call GetMem('OneEl ','CHEC','REAL',iDum,iDum)
 *
 CBS            write(6,*) 'Call the  Kernel'
 *
-               Call Kernel(Work(iExp),iPrim,Work(jExp),jPrim,
+               Call Kernel(Shells(iShll)%Exp,iPrim,
+     &                     Shells(jShll)%Exp,jPrim,
      &                     Work(iZeta),Work(ipZI),
      &                     Work(iKappa),Work(iPcoor),
      &                     Work(ipFnl),iPrim*jPrim,
@@ -476,9 +472,9 @@ CBS            write(6,*) 'Call the  Kernel'
      &                     nOrdOp,Hess,nHess,
      &                     IfHss,IndHss,ifgrd,indgrd,Work(ipDAO),
      &                     mdci,mdcj,nOp,lOper,nComp,
-     &                     iStabM,nStabM)
+     &                     iStabM,nStabM,nIrrep)
 
-#ifdef _DEBUG_
+#ifdef _DEBUGPRINT_
                write(6,*)  'Hess after Kernel call in dot1el '
                Call HssPrt(Hess,nHess)
 #endif
@@ -501,10 +497,10 @@ C     End Do
 *
       Call Free_iSD()
 *
-      Call GetMem('Kappa','FREE','REAL',iKappa,n2Max)
-      Call GetMem('PCoor','FREE','REAL',iPCoor,n2Max*3)
-      Call GetMem('Zeta','FREE','REAL',ipZI ,n2Max)
-      Call GetMem('Zeta','FREE','REAL',iZeta,n2Max)
+      Call GetMem('Kappa','FREE','REAL',iKappa,S%m2Max)
+      Call GetMem('PCoor','FREE','REAL',iPCoor,S%m2Max*3)
+      Call GetMem('Zeta','FREE','REAL',ipZI ,S%m2Max)
+      Call GetMem('Zeta','FREE','REAL',iZeta,S%m2Max)
 *
       Return
 c Avoid unused argument warnings
