@@ -16,27 +16,20 @@
 *                                                                      *
 * Object: input module for the gradient code                           *
 *                                                                      *
-* Called from: McKinley                                                *
-*                                                                      *
-* Calling    : QEnter                                                  *
-*              GetMem                                                  *
-*              DCopy   (ESSL)                                          *
-*              RecPrt                                                  *
-*              DaXpY   (ESSL)                                          *
-*              DDot_   (ESSL)                                          *
-*              DScal   (ESSL)                                          *
-*              DGEMM_  (ESSL)                                          *
-*              QExit                                                   *
-*                                                                      *
 *     Author: Roland Lindh, Dept. of Theoretical Chemistry,            *
 *             University of Lund, SWEDEN                               *
-*             September '91                                            *
+*             September 1991                                           *
 *                                                                      *
-*             Modified to complement GetInf, January '92.              *
+*             Modified to complement GetInf, January 1992              *
 ************************************************************************
+      use Basis_Info
+      use Center_Info
+      use Symmetry_Info, only: nIrrep, iChTbl, iOper, lIrrep, lBsFnc
+      use Temporary_Parameters
+      use Real_Info, only: CutInt
       Implicit Real*8 (A-H,O-Z)
 #include "itmax.fh"
-#include "info.fh"
+#include "Molcas.fh"
 #include "real.fh"
 #include "disp.fh"
 #include "disp2.fh"
@@ -52,11 +45,9 @@ c      Logical DoCholesky
       character*4 lab
       Logical Run_MCLR
       Character*80  KWord, Key
-      Integer iSym(3), iTemp(3*mxdc)
+      Integer iSym(3), iTemp(3*MxAtom)
       Data xyz/'x','y','z'/
 *
-      Call QEnter('InputH')
-
 c      Call DecideOnCholesky(DoCholesky)
 c      If (DoCholesky) Then
 c       write(6,*)'** Cholesky or RI/DF not yet implemented in McKinley '
@@ -85,7 +76,7 @@ c      EndIf
       Call lCopy(mxpert,[.true.],0,lPert,1)
       sIrrep=.false.
       iprint=0
-      Do 109 i = 1, 3*mxdc
+      Do 109 i = 1, 3*MxAtom
          IndxEq(i) = i
  109  Continue
 *
@@ -97,9 +88,8 @@ c      EndIf
       KWord = Key
       Call UpCase(KWord)
       If (KWord(1:1).eq.'*')    Go To 998
-      If (KWord.eq.BLine)       Go To 998
+      If (KWord.eq.'')       Go To 998
 *     If (KWord(1:4).eq.'EQUI') Go To 935
-*     If (KWord(1:4).eq.'MEMO') Go To 951
 *     If (KWord(1:4).eq.'NOTR') Go To 952
 *     If (KWord(1:4).eq.'NOIN') Go To 953
       If (KWord(1:4).eq.'SHOW') Go To 992
@@ -119,15 +109,12 @@ c      EndIf
       If (KWord(1:4).eq.'END ') Go To 997
       Write (6,*) 'InputH: Illegal keyword'
       Write (6,'(A,A)') 'KWord=',KWord
-      Call QTrace
       Call Abend()
  977  Write (6,*) 'InputH: end of input file.'
       Write (6,'(A,A)') 'Last command=',KWord
-      Call QTrace
       Call Abend()
  988  Write (6,*) 'InputH: error reading input file.'
       Write (6,'(A,A)') 'Last command=',KWord
-      Call QTrace
       Call Abend()
 *                                                                      *
 ****** MEM  ************************************************************
@@ -142,7 +129,7 @@ c      EndIf
 *
 975   Read(5,'(A)',Err=988) KWord
       If (KWord(1:1).eq.'*') Go To 975
-      If (KWord.eq.BLine)    Go To 975
+      If (KWord.eq.'')    Go To 975
       Call UpCase(KWord)
       Lab=KWORD(1:4)
       If (KWORD(1:4).eq.'HESS') Then
@@ -152,7 +139,6 @@ c      EndIf
       Else
          Write (6,*) 'InputH: Illegal perturbation keyword'
          Write (6,'(A,A)') 'KWord=',KWord
-         Call QTrace
          Call Abend()
       End If
 
@@ -166,12 +152,12 @@ c      EndIf
 *     lEq=.True.
 *936  Read(5,'(A)',Err=988) KWord
 *     If (KWord(1:1).eq.'*') Go To 936
-*     If (KWord.eq.BLine)    Go To 936
+*     If (KWord.eq.'')    Go To 936
 *     Read(KWord,*) nGroup
 *     Do 937 iGroup = 1, nGroup
 *938     Read(5,'(A)',Err=988) KWord
 *        If (KWord(1:1).eq.'*') Go To 938
-*        If (KWord.eq.BLine)    Go To 938
+*        If (KWord.eq.'')    Go To 938
 *        Read(KWord,*) nElem,(iTemp(iElem),iElem=1,nElem)
 *        Do 939 iElem=2,nElem
 *           IndxEq(iTemp(iElem)) = iTemp(1)
@@ -186,22 +172,11 @@ c      EndIf
 *
  942  Read(5,*) Cutint
 *     If (KWord(1:1).eq.'*') Go To 942
-*     If (KWord.eq.BLine)    Go To 942
+*     If (KWord.eq.'')    Go To 942
 *     Read(KWord,*,Err=988) CutInt
       CutInt = Abs(CutInt)
       Go To 998
 *                                                                      *
-****** MEMO ************************************************************
-*                                                                      *
-*     Screen off memory
-*
-*951  Read(5,'(A)',Err=988) KWord
-*     If (KWord(1:1).eq.'*') Go To 951
-*     If (KWord.eq.BLine)    Go To 951
-*     Read(KWord,*,Err=988) MemHid
-*     If (MemHid.le.0) MemHid = 1
-*     Go To 998
-*                                                                      *
 ****** NOIN ************************************************************
 *                                                                      *
 *     Disable the utilization of translational and
@@ -221,7 +196,7 @@ c      EndIf
 *962  Continue
       Read(5,*) nslct
 *     If (KWord(1:1).eq.'*') Go To 962
-*     If (KWord.eq.BLine)    Go To 962
+*     If (KWord.eq.'')    Go To 962
 *     Read(KWord,*) nSlct
 *
       Read(5,*) (iTemp(iElem),iElem=1,nSlct)
@@ -316,7 +291,6 @@ c      EndIf
       Call OpnMck(irc,iOpt,'MCKINT',Lu_Mck)
       If (iRC.ne.0) Then
          Write (6,*) 'InputH: Error opening MCKINT'
-         Call QTrace
          Call Abend()
       End If
       If (ipert.eq.1) Then
@@ -338,7 +312,6 @@ c      EndIf
         Call cWrMck(iRC,iOpt,LabelOp,1,Label2,iDummer)
         Write (6,*) 'InputH: Illegal perturbation option'
         Write (6,*) 'iPert=',iPert
-        Call QTrace
         Call Abend()
       Else If (ipert.eq.4) Then
         LabelOp='PERT    '
@@ -346,12 +319,10 @@ c      EndIf
         Call cWrMck(iRC,iOpt,LabelOp,1,Label2,iDummer)
         Write (6,*) 'InputH: Illegal perturbation option'
         Write (6,*) 'iPert=',iPert
-        Call QTrace
         Call Abend()
       Else
         Write (6,*) 'InputH: Illegal perturbation option'
         Write (6,*) 'iPert=',iPert
-        Call QTrace
         Call Abend()
       End If
 
@@ -361,9 +332,9 @@ c      EndIf
       mDisp = 0
       mdc = 0
       Do 10 iCnttp = 1, nCnttp
-         Do 20 iCnt = 1, nCntr(iCnttp)
+         Do 20 iCnt = 1, dbsc(iCnttp)%nCntr
             mdc = mdc + 1
-            mDisp = mDisp + 3*(nIrrep/nStab(mdc))
+            mDisp = mDisp + 3*(nIrrep/dc(mdc)%nStab)
  20      Continue
  10   Continue
 *
@@ -396,8 +367,8 @@ c      EndIf
      &           '********************************************'
       Write (6,*)
       End If
-      Call ICopy(mxdc*8,[0],0,IndDsp,1)
-      Call ICopy(mxdc*3,[0],0,InxDsp,1)
+      Call ICopy(MxAtom*8,[0],0,IndDsp,1)
+      Call ICopy(MxAtom*3,[0],0,InxDsp,1)
       Call GetMem('ATDISP','ALLO','INTE',ipad,mdisp)
       Call GetMem('DEGDISP','ALLO','INTE',ipdd,mdisp)
       nDisp = 0
@@ -409,15 +380,14 @@ c      EndIf
          mc = 1
          Do 110 iCnttp = 1, nCnttp
 *           Loop over unique centers associated with this basis set.
-            Do 120 iCnt = 1, nCntr(iCnttp)
+            Do 120 iCnt = 1, dbsc(iCnttp)%nCntr
                mdc = mdc + 1
                IndDsp(mdc,iIrrep) = nDisp
 *              Loop over the cartesian components
                Do 130 iCar = 0, 2
                   iComp = 2**iCar
-                  If ( TstFnc(iOper,nIrrep,iCoSet(0,0,mdc),
-     &                nIrrep/nStab(mdc),iChTbl,iIrrep,
-     &                iComp,nStab(mdc)) ) Then
+                  If ( TstFnc(dc(mdc)%iCoSet,
+     &                       iIrrep,iComp,dc(mdc)%nStab) ) Then
                       nDisp = nDisp + 1
                       If (nDisp.gt.mDisp) Then
                          Write (6,*) 'nDisp.gt.mDisp'
@@ -442,20 +412,19 @@ c      EndIf
                       End If
                       If (iPrint.ge.6)
      &                Write (6,'(I4,3X,A8,5X,A1,7X,8(I3,4X,I2,4X))')
-     &                      nDisp,LblCnt(mdc),xyz(iCar),
-     &                      (mc+iCo,iPrmt(NrOpr(iCoSet(iCo,0,mdc),
-     &                      iOper,nIrrep),iComp)*
-     &                      iChTbl(iIrrep,NrOpr(iCoSet(iCo,0,mdc),
-     &                      iOper,nIrrep)),
-     &                      iCo=0,nIrrep/nStab(mdc)-1 )
+     &                      nDisp,dc(mdc)%LblCnt,xyz(iCar),
+     &                      (mc+iCo,iPrmt(
+     &                      NrOpr(dc(mdc)%iCoSet(iCo,0)),iComp)*
+     &                      iChTbl(iIrrep,NrOpr(dc(mdc)%iCoSet(iCo,0))),
+     &                      iCo=0,nIrrep/dc(mdc)%nStab-1 )
                       Write (ChDisp(nDisp),'(A,1X,A1)')
-     &                       LblCnt(mdc),xyz(iCar)
+     &                       dc(mdc)%LblCnt,xyz(iCar)
                       iwork(ipad+ndisp-1)=icnttp
-                      iwork(ipdd+ndisp-1)=nIrrep/nstab(mdc)
+                      iwork(ipdd+ndisp-1)=nIrrep/dc(mdc)%nStab
                   End If
 *
  130           Continue
-               mc = mc + nIrrep/nStab(mdc)
+               mc = mc + nIrrep/dc(mdc)%nStab
  120        Continue
  110     Continue
 *
@@ -464,7 +433,6 @@ c      EndIf
       If (nDisp.ne.mDisp) Then
          Write (6,*) 'InputH: nDisp.ne.mDisp'
          Write (6,*) 'nDisp,mDisp=',nDisp,mDisp
-         Call QTrace
          Call Abend()
       End If
       If (sIrrep) Then
@@ -482,7 +450,6 @@ c      EndIf
       If (iRC.ne.0) Then
          Write (6,*) 'InputH: Error writing to MCKINT'
          Write (6,'(A,A)') 'labelOp=',labelOp
-         Call QTrace
          Call Abend()
       End If
       LABEL='DEGDISP'
@@ -492,7 +459,6 @@ c      EndIf
       If (iRC.ne.0) Then
          Write (6,*) 'InputH: Error writing to MCKINT'
          Write (6,'(A,A)') 'LABEL=',LABEL
-         Call QTrace
          Call Abend()
       End If
       Call GetMem('DEGDISP','Free','INTE',ipdd,mDisp)
@@ -503,7 +469,6 @@ c      EndIf
       If (iRC.ne.0) Then
          Write (6,*) 'InputH: Error writing to MCKINT'
          Write (6,'(A,A)') 'LABEL=',LABEL
-         Call QTrace
          Call Abend()
       End If
       Call GetMem('ATDISP','Free','INTE',ipad,mDisp)
@@ -514,7 +479,6 @@ c      EndIf
       If (iRC.ne.0) Then
          Write (6,*) 'InputH: Error writing to MCKINT'
          Write (6,'(A,A)') 'LABEL=',LABEL
-         Call QTrace
          Call Abend()
       End If
       Call GetMem('TDISP','FREE','INTE',ipTD,ndisp)
@@ -585,41 +549,42 @@ c      EndIf
 *        Generate temporary information of the symmetrical
 *        displacements.
 *
-         ldsp = 0
+        ldsp = 0
          mdc = 0
          iIrrep = 0
          Do 2100 iCnttp = 1, nCnttp
-            jxyz = ipCntr(iCnttp)
-            Do 2200 iCnt = 1, nCntr(iCnttp)
+            Do 2200 iCnt = 1, dbsc(iCnttp)%nCntr
                mdc = mdc + 1
-*              Call RecPrt(' Coordinates',' ',Work(jxyz),1,3)
+*              Call RecPrt(' Coordinates',' ',
+*    &                     dbsc(iCnttp)%Coor(1,iCnt),1,3)
                Fact = Zero
                iComp = 0
-               If (Work(jxyz  ).ne.Zero) iComp = iOr(iComp,1)
-               If (Work(jxyz+1).ne.Zero) iComp = iOr(iComp,2)
-               If (Work(jxyz+2).ne.Zero) iComp = iOr(iComp,4)
+               If (dbsc(iCnttp)%Coor(1,iCnt).ne.Zero)
+     &            iComp = iOr(iComp,1)
+               If (dbsc(iCnttp)%Coor(2,iCnt).ne.Zero)
+     &            iComp = iOr(iComp,2)
+               If (dbsc(iCnttp)%Coor(3,iCnt).ne.Zero)
+     &            iComp = iOr(iComp,4)
                Do 2250 jIrrep = 0, nIrrep-1
-                  If ( TstFnc(iOper,nIrrep,iCoSet(0,0,mdc),
-     &                  nIrrep/nStab(mdc),iChTbl,jIrrep,
-     &                  iComp,nStab(mdc)) ) Then
+                  If ( TstFnc(dc(mdc)%iCoSet,
+     &                        jIrrep,iComp,dc(mdc)%nStab) ) Then
                      Fact = Fact + One
                   End If
  2250          Continue
                Do 2300 iCar = 0, 2
                   iComp = 2**iCar
-                  If ( TstFnc(iOper,nIrrep,iCoSet(0,0,mdc),
-     &                  nIrrep/nStab(mdc),iChTbl,iIrrep,
-     &                  iComp,nStab(mdc)) ) Then
+                  If ( TstFnc(dc(mdc)%iCoSet,
+     &                        iIrrep,iComp,dc(mdc)%nStab) ) Then
                      ldsp = ldsp + 1
 *--------------------Transfer the coordinates
                      ip = 4*(ldsp-1) + ipC
-                     call dcopy_(3,Work(jxyz),1,Work(ip),1)
+                     call dcopy_(3,dbsc(iCnttp)%Coor(:,iCnt),1,
+     &                          Work(ip),1)
 *--------------------Transfer the multiplicity factor
                      Work(ip+3) = Fact
                      iWork(ipCar-1+ldsp) = iCar + 1
                   End If
  2300          Continue
-               jxyz = jxyz + 3
  2200       Continue
  2100    Continue
          If (iPrint.ge.99) Then
@@ -813,19 +778,11 @@ c      EndIf
 *
  9876 Continue
       Call Datimx(KWord)
-      goto 888
-        Call qTrace
-        Write(6,*) ' *** Error in subroutine INPUTG ***'
-        Write(6,*) '     Abend in subroutine WrOne'
-        Call Abend
-
- 888  Continue
       Call ICopy(nIrrep,[0],0,nFck,1)
       Do iIrrep=0,nIrrep-1
         If (iIrrep.ne.0) Then
           Do jIrrep=0,nIrrep-1
-           kIrrep=NrOpr(iEOR(ioper(jIrrep),ioper(iIrrep)),
-     &                  iOper,nIrrep)
+           kIrrep=NrOpr(iEOR(ioper(jIrrep),ioper(iIrrep)))
            If (kIrrep.lt.jIrrep)
      &     nFck(iIrrep)=nFck(iIrrep)+nBas(jIrrep)*nBas(kIrrep)
           End Do
@@ -836,6 +793,5 @@ c      EndIf
         End If
       End Do
 *
-      Call QExit('InputH')
       Return
       End
