@@ -34,14 +34,6 @@
 *                                                                      *
 *   lZeta, lEta : section length after prescreening.                   *
 *                                                                      *
-* Called from: Twoel                                                   *
-*                                                                      *
-* Calling    : QEnter                                                  *
-*              DNrm2_  (ESSL)                                          *
-*              IDAMax_ (ESSL)                                          *
-*              DGeTMO  (ESSL)                                          *
-*              QExit                                                   *
-*                                                                      *
 *     Author: Roland Lindh, Dept. of Theoretical Chemistry,            *
 *             University of Lund, SWEDEN                               *
 *             March '92                                                *
@@ -63,14 +55,13 @@
       Logical PreScr,ldot
       Integer IndEta(nEta),IndZet(nZeta), IndZ(mZeta), IndE(mEta)
 #include "real.fh"
-#ifdef _DEBUG_
+#ifdef _DEBUGPRINT_
 #include "print.fh"
 #endif
 *
-#ifdef _DEBUG_
+#ifdef _DEBUGPRINT_
       iRout = 180
       iPrint = nPrint(iRout)
-      Call qEnter('Screen')
 *
       If (iPrint.ge.99) Then
          Call RecPrt(' Data1',' ',Data1,nZeta,nDArray)
@@ -225,10 +216,9 @@
             End Do
          End Do
       End If
-#ifdef _DEBUG_
+#ifdef _DEBUGPRINT_
       If (iPrint.ge.39) Call RecPrt(' PAO',' ',
      &                              PAO,lZeta*lEta,mPAO)
-      Call qExit('Screen')
 #endif
       Return
 c Avoid unused argument warnings
@@ -265,14 +255,6 @@ c Avoid unused argument warnings
 *                                                                      *
 *   lZeta, lEta : section length after prescreening.                   *
 *                                                                      *
-* Called from: Twoel                                                   *
-*                                                                      *
-* Calling    : QEnter                                                  *
-*              DNrm2_  (ESSL)                                          *
-*              IDAMax_ (ESSL)                                          *
-*              DGeTMO  (ESSL)                                          *
-*              QExit                                                   *
-*                                                                      *
 *     Author: Roland Lindh, Dept. of Theoretical Chemistry,            *
 *             University of Lund, SWEDEN                               *
 *             March '92                                                *
@@ -294,14 +276,13 @@ c Avoid unused argument warnings
       Logical PreScr,ldot
       Integer IndEta(nEta),IndZet(nZeta), IndZ(mZeta), IndE(mEta)
 #include "real.fh"
-#ifdef _DEBUG_
+#ifdef _DEBUGPRINT_
 #include "print.fh"
 #endif
 *
-#ifdef _DEBUG_
+#ifdef _DEBUGPRINT_
       iRout = 180
       iPrint = nPrint(iRout)
-      Call qEnter('Screen')
 *
       If (iPrint.ge.99) Then
          Call RecPrt(' Data1',' ',Data1,nZeta,nDArray)
@@ -450,10 +431,9 @@ c Avoid unused argument warnings
             End Do
          End Do
       End If
-#ifdef _DEBUG_
+#ifdef _DEBUGPRINT_
       If (iPrint.ge.39) Call RecPrt(' PAO',' ',
      &                              PAO,lZeta*lEta,mPAO)
-      Call qExit('Screen')
 #endif
       Return
 c Avoid unused argument warnings
