@@ -21,6 +21,7 @@
 #include "disp_mclr.fh"
 #include "cicisp_mclr.fh"
 #include "WrkSpc.fh"
+#include "stdalloc.fh"
 #include "real.fh"
 #include "sa.fh"
 #include "dmrginfo_mclr.fh"
@@ -32,6 +33,7 @@
        Integer iKapDisp(nDisp),iCiDisp(nDisp)
        Character(Len=16) mstate
        Dimension rdum(1),idum(7,8)
+       Real*8, Allocatable:: D_K(:), Tmp(:)
 *                                                                      *
 ************************************************************************
 *                                                                      *
@@ -39,7 +41,6 @@
 *                                                                      *
 ************************************************************************
 *                                                                      *
-       Call QEnter('Out_PT2')
        isym=1
        CI=.true.
        Call Setup_MCLR(iSym)
@@ -53,6 +54,7 @@
           nDLMO=nDLMO+nash(is)
           nLCMO=nLCMO+nbas(is)*nbas(is)
        End Do
+       nNAC=(nDLMO+nDLMO**2)/2
        nDLMO=nDLMO*(nDLMO+1)/2
        nPLMO=nDLMO*(nDLMO+1)/2
 *
@@ -292,12 +294,13 @@ c
 *
 *----- First we fix the renormalization contribution
 *
-       Call Get_Fock_Occ(ipD_K,Length)
+       Call mma_allocate(D_K,nLCMO,Label='D_K')
+       Call Get_Fock_Occ(D_K,nLCMO)
 *      Calculates the effective Fock matrix
        Call Make_Conn(Work(ipF),Work(ipK2),
      &                Work(ipP_CI),work(ipD_CI))   !ipD_CI not changed
-       Call DaxPy_(ndens2,One,Work(ipD_K),1,Work(ipF),1)
-*      call dcopy_(ndens2,Work(ipD_K),1,Work(ipF),1)
+       Call DaxPy_(ndens2,One,D_K,1,Work(ipF),1)
+*      call dcopy_(ndens2,D_K,1,Work(ipF),1)
        Call Put_Fock_Occ(Work(ipF),nTot1)
 *
 *      Transposed one index transformation of the density
@@ -322,7 +325,7 @@ c Mult all terms that are not diag by 2
 *      Now with active density too, to form the variational density
 *
 !      gives \tilde{D}
-       Call OITD(Work(ipK2),1,Work(ipD_K),Work(ipDtmp),.True.)
+       Call OITD(Work(ipK2),1,D_K,Work(ipDtmp),.True.)
 *
        Do iS=1,nsym
 c
@@ -344,7 +347,9 @@ c
        end if
 *
        If (isNAC) Then
-         Call Get_D1MO(ipG1q,ng1)
+         ng1=nNAC
+         Call Getmem('TMP', 'ALLO','Real',ipG1q,ng1)
+         Call Get_D1MO(Work(ipG1q),ng1)
          iR = 0 ! set to dummy value.
        Else
          iR=iroot(istate)
@@ -367,10 +372,8 @@ c
 *    Construct a variationally stable density matrix. In MO
 c
 c D_eff = D^j + \tilde{D} +\bar{D}
-c ipD_K = (ipG1q + inact) + ipD_K + ipD_CI
+c D_K = (ipG1q + inact) + D_K + ipD_CI
 *
-C
-C       call dcopy_(ndens2, [Zero], 0, Work(ipD_K), 1)  !DEBUG
 C
        If (isNAC) Then
 *
@@ -384,15 +387,15 @@ c Note: no inactive part for transition densities
             j=jA+nish(is)
             iAA=iA+na(is)
             jAA=jA+na(is)
-            Work(ipD_K+ipmat(is,is)-1+i-1+(j-1)*nbas(is))=
-     &       Work(ipD_K+ipmat(is,is)-1+i-1+(j-1)*nbas(is))
+            D_K(ipmat(is,is)+i-1+(j-1)*nbas(is))=
+     &       D_K(ipmat(is,is)+i-1+(j-1)*nbas(is))
      &      +Work(ipD_CI+iAA-1+(jAA-1)*ntash)
      &      +Work(ipG1q-1+itri(iAA,jAA))
            End Do
           End Do
          End Do
          Call Getmem('TMP', 'ALLO','Real',ipT,nBuf/2)
-         Call NatOrb(Work(ipD_K),Work(ipCMO),Work(ipCMON),Work(ipO))
+         Call NatOrb(D_K,Work(ipCMO),Work(ipCMON),Work(ipO))
          Call dmat_MCLR(Work(ipCMON),Work(ipO),Work(ipT))
          Call Put_D1ao_var(Work(ipT),nTot1)
          Call Getmem('TMP', 'FREE','Real',ipT,nBuf/2)
@@ -449,8 +452,8 @@ c Note: no inactive part for transition densities
 c
 c The inactive density
 c
-           Work(ipD_K+ipmat(is,is)-1+i-1+(i-1)*nbas(is))=
-     &     Work(ipD_K+ipmat(is,is)-1+i-1+(i-1)*nbas(is))+Two
+           D_K(ipmat(is,is)+i-1+(i-1)*nbas(is))=
+     &     D_K(ipmat(is,is)+i-1+(i-1)*nbas(is))+Two
           End DO
           Do iA=1,nash(is)
            Do jA=1,nash(is)
@@ -461,8 +464,8 @@ c
 c
 c The active density ipG1q and \bar{D}
 c
-            Work(ipD_K+ipmat(is,is)-1+i-1+(j-1)*nbas(is))=
-     &       Work(ipD_K+ipmat(is,is)-1+i-1+(j-1)*nbas(is))
+            D_K(ipmat(is,is)+i-1+(j-1)*nbas(is))=
+     &       D_K(ipmat(is,is)+i-1+(j-1)*nbas(is))
      &      +Work(ipD_CI+iAA-1+(jAA-1)*ntash)
      &      +Work(ipG1q-1+itri(iAA,jAA))
            End Do
@@ -473,12 +476,13 @@ c Diagonalize the effective density to be able to use Prpt
 c ipO eigenvalues of eff dens
 c ipCMON eigenvectors (new orb coef)
 c
-         Call Getmem('TMP', 'ALLO','Real',ipT,nBuf/2)
-         Call NatOrb(Work(ipD_K),Work(ipCMO),Work(ipCMON),Work(ipO))
-         Call dmat_MCLR(Work(ipCMON),Work(ipO),Work(ipT))
-         Call Put_D1ao_Var(Work(ipT),nTot1)
-         Call Getmem('TMP', 'FREE','Real',ipT,nBuf/2)
-         Call get_D1MO(ipT,nTot1)
+         Call NatOrb(D_K,Work(ipCMO),Work(ipCMON),Work(ipO))
+         Call mma_Allocate(Tmp,nBuf/2,Label='Tmp')
+         Call dmat_MCLR(Work(ipCMON),Work(ipO),Tmp)
+         Call Put_D1ao_Var(Tmp,nTot1)
+         Call mma_deallocate(Tmp)
+         Call Getmem('TMP', 'ALLO','Real',ipT,nNac)
+         Call get_D1MO(Work(ipT),nNac)
          Call get_DLMO(ipTt,nTot1)
          Call DaxPy_(nTot1,1.0d0,Work(ipTt),1,Work(ipT),1)
          Call Getmem('DENS','FREE','Real',ipT,nTot1)
@@ -489,8 +493,8 @@ c
          Call WrVec('TMPORB',LuTmp,'O',nSym,nBas,nBas,
      &            rDum,Work(ipO),rDum,iDum,Note)
          Call Prpt()
-*                                                                     *
-***********************************************************************
+*                                                                      *
+************************************************************************
 *        There should now be dipole moments on the runfile which
 *        corresponds to the gradient of the energy w.r.t. the
 *        electric field. Let's update the list of values stored
@@ -518,8 +522,8 @@ c
             Call Free_Work(ipDMs)
             Call Free_Work(ipDM)
          End If
-***********************************************************************
-*                                                                     *
+************************************************************************
+*                                                                      *
        End If
        Call Getmem('TMP', 'FREE','Real',ipG1q,ng1)
 C
@@ -534,14 +538,14 @@ c
 c  Write the effective active one el density to disk in the same format as ipg1q
 c
 c       Call Getmem('TEMP1','ALLO','REAL',ipDeff_act,ndens2)
-c       call dcopy_(nDens2,Work(ipD_K),1,Work(ipDeff_act),1)
+c       call dcopy_(nDens2,D_K,1,Work(ipDeff_act),1)
 c       Do is=1,nSym
 c        Do i=1,nish(is)
 c
 c Subtract the inactive density
 c
 c         Work(ipDeff_act+ipmat(is,is)-1+i-1+(i-1)*nbas(is))=
-c     &   Work(ipD_K+ipmat(is,is)-1+i-1+(i-1)*nbas(is))-Two
+c     &   D_K(ipmat(is,is)+i-1+(i-1)*nbas(is))-Two
 c        End Do
 c       End Do
 c
@@ -555,7 +559,7 @@ c Diagonalize the effective density to be able to use Prpt
 c ipO eigenvalues of eff dens
 c ipCMON eigenvectors (new orb coef)
 c
-c      Call NatOrb(Work(ipD_K),Work(ipCMO),Work(ipCMON),Work(ipO))
+c      Call NatOrb(D_K,Work(ipCMO),Work(ipCMON),Work(ipO))
 c      Call Getmem('TMP', 'ALLO','Real',ipT,nBuf/2)
 c      Call dmat_MCLR(Work(ipCMON),Work(ipO),Work(ipT))
 c      Call Put_D1ao_Var(Work(ipT),nTot1)
@@ -585,7 +589,7 @@ c      Call Getmem('TMP', 'FREE','Real',ipT,nBuf/2)
 *
        Call GetMem('kappa1','FREE','Real',ipK1,  nDens2)
        Call Getmem('kappa2','FREE','Real',ipk2,  nDens2)
-         Call GetMem('Dens','FREE','Real',ipD_K,Length)
+       Call mma_deallocate(D_K)
        Call GetMem('ONEDEN','FREE','Real',ipDAO,nDens2)
        Call GetMem('ONEDEN','FREE','Real',ipD_CI,n1Dens)
        Call GetMem('ONEDEN','FREE','Real',ipD1,n1Dens)
@@ -598,7 +602,6 @@ c      Call Getmem('TMP', 'FREE','Real',ipT,nBuf/2)
 
        irc=ipclose(-1)
 *
-       Call QExit('Out_PT2')
 
        Return
        End
@@ -618,7 +621,6 @@ c
       Logical act
       itri(i,j)=Max(i,j)*(Max(i,j)-1)/2+Min(i,j)
 *
-      Call QEnter('OITD')
       call dcopy_(ndens2,[Zero],0,Dtmp,1)
 *
 *     Note: even with NAC we set the inactive block,
@@ -652,7 +654,6 @@ c
      &                 One,D(ipMat(iS,jS)),nOrb(iS))
          End If
       End Do
-      Call QExit('OITD')
       Return
       End
       Subroutine NatOrb(Dens,CMOO,CMON,OCCN)
