@@ -53,7 +53,6 @@
 *----------------------------------------------------------------------*
 *     Start and define the paper width                                 *
 *----------------------------------------------------------------------*
-      Call qEnter('InpPri')
       lPaper=132
       Zero = 0.0D0
 *----------------------------------------------------------------------*
@@ -251,6 +250,9 @@ C.. for GAS
       if(.not.DoSplitCAS) then  ! GLMJ
         Write(LF,Fmt2//'A,T45,I6)')'Number of root(s) required',
      &                             NROOTS
+*TRS
+      Call Get_iScalar('Relax CASSCF root',iRlxRoot)
+*TRS
         If (irlxroot.ne.0)
      &  Write(LF,Fmt2//'A,T45,I6)')'Root chosen for geometry opt.',
      &                             IRLXROOT
@@ -404,6 +406,7 @@ C.. for GAS
        EndIf
        IF(KSDFT.eq.'TBLYP'.or.KSDFT.eq.'TPBE'.or.KSDFT.eq.'TLSDA'
      &  .or.KSDFT.eq.'FTPBE'.or.KSDFT.eq.'FTLSDA'
+     &  .or.KSDFT.eq.'TOPBE'.or.KSDFT.eq.'FTOPBE'
      &  .or.KSDFT.eq.'FTBLYP'.or.KSDFT.eq.'TREVPBE'
      &  .or.KSDFT.eq.'FTREVPBE') then
         Write(LF,Fmt2//'A)') 'This is a MC-PDFT calculation '//
@@ -462,7 +465,6 @@ C.. for GAS
             Write(LF,*) 'InpPri: iRc from Call RdOne not 0'
             Write(LF,*) 'Label = ',Label
             Write(LF,*) 'iRc = ',iRc
-            Call QTrace
             Call Abend
          Endif
          Call GetMem('Ovrlp','Free','Real',iTmp0,nTot1+4)
@@ -510,6 +512,5 @@ C.. for GAS
 *----------------------------------------------------------------------*
 *     Exit                                                             *
 *----------------------------------------------------------------------*
-      Call qExit('InpPri')
       Return
       End
