@@ -31,6 +31,8 @@
 * Liviu Ungur, May 2017 (added support for  COMPLEX*16, 4D)
 * Liviu Ungur, Jan 2018 (added support for 5D arrays)
 
+#include "molcastypes.fh"
+
 * out-of-memory handling
       subroutine mma_oom(bufsize,mma_avail)
         implicit none
@@ -58,6 +60,22 @@
         call quit(_RC_MEMORY_ERROR_)
       end subroutine
 
+      subroutine mma_maxDBLE(mma_avail)
+        implicit none
+#include "SysDef.fh"
+        integer, intent(out) :: mma_avail
+        integer, external :: mma_avmem
+        mma_avail = mma_avmem()/RtoB
+      end subroutine
+
+      subroutine mma_maxINT(mma_avail)
+        implicit none
+#include "SysDef.fh"
+        integer, intent(out) :: mma_avail
+        integer, external :: mma_avmem
+        mma_avail = mma_avmem()/ItoB
+      end subroutine
+
       subroutine mma_maxbytes(mma_avail)
         implicit none
         integer, intent(out) :: mma_avail
@@ -65,38 +83,78 @@
         mma_avail = mma_avmem()
       end subroutine
 
+#ifdef _CAPITALS_
+#define cptr2woff_name 'CPTR2WOFF'
+#else
+#ifndef ADD_
+#define cptr2woff_name 'cptr2woff_'
+#endif
+#endif
+
 * type-specific pointer-to-offset routines
       integer function d_cptr2loff(buffer)
+        use, intrinsic :: iso_c_binding
         implicit none
-#include "molcastypes.fh"
-        real*8 :: buffer(*)
-        integer, external :: cptr2woff
+        real*8, target :: buffer(*)
+        interface
+          integer(kind=MOLCAS_C_INT) function cptr2woff(string, ptr)
+     &                               bind(C,name=cptr2woff_name)
+            use, intrinsic :: iso_c_binding
+            character(kind=c_char) :: string(*)
+            type(c_ptr), value :: ptr
+          end function
+        end interface
         integer, external :: kind2goff
-        d_cptr2loff = cptr2woff('REAL',buffer(1)) + kind2goff('REAL')
+        d_cptr2loff = cptr2woff('REAL',
+     &    c_loc(buffer(1))) + kind2goff('REAL')
       end function
       integer function i_cptr2loff(buffer)
+        use, intrinsic :: iso_c_binding
         implicit none
-#include "molcastypes.fh"
-        integer :: buffer(*)
-        integer, external :: cptr2woff
+        integer, target :: buffer(*)
+        interface
+          integer(kind=MOLCAS_C_INT) function cptr2woff(string, ptr)
+     &                               bind(C,name=cptr2woff_name)
+            use, intrinsic :: iso_c_binding
+            character(kind=c_char) :: string(*)
+            type(c_ptr), value :: ptr
+          end function
+        end interface
         integer, external :: kind2goff
-        i_cptr2loff = cptr2woff('INTE',buffer(1)) + kind2goff('INTE')
+        i_cptr2loff = cptr2woff('INTE',
+     &    c_loc(buffer(1))) + kind2goff('INTE')
       end function
       integer function c_cptr2loff(buffer)
+        use, intrinsic :: iso_c_binding
         implicit none
-#include "molcastypes.fh"
-        character(*) :: buffer(*)
-        integer, external :: cptr2woff
+        character(len=*), target :: buffer(*)
+        interface
+          integer(kind=MOLCAS_C_INT) function cptr2woff(string, ptr)
+     &                               bind(C,name=cptr2woff_name)
+            use, intrinsic :: iso_c_binding
+            character(kind=c_char) :: string(*)
+            type(c_ptr), value :: ptr
+          end function
+        end interface
         integer, external :: kind2goff
-        c_cptr2loff = cptr2woff('CHAR',buffer(1)) + kind2goff('CHAR')
+        c_cptr2loff = cptr2woff('CHAR',
+     &    c_loc(buffer(1))) + kind2goff('CHAR')
       end function
       integer function dc_cptr2loff(buffer)
+        use, intrinsic :: iso_c_binding
         implicit none
-#include "molcastypes.fh"
-        complex*16 :: buffer(*)
-        integer, external :: cptr2woff
+        complex*16, target :: buffer(*)
+        interface
+          integer(kind=MOLCAS_C_INT) function cptr2woff(string, ptr)
+     &                               bind(C,name=cptr2woff_name)
+            use, intrinsic :: iso_c_binding
+            character(kind=c_char) :: string(*)
+            type(c_ptr), value :: ptr
+          end function
+        end interface
         integer, external :: kind2goff
-        dc_cptr2loff = cptr2woff('REAL',buffer(1)) + kind2goff('REAL')
+        dc_cptr2loff = cptr2woff('REAL',
+     &    c_loc(buffer(1))) + kind2goff('REAL')
       end function
 
 * type-specific allocation subroutines
@@ -106,7 +164,6 @@
         integer :: n1
         character (len=*), optional :: label
 #include "SysDef.fh"
-#include "molcastypes.fh"
 #include "cptr2loff.fh"
         integer :: bufsize
         integer :: loffset
@@ -136,7 +193,6 @@
         integer, dimension(2) :: l1
         character (len=*), optional :: label
 #include "SysDef.fh"
-#include "molcastypes.fh"
 #include "cptr2loff.fh"
         integer :: n1
         integer :: bufsize
@@ -168,7 +224,6 @@
         integer :: n1
         character (len=*), optional :: label
 #include "SysDef.fh"
-#include "molcastypes.fh"
 #include "cptr2loff.fh"
         integer :: bufsize
         integer :: loffset
@@ -198,7 +253,6 @@
         integer, dimension(2) :: l1
         character (len=*), optional :: label
 #include "SysDef.fh"
-#include "molcastypes.fh"
 #include "cptr2loff.fh"
         integer :: n1
         integer :: bufsize
@@ -226,11 +280,10 @@
       end subroutine
       subroutine cmma_allo_1D(buffer,n1,label)
         implicit none
-        character(*), allocatable :: buffer(:)
+        character(len=*), allocatable :: buffer(:)
         integer :: n1
         character (len=*), optional :: label
 #include "SysDef.fh"
-#include "molcastypes.fh"
 #include "cptr2loff.fh"
         integer :: bufsize
         integer :: loffset
@@ -256,11 +309,10 @@
       end subroutine
       subroutine cmma_allo_1D_lim(buffer,l1,label)
         implicit none
-        character(*), allocatable :: buffer(:)
+        character(len=*), allocatable :: buffer(:)
         integer, dimension(2) :: l1
         character (len=*), optional :: label
 #include "SysDef.fh"
-#include "molcastypes.fh"
 #include "cptr2loff.fh"
         integer :: n1
         integer :: bufsize
@@ -292,7 +344,6 @@
         integer :: n1
         character (len=*), optional :: label
 #include "SysDef.fh"
-#include "molcastypes.fh"
 #include "cptr2loff.fh"
         integer :: bufsize
         integer :: loffset
@@ -322,7 +373,6 @@
         integer, dimension(2) :: l1
         character (len=*), optional :: label
 #include "SysDef.fh"
-#include "molcastypes.fh"
 #include "cptr2loff.fh"
         integer :: n1
         integer :: bufsize
@@ -354,7 +404,6 @@
         integer :: n1, n2
         character (len=*), optional :: label
 #include "SysDef.fh"
-#include "molcastypes.fh"
 #include "cptr2loff.fh"
         integer :: bufsize
         integer :: loffset
@@ -384,7 +433,6 @@
         integer, dimension(2) :: l1, l2
         character (len=*), optional :: label
 #include "SysDef.fh"
-#include "molcastypes.fh"
 #include "cptr2loff.fh"
         integer :: n1, n2
         integer :: bufsize
@@ -417,7 +465,6 @@
         integer :: n1, n2
         character (len=*), optional :: label
 #include "SysDef.fh"
-#include "molcastypes.fh"
 #include "cptr2loff.fh"
         integer :: bufsize
         integer :: loffset
@@ -447,7 +494,6 @@
         integer, dimension(2) :: l1, l2
         character (len=*), optional :: label
 #include "SysDef.fh"
-#include "molcastypes.fh"
 #include "cptr2loff.fh"
         integer :: n1, n2
         integer :: bufsize
@@ -480,7 +526,6 @@
         integer :: n1, n2
         character (len=*), optional :: label
 #include "SysDef.fh"
-#include "molcastypes.fh"
 #include "cptr2loff.fh"
         integer :: bufsize
         integer :: loffset
@@ -511,7 +556,6 @@
         integer, dimension(2) :: l1, l2
         character (len=*), optional :: label
 #include "SysDef.fh"
-#include "molcastypes.fh"
 #include "cptr2loff.fh"
         integer :: n1, n2
         integer :: bufsize
@@ -545,7 +589,6 @@
         integer :: n1, n2, n3
         character (len=*), optional :: label
 #include "SysDef.fh"
-#include "molcastypes.fh"
 #include "cptr2loff.fh"
         integer :: bufsize
         integer :: loffset
@@ -575,7 +618,6 @@
         integer, dimension(2) :: l1, l2, l3
         character (len=*), optional :: label
 #include "SysDef.fh"
-#include "molcastypes.fh"
 #include "cptr2loff.fh"
         integer :: n1, n2, n3
         integer :: bufsize
@@ -609,7 +651,6 @@
         integer :: n1, n2, n3
         character (len=*), optional :: label
 #include "SysDef.fh"
-#include "molcastypes.fh"
 #include "cptr2loff.fh"
         integer :: bufsize
         integer :: loffset
@@ -639,7 +680,6 @@
         integer, dimension(2) :: l1, l2, l3
         character (len=*), optional :: label
 #include "SysDef.fh"
-#include "molcastypes.fh"
 #include "cptr2loff.fh"
         integer :: n1, n2, n3
         integer :: bufsize
@@ -673,7 +713,6 @@
         integer :: n1, n2, n3
         character (len=*), optional :: label
 #include "SysDef.fh"
-#include "molcastypes.fh"
 #include "cptr2loff.fh"
         integer :: bufsize
         integer :: loffset
@@ -705,7 +744,6 @@
         integer, dimension(2) :: l1, l2, l3
         character (len=*), optional :: label
 #include "SysDef.fh"
-#include "molcastypes.fh"
 #include "cptr2loff.fh"
         integer :: n1, n2, n3
         integer :: bufsize
@@ -741,7 +779,6 @@
         integer :: n1, n2, n3, n4
         character (len=*), optional :: label
 #include "SysDef.fh"
-#include "molcastypes.fh"
 #include "cptr2loff.fh"
         integer :: bufsize
         integer :: loffset
@@ -773,7 +810,6 @@
         integer, dimension(2) :: l1, l2, l3, l4
         character (len=*), optional :: label
 #include "SysDef.fh"
-#include "molcastypes.fh"
 #include "cptr2loff.fh"
         integer :: n1, n2, n3, n4
         integer :: bufsize
@@ -813,7 +849,6 @@
         integer :: n1, n2, n3, n4
         character (len=*), optional :: label
 #include "SysDef.fh"
-#include "molcastypes.fh"
 #include "cptr2loff.fh"
         integer :: bufsize
         integer :: loffset
@@ -844,7 +879,6 @@
         integer, dimension(2) :: l1, l2, l3, l4
         character (len=*), optional :: label
 #include "SysDef.fh"
-#include "molcastypes.fh"
 #include "cptr2loff.fh"
         integer :: n1, n2, n3, n4
         integer :: bufsize
@@ -882,7 +916,6 @@
         integer :: n1, n2, n3, n4
         character (len=*), optional :: label
 #include "SysDef.fh"
-#include "molcastypes.fh"
 #include "cptr2loff.fh"
         integer :: bufsize
         integer :: loffset
@@ -912,7 +945,6 @@
         integer, dimension(2) :: l1, l2, l3, l4
         character (len=*), optional :: label
 #include "SysDef.fh"
-#include "molcastypes.fh"
 #include "cptr2loff.fh"
         integer :: n1, n2, n3, n4
         integer :: bufsize
@@ -951,7 +983,6 @@
         integer :: n1, n2, n3, n4, n5
         character (len=*), optional :: label
 #include "SysDef.fh"
-#include "molcastypes.fh"
 #include "cptr2loff.fh"
         integer :: bufsize
         integer :: loffset
@@ -982,7 +1013,6 @@
         integer, dimension(2) :: l1, l2, l3, l4, l5
         character (len=*), optional :: label
 #include "SysDef.fh"
-#include "molcastypes.fh"
 #include "cptr2loff.fh"
         integer :: n1, n2, n3, n4, n5
         integer :: bufsize
@@ -1020,7 +1050,6 @@
         integer :: n1, n2, n3, n4, n5
         character (len=*), optional :: label
 #include "SysDef.fh"
-#include "molcastypes.fh"
 #include "cptr2loff.fh"
         integer :: bufsize
         integer :: loffset
@@ -1051,7 +1080,6 @@
         integer, dimension(2) :: l1, l2, l3, l4, l5
         character (len=*), optional :: label
 #include "SysDef.fh"
-#include "molcastypes.fh"
 #include "cptr2loff.fh"
         integer :: n1, n2, n3, n4, n5
         integer :: bufsize
@@ -1089,7 +1117,6 @@
         integer :: n1, n2, n3, n4, n5
         character (len=*), optional :: label
 #include "SysDef.fh"
-#include "molcastypes.fh"
 #include "cptr2loff.fh"
         integer :: bufsize
         integer :: loffset
@@ -1121,7 +1148,6 @@
         integer, dimension(2) :: l1, l2, l3, l4, l5
         character (len=*), optional :: label
 #include "SysDef.fh"
-#include "molcastypes.fh"
 #include "cptr2loff.fh"
         integer :: n1, n2, n3, n4, n5
         integer :: bufsize
@@ -1155,12 +1181,53 @@
         end if
       end subroutine
 
+      subroutine dmma_allo_7D_lim(buffer,l1,l2,l3,l4,l5,l6,l7,label)
+        implicit none
+        real*8, allocatable :: buffer(:,:,:,:,:,:,:)
+        integer, dimension(2) :: l1, l2, l3, l4, l5, l6, l7
+        character (len=*), optional :: label
+#include "SysDef.fh"
+#include "cptr2loff.fh"
+        integer :: n1, n2, n3, n4, n5, n6, n7, n
+        integer :: bufsize
+        integer :: loffset
+        integer :: mma_avail
+        if (allocated(buffer)) then
+          call mma_double_allo
+        end if
+        call mma_maxbytes(mma_avail)
+        n1 = l1(2)-l1(1)+1
+        n2 = l2(2)-l2(1)+1
+        n3 = l3(2)-l3(1)+1
+        n4 = l4(2)-l4(1)+1
+        n5 = l5(2)-l5(1)+1
+        n6 = l6(2)-l6(1)+1
+        n7 = l7(2)-l7(1)+1
+        n = n1 * n2 * n3 * n4 * n5 * n6 * n7
+        bufsize = rtob * n
+        if (bufsize .gt. mma_avail) then
+          call mma_oom(bufsize,mma_avail)
+        else
+          allocate(buffer( l1(1):l1(2), l2(1):l2(2), l3(1):l3(2),
+     &                     l4(1):l4(2), l5(1):l5(2), l6(1):l6(2),
+     &                     l7(1):l7(2) ))
+          if (n.gt.0) then
+            loffset = cptr2loff(buffer(l1(1),l2(1),l3(1),l4(1),l5(1),
+     &                                 l6(1),l7(1)))
+            if (present(label)) then
+              call getmem(label,'RGST','REAL',loffset,n)
+            else
+              call getmem('dmma_7D','RGST','REAL',loffset,n)
+            end if
+          end if
+        end if
+      end subroutine
+
 * type-specific deallocation subroutines
       subroutine dmma_free_1D(buffer)
         implicit none
         real*8, allocatable :: buffer(:)
 #include "SysDef.fh"
-#include "molcastypes.fh"
 #include "cptr2loff.fh"
         integer :: n1
         integer :: loffset
@@ -1179,7 +1246,6 @@
         implicit none
         integer, allocatable :: buffer(:)
 #include "SysDef.fh"
-#include "molcastypes.fh"
 #include "cptr2loff.fh"
         integer :: n1
         integer :: loffset
@@ -1196,9 +1262,8 @@
       end subroutine
       subroutine cmma_free_1D(buffer)
         implicit none
-        character(*), allocatable :: buffer(:)
+        character(len=*), allocatable :: buffer(:)
 #include "SysDef.fh"
-#include "molcastypes.fh"
 #include "cptr2loff.fh"
         integer :: n1
         integer :: bufsize
@@ -1219,7 +1284,6 @@
         implicit none
         complex*16, allocatable :: buffer(:)
 #include "SysDef.fh"
-#include "molcastypes.fh"
 #include "cptr2loff.fh"
         integer :: n1
         integer :: loffset
@@ -1238,7 +1302,6 @@
         implicit none
         real*8, allocatable :: buffer(:,:)
 #include "SysDef.fh"
-#include "molcastypes.fh"
 #include "cptr2loff.fh"
         integer :: n1, n2
         integer :: loffset
@@ -1259,7 +1322,6 @@
         implicit none
         integer, allocatable :: buffer(:,:)
 #include "SysDef.fh"
-#include "molcastypes.fh"
 #include "cptr2loff.fh"
         integer :: n1, n2
         integer :: loffset
@@ -1280,7 +1342,6 @@
         implicit none
         complex*16, allocatable :: buffer(:,:)
 #include "SysDef.fh"
-#include "molcastypes.fh"
 #include "cptr2loff.fh"
         integer :: n1, n2
         integer :: loffset
@@ -1302,7 +1363,6 @@
         implicit none
         real*8, allocatable :: buffer(:,:,:)
 #include "SysDef.fh"
-#include "molcastypes.fh"
 #include "cptr2loff.fh"
         integer :: n1, n2, n3
         integer :: loffset
@@ -1325,7 +1385,6 @@
         implicit none
         integer, allocatable :: buffer(:,:,:)
 #include "SysDef.fh"
-#include "molcastypes.fh"
 #include "cptr2loff.fh"
         integer :: n1, n2, n3
         integer :: loffset
@@ -1348,7 +1407,6 @@
         implicit none
         complex*16, allocatable :: buffer(:,:,:)
 #include "SysDef.fh"
-#include "molcastypes.fh"
 #include "cptr2loff.fh"
         integer :: n1, n2, n3
         integer :: loffset
@@ -1374,7 +1432,6 @@
         implicit none
         integer, allocatable :: buffer(:,:,:,:)
 #include "SysDef.fh"
-#include "molcastypes.fh"
 #include "cptr2loff.fh"
         integer :: n1, n2, n3, n4
         integer :: loffset
@@ -1399,7 +1456,6 @@
         implicit none
         real*8, allocatable :: buffer(:,:,:,:)
 #include "SysDef.fh"
-#include "molcastypes.fh"
 #include "cptr2loff.fh"
         integer :: n1, n2, n3, n4
         integer :: loffset
@@ -1424,7 +1480,6 @@
         implicit none
         complex*16, allocatable :: buffer(:,:,:,:)
 #include "SysDef.fh"
-#include "molcastypes.fh"
 #include "cptr2loff.fh"
         integer :: n1, n2, n3, n4
         integer :: loffset
@@ -1450,7 +1505,6 @@
         implicit none
         integer, allocatable :: buffer(:,:,:,:,:)
 #include "SysDef.fh"
-#include "molcastypes.fh"
 #include "cptr2loff.fh"
         integer :: n1, n2, n3, n4, n5
         integer :: loffset
@@ -1477,7 +1531,6 @@
         implicit none
         real*8, allocatable :: buffer(:,:,:,:,:)
 #include "SysDef.fh"
-#include "molcastypes.fh"
 #include "cptr2loff.fh"
         integer :: n1, n2, n3, n4, n5
         integer :: loffset
@@ -1504,7 +1557,6 @@
         implicit none
         complex*16, allocatable :: buffer(:,:,:,:,:)
 #include "SysDef.fh"
-#include "molcastypes.fh"
 #include "cptr2loff.fh"
         integer :: n1, n2, n3, n4, n5
         integer :: loffset
@@ -1529,4 +1581,34 @@
         end if
       end subroutine
 
-
+      subroutine dmma_free_7D(buffer)
+        implicit none
+        real*8, allocatable :: buffer(:,:,:,:,:,:,:)
+#include "SysDef.fh"
+#include "cptr2loff.fh"
+        integer :: n1, n2, n3, n4, n5, n6, n7, n
+        integer :: loffset
+        n1 = size(buffer,1)
+        n2 = size(buffer,2)
+        n3 = size(buffer,3)
+        n4 = size(buffer,4)
+        n5 = size(buffer,5)
+        n6 = size(buffer,6)
+        n7 = size(buffer,7)
+        n = n1 * n2 * n3 * n4 * n5 * n6 * n7
+        if (allocated(buffer)) then
+          if (n.gt.0) then
+            loffset = cptr2loff(buffer(lbound(buffer,1),
+     &                                 lbound(buffer,2),
+     &                                 lbound(buffer,3),
+     &                                 lbound(buffer,4),
+     &                                 lbound(buffer,5),
+     &                                 lbound(buffer,6),
+     &                                 lbound(buffer,7)))
+            call getmem('dmma_7D','EXCL','REAL',loffset,n)
+          end if
+          deallocate(buffer)
+        else
+          call mma_double_free
+        end if
+      end subroutine
