@@ -83,7 +83,6 @@
         call getmem('kcnf','allo','inte',ivkcnf,nactel)
       end if
 
-      Call qEnter('David')
       Call Timing(Alfex_1,Swatch,Swatch,Swatch)
       Rc_CI = 0
       IPRLEV=IPRLOC(3)
@@ -259,7 +258,6 @@ C Timings on generation of the sigma vector
             Write(6,*) 'nBasvec, lRoots = ',nBasVec, lRoots
             If ( ICIRST.EQ.1 ) Write(6,*) 'CIREstart was used. ',
      & 'Check the number of roots in the previous calculation'
-            Call QTrace
             Call Abend
          Endif
          If ( iprlev.ge.DEBUG ) then
@@ -618,7 +616,6 @@ C Timings on generation of the sigma vector
       Call Timing(Alfex_2,Swatch,Swatch,Swatch)
       Alfex_2 = Alfex_2 - Alfex_1
       Alfex_3 = Alfex_3 + Alfex_2
-      Call qExit('David')
 
       Return
       End
