@@ -32,7 +32,6 @@
 *---- convert a pointer in H to a pointer for iH
 *     ipointer(i)=(i-1)*RtoI+1
 *
-      Call qEnter('ReadIn')
 *
 *     Initialize data and set defaults
 *
@@ -450,7 +449,8 @@
 7     CONTINUE
       IORBS=0
       DO 721 ISYM=1,NSYM
-721     NOTOT(ISYM)=0
+        NOTOT(ISYM)=0
+721   CONTINUE
       DO 723 ISYM=1,NSYM
         IO=NOTOT(ISYM)
         DO 722 I=1,NFMO(ISYM)+NFRO(ISYM)
@@ -706,7 +706,6 @@ C START OF NON-PERMANENT AREA:
       MEMPRM=MEMTOT-MEMWRK
 
       CALL ALLOC_MRCI
-      Call qExit('Readin')
       RETURN
 991   Continue
       WRITE(6,*)'READIN Error: Premature end of file while reading.'
