@@ -13,7 +13,7 @@
       Subroutine DFT_Grad(Grad,nGrad,dF_dRho,ndF_dRho,iSpin,
      &                    Grid,mGrid,dRho_dR,ndRho_dR,nGrad_Eff,
      &                    Rho,nRho,IndGrd,Weights,iTab,Temp,F_xc,
-     &                    dW_dR,iChBas,nChBas,iNQ)
+     &                    dW_dR,iNQ)
 ************************************************************************
 *                                                                      *
 *     Object: to trace the correct parts to get the contributions to   *
@@ -22,6 +22,7 @@
 *     Author: Roland Lindh, Dept. of Chemical Physics, University of   *
 *             Lund, Sweden.  May 2002 in Bologna, Italy.               *
 ************************************************************************
+      use KSDFT_Info, only: KSDFA
       Implicit Real*8 (a-h,o-z)
 #include "real.fh"
 #include "nq_info.fh"
@@ -38,7 +39,7 @@
      &       dRho_dR(ndRho_dR,mGrid,nGrad_Eff), OV(3,3), V(3,3),
      &       Rho(nRho,mGrid), R_Grid(3),
      &       Weights(mGrid), F_xc(mGrid), dW_dR(nGrad_Eff,mGrid)
-      Integer IndGrd(nGrad_Eff), iTab(4,nGrad_Eff), iChBas(0:nChBas-1)
+      Integer IndGrd(nGrad_Eff), iTab(4,nGrad_Eff)
 *                                                                      *
 ************************************************************************
 *                                                                      *
@@ -55,8 +56,8 @@
       R_Grid(1)=Work(ip_Coor(iNQ)  )
       R_Grid(2)=Work(ip_Coor(iNQ)+1)
       R_Grid(3)=Work(ip_Coor(iNQ)+2)
-*define _DEBUG_
-#ifdef _DEBUG_
+*define _DEBUGPRINT_
+#ifdef _DEBUGPRINT_
       Debug=.True.
       If (Debug) Then
          Call RecPrt('R_Grid',' ',R_Grid,1,3)
@@ -454,7 +455,7 @@
          Call WarningMessage(2,'Do_Grad: wrong functional type!')
          Call Abend()
       End If
-#ifdef _DEBUG_
+#ifdef _DEBUGPRINT_
       If (Debug) Then
          Call RecPrt('w * f^x before translational contributions',
      &               ' ',Temp,1,nGrad_Eff)
@@ -480,7 +481,7 @@
      &             iTab(2,jGrad).eq.Off  .and.
      &             IndGrd(jGrad).gt.0           ) iGrad=jGrad
             End Do
-#ifdef _DEBUG_
+#ifdef _DEBUGPRINT_
             If (Debug) Write (6,*) 'iGrad=',iGrad
 #endif
             If (iGrad.ne.0) Then
@@ -493,7 +494,7 @@
 *
                       Temp(iGrad)=Temp(iGrad)-Temp(jGrad)
 *
-#ifdef _DEBUG_
+#ifdef _DEBUGPRINT_
             If (Debug) Write (6,*) 'jGrad,Temp(jGrad)=',
      &                              jGrad,Temp(jGrad)
 #endif
@@ -502,7 +503,7 @@
 *
             End If
          End Do
-#ifdef _DEBUG_
+#ifdef _DEBUGPRINT_
       If (Debug) Call RecPrt('w * f^x',' ',Temp,1,nGrad_Eff)
 #endif
 *                                                                      *
@@ -517,7 +518,7 @@
      &              One,dW_dR,nGrad_Eff,
      &                  F_xc,mGrid,
      &              One,Temp,nGrad_Eff)
-#ifdef _DEBUG_
+#ifdef _DEBUGPRINT_
       If (Debug) Call RecPrt('w * f^x + w^x * f',' ',Temp,1,nGrad_Eff)
 #endif
 *                                                                      *
@@ -532,7 +533,7 @@
      &               1.0d0,OV,3,
      &               Work(ip_O),3,
      &               0.0d0,V,3)
-#ifdef _DEBUG_
+#ifdef _DEBUGPRINT_
       If (Debug) Call RecPrt('V',' ',V,3,3)
 #endif
 *
@@ -549,12 +550,14 @@
      &        KSDFA(1:7).eq.'TREVPBE'.or.
      &        KSDFA(1:8).eq.'FTREVPBE'.or.
      &        KSDFA(1:5).eq.'TBLYP'.or.
+     &        KSDFA(1:5).eq.'TOPBE'.or.
+     &        KSDFA(1:6).eq.'FTOPBE'.or.
      &        KSDFA(1:4).eq.'TPBE') then
             Tmp = DDot_(9,Work(ip_dOdx(jNQ,iCar)),1,V,1)*0.5
       else
             Tmp = DDot_(9,Work(ip_dOdx(jNQ,iCar)),1,V,1)
       end if
-#ifdef _DEBUG_
+#ifdef _DEBUGPRINT_
             If (Debug) Then
                Write (6,*)
                Write (6,*) 'iCar,jNQ=',iCar,jNQ
@@ -566,7 +569,7 @@
          End Do
 *
       End If !moving grid
-#ifdef _DEBUG_
+#ifdef _DEBUGPRINT_
       If (Debug) Call RecPrt('Gradient contribution from this block',
      &                       ' ',Temp,1,nGrad_Eff)
 #endif
@@ -582,7 +585,7 @@
             Grad(i) = Grad(i) + Fact*Temp(i_Eff)
          End If
       End Do
-#ifdef _DEBUG_
+#ifdef _DEBUGPRINT_
       If (Debug) Call RecPrt('Gradient accumulated so far',
      &                     ' ',Grad,1,nGrad)
       Debug=.False.
@@ -592,5 +595,4 @@
 *                                                                      *
       Return
 c Avoid unused argument warnings
-      If (.False.) Call Unused_integer_array(iChBas)
       End
