@@ -26,31 +26,21 @@
      &                    list_g,IndGrd,iTab,Temp,F_xc,dW_dR,iNQ,Maps2p,
      &                    dF_dRho,dF_dP2ontop,DFTFOCK,LOE_DB,LTEG_DB)
 ************************************************************************
-*                                                                      *
-* Object:                                                              *
-*                                                                      *
-* Called from: SubBlock                                                *
-*                                                                      *
-* Calling    : QEnter                                                  *
-*              AOEval                                                  *
-*              Do_Rho_*                                                *
-*              Kernel                                                  *
-*              DFT_Int                                                 *
-*              Do_DFT_Grad                                             *
-*              QExit                                                   *
-*                                                                      *
 *      Author:Roland Lindh, Department of Chemical Physics, University *
 *             of Lund, SWEDEN. November 2000                           *
 ************************************************************************
       use iSD_data
       use Real_Spherical
+      use Basis_Info
+      use Center_Info
+      use Phase_Info
+      use KSDFT_Info
       Implicit Real*8 (A-H,O-Z)
       External Kernel
 #include "SysDef.fh"
-#include "itmax.fh"
-#include "info.fh"
 #include "real.fh"
 #include "WrkSpc.fh"
+#include "stdalloc.fh"
 #include "print.fh"
 #include "debug.fh"
 #include "ksdft.fh"
@@ -84,8 +74,8 @@
       Real*8 P2_ontop_d(nP2_ontop,nGrad_Eff,mGrid)
       Integer ntot1
       Integer LOE_DB,LTEG_DB
-*define _DEBUG_
-#ifdef _DEBUG_
+*define _DEBUGPRINT_
+#ifdef _DEBUGPRINT_
       Logical Debug_Save
 #endif
 *                                                                      *
@@ -122,10 +112,7 @@
      &           KSDFA(1:6).eq.'FTOPBE'  .or.
      &           KSDFA(1:6).eq.'FTBLYP'
 ************************************************************************
-#ifdef _TIME_
-      Call qEnter('Do_Batch ')
-#endif
-#ifdef _DEBUG_
+#ifdef _DEBUGPRINT_
       Debug_Save=Debug
       Debug=Debug.or.iPrint.ge.99
 *
@@ -176,10 +163,6 @@
 *---- Evaluate the AOs on the grid points.                             *
 *                                                                      *
 ************************************************************************
-*
-#ifdef _TIME_
-      Call QEnter('AO')
-#endif
 *
       Call FZero(TabAO,nTabAO)
 c      write(6,*) 'nTabAO value in do_batch.f=', nTabAO
@@ -212,21 +195,20 @@ C        Call RecPrt('TabAO from disk',' ',TabAO,1,mTabAO)
          Do ilist_s=1,nlist_s
             ish=list_s(1,ilist_s)
 
+            iShll = iSD( 0,iSh)
             iAng  = iSD( 1,iSh)
             iCmp  = iSD( 2,iSh)
             iBas  = iSD( 3,iSh)
             iBas_Eff = List_Bas(1,ilist_s)
             iPrim = iSD( 5,iSh)
             iPrim_Eff=List_Exp(ilist_s)
-            iCff  = iSD( 4,iSh)
-            iCff_Eff=iCff+iPrim*(iBas-iBas_Eff)
-            iExp  = iSD( 6,iSh)
             iAO   = iSD( 7,iSh)
-            ixyz  = iSD( 8,iSh)
             mdci  = iSD(10,iSh)
             iShell= iSD(11,iSh)
             iShll = iSD(0,iSh)
-            call dcopy_(3,Work(ixyz),1,A,1)
+            iCnttp= iSD(13,iSh)
+            iCnt  = iSD(14,iSh)
+            A(1:3)=dbsc(iCnttp)%Coor(1:3,iCnt)
 *
             nDrv     = mRad - 1
             nForm    = 0
@@ -252,8 +234,8 @@ C        Call RecPrt('TabAO from disk',' ',TabAO,1,mTabAO)
             RA(1) = px*A(1)
             RA(2) = py*A(2)
             RA(3) = pz*A(3)
-            iSym=NrOpr(iR,iOper,nSym)
-#ifdef _DEBUG_
+            iSym=NrOpr(iR)
+#ifdef _DEBUGPRINT_
             If (debug) Write (6,*) 'mAO=',mAO
             If (iPrim_Eff.le.0 .or. iPrim_Eff.gt.iPrim) Then
                Call WarningMessage(2,'Do_batch: error in iPrim_Eff!')
@@ -265,7 +247,7 @@ C        Call RecPrt('TabAO from disk',' ',TabAO,1,mTabAO)
 *
 *---------- Evaluate AOs at RA
 *
-#ifdef _DEBUG_
+#ifdef _DEBUGPRINT_
             iPrint_132=nPrint(132)
             If (Debug) nPrint(132)=99
 #endif
@@ -273,14 +255,17 @@ C        Call RecPrt('TabAO from disk',' ',TabAO,1,mTabAO)
 *                                                                      *
 c            write(6,*) 'iOff =', iOff
             Call AOEval(iAng,mGrid,Grid,Work(ipxyz),RA,
-     &                  Transf(iShll),
+     &                  Shells(iShll)%Transf,
      &                  RSph(ipSph(iAng)),nElem(iAng),iCmp,
      &                  iWork(ipAng),nTerm,nForm,T_X,mRad,
-     &                  iPrim,iPrim_Eff,Work(iExp),Work(ipRadial),
-     &                  iBas_Eff,Work(iCff_Eff),TabAO(iOff),
+     &                  iPrim,iPrim_Eff,Shells(iShll)%Exp,
+     &                  Work(ipRadial),
+     &                  iBas_Eff,
+     &                  Shells(iShll)%pCff(1,iBas-iBas_Eff+1),
+     &                  TabAO(iOff),
      &                  mAO,px,py,pz,ipx,ipy,ipz)
             iOff = iOff + mAO*mGrid*iBas_Eff*iCmp
-#ifdef _DEBUG_
+#ifdef _DEBUGPRINT_
             nPrint(132)=iPrint_132
 #endif
 *
@@ -401,45 +386,38 @@ c            write(6,*) 'iOff =', iOff
 *
 cGLM            kAO   = iCmp*iBas_Eff*mGrid
             kAO   = iCmp*iBas*mGrid
-            nDeg  = nSym/nStab(mdci)
+            nDeg  = nSym/dc(mdci)%nStab
             nSO   = kAO*nDeg*mAO
             ipSOs = ipMem
             Call FZero(Work(ipSOs),nSO)
 *
             iR=list_s(2,ilist_s)
-            iSym=NrOpr(iR,iOper,nSym)
+            iSym=NrOpr(iR)
 *
 *---------- Distribute contributions of AOs if this particular shell
 *           on to the SOs of this shell. The SOs are only stored
 *           temporarily!
 *
             Call SOAdpt_NQ(TabAO(ipTabAO(iList_s,1)),mAO,mGrid,iBas,
-     &                  iBas_Eff,iCmp,iSym,Work(ipSOs),nDeg,iShell)
+     &                  iBas_Eff,iCmp,iSym,Work(ipSOs),nDeg,iAO)
 *
             Call GetMem('TmpCM','Allo','Real',ipTmpCMO,nCMO)
             Call GetMem('TDoIt','Allo','Inte',ipTDoIt,nMOs)
             Call  SODist2(Work(ipSOs),mAO,mGrid,iBas,
      &                   iCmp,nDeg,TabSO,
-     &                   iShell,nMOs,iAO,Work(ipTmpCMO),
+     &                   nMOs,iAO,Work(ipTmpCMO),
      &                   nCMO,iWork(ipTDoIt))
             Call GetMem('TmpCM','Free','Real',ipTmpCMO,nCMO)
             Call GetMem('TDoIt','Free','Inte',ipTDoIt,nMOs)
 *
             Call  SODist(Work(ipSOs),mAO,mGrid,iBas,iCmp,nDeg,TabMO,
-     &                  iShell,nMOs,iAO,CMOs,nCMO,DoIt)
+     &                  nMOs,iAO,CMOs,nCMO,DoIt)
 *
          End Do
       End If
 *                                                                      *
 ************************************************************************
 *                                                                      *
-#ifdef _TIME_
-      Call QExit('AO')
-      Call QEnter('Rho')
-#endif
-*                                                                      *
-************************************************************************
-*                                                                      *
 *---- Compute density and grad_density
 *                                                                      *
 ************************************************************************
@@ -463,8 +441,6 @@ cGLM            kAO   = iCmp*iBas_Eff*mGrid
 **************************************************************************
 * TLSDA,TLSDA5                                                           *
 **************************************************************************
-
-
        If(KSDFA(1:5).eq.'TLSDA'.or.KSDFA(1:6).eq.'TLSDA5') then !GLM
         if(Debug) write(6,*) 'in do_batch.f for TLSDA option'
 
@@ -536,9 +512,17 @@ cGLM          if(dTot.ge.thrsrho.and.P2_ontop(1,iGrid+1).ge.thrsrho) then
 * Compute gradients
           end if
 *         ^ end if for little rho
-          write(LuMC,'(3F12.6,5E20.6)')
-     &(Grid(i,iGrid+1),i=1,3),Rho(1,iGrid+1),
-     &Rho(2,iGrid+1),dTot,P2_ontop(1,iGrid+1),ratio
+          write(LuMC,'(3(F10.6,A),7(F17.10,A))')
+     &          Grid(1,iGrid+1),',',
+     &          Grid(2,iGrid+1),',',
+     &          Grid(3,iGrid+1),',',
+     &          Rho(1,iGrid+1)*Weights(iGrid+1),',',
+     &          Rho(2,iGrid+1)*Weights(iGrid+1),',',
+     &          dTot*Weights(iGrid+1),',',
+     &          Weights(iGrid+1),',',
+     &          dTot,',',
+     &          P2_ontop(1,iGrid+1),',',
+     &          ratio
          end do
 *        ^ end loop over grid points
        Else !GRADIENT CALCULATION
@@ -580,6 +564,7 @@ cGLM           if(dTot.ge.thrsrho.and.P2_ontop(1,iGrid+1).ge.thrsrho) then
              end if
            end if
             end do!ngrad_eff
+#ifdef _DEBUGPRINT_
           !if(dTot.ge.thrsrho.and.P2_ontop(1,iGrid+1).ge.thrsrho) then
 !         write(*,*) Grid(1,iGrid+1),Grid(2,iGrid+1),Grid(3,iGrid+1)
           if(Grid(1,iGrid+1).eq.0d0.and.
@@ -597,16 +582,18 @@ cGLM           if(dTot.ge.thrsrho.and.P2_ontop(1,iGrid+1).ge.thrsrho) then
      &dTot,dTot_d,Rho(1,iGrid+1),Rho(2,iGrid+1),Zeta,p2_ontop(1,iGrid+1)
           end if
           !end if
+#endif
 
-*         ^ end if for little rho
 !          write(LuMC,'(3F12.6,5E12.4)')
 !     &(Grid(i,iGrid+1),i=1,3),Rho(1,iGrid+1),
 !     &Rho(2,iGrid+1),dTot,P2_ontop_d(1,iGrid+1),ratio
            end do!igrid
        End if !not gradient or gradient
        End if !tlsda
+#ifdef _DEBUGPRINT_
 !       Close(97)
 !       Close(98)
+#endif
 
 
 cRKCft
@@ -653,6 +640,15 @@ cRKCft
           do iGrid=0,mGrid-1
            dTot=Rho(1,iGrid+1)+Rho(2,iGrid+1)
            ratio = 0.0d0
+           write(LuMT,'(3(F10.6,A),5(F17.10,A))')
+     &       Grid(1,iGrid+1),',',
+     &       Grid(2,iGrid+1),',',
+     &       Grid(3,iGrid+1),',',
+     &       Rho(1,iGrid+1)*Weights(iGrid+1),',',
+     &       Rho(2,iGrid+1)*Weights(iGrid+1),',',
+     &       dTot*Weights(iGrid+1),',',
+     &       Weights(iGrid+1),',',
+     &       dTot
 cGLM       if(dTot.ge.thrsrho.and.P2_ontop(1,iGrid+1).ge.thrsrho) then
            if(dTot.ge.thrsrho) then
              ratio = 4.0d0*P2_ontop(1,iGrid+1)/(dTot**2.0d0)
@@ -678,9 +674,17 @@ cGLM       if(dTot.ge.thrsrho.and.P2_ontop(1,iGrid+1).ge.thrsrho) then
              end if
            end if
 *         ^ end if for little rho
-          write(LuMC,'(3F12.6,5E20.6)')
-     &(Grid(i,iGrid+1),i=1,3),Rho(1,iGrid+1),
-     &Rho(2,iGrid+1),dTot,P2_ontop(1,iGrid+1),ratio
+          write(LuMC,'(3(F10.6,A),7(F17.10,A))')
+     &          Grid(1,iGrid+1),',',
+     &          Grid(2,iGrid+1),',',
+     &          Grid(3,iGrid+1),',',
+     &          Rho(1,iGrid+1)*Weights(iGrid+1),',',
+     &          Rho(2,iGrid+1)*Weights(iGrid+1),',',
+     &          dTot*Weights(iGrid+1),',',
+     &          Weights(iGrid+1),',',
+     &          dTot,',',
+     &          P2_ontop(1,iGrid+1),',',
+     &          ratio
           end do
 
 !******************************************************************
@@ -751,9 +755,17 @@ cGLM      if(dTot.ge.thrsrho.and.P2_ontop(1,iGrid+1).ge.thrsrho) then
              end if
            end if
 *          ^ end if for little rho
-          write(LuMC,'(3F12.6,5E20.6)')
-     &(Grid(i,iGrid+1),i=1,3),Rho(1,iGrid+1),
-     &Rho(2,iGrid+1),dTot,P2_ontop(1,iGrid+1),ratio
+          write(LuMC,'(3(F10.6,A),7(F17.10,A))')
+     &          Grid(1,iGrid+1),',',
+     &          Grid(2,iGrid+1),',',
+     &          Grid(3,iGrid+1),',',
+     &          Rho(1,iGrid+1)*Weights(iGrid+1),',',
+     &          Rho(2,iGrid+1)*Weights(iGrid+1),',',
+     &          dTot*Weights(iGrid+1),',',
+     &          Weights(iGrid+1),',',
+     &          dTot,',',
+     &          P2_ontop(1,iGrid+1),',',
+     &          ratio
           end do!loop over effective coordinates
           end do!loop over gridpts
 !         Call GetMem('P2_ontop_d','Free','Real',ipP2_d,mGrid*nGrad_Eff)
@@ -863,7 +875,15 @@ c         write(6,*) 'thrsrho2', thrsrho2
           grad_y = Rho(4,iGrid+1)+Rho(7,iGrid+1)
           grad_z = Rho(5,iGrid+1)+Rho(8,iGrid+1)
           ratio = 0.0d0
-
+          write(LuMT,'(3(F10.6,A),5(F17.10,A))')
+     &       Grid(1,iGrid+1),',',
+     &       Grid(2,iGrid+1),',',
+     &       Grid(3,iGrid+1),',',
+     &       Rho(1,iGrid+1)*Weights(iGrid+1),',',
+     &       Rho(2,iGrid+1)*Weights(iGrid+1),',',
+     &       dTot*Weights(iGrid+1),',',
+     &       Weights(iGrid+1),',',
+     &       dTot
 cGLM       if(dTot.ge.thrsrho.and.abs(P2_ontop(1,iGrid+1)).ge.
 cGLM     &                               0.25*thrsrho**3.0d0)then
           if(dTot.ge.thrsrho) then
@@ -959,9 +979,17 @@ c
 *          ^ end conditional regarding the ratio
           end if
 *         ^ end if over little density
-         write(LuMC,'(3F12.6,5E20.6)')
-     &(Grid(i,iGrid+1),i=1,3),Rho(1,iGrid+1),
-     &Rho(2,iGrid+1),dTot,P2_ontop(1,iGrid+1),ratio
+          write(LuMC,'(3(F10.6,A),7(F17.10,A))')
+     &          Grid(1,iGrid+1),',',
+     &          Grid(2,iGrid+1),',',
+     &          Grid(3,iGrid+1),',',
+     &          Rho(1,iGrid+1)*Weights(iGrid+1),',',
+     &          Rho(2,iGrid+1)*Weights(iGrid+1),',',
+     &          dTot*Weights(iGrid+1),',',
+     &          Weights(iGrid+1),',',
+     &          dTot,',',
+     &          P2_ontop(1,iGrid+1),',',
+     &          ratio
         end do!end loop over grid points
 
        Else !GRADIENT CALCULATION
@@ -1111,6 +1139,15 @@ c         write(6,*)'X Y Z spinDens and grad aft on-top density'
           grad_y = Rho(4,iGrid+1)+Rho(7,iGrid+1)
           grad_z = Rho(5,iGrid+1)+Rho(8,iGrid+1)
           ratio = 0.0d0
+          write(LuMT,'(3(F10.6,A),5(F17.10,A))')
+     &       Grid(1,iGrid+1),',',
+     &       Grid(2,iGrid+1),',',
+     &       Grid(3,iGrid+1),',',
+     &       Rho(1,iGrid+1)*Weights(iGrid+1),',',
+     &       Rho(2,iGrid+1)*Weights(iGrid+1),',',
+     &       dTot*Weights(iGrid+1),',',
+     &       Weights(iGrid+1),',',
+     &       dTot
 cGLM      if(dTot.ge.thrsrho.and.P2_ontop(1,iGrid+1).ge.thrsrho) then
           if(dTot.ge.thrsrho) then
             ratio = 4.0d0*P2_ontop(1,iGrid+1)/(dTot**2.0d0)
@@ -1241,9 +1278,17 @@ cGLM      if(dTot.ge.thrsrho.and.P2_ontop(1,iGrid+1).ge.thrsrho) then
 *          ^ end if over zeta=0
           end if
 *         ^ end if over little density
-         write(LuMC,'(3F12.6,5E20.6)')
-     &(Grid(i,iGrid+1),i=1,3),Rho(1,iGrid+1),
-     &Rho(2,iGrid+1),dTot,P2_ontop(1,iGrid+1),ratio
+          write(LuMC,'(3(F10.6,A),7(F17.10,A))')
+     &          Grid(1,iGrid+1),',',
+     &          Grid(2,iGrid+1),',',
+     &          Grid(3,iGrid+1),',',
+     &          Rho(1,iGrid+1)*Weights(iGrid+1),',',
+     &          Rho(2,iGrid+1)*Weights(iGrid+1),',',
+     &          dTot*Weights(iGrid+1),',',
+     &          Weights(iGrid+1),',',
+     &          dTot,',',
+     &          P2_ontop(1,iGrid+1),',',
+     &          ratio
         end do
 *       ^ end loop over grid points
 
@@ -1648,26 +1693,16 @@ C     Write (*,*) Dens_I,Grad_I,Tau_I
 *                                                                      *
 ************************************************************************
 *                                                                      *
-#ifdef _TIME_
-      Call QExit('Rho')
-#endif
-*                                                                      *
-************************************************************************
-*                                                                      *
 *-- (A.Ohrn): Here I add the routine which constructs the kernel for
 *   the Xhole application. A bit 'cheating' but hey what da hey!
 *
       If(l_Xhol) then
+#ifdef _NOT_USED_TESTED_OR_MAINTAINED_
         Call Xhole(nRho,mGrid,Rho,Grid,mAO,nMOs,TabMO,ndF_dRho,nD,
      &             dF_dRho,Weights,ip_OrbDip,Func)
+#endif
         Go To 1979
       Endif
-*                                                                      *
-************************************************************************
-*                                                                      *
-#ifdef _TIME_
-      Call QEnter('Functional')
-#endif
 ************************************************************************
 *                                                                      *
 *---- Evaluate the functional on the grid                              *
@@ -1676,12 +1711,12 @@ C     Write (*,*) Dens_I,Grad_I,Tau_I
 *                                                                      *
       Call FZero(dF_dRho,ndF_dRho*mGrid)
       Call FZero(F_xc,mGrid)
-      Call GetMem('F_xca','Allo','Real',ip_F_xca,mGrid)
-      Call GetMem('F_xcb','Allo','Real',ip_F_xcb,mGrid)
-      Call GetMem('tmpB','Allo','Real',ip_tmpB,mGrid)
-      Call FZero(Work(ip_F_xca),mGrid)
-      Call FZero(Work(ip_F_xcb),mGrid)
-      Call FZero(Work(ip_tmpB),mGrid)
+      Call mma_allocate(F_xca,mGrid,Label='F_xca')
+      Call mma_allocate(F_xcb,mGrid,Label='F_xcb')
+      Call mma_allocate(tmpB,mGrid,Label='tmpB')
+      F_xca(:)=Zero
+      F_xcb(:)=Zero
+      tmpB(:)=Zero
 *
 *1)   evaluate the energy density, the derivative of the functional with
 *     respect to rho and grad rho.
@@ -1700,19 +1735,13 @@ cGLM     &            ndF_dRho,dF_dP2ontop,ndF_dP2ontop,T_Rho,Work(ip_tmpB))
 *
       Func=Func+DDot_(mGrid,Weights,1,F_xc,1)
 cGLM     write(6,*) 'Func in do_batch =', Func
-      Funcaa=Funcaa+DDot_(mGrid,Weights,1,Work(ip_F_xca),1)
-      Funcbb=Funcbb+DDot_(mGrid,Weights,1,Work(ip_F_xcb),1)
-      Funccc=Funccc+DDot_(mGrid,Weights,1,Work(ip_tmpB),1)
-         call xflush(6)
-      Call GetMem('tmpB','Free','Real',ip_tmpB,mGrid)
-      Call GetMem('F_xcb','Free','Real',ip_F_xcb,mGrid)
-      Call GetMem('F_xca','Free','Real',ip_F_xca,mGrid)
-*                                                                      *
-************************************************************************
-*                                                                      *
-#ifdef _TIME_
-      Call QExit('Functional')
-#endif
+      Funcaa=Funcaa+DDot_(mGrid,Weights,1,F_xca,1)
+      Funcbb=Funcbb+DDot_(mGrid,Weights,1,F_xcb,1)
+      Funccc=Funccc+DDot_(mGrid,Weights,1,tmpB,1)
+      call xflush(6)
+      Call mma_deallocate(F_xca)
+      Call mma_deallocate(F_xcb)
+      Call mma_deallocate(tmpB)
 *                                                                      *
 ************************************************************************
 *                                                                      *
@@ -1722,12 +1751,6 @@ cGLM     write(6,*) 'Func in do_batch =', Func
 *                                                                      *
 ************************************************************************
 *                                                                      *
-#ifdef _TIME_
-         Call QEnter('Integral')
-#endif
-*                                                                      *
-************************************************************************
-*                                                                      *
 *---- Compute the DFT contribution to the Fock matrix                  *
 *                                                                      *
 ************************************************************************
@@ -1879,7 +1902,7 @@ cGLM     write(6,*) 'Func in do_batch =', Func
 !               Call Get_dArray('ONTOPO',work(LOE_DB),NTOT1)
 !               Call Get_dArray('ONTOPT',work(LTEG_DB),NFINT)
 
-               Call Calc_OTPUVXGGA(Work(LTEG_DB),TabMO,mAO,mGrid,
+               Call Calc_OTPUVXGGA_2(Work(LTEG_DB),TabMO,mAO,mGrid,
      &         nMOs,P2_ontop,nP2_ontop,Rho,nRho,dF_dRho,
      &         ndF_dRho,Work(ipRhoI),Work(ipRhoA),mRho,Weights,
      &         D1MO,nD1MO,nsym)
@@ -1980,12 +2003,6 @@ cGLM     write(6,*) 'Func in do_batch =', Func
 *                                                                      *
 ************************************************************************
 *                                                                      *
-#ifdef _TIME_
-         Call QExit('Integral')
-#endif
-*                                                                      *
-************************************************************************
-*                                                                      *
 *    Compute the DFT contribution to the gradient                      *
 *                                                                      *
 ************************************************************************
@@ -1994,7 +2011,7 @@ cGLM     write(6,*) 'Func in do_batch =', Func
 *
          Call DFT_Grad(Grad,nGrad,dF_dRho,ndF_dRho,nD,Grid,mGrid,
      &                 dRho_dR,ndRho_dR,nGrad_Eff,Rho,nRho,IndGrd,
-     &                 Weights,iTab,Temp,F_xc,dW_dR,iChBas,MxFnc,iNQ)
+     &                 Weights,iTab,Temp,F_xc,dW_dR,iNQ)
 *
       End If
 *                                                                      *
@@ -2004,11 +2021,8 @@ cGLM     write(6,*) 'Func in do_batch =', Func
         Call GetMem('Rho_I','Free','Real',ipRhoI,mGrid*mRho)
         Call GetMem('Rho_A','Free','Real',ipRhoA,mGrid*mRho)
       End If
-#ifdef _DEBUG_
+#ifdef _DEBUGPRINT_
       Debug=Debug_Save
-#endif
-#ifdef _TIME_
-      Call qExit('Do_Batch ')
 #endif
       Return
       End
