@@ -20,21 +20,15 @@
 *                                                                      *
 * Object: to compute the gradient of rho, grad rho, and nabla rho      *
 *                                                                      *
-* Called from: Do_Batch                                                *
-*                                                                      *
-* Calling    : QEnter                                                  *
-*              QExit                                                   *
-*                                                                      *
 *      Author:Roland Lindh, Department of Theoretical Chemistry,       *
 *             Lund university, SWEDEN.  September 2007                 *
 ************************************************************************
       use iSD_data
+      use k2_arrays, only: DeDe, ipDijS
       Implicit Real*8 (A-H,O-Z)
-#include "itmax.fh"
-#include "info.fh"
+#include "Molcas.fh"
 #include "disp.fh"
 #include "real.fh"
-#include "WrkSpc.fh"
 #include "print.fh"
 #include "debug.fh"
 #include "nsd.fh"
@@ -55,13 +49,11 @@
 *                                                                      *
 ************************************************************************
 *                                                                      *
-#ifdef _DEBUG_
-      Call QEnter('dRho_dR_meta_GGA')
+#ifdef _DEBUGPRINT_
       If (Debug) Then
          Write (6,*) 'mAO=',mAO
          Write (6,*) 'mGrid=',mGrid
          Write (6,*) 'nTabAO=',nTabAO
-         Write (6,*) 'nIrrep=',nIrrep
          Write (6,*) 'nlist_s=',nlist_s
          Do iList_s = 1, nList_s
             Write (6,*) 'iList_s=',iList_s
@@ -96,7 +88,7 @@
          iShell= iSD(11,iS)
          index_i=list_bas(2,ilist_s)
 *
-         lDCRE=NrOpr(kDCRE,iOper,nIrrep)
+         lDCRE=NrOpr(kDCRE)
 *
          jNQ=Maps2p(iS,lDCRE)
          Call ICopy(3,list_g(1,ilist_s),1,IndGrd_Eff(1,1),1)
@@ -116,7 +108,7 @@
             jBas_Eff=list_bas(1,jlist_s)
             index_j =list_bas(2,jlist_s)
 *
-            lDCRR=NrOpr(kDCRR,iOper,nIrrep)
+            lDCRR=NrOpr(kDCRR)
 *
             kNQ=Maps2p(jS,lDCRR)
             Call ICopy(3,list_g(1,jlist_s),1,IndGrd_Eff(1,2),1)
@@ -130,7 +122,7 @@
             ijS=iTri(iShell,jShell)
             ipTmp=ipDijs
             Call Dens_Info(ijS,ipDij,ipDSij,mDCRij,ipDDij,ipTmp,nD)
-#ifdef _DEBUG_
+#ifdef _DEBUGPRINT_
             If (Debug) Then
                Write (6,*)
                Write (6,*) 'iS,jS=',iS,jS
@@ -145,32 +137,32 @@
             If (ilist_s.eq.jlist_s) Deg=One
 *
             iER=iEOr(kDCRE,kDCRR)
-            lDCRER=NrOpr(iER,iOper,nIrrep)
+            lDCRER=NrOpr(iER)
 *
             ip_D_a=ipDij+lDCRER*mDij
             ip_D_b=ip_D_a
             If (nD.ne.1) ip_D_b=ipDSij+lDCRER*mDij
 *
             If (nD.ne.1) Then
-               ix=iDAMax_(mDij,Work(ip_D_a),1)
-               iy=iDAMax_(mDij,Work(ip_D_b),1)
-               DMax_ij=Half*( Abs(Work(ip_D_a-1+ix))
-     &                       +Abs(Work(ip_D_b-1+iy)) )
+               ix=iDAMax_(mDij,DeDe(ip_D_a),1)
+               iy=iDAMax_(mDij,DeDe(ip_D_b),1)
+               DMax_ij=Half*( Abs(DeDe(ip_D_a-1+ix))
+     &                       +Abs(DeDe(ip_D_b-1+iy)) )
             Else
-               ix=iDAMax_(mDij,Work(ip_D_a),1)
-               DMax_ij=Abs(Work(ip_D_a-1+ix))
+               ix=iDAMax_(mDij,DeDe(ip_D_a),1)
+               DMax_ij=Abs(DeDe(ip_D_a-1+ix))
             End If
             DMax_ij=DMax_ij*Fact(ij)
             If (TMax_i*TMax_j*DMax_ij.lt.T_X) Go To 98
-#ifdef _DEBUG_
+#ifdef _DEBUGPRINT_
             If (Debug) Then
                Write (6,*) 'dRho_dR_meta_GGA2'
                nBB = iBas*jBas
                nCC = iCmp*jCmp
                Write (6,*) 'iER,lDCRER=',iER,lDCRER
-               Call RecPrt('DAij',' ',Work(ip_D_a),nBB,nCC)
+               Call RecPrt('DAij',' ',DeDe(ip_D_a),nBB,nCC)
                If (nD.ne.1)
-     &            Call RecPrt('DBij',' ',Work(ip_D_b),nBB,nCC)
+     &            Call RecPrt('DBij',' ',DeDe(ip_D_b),nBB,nCC)
             End If
 #endif
 *
@@ -188,7 +180,7 @@
             If (nD.eq.1) Then
                If (iShell.ge.jShell) Then
                Call Do_Rho9da(dRho_dR,    mGrid,nGrad_Eff,
-     &                       Work(ip_D_a),                  mAO,
+     &                       DeDe(ip_D_a),                  mAO,
      &                       TabAO(ipTabAO(iList_s)),iBas,iBas_Eff,iCmp,
      &                       TabAO(ipTabAO(jList_s)),jBas,jBas_Eff,jCmp,
      &                       Fact(ij)*Deg,IndGrd_Eff,
@@ -196,7 +188,7 @@
      &                       Index(index_i),Index(index_j))
                Else
                Call Do_Rho9da(dRho_dR,    mGrid,nGrad_Eff,
-     &                       Work(ip_D_a),                  mAO,
+     &                       DeDe(ip_D_a),                  mAO,
      &                       TabAO(ipTabAO(jList_s)),jBas,jBas_Eff,jCmp,
      &                       TabAO(ipTabAO(iList_s)),iBas,iBas_Eff,iCmp,
      &                       Fact(ij)*Deg,IndGrd_Eff,
@@ -206,7 +198,7 @@
             Else
                If (iShell.ge.jShell) Then
                Call Do_Rho9d_(dRho_dR,    mGrid,nGrad_Eff,
-     &                       Work(ip_D_a),Work(ip_D_b),     mAO,
+     &                       DeDe(ip_D_a),DeDe(ip_D_b),     mAO,
      &                       TabAO(ipTabAO(iList_s)),iBas,iBas_Eff,iCmp,
      &                       TabAO(ipTabAO(jList_s)),jBas,jBas_Eff,jCmp,
      &                       Fact(ij)*Deg,IndGrd_Eff,
@@ -214,7 +206,7 @@
      &                       Index(index_i),Index(index_j))
                Else
                Call Do_Rho9d_(dRho_dR,    mGrid,nGrad_Eff,
-     &                       Work(ip_D_a),Work(ip_D_b),     mAO,
+     &                       DeDe(ip_D_a),DeDe(ip_D_b),     mAO,
      &                       TabAO(ipTabAO(jList_s)),jBas,jBas_Eff,jCmp,
      &                       TabAO(ipTabAO(iList_s)),iBas,iBas_Eff,iCmp,
      &                       Fact(ij)*Deg,IndGrd_Eff,
@@ -230,11 +222,10 @@
 *                                                                      *
 ************************************************************************
 *                                                                      *
-#ifdef _DEBUG_
+#ifdef _DEBUGPRINT_
       If (Debug) Call RecPrt('dRho_dR_meta_GGA: dRho_dR',' ',dRho_dR,
      &                        ndRho_dR*mGrid,nGrad_Eff)
 *
-      Call QExit('dRho_dR_meta_GGA')
 #endif
       Return
       End
