@@ -14,29 +14,18 @@
      &                         list_s,nlist_s,TabAO,ipTabAO,mAO,nTabAO,
      &                         Fact,mdc,TabAOMax,list_bas,Index,nIndex)
 ************************************************************************
-*                                                                      *
-* Object:                                                              *
-*                                                                      *
-* Called from: Do_Batch                                                *
-*                                                                      *
-* Calling    : QEnter                                                  *
-*              QExit                                                   *
-*                                                                      *
 *      Author:Roland Lindh, Department of Chemical Physics, University *
 *             of Lund, SWEDEN.  2000                                   *
 ************************************************************************
       use iSD_data
+      use k2_arrays, only: DeDe, ipDijS
       Implicit Real*8 (A-H,O-Z)
-#include "itmax.fh"
-#include "info.fh"
 #include "real.fh"
-#include "WrkSpc.fh"
 #include "print.fh"
 #include "debug.fh"
 #include "nq_info.fh"
 #include "nsd.fh"
 #include "setup.fh"
-#include "k2.fh"
       Integer list_s(2,nlist_s), ipTabAO(nlist_s), list_bas(2,nlist_s),
      &        Index(nIndex)
       Real*8 Rho(nRho,mGrid), Fact(mdc**2),
@@ -51,16 +40,14 @@
 *                                                                      *
 *define _TIME_
 #ifdef _TIME_
-      Call QEnter('Rho_meta_GGA')
 #endif
-*define _DEBUG_
-#ifdef _DEBUG_
+*define _DEBUGPRINT_
+#ifdef _DEBUGPRINT_
       Debug=.True.
       If (Debug) Then
          Write (6,*) 'mAO=',mAO
          Write (6,*) 'mGrid=',mGrid
          Write (6,*) 'nTabAO=',nTabAO
-         Write (6,*) 'nIrrep=',nIrrep
          Write (6,*) 'nlist_s=',nlist_s
          Do iList_s = 1, nList_s
             Write (6,*) 'iList_s=',iList_s
@@ -104,32 +91,32 @@
          ij = (mdci-1)*mdc + mdci
 *
          iER=iEOr(kDCRE,kDCRE)
-         lDCRER=NrOpr(iER,iOper,nIrrep)
+         lDCRER=NrOpr(iER)
 *
          ip_D_a=ipDij+lDCRER*mDij
          ip_D_b=ip_D_a
          If (nD.ne.1) ip_D_b=ipDSij+lDCRER*mDij
 *
          If (nD.ne.1) Then
-            ix=iDAMax_(mDij,Work(ip_D_a),1)
-            iy=iDAMax_(mDij,Work(ip_D_b),1)
-            DMax_ii=Half*( Abs(Work(ip_D_a-1+ix))
-     &                    +Abs(Work(ip_D_b-1+iy)) )
+            ix=iDAMax_(mDij,DeDe(ip_D_a),1)
+            iy=iDAMax_(mDij,DeDe(ip_D_b),1)
+            DMax_ii=Half*( Abs(DeDe(ip_D_a-1+ix))
+     &                    +Abs(DeDe(ip_D_b-1+iy)) )
          Else
-            ix=iDAMax_(mDij,Work(ip_D_a),1)
-            DMax_ii=Abs(Work(ip_D_a-1+ix))
+            ix=iDAMax_(mDij,DeDe(ip_D_a),1)
+            DMax_ii=Abs(DeDe(ip_D_a-1+ix))
          End If
          If (TMax_i*TMax_i*DMax_ii.ge.T_X) Then
             If (nD.eq.1) Then
                Call Do_Rho5a_d(Rho,nRho,mGrid,
-     &                         Work(ip_D_a),mAO,
+     &                         DeDe(ip_D_a),mAO,
      &                         TabAO(ipTabAO(iList_s)),
      &                         iBas,iBas_Eff,iCmp,
      &                         Fact(ij),T_X,TMax_i*TMax_i,
      &                         Index(index_i))
             Else
                Call Do_Rho5_d(Rho,nRho,mGrid,
-     &                        Work(ip_D_a),Work(ip_D_b),mAO,
+     &                        DeDe(ip_D_a),DeDe(ip_D_b),mAO,
      &                        TabAO(ipTabAO(iList_s)),
      &                        iBas,iBas_Eff,iCmp,
      &                        Fact(ij),T_X,TMax_i*TMax_i,
@@ -158,7 +145,7 @@
             ijS=iTri(iShell,jShell)
             ip_Tmp=ipDijs
             Call Dens_Info(ijS,ipDij,ipDSij,mDCRij,ipDDij,ip_Tmp,nD)
-#ifdef _DEBUG_
+#ifdef _DEBUGPRINT_
             If (Debug) Then
                Write (6,*)
                Write (6,*) 'iS,jS=',iSkal,jSkal
@@ -170,23 +157,23 @@
             ij = (mdcj-1)*mdc + mdci
 *
             iER=iEOr(kDCRE,kDCRR)
-            lDCRER=NrOpr(iER,iOper,nIrrep)
+            lDCRER=NrOpr(iER)
 *
             ip_D_a=ipDij+lDCRER*mDij
             ip_D_b=ip_D_a
             If (nD.ne.1) ip_D_b=ipDSij+lDCRER*mDij
 *
             If (nD.ne.1) Then
-               ix=iDAMax_(mDij,Work(ip_D_a),1)
-               iy=iDAMax_(mDij,Work(ip_D_b),1)
-               DMax_ij=Half*( Abs(Work(ip_D_a-1+ix))
-     &                       +Abs(Work(ip_D_b-1+iy)) )
+               ix=iDAMax_(mDij,DeDe(ip_D_a),1)
+               iy=iDAMax_(mDij,DeDe(ip_D_b),1)
+               DMax_ij=Half*( Abs(DeDe(ip_D_a-1+ix))
+     &                       +Abs(DeDe(ip_D_b-1+iy)) )
             Else
-               ix=iDAMax_(mDij,Work(ip_D_b),1)
-               DMax_ij=Abs(Work(ip_D_a-1+ix))
+               ix=iDAMax_(mDij,DeDe(ip_D_b),1)
+               DMax_ij=Abs(DeDe(ip_D_a-1+ix))
             End If
             If (TMax_i*TMax_j*DMax_ij.lt.T_X) Go To 998
-#ifdef _DEBUG_
+#ifdef _DEBUGPRINT_
             If (Debug) Then
                Write (6,*) 'Rho_meta_GGA1'
                nBB = iBas*jBas
@@ -194,26 +181,24 @@
                Write (6,*) 'iShell,jshell=', iShell,jshell
                Write (6,*) 'kDCRE,kDCRR=', kDCRE,kDCRR
                Write (6,*) 'iER,lDCRER=',iER,lDCRER
-               Write (6,*) 'MaxDe,MaxDCR=',MaxDe,MaxDCR
-               Write (6,*) 'ipDeDe,nDeDe_DFT=',ipDeDe, nDeDe_DFT
                Write (6,*) 'ip_D_a=',ip_D_a
-               Call RecPrt('DAij',' ',Work(ip_D_a),nBB,nCC)
+               Call RecPrt('DAij',' ',DeDe(ip_D_a),nBB,nCC)
                If (nD.ne.1)
-     &            Call RecPrt('DBij',' ',Work(ip_D_b),nBB,nCC)
+     &            Call RecPrt('DBij',' ',DeDe(ip_D_b),nBB,nCC)
             End If
 #endif
 *
             If (nD.eq.1) Then
                If (iShell.ge.jShell) Then
                Call Do_Rho5a(Rho,nRho,mGrid,
-     &                       Work(ip_D_a),                  mAO,
+     &                       DeDe(ip_D_a),                  mAO,
      &                       TabAO(ipTabAO(iList_s)),iBas,iBas_Eff,iCmp,
      &                       TabAO(ipTabAO(jList_s)),jBas,jBas_Eff,jCmp,
      &                       Fact(ij)*Two,T_X,TMax_i*TMax_j,
      &                       Index(index_i),Index(index_j))
                Else
                Call Do_Rho5a(Rho,nRho,mGrid,
-     &                       Work(ip_D_a),                  mAO,
+     &                       DeDe(ip_D_a),                  mAO,
      &                       TabAO(ipTabAO(jList_s)),jBas,jBas_Eff,jCmp,
      &                       TabAO(ipTabAO(iList_s)),iBas,iBas_Eff,iCmp,
      &                       Fact(ij)*Two,T_X,TMax_i*TMax_j,
@@ -222,14 +207,14 @@
             Else
                If (iShell.ge.jShell) Then
                Call Do_Rho5_(Rho,nRho,mGrid,
-     &                       Work(ip_D_a),Work(ip_D_b),     mAO,
+     &                       DeDe(ip_D_a),DeDe(ip_D_b),     mAO,
      &                       TabAO(ipTabAO(iList_s)),iBas,iBas_Eff,iCmp,
      &                       TabAO(ipTabAO(jList_s)),jBas,jBas_Eff,jCmp,
      &                       Fact(ij)*Two,T_X,TMax_i*TMax_j,
      &                       Index(index_i),Index(index_j))
                Else
                Call Do_Rho5_(Rho,nRho,mGrid,
-     &                       Work(ip_D_a),Work(ip_D_b),     mAO,
+     &                       DeDe(ip_D_a),DeDe(ip_D_b),     mAO,
      &                       TabAO(ipTabAO(jList_s)),jBas,jBas_Eff,jCmp,
      &                       TabAO(ipTabAO(iList_s)),iBas,iBas_Eff,iCmp,
      &                       Fact(ij)*Two,T_X,TMax_i*TMax_j,
@@ -242,7 +227,7 @@
  999     Continue
       End Do                         ! ilist_s
 *
-#ifdef _DEBUG_
+#ifdef _DEBUGPRINT_
       If (Debug) Then
 c        Do iGrid=1,mGrid_Eff
 c           Write (*,*) (Rho(iRho,iGrid),iRho=1,nRho)
@@ -252,7 +237,6 @@ c        End Do
 *
 #endif
 #ifdef _TIME_
-      Call QExit('Rho_GGA')
 #endif
       Return
       End
@@ -272,7 +256,6 @@ c        End Do
 ************************************************************************
 *                                                                      *
 #ifdef _TIME_
-      Call QEnter('Do_Rho5a')
 #endif
       Do jCB_Eff = 1, jBas_Eff*jCmp
          jCB = Index_j(jCB_Eff)
@@ -311,7 +294,6 @@ c        End Do
       End Do             ! jCB
 *
 #ifdef _TIME_
-      Call QExit('Do_Rho5a')
 #endif
       Return
       End
@@ -390,7 +372,6 @@ c        End Do
 ************************************************************************
 *                                                                      *
 #ifdef _TIME_
-      Call QEnter('Do_Rho5a_d')
 #endif
       Do jCB_Eff = 1, iBas_Eff*iCmp
          jCB=Index_i(jCB_Eff)
@@ -449,7 +430,6 @@ c        End Do
       End Do             ! jCB
 *
 #ifdef _TIME_
-      Call QExit('Do_Rho5a_d')
 #endif
       Return
       End
