@@ -233,7 +233,8 @@ C     Print *,'Is_Roots_Set, nRoots, iRoot = ',Is_Roots_Set,nRoots,iRoot
      &    Method(1:5) .eq. 'CCSDT'  .OR.
      &    Method(1:4) .eq. 'CHCC'   .OR.
      &    Method(1:6) .eq. 'MCPDFT' .OR.
-     &    Method(1:4) .eq. 'CHT3') Then
+     &    Method(1:4) .eq. 'CHT3'   .OR.
+     &    Method(1:8) .eq. 'EXTERNAL') Then
          If (iPL_Save.ge.3) Then
             Write (LuWr,*)
             Write (LuWr,'(A,A,A)')
@@ -270,10 +271,6 @@ C     Print *,'Is_Roots_Set, nRoots, iRoot = ',Is_Roots_Set,nRoots,iRoot
       iChCar(1) = iSymX
       iChCar(2) = iSymY
       iChCar(3) = iSymZ
-      nOper=0
-      If (nIrrep.eq.8) nOper=3
-      If (nIrrep.eq.4) nOper=2
-      If (nIrrep.eq.2) nOper=1
       MaxDCR = nIrrep
 *                                                                      *
 ************************************************************************
@@ -307,8 +304,8 @@ C     Print *,'Is_Roots_Set, nRoots, iRoot = ',Is_Roots_Set,nRoots,iRoot
 *
 *           Find the stabilizer of this center
 *
-            iChxyz=iChAtm(Work(ipCoor+(i-1)*3),iOper,nOper,iChCar)
-            Call Stblz(iChxyz,iOper,nIrrep,nStab,jStab,MaxDCR,iCoSet)
+            iChxyz=iChAtm(Work(ipCoor+(i-1)*3))
+            Call Stblz(iChxyz,nStab,jStab,MaxDCR,iCoSet)
 *
             Call IZero(iDispXYZ,3)
             Do j = 0, nStab-1
@@ -363,7 +360,7 @@ C     Print *,'Is_Roots_Set, nRoots, iRoot = ',Is_Roots_Set,nRoots,iRoot
       Call Allocate_Work(ipDeg,3*nAtoms)
       Call FZero(Work(ipDeg),3*nAtoms)
       Do i = 1, nAtoms
-         rDeg=DBLE(iDeg(Work(ipCoor+(i-1)*3),iOper,nSym))
+         rDeg=DBLE(iDeg(Work(ipCoor+(i-1)*3)))
          Work(ipDeg+(i-1)*3  )=rDeg
          Work(ipDeg+(i-1)*3+1)=rDeg
          Work(ipDeg+(i-1)*3+2)=rDeg
@@ -414,7 +411,7 @@ C     Print *,'Is_Roots_Set, nRoots, iRoot = ',Is_Roots_Set,nRoots,iRoot
       iPL_Base=0
       If (iPL_Save.ge.3) iPl_Base=iPL_Save
 *
-#ifdef _DEBUG_
+#ifdef _DEBUGPRINT_
       Call RecPrt('BMtrx',' ',Work(ip_BMtrx),3*nAtoms,mInt)
       Call RecPrt('TMtrx',' ',Work(ip_TMtrx),mInt,mInt)
       Call RecPrt('Degeneracy vector',' ',Work(ipDeg),3,nAtoms)
@@ -639,6 +636,19 @@ C     Print *,'Is_Roots_Set, nRoots, iRoot = ',Is_Roots_Set,nRoots,iRoot
             If (iReturn .ne. 0) Then
                Write(LuWr,*) 'Numerical_Gradient failed ...'
                Write(LuWr,*) 'RASSCF returned with return code, rc = ',
+     &                     iReturn
+               Write(LuWr,*) 'for the perturbation iDisp = ',iDisp
+               Call Abend()
+            End If
+         Else If (Method(1:8) .eq. 'EXTERNAL') Then
+            Call StartLight('false')
+            Call init_run_use()
+            Call Disable_Spool()
+            Call False_program(ireturn)
+            Call ReClose()
+            If (iReturn .ne. 0) Then
+               Write(LuWr,*) 'Numerical_Gradient failed ...'
+               Write(LuWr,*) 'FALSE returned with return code, rc = ',
      &                     iReturn
                Write(LuWr,*) 'for the perturbation iDisp = ',iDisp
                Call Abend()
@@ -995,7 +1005,7 @@ C_MPP End Do
 *
          Call F_Inquire('QMMM',Exist)
          If (Exist .and. DoTinker) Then
-            Call LA_Morok(nAtoms,ipTmp,1)
+            Call LA_Morok(nAtoms,Work(ipTmp),1)
          End If
 *
          If (iR.eq.iRoot) Call Put_Grad(Work(ipTmp),3*nAtoms)
@@ -1056,7 +1066,7 @@ C_MPP End Do
       If (Method(1:6) .eq. 'CASSCF' .OR.
      &    Method(1:6) .eq. 'RASSCF' ) Then
          Call Get_iScalar('Relax CASSCF root',irlxroot1)
-         Call Get_iScalar('Relax Original ro',irlxroot2)
+         Call Get_iScalar('Relax Original root',irlxroot2)
          If (iRlxRoot1.ne.iRlxRoot2) Then
             Call Put_iScalar('Relax CASSCF root',irlxroot2)
             Call Put_iScalar('NumGradRoot',irlxroot2)
