@@ -12,22 +12,12 @@
 ************************************************************************
       SubRoutine InpRct(LuSpool)
 ************************************************************************
-*                                                                      *
-* Object:                                                              *
-*                                                                      *
-* Called from:                                                         *
-*                                                                      *
-* Calling    : QEnter                                                  *
-*              QExit                                                   *
-*                                                                      *
 *     Author: Roland Lindh, Dept. of Theoretical Chemistry,            *
 *             University of Lund, SWEDEN                               *
 *                                                                      *
 *             Modified for Langevin polarizabilities, March 2000 (RL)  *
 ************************************************************************
       Implicit Real*8 (A-H,O-Z)
-#include "itmax.fh"
-#include "info.fh"
 #include "real.fh"
 #include "print.fh"
 #include "rctfld.fh"
@@ -37,7 +27,6 @@
 *
       iRout=1
       iPrint=nPrint(iRout)
-*     Call qEnter('InpRct')
 *                                                                      *
 ************************************************************************
 *                                                                      *
@@ -151,9 +140,6 @@
 *                                                                      *
 ************************************************************************
 *                                                                      *
-      Do i = 1, 80
-         BLine(i:i) = ' '
-      End Do
       iPrint=5
 *                                                                      *
 ************************************************************************
@@ -164,7 +150,7 @@
       KWord = Key
       Call UpCase(KWord)
       If (KWord(1:1).eq.'*')    Go To 998
-      If (KWord.eq.BLine)       Go To 998
+      If (KWord.eq.'')       Go To 998
       If (KWord(1:4).eq.'REAC') Go To 900
       If (KWord(1:4).eq.'PRIN') Go To 910
       If (KWord(1:4).eq.'LANG') Go To 911
@@ -460,7 +446,7 @@ C%      Go To 998
       Kword=Get_Ln(LuSpool)
       Call UpCase(KWord)
       If (KWord(1:1).eq.'*')    Go To 938
-      If (KWord.eq.BLine)       Go To 938
+      If (KWord.eq.'')       Go To 938
       If (KWord(1:3).eq.'END')  Go To 998
       Read(KWord,*,err=988) ii,val
       CovRadT_(ii)=val
@@ -548,7 +534,6 @@ c      write(6,*)'COVR',ii,val
 *                                                                      *
 ************************************************************************
 *                                                                      *
-*     Call qExit('InpRct')
       Return
 *                                                                      *
 ************************************************************************
