@@ -41,13 +41,13 @@ c----------------------------------------------------------------------
       Dimension Tessera(4,*)
       Dimension AtmC(3,*)
 #include "real.fh"
-#include "itmax.fh"
-#include "info.fh"
 #include "print.fh"
 #include "WrkSpc.fh"
 #include "stdalloc.fh"
       Real*8 Temp(3)
       Real*8, Allocatable :: Chrg(:)
+      Logical Found
+      Real*8, Allocatable :: D1ao(:)
 *                                                                      *
       Call mma_allocate(Chrg,nat)
       Call Get_dArray('Nuclear charge',Chrg,nAt)
@@ -76,14 +76,21 @@ c----------------------------------------------------------------------
 *
 *     Get the total 1st order AO density matrix
 *
-      Call Get_D1ao(ipD1ao,nDens)
+      Call Qpg_dArray('D1ao',Found,nDens)
+      If (Found .and. nDens/=0) Then
+         Call mma_allocate(D1ao,nDens,Label='D1ao')
+      Else
+         Write (6,*) 'Mlt_pcm: D1ao not found.'
+         Call Abend()
+      End If
+      Call Get_D1ao(D1ao,nDens)
 *
       Call Allocate_Work(ipFactOp,nTs)
       Call Allocate_iWork(iplOper,nTs)
       call dcopy_(nTs,[One],0,Work(ipFactOp),1)
       Call ICopy(nTs,[255],0,iWork(iplOper),1)
 *
-      Call drv_ef_PCM(Work(ipFactOp),nTs,Work(ipD1ao),nDens,
+      Call drv_ef_PCM(Work(ipFactOp),nTs,D1ao,nDens,
      &              Tessera,iWork(iplOper),
      &              EF_e,nOrdOp)
       If(nOrdOp.eq.0) then
@@ -94,7 +101,7 @@ c----------------------------------------------------------------------
 *
       Call Free_iWork(iplOper)
       Call Free_Work(ipFactOp)
-      Call GetMem('D1ao','Free','Real',ipD1ao,nDens)
+      Call mma_deallocate(D1ao)
 *
       Return
       End
@@ -107,26 +114,6 @@ c----------------------------------------------------------------------
 *         order density matrix and accumulate contributions to the     *
 *         global multipole expansion.                                  *
 *                                                                      *
-* Called from: RctFld                                                  *
-*                                                                      *
-* Calling    : QEnter                                                  *
-*              GetMem                                                  *
-*              ZXia                                                    *
-*              SetUp1                                                  *
-*              MltInt                                                  *
-*              DGeMV    (ESSL)                                         *
-*              RecPrt                                                  *
-*              DCopy    (ESSL)                                         *
-*              DGEMM_   (ESSL)                                         *
-*              CarSph                                                  *
-*              DGeTMO   (ESSL)                                         *
-*              DaXpY    (ESSL)                                         *
-*              SOGthr                                                  *
-*              DesymD                                                  *
-*              DScal    (ESSL)                                         *
-*              TriPrt                                                  *
-*              QExit                                                   *
-*                                                                      *
 *     Author: Roland Lindh, IBM Almaden Research Center, San Jose, CA  *
 *             January '90                                              *
 *             Modified for Hermite-Gauss quadrature November '90       *
@@ -143,12 +130,14 @@ c----------------------------------------------------------------------
 ************************************************************************
       use Real_Spherical
       use iSD_data
+      use Basis_Info
+      use Center_Info
+      use Sizes_of_Seward, only: S
+      use Symmetry_Info, only: nIrrep
       Implicit Real*8 (A-H,O-Z)
 #include "angtp.fh"
-#include "info.fh"
 #include "real.fh"
 #include "WrkSpc.fh"
-#include "lundio.fh"
 #include "print.fh"
 #include "nsd.fh"
 #include "setup.fh"
@@ -165,16 +154,15 @@ c----------------------------------------------------------------------
 *
       iRout = 112
       iPrint = nPrint(iRout)
-      Call qEnter('drv_ef_PCM')
 *
       iIrrep = 0
 *
 *     Auxiliary memory allocation.
 *
-      Call GetMem('Zeta','ALLO','REAL',iZeta,m2Max)
-      Call GetMem('Zeta','ALLO','REAL',ipZI ,m2Max)
-      Call GetMem('Kappa','ALLO','REAL',iKappa,m2Max)
-      Call GetMem('PCoor','ALLO','REAL',iPCoor,m2Max*3)
+      Call GetMem('Zeta','ALLO','REAL',iZeta,S%m2Max)
+      Call GetMem('Zeta','ALLO','REAL',ipZI ,S%m2Max)
+      Call GetMem('Kappa','ALLO','REAL',iKappa,S%m2Max)
+      Call GetMem('PCoor','ALLO','REAL',iPCoor,S%m2Max*3)
 *                                                                      *
 ************************************************************************
 *                                                                      *
@@ -189,30 +177,28 @@ c----------------------------------------------------------------------
          iAng   = iSD( 1,iS)
          iCmp   = iSD( 2,iS)
          iBas   = iSD( 3,iS)
-         iCff   = iSD( 4,iS)
          iPrim  = iSD( 5,iS)
-         iExp   = iSD( 6,iS)
          iAO    = iSD( 7,iS)
-         ixyz   = iSD( 8,iS)
          mdci   = iSD(10,iS)
          iShell = iSD(11,iS)
-         call dcopy_(3,Work(ixyz),1,A,1)
+         iCnttp = iSD(13,iS)
+         iCnt   = iSD(14,iS)
+         A(1:3)=dbsc(iCnttp)%Coor(1:3,iCnt)
          Do jS = 1, iS
             jShll  = iSD( 0,jS)
             jAng   = iSD( 1,jS)
             jCmp   = iSD( 2,jS)
             jBas   = iSD( 3,jS)
-            jCff   = iSD( 4,jS)
             jPrim  = iSD( 5,jS)
-            jExp   = iSD( 6,jS)
             jAO    = iSD( 7,jS)
-            jxyz   = iSD( 8,jS)
             mdcj   = iSD(10,jS)
             jShell = iSD(11,jS)
-            call dcopy_(3,Work(jxyz),1,B,1)
+            jCnttp = iSD(13,jS)
+            jCnt   = iSD(14,jS)
+            B(1:3)=dbsc(jCnttp)%Coor(1:3,jCnt)
 *
             iSmLbl = 1
-            nSO = MemSO1(iSmLbl,iCmp,jCmp,iShell,jShell)
+            nSO = MemSO1(iSmLbl,iCmp,jCmp,iShell,jShell,iAO,jAO)
             If (nSO.eq.0) Go To 131
             If (iPrint.ge.19) Write (6,'(A,A,A,A,A)')
      &        ' ***** (',AngTp(iAng),',',AngTp(jAng),') *****'
@@ -221,27 +207,27 @@ c----------------------------------------------------------------------
 *
             Call EFMmP(nOrder,MemKer,iAng,jAng,nOrdOp)
 *           Write (*,*)nOrder,MemKer,iAng,jAng,nOrdOp
-            MemKrn=MemKer*m2Max
+            MemKrn=MemKer*S%m2Max
             Call GetMem('Kernel','ALLO','REAL',iKern,MemKrn)
 *
 *           Allocate memory for the final integrals, all in the
 *           primitive basis.
 *
             nComp = (nOrdOp+1)*(nOrdOp+2)/2
-            lFinal = MaxPrm(iAng) * MaxPrm(jAng)
+            lFinal = S%MaxPrm(iAng) * S%MaxPrm(jAng)
      &             * nElem(iAng)*nElem(jAng)
      &             * nComp
             Call GetMem('Final','ALLO','REAL',ipFnl,lFinal)
 *
 *           Scratch area for contraction step
 *
-            nScr1 =  MaxPrm(iAng)*MaxPrm(jAng) *
+            nScr1 =  S%MaxPrm(iAng)*S%MaxPrm(jAng) *
      &               nElem(iAng)*nElem(jAng)
             Call GetMem('Scrtch','ALLO','REAL',iScrt1,nScr1)
 *
 *           Scratch area for the transformation to spherical gaussians
 *
-            nScr2=MaxPrm(iAng)*MaxPrm(jAng)*nElem(iAng)*nElem(jAng)
+            nScr2=S%MaxPrm(iAng)*S%MaxPrm(jAng)*nElem(iAng)*nElem(jAng)
             Call GetMem('ScrSph','Allo','Real',iScrt2,nScr2)
 *
             nDAO =iPrim*jPrim*nElem(iAng)*nElem(jAng)
@@ -250,22 +236,22 @@ c----------------------------------------------------------------------
 *           At this point we can compute Zeta.
 *
             Call ZXia(Work(iZeta),Work(ipZI),
-     &                iPrim,jPrim,Work(iExp),Work(jExp))
+     &                iPrim,jPrim,Shells(iShll)%Exp,
+     &                            Shells(jShll)%Exp)
 *
             AeqB = iS.eq.jS
 *
 *           Find the DCR for A and B
 *
-            Call DCR(LmbdR,iOper,nIrrep,jStab(0,mdci),
-     &               nStab(mdci),jStab(0,mdcj),
-     &               nStab(mdcj),iDCRR,nDCRR)
+            Call DCR(LmbdR,dc(mdci)%iStab,dc(mdci)%nStab,
+     &                     dc(mdcj)%iStab,dc(mdcj)%nStab,iDCRR,nDCRR)
             If (iPrint.ge.49) Write (6,'(10A)')
      &         ' {R}=(',(ChOper(iDCRR(i)),i=0,nDCRR-1),')'
 *
 *-----------Find the stabilizer for A and B
 *
-            Call Inter(jStab(0,mdci),nStab(mdci),
-     &                 jStab(0,mdcj),nStab(mdcj),
+            Call Inter(dc(mdci)%iStab,dc(mdci)%nStab,
+     &                 dc(mdcj)%iStab,dc(mdcj)%nStab,
      &                 iStabM,nStabM)
 *
 *           Allocate memory for the elements of the Fock or 1st order
@@ -279,29 +265,30 @@ c----------------------------------------------------------------------
 *
             Call SOGthr(Work(ipDSO),iBas,jBas,nSO,FD,
      &                  n2Tri(iSmLbl),iSmLbl,
-     &                  iCmp,jCmp,iShell,jShell,AeqB,iAO,jAO)
+     &                  iCmp,jCmp,iShell,jShell,
+     &                  AeqB,iAO,jAO)
 *
 *           Project the Fock/1st order density matrix in AO
 *           basis on to the primitive basis.
 *
             If (iPrint.ge.99) Then
                Call RecPrt(' Left side contraction',' ',
-     &                     Work(iCff),iPrim,iBas)
+     &                     Shells(iShll)%pCff,iPrim,iBas)
                Call RecPrt(' Right side contraction',' ',
-     &                     Work(jCff),jPrim,jBas)
+     &                     Shells(jShll)%pCff,jPrim,jBas)
             End If
 *
 *           Transform IJ,AB to J,ABi
             Call DGEMM_('T','T',
      &                  jBas*nSO,iPrim,iBas,
      &                  1.0d0,Work(ipDSO),iBas,
-     &                  Work(iCff),iPrim,
+     &                        Shells(iShll)%pCff,iPrim,
      &                  0.0d0,Work(ipDSOp),jBas*nSO)
 *           Transform J,ABi to AB,ij
             Call DGEMM_('T','T',
      &                  nSO*iPrim,jPrim,jBas,
      &                  1.0d0,Work(ipDSOp),jBas,
-     &                  Work(jCff),jPrim,
+     &                        Shells(jShll)%pCff,jPrim,
      &                  0.0d0,Work(ipDSO),nSO*iPrim)
 *           Transpose to ij,AB
             Call DGeTmO(Work(ipDSO),nSO,nSO,iPrim*jPrim,Work(ipDSOp),
@@ -315,9 +302,7 @@ c----------------------------------------------------------------------
 *           Loops over symmetry operations.
 *
             Do lDCRR = 0, nDCRR-1
-               RB(1)  = DBLE(iPhase(1,iDCRR(lDCRR)))*B(1)
-               RB(2)  = DBLE(iPhase(2,iDCRR(lDCRR)))*B(2)
-               RB(3)  = DBLE(iPhase(3,iDCRR(lDCRR)))*B(3)
+               Call OA(iDCRR(lDCRR),B,RB)
 *
 *--------------Loop over operators
 *
@@ -331,8 +316,8 @@ c----------------------------------------------------------------------
 *
 *-----------------Find the DCR for M and S
 *
-                  Call DCR(LmbdT,iOper,nIrrep,iStabM,nStabM,
-     &                     iStabO,nStabO,iDCRT,nDCRT)
+                  Call DCR(LmbdT,iStabM,nStabM,iStabO,nStabO,
+     &                     iDCRT,nDCRT)
                   If (iPrint.ge.49) Then
                      Write (6,'(10A)') ' {M}=(',(ChOper(iStabM(i)),
      &                     i=0,nStabM-1),')'
@@ -345,7 +330,7 @@ c----------------------------------------------------------------------
 *-----------------Compute normalization factor due the DCR symmetrization
 *                 of the two basis functions and the operator.
 *
-                  iuv = nStab(mdci)*nStab(mdcj)
+                  iuv = dc(mdci)%nStab*dc(mdcj)%nStab
                   FactNd = DBLE(iuv*nStabO) / DBLE(nIrrep**2*LmbdT)
                   If (MolWgh.eq.1) Then
                      FactNd = FactNd * DBLE(nIrrep)**2 / DBLE(iuv)
@@ -356,17 +341,12 @@ c----------------------------------------------------------------------
                   FactNd = FactNd * FactOp(iTile)
 *
                   Do lDCRT = 0, nDCRT-1
-                     nOp(1) = NrOpr(iDCRT(lDCRT),iOper,nIrrep)
-                     nOp(2) = NrOpr(iEor(iDCRT(lDCRT),
-     &                             iDCRR(lDCRR)),iOper,nIrrep)
-                     nOp(3) = NrOpr(0,iOper,nIrrep)
+                     nOp(1) = NrOpr(iDCRT(lDCRT))
+                     nOp(2) = NrOpr(iEor(iDCRT(lDCRT),iDCRR(lDCRR)))
+                     nOp(3) = NrOpr(0)
 
-                     TA(1)  = DBLE(iPhase(1,iDCRT(lDCRT)))*A(1)
-                     TA(2)  = DBLE(iPhase(2,iDCRT(lDCRT)))*A(2)
-                     TA(3)  = DBLE(iPhase(3,iDCRT(lDCRT)))*A(3)
-                     TRB(1) = DBLE(iPhase(1,iDCRT(lDCRT)))*RB(1)
-                     TRB(2) = DBLE(iPhase(2,iDCRT(lDCRT)))*RB(2)
-                     TRB(3) = DBLE(iPhase(3,iDCRT(lDCRT)))*RB(3)
+                     Call OA(iDCRT(lDCRT),A,TA)
+                     Call OA(iDCRT(lDCRT),RB,TRB)
                      If (iPrint.ge.49) Then
                         Write (6,'(A,/,3(3F6.2,2X))')
      &                  ' *** Centers A, B, C ***',
@@ -381,14 +361,15 @@ c----------------------------------------------------------------------
 *
                      Call DesymD(iSmLbl,iAng,jAng,iCmp,jCmp,
      &                           iShell,jShell,iShll,jShll,
-     &                           Work(ipDAO),iPrim,jPrim,
+     &                           iAO,jAO,Work(ipDAO),iPrim,jPrim,
      &                           Work(ipDSOp),nSO,nOp,FactNd)
 *
 *--------------------Project the spherical harmonic space onto the
 *                    cartesian space.
 *
                      kk = nElem(iAng)*nElem(jAng)
-                     If (Transf(iShll).or.Transf(jShll)) Then
+                     If (Shells(iShll)%Transf.or.
+     &                   Shells(jShll)%Transf) Then
 *
 *-----------------------ij,AB --> AB,ij
                         Call DGeTmO(Work(ipDAO),iPrim*jPrim,iPrim*jPrim,
@@ -397,9 +378,11 @@ c----------------------------------------------------------------------
                         Call SphCar(Work(iScrt1),iCmp*jCmp,iPrim*jPrim,
      &                              Work(iScrt2),nScr2,
      &                              RSph(ipSph(iAng)),
-     &                              iAng,Transf(iShll),Prjct(iShll),
+     &                              iAng,Shells(iShll)%Transf,
+     &                                   Shells(iShll)%Prjct,
      &                              RSph(ipSph(jAng)),
-     &                              jAng,Transf(jShll),Prjct(jShll),
+     &                              jAng,Shells(jShll)%Transf,
+     &                                   Shells(jShll)%Prjct,
      &                              Work(ipDAO),kk)
                      End If
                      If (iPrint.ge.99) Call RecPrt(
@@ -408,7 +391,8 @@ c----------------------------------------------------------------------
 *
 *--------------------Compute kappa and P.
 *
-                     Call Setup1(Work(iExp),iPrim,Work(jExp),jPrim,
+                     Call Setup1(Shells(iShll)%Exp,iPrim,
+     &                           Shells(jShll)%Exp,jPrim,
      &                   TA,TRB,Work(iKappa),Work(iPCoor),Work(ipZI))
 *
 *
@@ -416,13 +400,14 @@ c----------------------------------------------------------------------
 *
 cpcm_solvent
 c        write(6,*)'Work(iExp),iPrim,Work(jExp),jPrim'
-c        write(6,*)Work(iExp),iPrim,Work(jExp),jPrim
+c        write(6,*)Shells(iShll)%Exp(1),iPrim,Shells(jShll)%Exp(1),jPrim
 c        write(6,*)'Work(iZeta),Work(ipZI),Work(iKappa),Work(iPcoor)'
 c        write(6,*)Work(iZeta),Work(ipZI),Work(iKappa),Work(iPcoor)
 c        write(6,*)'Work(ipFnl),iPrim*jPrim,nComp,iAng,jAng,norder'
 c        write(6,*)Work(ipFnl),iPrim*jPrim,nComp,iAng,jAng,norder
 cpcm_solvent end
-                     Call EFPrm(Work(iExp),iPrim,Work(jExp),jPrim,
+                     Call EFPrm(Shells(iShll)%Exp,iPrim,
+     &                          Shells(jShll)%Exp,jPrim,
      &                          Work(iZeta),Work(ipZI),
      &                          Work(iKappa),Work(iPcoor),
      &                          Work(ipFnl),iPrim*jPrim,nComp,
@@ -466,13 +451,12 @@ cpcm_solvent end
          End Do
       End Do
 *
-      Call GetMem('PCoor','FREE','REAL',iPCoor,n2Max*3)
-      Call GetMem('Kappa','FREE','REAL',iKappa,n2Max)
-      Call GetMem('Zeta','FREE','REAL',ipZI ,n2Max)
-      Call GetMem('Zeta','FREE','REAL',iZeta,n2Max)
+      Call GetMem('PCoor','FREE','REAL',iPCoor,S%m2Max*3)
+      Call GetMem('Kappa','FREE','REAL',iKappa,S%m2Max)
+      Call GetMem('Zeta','FREE','REAL',ipZI ,S%m2Max)
+      Call GetMem('Zeta','FREE','REAL',iZeta,S%m2Max)
 *
 c     Call GetMem('drv_ef_PCM','CHEC','REAL',iDum,iDum)
 *
-      Call qExit('drv_ef_PCM')
       Return
       End
