@@ -26,35 +26,35 @@
       Integer, intent(in)          :: nexch(nneq)
       Integer, intent(in)          :: neq(nneq)
       Integer, intent(in)          :: i_pair(npair,2)
-      Real(kind=wp), intent(in)    :: rot(nneq,neqv,3,3)
-      Real(kind=wp), intent(in)    :: soe(nneq,nmax)
-      Complex(kind=wp), intent(in) :: MM(nneq,3,nmax,nmax)
-      Complex(kind=wp), intent(in) :: SM(nneq,3,nmax,nmax)
-      Complex(kind=wp), intent(in) :: HLIN1(npair,nmax,nmax,nmax,nmax)
-      Complex(kind=wp), intent(in) :: HLIN3(npair,nmax,nmax,nmax,nmax)
-      Complex(kind=wp), intent(in) :: HLIN9(npair,nmax,nmax,nmax,nmax)
-      Complex(kind=wp), intent(in) :: HDIP(npair,nmax,nmax,nmax,nmax)
-      Complex(kind=wp), intent(in) :: HDMO(npair,nmax,nmax,nmax,nmax)
-      Complex(kind=wp), intent(in) :: HITO(npair,nmax,nmax,nmax,nmax)
+      Real(kind=8), intent(in)    :: rot(nneq,neqv,3,3)
+      Real(kind=8), intent(in)    :: soe(nneq,nmax)
+      Complex(kind=8), intent(in) :: MM(nneq,3,nmax,nmax)
+      Complex(kind=8), intent(in) :: SM(nneq,3,nmax,nmax)
+      Complex(kind=8), intent(in) :: HLIN1(npair,nmax,nmax,nmax,nmax)
+      Complex(kind=8), intent(in) :: HLIN3(npair,nmax,nmax,nmax,nmax)
+      Complex(kind=8), intent(in) :: HLIN9(npair,nmax,nmax,nmax,nmax)
+      Complex(kind=8), intent(in) :: HDIP(npair,nmax,nmax,nmax,nmax)
+      Complex(kind=8), intent(in) :: HDMO(npair,nmax,nmax,nmax,nmax)
+      Complex(kind=8), intent(in) :: HITO(npair,nmax,nmax,nmax,nmax)
       Logical, intent(in)          :: Dipol
       Logical, intent(in)          :: AnisoLines1
       Logical, intent(in)          :: AnisoLines3
       Logical, intent(in)          :: AnisoLines9
       Logical, intent(in)          :: DM_exchange
       Logical, intent(in)          :: JITO_exchange
-      Character(1), intent(in)     :: itype(nneq)
+      Character(Len=1), intent(in) :: itype(nneq)
       ! local variables
       Integer       ::   i,j,l,k,lp,i1,i2,j1,j2,lb1,lb2,iopt,ibuf,
      &                   is1,is2,js1,js2,k1,k2,q1,q2,n1,n2,nsize
       Integer       ::   nind(lmax,2),l1(2),l2(2),l3(2),l4(2)
-      Real(kind=wp) ::   J1C(3,3), J1Cr(3,3) !, J1C_trans(3,3)
-      Complex(kind=wp), allocatable :: JN(:,:,:,:)
-      Complex(kind=wp), allocatable :: JB(:,:,:,:)
-      Complex(kind=wp), allocatable :: JS(:,:,:,:)
-      Real(kind=wp)    :: dznrm2_,RL1,RL3,RL9,RDI,RDM,RIT
-      Real(kind=wp)    :: g1(3),g2(3),mg1(3,3),mg2(3,3)
+      Real(kind=8) ::   J1C(3,3), J1Cr(3,3) !, J1C_trans(3,3)
+      Complex(kind=8), allocatable :: JN(:,:,:,:)
+      Complex(kind=8), allocatable :: JB(:,:,:,:)
+      Complex(kind=8), allocatable :: JS(:,:,:,:)
+      Real(kind=8)    :: dznrm2_,RL1,RL3,RL9,RDI,RDM,RIT
+      Real(kind=8)    :: g1(3),g2(3),mg1(3,3),mg2(3,3)
       External         :: dznrm2_
-      Real(kind=wp)    :: cm_to_MHz
+      Real(kind=8)    :: cm_to_MHz
       logical DBG
 
       cm_to_MHz=29979.2458_wp
