@@ -50,7 +50,6 @@
 *----------------------------------------------------------------------*
 * Enter.                                                               *
 *----------------------------------------------------------------------*
-      Call Qenter('EqScf')
 *----------------------------------------------------------------------*
 * Make some conversions, initializations and zeros.                    *
 *----------------------------------------------------------------------*
@@ -659,7 +658,6 @@ c          write(6,*)'ipAOSum',ipAOSum
      &,it4h,':',it4m,':',t4s
 8     Format(A,I4,A,I3,A,F5.2)
 
-      Call Qexit('EqScf')
       Return
       End
 
