@@ -74,11 +74,11 @@
       Character Line*120,BlLine*120,Title*100,OrbName*100,WhatGet*10
       Character StLine*120
       Dimension iDummy(1)
+      Integer ipACC
 
 *-----------------------------------------------------------------------*
 * Enter                                                                 *
 *-----------------------------------------------------------------------*
-      Call QEnter('QFREAD')
 
 *------------------------------------------------------------------------*
 * Print the joblabel. It is obtained in get_input.f                      *
@@ -407,6 +407,5 @@
 *----------------------------------------------------------------------*
 * Here is the end.                                                     *
 *----------------------------------------------------------------------*
-      Call QExit('QFREAD')
       Return
       End
