@@ -60,7 +60,6 @@ c     Logical Exist
 #include "pamint.fh"
       Common /IDSXCI/ IDXCI(mxAct),IDXSX(mxAct)
 *PAM05      SymProd(i,j)=1+iEor(i-1,j-1)
-      Call qEnter('DMRGCTL')
 *
 C Local print level (if any)
       IPRLEV=IPRLOC(3)
@@ -478,7 +477,6 @@ c       Call Put_dArray("RF CASSCF Vector",Work(ipRF),nConf)
 c       Call Free_Work(ipRF)
 c     End If
 *
-      Call qExit('DMRGCTL')
       Return
       End
 
