@@ -32,7 +32,8 @@
       use qcmaquis_interface_environment, only: print_dmrg_info
 #endif
       use fcidump, only : DumpOnly
-      use fciqmc, only : DoNECI
+      use fciqmc, only: DoNECI
+      use CC_CI_mod, only: Do_CC_CI
 
       Implicit Real*8 (A-H,O-Z)
 #include "rasdim.fh"
@@ -69,7 +70,6 @@
 *----------------------------------------------------------------------*
 *     Start and define the paper width                                 *
 *----------------------------------------------------------------------*
-      Call qEnter('InpPri')
       lPaper=132
       Zero = 0.0D0
 *----------------------------------------------------------------------*
@@ -96,6 +96,8 @@
      &           KSDFT(1:5).eq.'TS12G'   .or.
      &           KSDFT(1:4).eq.'TPBE'    .or.
      &           KSDFT(1:5).eq.'FTPBE'   .or.
+     &           KSDFT(1:5).eq.'TOPBE'   .or.
+     &           KSDFT(1:6).eq.'FTOPBE'  .or.
      &           KSDFT(1:7).eq.'TREVPBE' .or.
      &           KSDFT(1:8).eq.'FTREVPBE'.or.
      &           KSDFT(1:6).eq.'FTLSDA'  .or.
@@ -447,8 +449,8 @@ C.. for GAS
 * NN.14 FIXME: in DMRG-CASSCF, skip this check for the time
 *              since Block DMRG code will check this internally
 *     If (NROOTS .GT. NCSASM(LSYM)) Then
-      If (.not. (DoNECI .or. DumpOnly .or. doDMRG .or. doBlockDMRG)
-     &    .and. (NROOTS > NCSASM(LSYM))) Then
+      If (.not. any([DoNECI, Do_CC_CI, DumpOnly, doDMRG, doBlockDMRG])
+     &    .and. NROOTS > NCSASM(LSYM)) Then
          Write(LF,*) '************ ERROR ***********'
          Write(LF,*) ' You can''t ask for more roots'
          Write(LF,*) ' than there are configurations '
@@ -565,7 +567,6 @@ C.. for GAS
             Write(LF,*) 'InpPri: iRc from Call RdOne not 0'
             Write(LF,*) 'Label = ',Label
             Write(LF,*) 'iRc = ',iRc
-            Call QTrace
             Call Abend
          Endif
          Call GetMem('Ovrlp','Free','Real',iTmp0,nTot1+4)
@@ -613,6 +614,5 @@ C.. for GAS
 *----------------------------------------------------------------------*
 *     Exit                                                             *
 *----------------------------------------------------------------------*
-      Call qExit('InpPri')
       Return
       End
