@@ -43,6 +43,7 @@
 #include "ciinfo.fh"
 #include "rctfld.fh"
 #include "WrkSpc.fh"
+#include "stdalloc.fh"
 #include "SysDef.fh"
 #include "input_ras.fh"
 
@@ -54,11 +55,10 @@
       Character*3 SNAC
 #endif
       Logical FullMlk, get_BasisType
-cnf
       Logical Do_ESPF,lSave, lOPTO, Do_DM
-cnf
       DIMENSION CMO(*),OCCN(*),SMAT(*)
       Dimension Temp(2,mxRoot)
+      Real*8, Allocatable:: DSave(:)
 
 ** (SVC) added for new supsym vector input
 *      DIMENSION NXSYM(mxOrb),nUND(mxOrb)
@@ -74,7 +74,6 @@ cnf
 *----------------------------------------------------------------------*
 *     Start and define the paper width                                 *
 *----------------------------------------------------------------------*
-      Call qEnter('OutCtl')
 C Local print level (if any)
       IPRLEV=IPRLOC(6)
       IF(IPRLEV.ge.DEBUG) THEN
@@ -306,7 +305,6 @@ C Local print level (if any)
             Write(LF,*) 'OutCtl: iRc from Call RdOne not 0'
             Write(LF,*) 'Label = ',Label
             Write(LF,*) 'iRc = ',iRc
-            Call QTrace
             Call Abend
          Endif
          Call GetMem('Ovrlp','Free','Real',iTmp0,nTot1+4)
@@ -528,7 +526,29 @@ C Local print level (if any)
 
       iTol = Cho_X_GetTol(8)
       if(doDMRG) iTol = 6
-      Call Add_Info('E_RASSCF',ENER(1,ITER),NRoots,iTol)
+*
+      Line(1:8)='E_RASSCF'
+      j=8
+      Do i=1, nRoots
+         If (nRoots.gt.1) Then
+            If (i-1.lt.10) Then
+               j=11
+               Write (Line(9:j),'(A,I1,A)') '[',i-1,']'
+            Else If (i-1.lt.100) Then
+               j=12
+               Write (Line(9:j),'(A,I2,A)') '[',i-1,']'
+            Else If (i-1.lt.1000) Then
+               j=13
+               Write (Line(9:j),'(A,I3,A)') '[',i-1,']'
+            Else If (i-1.lt.10000) Then
+               j=14
+               Write (Line(9:j),'(A,I4,A)') '[',i-1,']'
+            End If
+         Else
+            j=8
+         End If
+         Call Add_Info(Line(1:j),ENER(iRoot(i),ITER),1,iTol)
+      End Do
 *---------------------------------------------------------------
 * New JOBIPH layout: Also write hamiltonian matrix at IADR15(17):
 *---------------------------------------------------------------
@@ -598,7 +618,8 @@ C Local print level (if any)
 *
 *     But first save the 1st order density for gradients
 *
-      Call Get_D1AO(ipDSave,NTOT1)
+      Call mma_allocate(DSave,nTot1,Label='DSave')
+      Call Get_D1AO(DSave,NTOT1)
 *
 *     The dipole moments will also be stored over all kroot states.
 *
@@ -670,9 +691,9 @@ C Local print level (if any)
         Call WrVec('TMPORB',LuTmp,'CO',nSym,nBas,nBas,
      &            CMO,OCCN,Dum,iDum,Note)
         CALL PRPT()
-*                                                                     *
-***********************************************************************
-*       Store away the dipole moment of this state                    *
+*                                                                      *
+************************************************************************
+*       Store away the dipole moment of this state                     *
 *
         Call Qpg_dArray('Dipole Moment',Do_DM,iDum(1))
         If (Do_DM) Then
@@ -681,9 +702,9 @@ C Local print level (if any)
 *          Call RecPrt('Dipole Moment',' ',Work(ipDM),1,3)
            Call DCopy_(3,Work(ipDM),1,Work(ipDMs+(KROOT-1)*3),1)
         End If
-*                                                                     *
-***********************************************************************
-*                                                                     *
+*                                                                      *
+************************************************************************
+*                                                                      *
 *
 *       Compute spin orbitals and spin population
 *       (Note: this section overwrites the pseudo natural orbitals
@@ -802,8 +823,8 @@ cnf
 *
 *     Restore the correct 1st order density for gradient calculations.
 *
-      Call Put_D1AO(Work(ipDSave),NTOT1)
-      Call GetMem('DSave','Free','REAL',ipDSave,nTot1)
+      Call Put_D1AO(DSave,NTOT1)
+      Call mma_deallocate(DSave)
 *
 *     Save the list of dipole moments on the run file.
 *
@@ -818,6 +839,5 @@ cnf
       CALL GETMEM('CMON','FREE','REAL',icmon,NTOT2)
 *----------------------------------------------------------------------*
 
-      Call qExit('OutCtl')
       Return
       End
