@@ -56,12 +56,16 @@
       use qcmaquis_interface_environment, only:
      &    finalize_dmrg, dump_dmrg_info
 #endif
-      use stdalloc
+      use stdalloc, only: mma_allocate, mma_deallocate
       use write_orbital_files, only : OrbFiles, putOrbFile
-      use fciqmc, only : FCIQMC_ctl, DoNECI, fciqmc_cleanup => cleanup
+
+      use generic_CI, only: CI_solver_t
+      use fciqmc, only: DoNECI, fciqmc_solver_t
+      use CC_CI_mod, only: Do_CC_CI, CC_CI_solver_t
       use fcidump, only : make_fcidumps, transform, DumpOnly
 
       use orthonormalization, only : ON_scheme
+      use print_RDMs_NECI_format, only: printRDMs_NECI
 
       Implicit Real*8 (A-H,O-Z)
 
@@ -102,6 +106,9 @@
       Character*1 CTHRE, CTHRSX, CTHRTE
       Logical DoQmat,DoActive, l_casdft
       Logical IfOpened
+#ifdef _DMRG_
+      Logical Do_ESPF
+#endif
 
 * --------- Cholesky stuff:
       Integer ALGO
@@ -122,13 +129,18 @@
 * --------- FCIDUMP stuff:
       real*8, allocatable :: orbital_E(:), folded_Fock(:)
 * --------- End FCIDUMP stuff:
+* --------- Procedure pointers for CI-solvers
+        class(CI_solver_t), allocatable :: CI_solver
+* --------- End Procedure pointers.
+
+! actual_iter starts at 0, so iter 1A == 0, 1B == 1, 2 == 2, 3 == 3 and so on
+      integer :: actual_iter
 
       Common /IDSXCI/ IDXCI(mxAct),IDXSX(mxAct)
 
       External Get_ProgName
       Character*100 ProgName, Get_ProgName
       Character*15 STLNE2
-      External QEnter, QExit
       External RasScf_Init
       External Scan_Inp
       External Proc_Inp
@@ -143,7 +155,6 @@
 
 * Start the traceback utilities
 *
-      Call QENTER(ROUTINE)
 
 * Set status line for monitor:
       Call StatusLine('RASSCF:',' Just started.')
@@ -224,7 +235,7 @@
 
 * Process the input:
       Call StatusLine('RASSCF:',' Processing input')
-      Call Proc_Inp(DSCF,Info,lOPTO,iRc)
+      Call Proc_Inp(DSCF,lOPTO,iRc)
 * If something goes wrong in proc_inp:
       If (iRc.ne._RC_ALL_IS_WELL_) Then
        If (IPRLEV.ge.TERSE) Then
@@ -252,6 +263,18 @@
 
       Call InpPri(lOpto)
 
+* Note that CI_solver subclasses can provide a final procedure
+* (some people might call it destructor). Hence the deallocation and
+* cleanup is automatically performed, when it goes out of scope.
+      if (DoNECI) then
+        allocate(fciqmc_solver_t :: CI_solver)
+      else if (Do_CC_CI) then
+        allocate(CC_CI_solver_t :: CI_solver)
+      end if
+
+      if (allocated(CI_solver)) call CI_solver%init()
+
+
 *
 * If this is not CASDFT make sure the DFT flag is unset
 *
@@ -275,6 +298,8 @@
      &            KSDFT(1:5).eq.'TS12G'   .or.
      &            KSDFT(1:4).eq.'TPBE'    .or.
      &            KSDFT(1:5).eq.'FTPBE'   .or.
+     &            KSDFT(1:5).eq.'TOPBE'   .or.
+     &            KSDFT(1:6).eq.'FTOPBE'  .or.
      &            KSDFT(1:7).eq.'TREVPBE' .or.
      &            KSDFT(1:8).eq.'FTREVPBE'.or.
      &            KSDFT(1:6).eq.'FTLSDA'  .or.
@@ -314,7 +339,6 @@
       If (iCIRST.eq.1.and.DumpOnly) then
         write(6,*) 'ICIRST and DumpOnly flags are not compatible!'
         write(6,*) 'Choose only one.'
-        Call QTrace
         Call Abend
       end if
 
@@ -587,6 +611,7 @@ c At this point all is ready to potentially dump MO integrals... just do it if r
       ECAS   = 0.0d0
       ROTMAX = 0.0d0
       ITER   = 0
+      actual_iter = 0
       IFINAL = 0
       TMXTOT = 0.0D0
       Call GetMem('FOcc','ALLO','REAL',ipFocc,nTot1)
@@ -618,8 +643,10 @@ c At this point all is ready to potentially dump MO integrals... just do it if r
       ! DMRGCI and CIOnly.It's enabled only for DMRGCI with QCMaquis
       ! now, (to exclude potential side effects)
       ! but consider extending it to other cases!
+      call DecideOnESPF(Do_ESPF)
+      !write(LF,*) ' |rasscf> DecideOnESPF == ',Do_ESPF
       If (( ITER.EQ.1 ).and.((.not.(DoDMRG.and.(ICIONLY.NE.0))).or.lRf
-     &    .or.domcpdftDMRG))THEN
+     &    .or.domcpdftDMRG.or.Do_ESPF))THEN
 #else
       If ( ITER.EQ.1 ) THEN
 #endif
@@ -805,8 +832,9 @@ c         write(6,*) (WORK(LTUVX+ind),ind=0,NACPR2-1)
           goto 2010
         end if
 
-        if (DoNECI) then
-          call FCIQMC_ctl(CMO=work(LCMO : LCMO + nTot2 - 1),
+        if (allocated(CI_solver)) then
+          call CI_solver%run(actual_iter=actual_iter,
+     &                    CMO=work(LCMO : LCMO + nTot2 - 1),
      &                    DIAF=work(LDIAF : LDiaf + nTot - 1),
      &                    D1I_AO=work(lD1I : lD1I + nTot2 - 1),
      &                    D1A_AO=work(lD1A : lD1A + nTot2 - 1),
@@ -827,7 +855,7 @@ c         write(6,*) (WORK(LTUVX+ind),ind=0,NACPR2-1)
         else
           CALL CICTL(WORK(LCMO),
      &               WORK(LDMAT),WORK(LDSPN),WORK(LPMAT),WORK(LPA),
-     &               WORK(LFI),WORK(LD1I),WORK(LD1A),
+     &               WORK(LFI),WORK(LFA),WORK(LD1I),WORK(LD1A),
      &               WORK(LTUVX),IFINAL)
 
           if(dofcidump)then
@@ -853,20 +881,6 @@ c         write(6,*) (WORK(LTUVX+ind),ind=0,NACPR2-1)
           End If
         end if
 
-        If ( IPRLEV.ge.DEBUG ) then
-          Write(LF,*)
-          Write(LF,*) ' PUVX in rasscf af FCIQMC_ctl'
-          Write(LF,*) ' ---------------------'
-          Write(LF,*)
-          call wrtmat(Work(LPUVX),1,nFint, 1, nFint)
-
-          Write(LF,*)
-          Write(LF,*) ' ---------------------'
-        end if
-
-c       CALL TRIPRT('One-body dmat, D, in RASSCF aft first CICTL',
-c     &             ' ',Work(LDMAT),NAC)
-
 c.. dongxia testing jobiph
 c.. upt to here, jobiph are all zeros at iadr15(2)
 * If CASVB job, go directly to return.
@@ -976,11 +990,12 @@ c.. upt to here, jobiph are all zeros at iadr15(2)
         End if
       END IF
 ************************************************************************
-*         ^ End First iteration
+*     ^ End First iteration
 ************************************************************************
 *
 * Print header to file containing informations on CI iterations.
 *
+      actual_iter = actual_iter + 1
       Write(IterFile,*)
       Write(IterFile,'(20A4)') ('****',i=1,20)
       IF (Iter .Eq. 1) Then
@@ -1081,8 +1096,9 @@ c.. upt to here, jobiph are all zeros at iadr15(2)
         End If
 
         Call Timing(Swatch,Swatch,Zenith_1,Swatch)
-        if (DoNECI) then
-          call FCIQMC_ctl(CMO=work(LCMO : LCMO + nTot2 - 1),
+        if (allocated(CI_solver)) then
+          call CI_solver%run(actual_iter=actual_iter,
+     &                    CMO=work(LCMO : LCMO + nTot2 - 1),
      &                    DIAF=work(LDIAF : LDiaf + nTot - 1),
      &                    D1I_AO=work(lD1I : lD1I + nTot2 - 1),
      &                    D1A_AO=work(lD1A : lD1A + nTot2 - 1),
@@ -1091,20 +1107,7 @@ c.. upt to here, jobiph are all zeros at iadr15(2)
      &                    D1S_MO=work(lDSPN : lDSPN + nAcPar - 1),
      &                    DMAT=work(lDMAT : lDMAT + nAcPar - 1),
      &                    PSMAT=work(lpmat : lPMat + nAcpr2 - 1),
-     &                    PAMAT=work(lpa : lpa + nAcPr2 - 1),
-     &                    fake_run=(iter==1))
-          If ( IPRLEV.ge.DEBUG ) then
-            Write(LF,*)
-            Write(LF,*) ' D1A in AO basis in RASSCF af FCIQMC_ctl 2'
-            Write(LF,*) ' ---------------------'
-            Write(LF,*)
-            iOff=1
-            Do iSym = 1,nSym
-              iBas = nBas(iSym)
-              call wrtmat(Work(lD1A+ioff-1),iBas,iBas, iBas, iBas)
-              iOff = iOff + iBas*iBas
-            End Do
-          end if
+     &                    PAMAT=work(lpa : lpa + nAcPr2 - 1))
 #if defined _ENABLE_BLOCK_DMRG_ || defined _ENABLE_CHEMPS2_DMRG_
         else If(DoBlockDMRG) Then
             CALL DMRGCTL(WORK(LCMO),
@@ -1115,9 +1118,10 @@ c.. upt to here, jobiph are all zeros at iadr15(2)
         else
           CALL CICTL(WORK(LCMO),
      &               WORK(LDMAT),WORK(LDSPN),WORK(LPMAT),WORK(LPA),
-     &               WORK(LFI),WORK(LD1I),WORK(LD1A),
+     &               WORK(LFI),WORK(LFA),WORK(LD1I),WORK(LD1A),
      &               WORK(LTUVX),IFINAL)
         end if
+
 c      call triprt('twxy',' ',WORK(LTUVX),nAc*(nAc+1)/2)
 c      call triprt('P-mat 2',' ',WORK(LPMAT),nAc*(nAc+1)/2)
 
@@ -1174,7 +1178,6 @@ c      call triprt('P-mat 2',' ',WORK(LPMAT),nAc*(nAc+1)/2)
            Write(LF,*) 'SGFCIN: iRc from Call RdOne not 0'
            Write(LF,*) 'Label = ',Label
            Write(LF,*) 'iRc = ',iRc
-           Call QTrace
            Call Abend
           End if
 
@@ -1290,32 +1293,8 @@ c      Call rasscf_xml(Iter)
         iOff = iOff + (iBas*iBas+iBas)/2
        End Do
       End If
-        IF (DoNECI) THEN
-          write(6,*)'RASSCF: For NECI orbital energies are approximated'
-          write(6,*)'to the diagonal value of the Fock matrix properly'
-          write(6,*)'transformed accordingly to e(X) rotation matrix'
-c This is of course not true other than for special cases ... but some might find it beneficial!
-          iOff  = 0
-          iOff2 = 0
-          Do iSym = 1,nSym
-            iBas = nBas(iSym)
-            if(iBas.gt.0) then
-             do iDiag = 1,iBas
-               WORK(LDIAF+iDiag-1+iOff)=
-     &            WORK(LFA+(iDiag*(iDiag+1)/2)+iOff2-1)
-             end do
-             write(6,*) 'OrbEn in line for sym = ',iSym
-             write(6,*) (Work(LDIAF+i+ioff), i = 0,iBas-1)
-             iOff  = iOff + iBas
-             iOff2 = iOff2 + (iBas*iBas+iBas)/2
-            end if
-          End Do
-        END IF
-cGLM   write(6,*) 'ECAS in RASSCF after call to SXCTL', ECAS
-      If (DoCholesky.and.ALGO.eq.2) Then
-         Call GetMem('Q-mat','Free','Real',ipQmat,NTav)
-      EndIf
 
+cGLM   write(6,*) 'ECAS in RASSCF after call to SXCTL', ECAS
       If ( IPRLEV.ge.DEBUG ) then
         Write(LF,*)
         Write(LF,*) ' D1A in AO basis in RASSCF af SXCTL'
@@ -1504,7 +1483,7 @@ cGLM some additional printout for MC-PDFT
         else
           IF(doDMRG)then
 
-#ifdef _DMRG_DEBUG_
+#ifdef _DMRG_DEBUGPRINT_
             write(lf,*) "DMRG-SCF energy    ",ECAS
             write(lf,*) "DMRG sweeped energy",EAV
 #endif
@@ -1730,8 +1709,9 @@ c Clean-close as much as you can the CASDFT stuff...
 *
       Call Timing(Swatch,Swatch,Zenith_1,Swatch)
 
-      if(DoNECI) then
-        call FCIQMC_ctl(CMO=work(LCMO : LCMO + nTot2 - 1),
+      if (allocated(CI_solver)) then
+          call CI_solver%run(actual_iter=actual_iter,
+     &                    CMO=work(LCMO : LCMO + nTot2 - 1),
      &                    DIAF=work(LDIAF : LDiaf + nTot - 1),
      &                    D1I_AO=work(lD1I : lD1I + nTot2 - 1),
      &                    D1A_AO=work(lD1A : lD1A + nTot2 - 1),
@@ -1759,7 +1739,7 @@ c Clean-close as much as you can the CASDFT stuff...
       else
         CALL CICTL(WORK(LCMO),
      &           WORK(LDMAT),WORK(LDSPN),WORK(LPMAT),WORK(LPA),
-     &           WORK(LFI),WORK(LD1I),WORK(LD1A),
+     &           WORK(LFI),WORK(LFA),WORK(LD1I),WORK(LD1A),
      &           WORK(LTUVX),IFINAL)
       end if
 
@@ -1942,11 +1922,21 @@ c  i_root>0 gives natural spin orbitals for that root
       Call OrbFiles(JOBIPH,IPRLEV)
 *
 ************************************************************************
+************ Printing final RDMs in NECI format        *****************
+************************************************************************
+      If ( IPRLEV.ge.DEBUG ) then
+       Call printRDMs_NECI(Work(LDMAT),NAC,Work(LPMAT),Work(LPA),NACPAR)
+      End If
+************************************************************************
 ******************           Closing up RASSCF       *******************
 ************************************************************************
 
 2010   continue
 
+      If (DoCholesky.and.ALGO.eq.2) Then
+         Call GetMem('Q-mat','Free','Real',ipQmat,NTav)
+      EndIf
+
 c deallocating TUVX memory...
       IF(NAC.GT.0) THEN
          Call GetMem('TUVX','Free','Real',LTUVX,NACPR2)
@@ -1993,18 +1983,11 @@ c deallocating TUVX memory...
 
 *
 * Skip Lucia stuff if NECI or BLOCK-DMRG is on
-      If (.not.(DoNECI.or.DumpOnly.or.doDMRG.or.doBlockDMRG)) then
-          Call Lucia_Util('CLOSE',iDummy,iDummy,Dummy)
-      else if (DoNECI) then
-          CALL GETMEM('INT1  ','FREE','REAL',kint1_pointer,NAC**2)
-          call fciqmc_cleanup()
+      If (.not. any([allocated(CI_solver), DumpOnly,
+     &              doDMRG, doBlockDMRG])) then
+        Call Lucia_Util('CLOSE',iDummy,iDummy,Dummy)
       end if
-* We better deallocate before it is too late...
-c     if(DoNECI) then
-c       CALL GETMEM('INT1  ','FREE','REAL',kint1_pointer,NAC**2)
-c     end if
-*
-*
+
 
       Call StatusLine('RASSCF:','Finished.')
       If (IPRLEV.GE.2) Write(LF,*)
@@ -2047,10 +2030,15 @@ c      End If
       EndIf
 
       if (.not. (iDoGas .or. doDMRG .or. doBlockDMRG
-     &          .or. DoNECI .or. DumpOnly)) then
+     &          .or. allocated(CI_solver) .or. DumpOnly)) then
         Call MKGUGA_FREE
       end if
 
+      if (allocated(CI_solver)) then
+          call CI_solver%cleanup()
+          deallocate(CI_solver)
+      end if
+
 !Leon: The velociraptor comes! xkcd.com/292/
  9989 Continue
 * DMRG: Save results for other use
@@ -2112,7 +2100,7 @@ C Close the one-electron integral file:
         END DO
         Close(LUInput)
       End If
-      Call qExit(ROUTINE)
 
       return
-      End
+
+      end subroutine rasscf
