@@ -45,15 +45,20 @@
 *>    \f[ D^{\text{AO}, A}_S = C^A (D^A_\alpha - D^A_\beta) (C^A)^\dagger \f]
       Subroutine SGFCIN(CMO, F, FI, D1I, D1A, D1S)
 #ifdef _DMRG_
-!     module dependencies
       use qcmaquis_interface_cfg
 #endif
+      use fcidump, only: DumpOnly
+      use fciqmc, only: DoNECI
+      use CC_CI_mod, only: Do_CC_CI
+
       use rasscf_data, only : EMY, KSDFT, dftfock, exfac, nac, nacpar,
      &    noneq, potnuc, rfpert,
      &    tot_charge, tot_el_charge, tot_nuc_charge,
      &    doBlockDMRG
       use general_data, only : iSpin, nActEl, nSym, nTot1,
      &    nBas, nIsh, nAsh, nFro
+
+
       implicit none
 #include "rasdim.fh"
 #include "output_ras.fh"
@@ -70,6 +75,10 @@
       Character*8 PAMlbl
       Logical First, Dff, Do_DFT, Found
       Logical Do_ESPF
+
+#ifndef _DMRG_
+      logical :: doDMRG = .false.
+#endif
 *
       Logical Do_OFemb, KEonly, OFE_first
       COMMON  / OFembed_L / Do_OFemb,KEonly,OFE_first
@@ -90,13 +99,13 @@
      &  iTmp8, iTmpx, iTmpz, iTu, j, l_ndsd, lx0, lx1, lx2, lx3,
      &  mxna, mxnb, nAt, nst, nt, ntu, nu, nvxc
 
-      Call qEnter(ROUTINE)
 C Local print level (if any)
       IPRLEV=IPRLOC(3)
       IPRLEV=0000
       IF(IPRLEV.ge.DEBUG) THEN
          WRITE(LF,*)' Entering ',ROUTINE
       END IF
+
 *
 *     Generate molecular charges
       Call GetMem('Ovrlp','Allo','Real',iTmp0,nTot1+4)
@@ -111,7 +120,6 @@ C Local print level (if any)
          Write(LF,*) 'SGFCIN: iRc from Call RdOne not 0'
          Write(LF,*) 'Label = ',Label
          Write(LF,*) 'iRc = ',iRc
-         Call QTrace
          Call Abend
       Endif
       Call GetMem('Ovrlp','Free','Real',iTmp0,nTot1+4)
@@ -135,7 +143,6 @@ C Local print level (if any)
          Write(LF,*) 'SGFCIN: iRc from Call RdOne not 0'
          Write(LF,*) 'Label = ',Label
          Write(LF,*) 'iRc = ',iRc
-         Call QTrace
          Call Abend
       Endif
       If ( IPRLEV.ge.DEBUG ) then
@@ -200,45 +207,43 @@ C Local print level (if any)
       ERFX = Zero
       ERFhi = Zero
       iCharge=Int(Tot_Charge)
+
+      Call GetMem('DtmpI','Allo','Real',iTmp3,nTot1)
+      Call GetMem('DtmpA','Allo','Real',iTmp4,nTot1)
+      Call GetMem('DtmpS','Allo','Real',iTmp7,nTot1)
+
       Call DecideOnESPF(Do_ESPF)
+*
+*---- Generate total density
+*
+      Call Fold(nSym,nBas,D1I,Work(iTmp3))
+      Call Fold(nSym,nBas,D1A,Work(iTmp4))
+      Call Daxpy_(nTot1,1.0D0,Work(iTmp4),1,Work(iTmp3),1)
+      Call Put_D1ao(Work(iTmp3),nTot1)
+*     Write(LF,*)
+*     Write(LF,*) ' D1ao in AO basis in SGFCIN'
+*     Write(LF,*) ' ---------------------'
+*     Write(LF,*)
+*     iOff=0
+*     Do iSym = 1,nSym
+*       iBas = nBas(iSym)
+*       Call TriPrt(' ','(5G17.11)',Work(iTmp3+iOff),iBas)
+*       iOff = iOff + (iBas*iBas+iBas)/2
+*     End Do
+*
+*---- Generate spin-density
+*
+      Call Fold(nSym,nBas,D1S,Work(iTmp7))
+      Call Put_D1Sao(Work(iTmp7),nTot1)
+
+      If(KSDFT(1:3).ne.'SCF' .or. Do_OFemb) Then
+        Call Put_iArray('nFro',nFro,nSym)
+        Call Put_iArray('nAsh',nAsh,nSym)
+        Call Put_iArray('nIsh',nIsh,nSym)
+      End If
+
       If ( Do_ESPF .or. lRF .or. KSDFT.ne.'SCF'
-     &                      .or. Do_OFemb) Then
-        Call GetMem('DtmpI','Allo','Real',iTmp3,nTot1)
-        Call GetMem('DtmpA','Allo','Real',iTmp4,nTot1)
-        Call GetMem('DtmpS','Allo','Real',iTmp7,nTot1)
-*
-*------ Generate total density
-*
-        Call Fold(nSym,nBas,D1I,Work(iTmp3))
-        Call Fold(nSym,nBas,D1A,Work(iTmp4))
-        Call Daxpy_(nTot1,1.0D0,Work(iTmp4),1,Work(iTmp3),1)
-        Call Put_D1ao(Work(iTmp3),nTot1)
-*        Write(LF,*)
-*        Write(LF,*) ' D1ao in AO basis in SGFCIN'
-*        Write(LF,*) ' ---------------------'
-*        Write(LF,*)
-*        iOff=0
-*        Do iSym = 1,nSym
-*          iBas = nBas(iSym)
-*          Call TriPrt(' ','(5G17.11)',Work(iTmp3+iOff),iBas)
-*          iOff = iOff + (iBas*iBas+iBas)/2
-*        End Do
-*
-*------ Generate spin-density
-*
-
-*        do i=1,nBas(1)
-*          write(*,*)i,"0000 D1S,Work(iTmp7)",D1S(i),Work(iTmp7+i-1)
-*        end do
-
-        Call Fold(nSym,nBas,D1S,Work(iTmp7))
-        Call Put_D1Sao(Work(iTmp7),nTot1)
-
-!        do i=1,nTot1
-!          Work(iTmp7+i-1)=Zero
-!          write(*,*)i,"1111 D1S,Work(iTmp7)",D1S(i),Work(iTmp7+i-1)
-!        end do
-
+     &                      .or. Do_OFemb ) Then
 *
 *------ Scratch for one- and two-electron type contributions
 *
@@ -252,44 +257,34 @@ C Local print level (if any)
         Do_DFT=.True.
 
         Call Timing(Rado_1,Swatch,Swatch,Swatch)
-        If(KSDFT(1:3).ne.'SCF' .or. Do_OFemb) Then
-           Call Put_iArray('nFro',nFro,nSym)
-           Call Put_iArray('nAsh',nAsh,nSym)
-           Call Put_iArray('nIsh',nIsh,nSym)
-        End If
 
         Call DrvXV(Work(iTmp5),Work(iTmp6),Work(iTmp3),
      &             PotNuc,nTot1,First,Dff,NonEq,lRF,
      &             KSDFT,ExFac,iCharge,iSpin,D1I,D1A,
      &             nTot1,DFTFOCK,Do_DFT)
-      If ( IPRLEV.ge.DEBUG ) then
-        Write(LF,*)
-        Write(LF,*) ' Work(iTmp5), h1 (DFT), in AO basis in SGFCIN'
-        Write(LF,*) ' ---------------------'
-        Write(LF,*)
-        iOff=0
-        Do iSym = 1,nSym
-          iBas = nBas(iSym)
-          Call TriPrt(' ','(5G17.11)',Work(iTmp5+iOff),iBas)
-          iOff = iOff + (iBas*iBas+iBas)/2
-        End Do
-      End If
+        If ( IPRLEV.ge.DEBUG ) then
+          Write(LF,*)
+          Write(LF,*) ' Work(iTmp5), h1 (DFT), in AO basis in SGFCIN'
+          Write(LF,*) ' ---------------------'
+          Write(LF,*)
+          iOff=0
+          Do iSym = 1,nSym
+            iBas = nBas(iSym)
+            Call TriPrt(' ','(5G17.11)',Work(iTmp5+iOff),iBas)
+            iOff = iOff + (iBas*iBas+iBas)/2
+          End Do
+        End If
         Call Timing(Rado_2,Swatch,Swatch,Swatch)
         Rado_2 = Rado_2 - Rado_1
         Rado_3 = Rado_3 + Rado_2
 
+
         ERF1=Zero
         ERF2=dDot_(nTot1,Work(iTmp6),1,Work(iTmp4),1)
         ERFX= ERF1-0.5d0*ERF2
         Call Daxpy_(nTot1,1.0d0,Work(iTmp5),1,Work(iTmp1),1)
 
-!        do i=1,nTot1
-!          write(*,*)"   0000  FI",FI(i)
-!        end do
         Call Daxpy_(nTot1,1.0d0,Work(iTmp6),1,FI,1)
-!        do i=1,nTot
-!          write(*,*)"   1111  FI",FI(i)
-!        end do
 *
 *       Insert PAM integrals to one electron Hamiltonian
 *
@@ -298,7 +293,7 @@ C Local print level (if any)
           Do iPAM=1,nPAM
              Write(PAMlbl,'(A,I3.3)') 'PAM  ',ipPam(iPAM)
              Call dCopy_(nTot1,[Zero],0,Work(iTmp8),1)
-          iComp=1
+             iComp=1
              Call RdOne(iRc,iOpt,PAMlbl,iComp,Work(iTmp8),iSyLbl)
              Call Daxpy_(nTot1,CPAM(iPAM),Work(iTmp8),1,Work(iTmp1),1)
           End Do
@@ -306,10 +301,12 @@ C Local print level (if any)
         End If
         Call GetMem('gtmp','Free','Real',iTmp6,nTot1)
         Call GetMem('htmp','Free','Real',iTmp5,nTot1)
-        Call GetMem('DtmpS','Free','Real',iTmp7,nTot1)
-        Call GetMem('DtmpA','Free','Real',iTmp4,nTot1)
-        If(.not.Do_OFemb) Call GetMem('DtmpI','Free','Real',iTmp3,nTot1)
       End If
+
+      Call GetMem('DtmpS','Free','Real',iTmp7,nTot1)
+      Call GetMem('DtmpA','Free','Real',iTmp4,nTot1)
+      If(.not.Do_OFemb) Call GetMem('DtmpI','Free','Real',iTmp3,nTot1)
+*
       If ( RFpert ) then
 *
 *       Read the reaction field from RunFile or RunOld
@@ -503,15 +500,12 @@ Cbjp
       END DO
 
 !Quan: Fix bug, skip Lucia stuff with DMRG
-#if defined _ENABLE_BLOCK_DMRG_ || defined _ENABLE_CHEMPS2_DMRG_
-      if (.not.(doBlockDMRG)) then
-#elif defined _DMRG_
-      if(.not.doDMRG)then
-#endif
+! and other external CI solvers.
+      if (.not. any([DoNECI, Do_CC_CI, DumpOnly,
+     &              doDMRG, doBlockDMRG])) then
         CALL CP_ONE_INT(WORK(LX0),ITU)
-#if defined _ENABLE_BLOCK_DMRG_ || defined _ENABLE_CHEMPS2_DMRG_ || defined _DMRG_
       endif
-#endif
+
       CALL GETMEM('XXX1','FREE','REAL',LX1,NTOT1)
       CALL GETMEM('XXX0','FREE','REAL',LX0,NTOT1)
 
@@ -524,7 +518,7 @@ Cbjp
         Call TriPrt(' ',' ',F,NAC)
       End If
 
-      Call qExit('SGFCIN')
+
 
       Return
       End
