@@ -24,7 +24,7 @@
       use qcmaquis_info
 #endif
       use mspt2_eigenvectors
-      use rassi_aux, only : jDisk_TDM, iDisk_TDM, AO_Mode
+      use rassi_aux, only : AO_Mode, jDisk_TDM, iDisk_TDM
       IMPLICIT REAL*8 (A-H,O-Z)
 #include "prgm.fh"
       CHARACTER*16 ROUTINE
@@ -56,6 +56,9 @@
       Real*8 Energies(1:20)
       Integer IAD,LUIPHn,lThetaM,LUCITH
       Real*8 Norm_fac
+CC    NTO section
+      Logical DoNTO
+CC    NTO section
       External IsFreeUnit
 
       type mixed_1pdensities
@@ -86,7 +89,6 @@
 #endif
 #include "SysDef.fh"
 
-      CALL QENTER(ROUTINE)
 #define _TIME_GTDM
 #ifdef _TIME_GTDM_
       Call CWTime(TCpu1,TWall1)
@@ -801,6 +803,19 @@ C General 1-particle transition density matrix:
      &            IWORK(LOMAP),WORK(LDET1),WORK(LDET2),SIJ,NASHT,
      &            TRAD,TRASD,WERD,ISTATE,
      &            JSTATE,job1,job2,ist,jst)
+C Calculate Natural Transition Orbital (NTO):
+        IF (IFNTO) THEN
+         IF (job1.ne.job2) THEN
+           DoNTO=.true.
+         Else
+           DoNTO=.false.
+         End If
+         IF (DoNTO) Then
+          Call NTOCalc(job1,job2,ISTATE,JSTATE,TRAD,TRASD,MPLET1)
+          write(6,*) 'ntocalculation finished'
+         End If
+        End If
+C End of Calculating NTO
 
         IF(IFTWO.AND.(MPLET1.EQ.MPLET2)) THEN
 C Compute 1-electron contribution to Hamiltonian matrix element:
@@ -988,26 +1003,30 @@ C             Write density 1-matrices in AO basis to disk.
      &                    TDMAB,TDM2,CMO1,CMO2)
           END IF
 
+          !Store SIJ temporarily
+          IF (IFEJOB.and.(ISTATE.ne.JSTATE)) THEN
+            HAM(ISTATE,JSTATE) = SIJ
+            HAM(JSTATE,ISTATE) = SIJ
+          END IF
           IF(IFHAM.AND..NOT.(IFHEXT.or.IFHEFF.or.IFEJOB))THEN
             HZERO              = ECORE*SIJ
             HIJ                = HZERO+HONE+HTWO
             HAM(ISTATE,JSTATE) = HIJ
             HAM(JSTATE,ISTATE) = HIJ
 
-         !SI-PDFT related code for "second_time" case
-          if(second_time) then
-            Energies(:) =0.0d0
-            CALL DANAME(LUIPH,'JOBGS')
-            IAD = 0
-            Call IDAFILE(LUIPH,2,ITOC15,30,IAD)
-            IAD=ITOC15(6)
-            Call DDAFILE(LUIPH,2,Energies,NSTAT(JOB1),IAD)
-            do i=1,NSTAT(JOB1)
-              HAM(i,i) = Energies(i)
-            end do
-            Call DACLOS(LUIPH)
-          end if
-
+            !SI-PDFT related code for "second_time" case
+            if(second_time) then
+              Energies(:) =0.0d0
+              CALL DANAME(LUIPH,'JOBGS')
+              IAD = 0
+              Call IDAFILE(LUIPH,2,ITOC15,30,IAD)
+              IAD=ITOC15(6)
+              Call DDAFILE(LUIPH,2,Energies,NSTAT(JOB1),IAD)
+              do i=1,NSTAT(JOB1)
+                HAM(i,i) = Energies(i)
+              end do
+              Call DACLOS(LUIPH)
+            end if
 
             IF(IPGLOB.GE.DEBUG) THEN
               WRITE(6,'(1x,a,2I5)')' ISTATE, JSTATE:',ISTATE,JSTATE
@@ -1021,6 +1040,23 @@ C             Write density 1-matrices in AO basis to disk.
         END DO job1_loop
 
       END DO job2_loop
+*
+** For ejob, create an approximate off-diagonal based on the overlap (temporarily stored in HIJ)
+*
+      IF (IFEJOB) THEN
+        DO JST=1,NSTAT(JOB2)
+          JSTATE=ISTAT(JOB2)-1+JST
+          DO IST=1,NSTAT(JOB1)
+            ISTATE=ISTAT(JOB1)-1+IST
+            IF(ISTATE.LE.JSTATE) CYCLE
+            SIJ=HAM(ISTATE,JSTATE)
+            HII=HAM(ISTATE,ISTATE)
+            HJJ=HAM(JSTATE,JSTATE)
+            HAM(ISTATE,JSTATE) = SIJ*(HII+HJJ)*0.5D0
+            HAM(JSTATE,ISTATE) = SIJ*(HII+HJJ)*0.5D0
+          END DO
+        END DO
+      END IF
 
       IF(DoGSOR) then
         if(job1.ne.job2) then
@@ -1256,6 +1292,5 @@ C             Write density 1-matrices in AO basis to disk.
       write(6,*) 'Time for GTDM : ',TCpu2-TCpu1,TWall2-TWall1
 #endif
 
-      CALL QEXIT(ROUTINE)
       RETURN
       END
