@@ -12,7 +12,7 @@
       !> module dependencies
       use rassi_global_arrays, only: JBNUM
       use sorting, only : argsort
-      use sorting_funcs, only : le_r
+      use sorting_funcs, only : leq_r
 #ifdef _HDF5_
       use Dens2HDF5
 #endif
@@ -79,7 +79,6 @@
 
 
 
-      Call qEnter(ROUTINE)
 
 C CONSTANTS:
       AU2EV=CONV_AU_TO_EV_
@@ -593,7 +592,7 @@ C Update LoopDivide (SUBSets keyword)
 C Assume the SO "ground states" are mostly formed by the SF "ground states"
       If (ReduceLoop) Then
         Call mma_Allocate(IndexE,nState,Label='IndexE')
-        IndexE(:)=ArgSort(Energy, le_r)
+        IndexE(:)=ArgSort(Energy, leq_r)
         n=0
         Do iState=1,LoopDivide
           Job=JbNum(IndexE(iState))
@@ -613,7 +612,6 @@ C Assume the SO "ground states" are mostly formed by the SF "ground states"
 
       call mma_deallocate(HAMSOR)
       call mma_deallocate(HAMSOI)
-      Call qExit(ROUTINE)
       RETURN
 
       END
