@@ -12,7 +12,8 @@
 *               2011, Thomas Bondo Pedersen                            *
 ************************************************************************
       SUBROUTINE CHO_GET_GRAD(irc,nDen,
-     &                        ipDLT,ipDLT2,ipMSQ,ipTxy,DoExchange,lSA,
+     &                        ipDLT,ipDLT2,ipMSQ,
+     &                        Txy,nTxy,ipTxy,DoExchange,lSA,
      &                        nChOrb_,ipAorb,nAorb,DoCAS,
      &                        Estimate,Update,
      &                        V_k,U_k,Z_p_k,nnP,npos,nZpk)
@@ -116,7 +117,7 @@
       Integer   ipIndx, ipIndik,npos(8,3)
       Integer   iSTSQ(8), iSTLT(8), iSSQ(8,8), nnA(8,8), nInd
       Real*8    tread(2),tcoul(2),tmotr(2),tscrn(2),tcasg(2),tmotr2(2)
-      Real*8    V_k(*),Z_p_k(nZpk,*), U_k(*)
+      Real*8    Txy(nTxy),V_k(*),Z_p_k(nZpk,*), U_k(*)
       Character*6  Fname
       Character*50 CFmt
       Character*12 SECNAM
@@ -139,7 +140,6 @@
 #endif
 #include "para_info.fh"
 #include "print.fh"
-      Parameter (MxShll=iTabMx*MxAtom)
       Integer iBDsh(MxShll*8)
       Common /BDshell/ iBDsh
 
@@ -192,7 +192,7 @@ ctbp &                      i + (j-1)*(nChOrb_(iSym,jDen)+1)
 *                                                                      *
 ************************************************************************
 *                                                                      *
-#ifdef _DEBUG_
+#ifdef _DEBUGPRINT_
 c      Debug=.true.
       Debug=.false.! to avoid double printing
 #else
@@ -208,7 +208,6 @@ c      Debug=.true.
       iRout = 9
       iPrint = nPrint(iRout)
 
-      Call QEnter(SECNAM)
 
       CALL CWTIME(TOTCPU1,TOTWALL1) !start clock for total time
 
@@ -718,7 +717,6 @@ c            !set index arrays at iLoc
                WRITE(6,*) ' mTvec = ',mTvec
                WRITE(6,*) ' LFMAX = ',LFMAX
                irc = 33
-               CALL QTrace()
                CALL Abend()
                nBatch = -9999  ! dummy assignment
             End If
@@ -1642,7 +1640,7 @@ C --- subtraction is done in the 1st reduced set
                             If (iMO1.eq.iMO2) Then
                               CALL DGEMM_('T','N',nnP(jSym),JNUM,
      &                                         nnA(iSymx,iSymy),
-     &                               ONE,Work(ipTxy(iSymx,iSymy,iTxy)),
+     &                               ONE,Txy(ipTxy(iSymx,iSymy,iTxy)),
      &                                   nnP(jSym),
      &                                   Work(ipLxy(iSymx)),
      &                                   nnA(iSymx,iSymy),
@@ -1660,7 +1658,7 @@ C --- subtraction is done in the 1st reduced set
                                   Do k=0,nAOrb(iSymx)-1
                                     Do l=0,k
                                        temp=temp+0.5d0*
-     &                                     Work(ioff+k*(k+1)/2+l)*
+     &                                     Txy(ioff+k*(k+1)/2+l)*
      &                                    (Work(jOff+k*nAOrb(iSymx)+l)+
      &                                     Work(jOff+l*nAOrb(iSymx)+k))
                                     End Do
@@ -1833,7 +1831,6 @@ C--- have performed screening in the meanwhile
 
       irc  = 0
 
-      CAll QExit(SECNAM)
 
       Return
       END
