@@ -236,7 +236,7 @@ C
          jCmp=iSD(2,jShell)
          jBas=iSD(3,jShell)
          jAO=iSD(7,jShell)
-#if defined (_DEBUG_)
+#if defined (_DEBUGPRINT_)
          If (jBas*jCmp.ne.nBasSh(jShell)) Then
             Call WarningMessage(2,SecNam//': jBas*jCmp != nBasSh')
             Write(6,'(A,5(1X,I10))')
@@ -255,7 +255,7 @@ C
       Call mma_deallocate(ScrSph)
       Call mma_deallocate(Kern)
 *
-#if defined (_DEBUG_)
+#if defined (_DEBUGPRINT_)
       If ((ipInt-1).ne.l_xInt) Then
          Call WarningMessage(2,
      &                    SecNam//': integral array dimension problem!')
@@ -276,6 +276,7 @@ C     Purpose: sort the integrals of auxiliary functions.
 C
 C     NOTE: symmetry not implemented!
 C
+      use SOAO_Info, only: iAOtSO
       Implicit Real*8 (a-h,o-z)
       Integer jBas
       Integer jCmp
@@ -283,12 +284,10 @@ C
       Integer jAO
       Integer nPrp
       Real*8  PrpInt(nPrp)
-#include "itmax.fh"
-#include "info.fh"
 #include "WrkSpc.fh"
 #include "localdf_bas.fh"
 
-#if defined (_DEBUG_)
+#if defined (_DEBUGPRINT_)
       Character*16 SecNam
       Parameter (SecNam='LDF_SortAuxInt_1')
 #endif
@@ -302,7 +301,7 @@ C
       Do jComp=1,jCmp
          jSO0=iAOtSO(jAO+jComp,0)-1
          Do j=1,jBas
-#if defined (_DEBUG_)
+#if defined (_DEBUGPRINT_)
             If (iShlSO(jSO0+j).lt.1 .or. iShlSO(jSO0+j).gt.nPrp) Then
                Call WarningMessage(2,
      &                          SecNam//': PrpInt index out of bounds!')
@@ -526,6 +525,7 @@ C     Purpose: sort the integrals of 2C auxiliary functions.
 C
 C     NOTE: symmetry not implemented!
 C
+      use SOAO_Info, only: iAOtSO
       Implicit Real*8 (a-h,o-z)
       Integer iBas, jBas
       Real*8  SOInt(iBas*jBas,*)
@@ -534,13 +534,11 @@ C
       Integer iCount
       Integer nPrp
       Real*8  PrpInt(nPrp)
-#include "itmax.fh"
-#include "info.fh"
 #include "WrkSpc.fh"
 #include "localdf_bas.fh"
 #include "localdf_int.fh"
 
-#if defined (_DEBUG_)
+#if defined (_DEBUGPRINT_)
       Character*16 SecNam
       Parameter (SecNam='LDF_SortAuxInt_2')
       Character*53 Str
@@ -552,7 +550,7 @@ C
       iShlSO(i)=iWork(ip_iShlSO-1+i)
       IndxG2(i,j)=iWork(ip_IndxG2-1+l_IndxG2_1*(j-1)+i)
 
-#if defined (_DEBUG_)
+#if defined (_DEBUGPRINT_)
       nErr=0
       Do iComp=1,iCmp
          Do ii=0,iBas-1
@@ -603,7 +601,7 @@ C
                      iSOi=iShlSO(iSO0+ii)
                      i_j=i_j_0+iSOi
                      If (IndxG2(i_j,SPAB).gt.0) Then
-#if defined (_DEBUG_)
+#if defined (_DEBUGPRINT_)
                         If (IndxG2(i_j,SPAB).gt.nPrp) Then
                            Call WarningMessage(2,
      &                              SecNam//': index out of bounds [1]')
@@ -632,7 +630,7 @@ C
                   iSOi=iShlSO(iSO0+ii)
                   i_j=i_j_0+iSOi
                   If (IndxG2(i_j,SPAB).gt.0) Then
-#if defined (_DEBUG_)
+#if defined (_DEBUGPRINT_)
                      If (IndxG2(i_j,SPAB).gt.nPrp) Then
                         Call WarningMessage(2,
      &                            SecNam//': index out of bounds [1.2]')
@@ -665,7 +663,7 @@ C
                      iSOi=iShlSO(iSO0+ii)
                      i_j=i_j_0+iSOi
                      If (IndxG2(i_j,SPAB).gt.0) Then
-#if defined (_DEBUG_)
+#if defined (_DEBUGPRINT_)
                         If (IndxG2(i_j,SPAB).gt.nPrp) Then
                            Call WarningMessage(2,
      &                              SecNam//': index out of bounds [2]')
@@ -688,7 +686,7 @@ C
          End Do
       End If
 
-#if defined (_DEBUG_)
+#if defined (_DEBUGPRINT_)
       Call GetMem('PrpSav','Free','Real',ipPrpInt,lPrpInt)
 #endif
 
