@@ -10,12 +10,10 @@
 ************************************************************************
 
       INTEGER FUNCTION mn2K(iab,lSym)
-
+      use pso_stuff
       Integer  iab, lSym
-#include "WrkSpc.fh"
-#include "pso.fh"
 
       lab = iOff_ij2K(lSym) + iab
-      mn2K = iWork(lab)
+      mn2K = ij2K(lab)
 
       End
