@@ -57,6 +57,7 @@
 *> - '``D1av``'                     Average one particle density matrix, AO basis.
 *> - '``D1mo``'                     One particle density matrix, MO basis.
 *> - '``D1sao``'                    One particle spin density matrix, AO basis.
+*> - '``D1activeao``'               One particle density matrix, AO basis, active orbitals
 *> - '``D2av``'                     Average two particle density matrix for the active space, AO basis.
 *> - '``dExcdRa``'                  The potential of the exchange-correlation functional.
 *> - '``DLAO``'
@@ -92,7 +93,6 @@
 *> - '``Unique Coordinates``'       Cartesian coordinates for the symmetry unique atoms.
 *> - '``Last energies``'            Energies for all roots in the last calculation.
 *> - '``Dipole moment``'            The last computed dipole moment.
-*> - '``GeoPC``'                    The Cartesian coordinates for the unique point charges.
 *> - '``MkNemo.vDisp``'             The displacements matrix as specified in the mknemo module.
 *> - '``MkNemo.tqCluster``'         The transformation matrix for clusters as specified in the mknemo module.
 *> - '``MkNemo.Energies``'          The energies of super-system and clusters as specified in the mknemo module.
@@ -209,9 +209,9 @@ c mess started here :)
          RecLab( 50)='Quad_r          '
          RecLab( 51)='RCTFLD          '
          RecLab( 52)='RFrInfo         '
-         RecLab( 53)='SewRInfo        '
-         RecLab( 54)='SewTInfo        '
-         RecLab( 55)='SewXInfo        '
+         RecLab( 53)='                '
+         RecLab( 54)='DKH_Info        '
+         RecLab( 55)='Real_Info       '
          RecLab( 56)='Last orbitals_ab'
          RecLab( 57)='SCFInfoI_ab     '
          RecLab( 58)='SCFInfoR_ab     '
@@ -236,11 +236,11 @@ c mess started here :)
          RecLab( 77)='MpProp Orb Ener '
          RecLab( 78)='LoProp H0       '
          RecLab( 79)='Dipole moment   '
-         RecLab( 80)='GeoPC           '
+         RecLab( 80)='RICD_Info       '
          RecLab( 81)='BMtrx           '
          RecLab( 82)='CList           '
          RecLab( 83)='DList           '
-         RecLab( 84)='RMax_Shll       '
+         RecLab( 84)='                ' ! Unused
          RecLab( 85)='MkNemo.vDisp    '
          RecLab( 86)='MkNemo.tqCluster'
          RecLab( 87)='MkNemo.Energies '
@@ -318,7 +318,7 @@ c mess started here :)
          RecLab(159)='HAMSOR_SINGLE   '
          RecLab(160)='HAMSOI_SINGLE   '
          RecLab(161)='Last Dipole Mome' !nts
-         RecLab(162)='Un_cen Charge   '
+         RecLab(162)='Un_cen Effective' ! Charge
          RecLab(163)='Un_cen Coordinat' !es
          RecLab(164)='ANGMR_NSS       '
          RecLab(165)='ANGMI_NSS       '
@@ -326,6 +326,26 @@ c mess started here :)
          RecLab(167)='EDIPI_NSS       '
          RecLab(168)='SPINR_NSS       '
          RecLab(169)='SPINI_NSS       '
+         RecLab(170)='Proj_Coord      '
+         RecLab(171)='d1activeao      '
+         RecLab(172)='Keep_Coord      '
+         RecLab(173)='PCMSph          '
+         RecLab(174)='PCMTess         '
+         RecLab(175)='Vert            '
+         RecLab(176)='Centr           '
+         RecLab(177)='SSph            '
+         RecLab(178)='PCMDM           '
+         RecLab(179)='EF_Centers      '
+         RecLab(180)='OAM_Center      '
+         RecLab(181)='OMQ_Center      '
+         RecLab(182)='DMS_Centers     '
+         RecLab(183)='Wel_Info        '
+         RecLab(184)='AMP_Center      '
+         RecLab(185)='RP_Centers      '
+         RecLab(186)='XF              '
+         RecLab(187)='rDmp            '
+         RecLab(188)='rDmp:A          '
+         RecLab(189)='rDmp:S          '
 *                     1234567890123456
 *
 *        If you go beyond 256: update pg_da_info.fh and this line!
@@ -371,7 +391,7 @@ c mess started here :)
             Write(6,*) '*** Warning, writing temporary dArray field'
             Write(6,*) '***   Field: ',Label
             Write(6,*) '***'
-#ifdef _BIGOT_
+#ifndef _DEVEL_
             Call AbEnd()
 #endif
          End If
