@@ -654,7 +654,7 @@
 *           get last gradient grad(n) from LList
 *
             Call GetVec(LuGrd,iter,LLGrad,inode,Grd1,nOV*nD)
-#ifdef _DEBUG_
+#ifdef _DEBUGPRINT_
             Call RecPrt('Wfctl: g(n)',' ',Grd1,1,nOV*nD)
 #endif
 *
@@ -668,7 +668,7 @@
 *           store dX(n) vector from Disp to LList
 *
             Call PutVec(Disp,nOV*nD,LuDel,iter,MemRsv,'NOOP',LLDelt)
-#ifdef _DEBUG_
+#ifdef _DEBUGPRINT_
             Write (6,*) 'LuDel,LLDelt:',LuDel,LLDelt
             Call RecPrt('Wfctl: dX(n)',' ',Disp,1,nOV*nD)
 #endif
@@ -863,7 +863,7 @@
 *                                                                      *
 *------- Perform another iteration if necessary
 *
-*        Convergence criterions are
+*        Convergence criteria are
 *
 *        Either,
 *
@@ -872,11 +872,11 @@
 *        3) the absolute Fock matrix change is smaller than FThr
 *        4) the absolute density matrix change is smaller than DThr,
 *           and
-*        5) it step is NOT a Quasi NR step
+*        5) step is NOT a Quasi NR step
 *
 *        or
 *
-*        1) it step is a Quasi NR step, and
+*        1) step is a Quasi NR step, and
 *        2) DltNrm.le.DltNth
 *
 *        or
