@@ -11,25 +11,30 @@
 * Copyright (C) 1991, Roland Lindh                                     *
 *               1996, Per Ake Malmqvist                                *
 ************************************************************************
-      SubRoutine Drv1El(DInf,nDInf,Info)
+      SubRoutine Drv1El()
 ************************************************************************
 *                                                                      *
 * Object: driver for computation of one-electron matrices.             *
 *                                                                      *
-* Called from: Seward                                                  *
-*                                                                      *
-* Calling    : QEnter                                                  *
-*              OneEl                                                   *
-*              GetDens                                                 *
-*              QExit                                                   *
-*                                                                      *
 *     Author: Roland Lindh, Dept. of Theoretical Chemistry,            *
 *             University of Lund, SWEDEN                               *
 *             January 1991                                             *
 ************************************************************************
+      Use AMFI_Info
+      Use Basis_Info
       Use GeoList
       Use MpmC
       Use PrpPnt
+      Use External_Centers
+      Use SW_file
+      use Symmetry_Info, only: iChBas
+      use Temporary_Parameters, only: PrPrt, Short, Primitive_Pass
+      use PAM2
+      use DKH_Info, only: BSS, DKroll
+      use Sizes_of_Seward, only: S
+      use Real_Info, only: PotNuc, kVector
+      use Logical_Info, only: Vlct, lRel, lAMFI, NEMO, Do_FckInt,
+     &                        DoFMM, EMFR, GIAO, lPSOI
       Implicit Real*8 (A-H,O-Z)
       External MltInt, KnEInt, MVeInt,  VeInt,  D1Int,  NAInt,  EFInt,
      &         OAMInt, OMQInt, DMSInt, WelInt, XFdInt,  PrjInt,
@@ -47,7 +52,10 @@
      &         KneMem_GIAO,
      &          NAMem_GIAO,
      &          dTdmu_Mem
-      Real*8 DInf(nDInf)
+      External PAM2Int, FragPint,
+     &         PAM2Mem, FragPMem
+      External P_Int, EPEInt,
+     &         P_Mem, EPEMem
 #ifdef _FDE_
       ! Embedding
       External embPotMem, embPotKernel
@@ -63,13 +71,10 @@
       Real*8, Dimension(:), Allocatable :: CoorO, Nuc, KnE_Int, NA_Int,
      &                                     FragP, OneHam, PtEl,
      &                                     PtNuc, SumEl, SumNuc
-      Real*8, Dimension(:,:), Allocatable :: PAMexp
-      External PAM2Int, FragPint, PAM2Mem, FragPMem
-      External P_Int, EPEInt,
-     &         P_Mem, EPEMem
-      logical lECPnp,lPAM2np
-#include "itmax.fh"
-#include "info.fh"
+      logical lECPnp,lECP
+      logical lPAM2np,lPAM2
+      logical lPP, lFAIEMP
+#include "Molcas.fh"
 #include "print.fh"
 #include "nq_info.fh"
 #include "real.fh"
@@ -92,7 +97,6 @@
 *
       iRout = 131
       iPrint = nPrint(iRout)
-*     Call qEnter('Drv1El')
 *
       Call StatusLine(' Seward:',' Computing 1-electron integrals')
 *
@@ -101,7 +105,17 @@
 #ifdef _FDE_
       if (embPot) call EmbPotRdRun
 #endif
-
+*
+      lPAM2 = .False.
+      lECP  = .False.
+      lPP   = .False.
+      lFAIEMP = .False.
+      Do i = 1, nCnttp
+         lPam2 = lPam2 .or. dbsc(i)%lPam2
+         lECP  = lECP  .or. dbsc(i)%ECP
+         lPP   = lPP   .or. dbsc(i)%nPP.ne.0
+         lFAIEMP  = lFAIEMP  .or. dbsc(i)%Frag
+      End Do
 *
 *     set center selector in OneSwi to all centers (default)
 *
@@ -146,7 +160,7 @@
       PLabel=' '
       rHrmt=One
       iLow = 0
-      mMltpl=nMltpl
+      mMltpl=S%nMltpl
       If (Prprt) iLow = 1
 *
 *     If not Douglas-Kroll and primitive pass do no property integrals
@@ -156,7 +170,7 @@
          If (.Not. DKroll) mMltpl=-1
       End If
 *
-      Do 10 iMltpl = iLow, nMltpl
+      Do 10 iMltpl = iLow, S%nMltpl
          Write (Label,'(A,I2)') 'Mltpl ', iMltpl
          nComp = (iMltpl+1)*(iMltpl+2)/2
          Call DCopy_(3,Coor_MPM(1,iMltpl+1),1,Ccoor,1)
@@ -190,8 +204,7 @@
      &              + Mod(iy,2)*iChBas(3)
      &              + Mod(iz,2)*iChBas(4)
 *
-               OperI(1+iComp) = MltLbl(iSymX,MltLbl(iSymY,iSymZ,
-     &                            nIrrep),nIrrep)
+               OperI(1+iComp) = MltLbl(iSymX,MltLbl(iSymY,iSymZ))
                OperC(1+iComp) = iChO
                Call DCopy_(3,Coor_MPM(1,iMltpl+1),1,
      &                    CoorO(1+iComp*3),1)
@@ -199,8 +212,7 @@
  12         Continue
  11      Continue
 *
-         Call MltNuc(CoorO,Chrg,Centr,kCentr,
-     &               Nuc,iMltpl,nComp)
+         Call MltNuc(CoorO,Chrg,Centr,S%kCentr,Nuc,iMltpl,nComp)
 *--- pow hack
          If(iMltpl.eq.0) Then
             Call Put_dScalar('Total Nuclear Charge',Nuc(1))
@@ -295,22 +307,23 @@
          iPAMcount=1
         Do 348 kCnttpPAM = 1, nCnttp
 
-           iAddr=ipPAM2xp(kCnttpPAM)
-           nPAMltpl=nPAM2(kCnttpPAM)
+           nPAMltpl=dbsc(kCnttpPAM)%nPAM2
 
            If(nPAMltpl.lt.0) Go To 348
+*
+           iAddr=1
            Do 347 iPAMltpl=0,nPAMltpl
               nOrdOp= iPAMltpl
               nComp =(iPAMltpl+1)*(iPAMltpl+2)/2
-              iPAMPrim=Int(Work(iAddr))
-              iPAMBas =Int(Work(iAddr+1))
+              iPAMPrim=Int(dbsc(kCnttpPAM)%PAM2(iAddr))
+              iPAMBas =Int(dbsc(kCnttpPAM)%PAM2(iAddr+1))
 
               if(iPAMBas.eq.0.or.iPAMPrim.eq.0) go to 3471
-              Call dcopy_(3,[Zero],0,Ccoor,1)
+              Ccoor(:)=Zero
               Call Allocate_Auxiliary()
               Do iComp=0,nComp-1
-                 Call dcopy_(3,Work(ipCntr(kCnttpPAM)),
-     &                      1,CoorO(1+3*iComp),1)
+                 Call dcopy_(3,dbsc(kCnttpPAM)%Coor,1,
+     &                       CoorO(1+3*iComp),1)
               End Do
 *
 *****    Define symmetry properties of the operator:
@@ -354,9 +367,11 @@
 *****    Loop over basis finction
 *
          Call mma_allocate(PAMexp,iPAMPrim,2,label='PAMexp')
-         Call dcopy_(iPAMPrim,Work(iAddr+2),1,PAMexp(1,1),1)
+         Call dcopy_(iPAMPrim,dbsc(kCnttpPAM)%PAM2(iAddr+2),1,
+     &               PAMexp(1,1),1)
          Do iPAMf=1,iPAMBas
-            Call dcopy_(iPAMPrim,Work(iAddr+2+iPAMPrim*iPAMf),1,
+            Call dcopy_(iPAMPrim,
+     &                  dbsc(kCnttpPAM)%PAM2(iAddr+2+iPAMPrim*iPAMf),1,
      &                  PAMexp(1,2),1)
             Write (Label,'(A,I2.2,I1.1,I2.2)')
      &             'PAM', kCnttpPAM,iPAMltpl,iPAMf
@@ -377,7 +392,7 @@ c           iPAMcount=iPAMcount+1
  3471    iAddr=iAddr+2+iPAMPrim*(iPAMBas+1)
  347     Continue
  348    Continue
-      close(28)
+        close(28)
       End If
 ************************************************************************
 ************************************************************************
@@ -464,7 +479,7 @@ c           iPAMcount=iPAMcount+1
      &                 dum,1,dum,idum,0,0,
      &                 dum,1,0)
          End If
-         If (lXF.and..Not.Primitive_Pass) Then
+         If (Allocated(XF).and..Not.Primitive_Pass) Then
             mOrdOp=nOrd_XF
             Label='XFdInt  '
             Call OneEl(XFdInt,XFdMem,Label,ipList,OperI,nComp,
@@ -649,7 +664,7 @@ c           iPAMcount=iPAMcount+1
 *        Note that this parsing is a bit different here!
 *
          Write (Label,'(A,I1,I5)') 'EF',nOrdOp,iEF
-         Call dcopy_(3,Work(ipEF+(iEF-1)*3),1,Ccoor,1)
+         Ccoor(:)=EF_Centers(:,iEF)
 *
          iSymR(0) = 1
          If (Ccoor(1).ne.Zero) iSymR(0) = iOr(iSymR(0),iSymX)
@@ -687,14 +702,14 @@ c           iPAMcount=iPAMcount+1
 *
                iSymX=1
                If (Mod(ix,2).ne.0) iSymX=iSymR(1)
-               iSymCX=MltLbl(iSymR(0),iSymX,nIrrep)
+               iSymCX=MltLbl(iSymR(0),iSymX)
                iSymY=1
                If (Mod(iy,2).ne.0) iSymY=iSymR(2)
-               iSymCXY=MltLbl(iSymCX,iSymY,nIrrep)
+               iSymCXY=MltLbl(iSymCX,iSymY)
                iSymZ=1
                If (Mod(iz,2).ne.0) iSymZ=iSymR(3)
 *
-               OperI(1+(iComp-1)) = MltLbl(iSymCXY,iSymZ,nIrrep)
+               OperI(1+(iComp-1)) = MltLbl(iSymCXY,iSymZ)
                OperC(1+(iComp-1)) = Mod(ix,2)*iChBas(2)
      &                              + Mod(iy,2)*iChBas(3)
      &                              + Mod(iz,2)*iChBas(4)
@@ -703,8 +718,7 @@ c           iPAMcount=iPAMcount+1
             End Do
          End Do
 *
-         Call EFNuc(CoorO,Chrg,Centr,kCentr,
-     &               Nuc,nOrdOp)
+         Call EFNuc(CoorO,Chrg,Centr,S%kCentr,Nuc,nOrdOp)
          Call OneEl(EFInt,EFMem,Label,ipList,OperI,nComp,
      &              CoorO,nOrdOp,Nuc,rHrmt,OperC,
      &              dum,1,dum,idum,0,0,
@@ -775,15 +789,15 @@ c           iPAMcount=iPAMcount+1
 ************************************************************************
       PLabel=' '
       rHrmt=-One
-      If (lOAM.and..Not.Primitive_Pass) Then
+      If (Allocated(OAM_Center).and..Not.Primitive_Pass) Then
          Label='AngMom  '
          nComp = 3
          nOrdOp = 2
          Call Allocate_Auxiliary()
-         Call dcopy_(3,Work(ipOAM),1,CoorO(1  ),1)
-         Call dcopy_(3,Work(ipOAM),1,CoorO(1+3),1)
-         Call dcopy_(3,Work(ipOAM),1,CoorO(1+6),1)
-         Call dcopy_(3,Work(ipOAM),1,Ccoor,1)
+         Call dcopy_(3,OAM_Center,1,CoorO(1  ),1)
+         Call dcopy_(3,OAM_Center,1,CoorO(1+3),1)
+         Call dcopy_(3,OAM_Center,1,CoorO(1+6),1)
+         Call dcopy_(3,OAM_Center,1,Ccoor,1)
          ixyz=1
          iSymX = 2**IrrFnc(ixyz)
          ixyz=2
@@ -797,18 +811,15 @@ c           iPAMcount=iPAMcount+1
          iSymCz = iSymZ
          If (Ccoor(3).ne.Zero) iSymCz = iOr(iSymCz,1)
 *
-         iSymLx = iOr(MltLbl(iSymCy,iSymZ,nIrrep),
-     &                MltLbl(iSymCz,iSymY,nIrrep))
+         iSymLx = iOr(MltLbl(iSymCy,iSymZ),MltLbl(iSymCz,iSymY))
          iChOx = iChBas(3) + iChBas(4)
          OperI(1  ) = iSymLx
          OperC(1  ) = iChOx
-         iSymLy = iOr(MltLbl(iSymCz,iSymX,nIrrep),
-     &                MltLbl(iSymCx,iSymZ,nIrrep))
+         iSymLy = iOr(MltLbl(iSymCz,iSymX),MltLbl(iSymCx,iSymZ))
          iChOy = iChBas(4) + iChBas(2)
          OperI(1+1) = iSymLy
          OperC(1+1) = iChOy
-         iSymLz = iOr(MltLbl(iSymCx,iSymY,nIrrep),
-     &                MltLbl(iSymCy,iSymX,nIrrep))
+         iSymLz = iOr(MltLbl(iSymCx,iSymY),MltLbl(iSymCy,iSymX))
          iChOz = iChBas(2) + iChBas(3)
          OperI(1+2) = iSymLz
          OperC(1+2) = iChOz
@@ -832,7 +843,7 @@ c           iPAMcount=iPAMcount+1
 ************************************************************************
       PLabel=' '
       rHrmt=-One
-      If (Vlct.and.(nMltpl.ge.2).and..Not.Primitive_Pass) Then
+      If (Vlct.and.(S%nMltpl.ge.2).and..Not.Primitive_Pass) Then
          Label='MLTPV  2'
          nComp = 6
          nOrdOp = 2
@@ -860,22 +871,22 @@ c           iPAMcount=iPAMcount+1
 * Calculates QpV_ij = r_i*p_j+p_i*r_j (or rater p -> nabla)
 *
 * QpVxx
-         OperI(1  ) = MltLbl(iSymCx,iSymX,nIrrep)
+         OperI(1  ) = MltLbl(iSymCx,iSymX)
          OperC(1  ) = iChBas(2)
 * QpVxy
-         OperI(1+1) = MltLbl(iSymCx,iSymY,nIrrep)
+         OperI(1+1) = MltLbl(iSymCx,iSymY)
          OperC(1+1) = iChBas(2) + iChBas(3)
 * QpVxz
-         OperI(1+2) = MltLbl(iSymCx,iSymZ,nIrrep)
+         OperI(1+2) = MltLbl(iSymCx,iSymZ)
          OperC(1+2) = iChBas(2) + iChBas(4)
 * QpVyy
-         OperI(1+3) = MltLbl(iSymCy,iSymY,nIrrep)
+         OperI(1+3) = MltLbl(iSymCy,iSymY)
          OperC(1+3) = iChBas(3)
 * QpVyz
-         OperI(1+4) = MltLbl(iSymCy,iSymZ,nIrrep)
+         OperI(1+4) = MltLbl(iSymCy,iSymZ)
          OperC(1+4) = iChBas(3) + iChBas(4)
 * QpVzz
-         OperI(1+5) = MltLbl(iSymCz,iSymZ,nIrrep)
+         OperI(1+5) = MltLbl(iSymCz,iSymZ)
          OperC(1+5) = iChBas(4)
 *
          Call DCopy_(nComp,[Zero],0,Nuc,1)
@@ -885,7 +896,7 @@ c           iPAMcount=iPAMcount+1
      &              dum,1,0)
 *
          Call Deallocate_Auxiliary()
-      End If   ! Vlct.and.(nMltpl.ge.2)
+      End If   ! Vlct.and.(S%nMltpl.ge.2)
 ************************************************************************
 ************************************************************************
 *12c)                                                                  *
@@ -896,16 +907,16 @@ c           iPAMcount=iPAMcount+1
 ************************************************************************
       PLabel=' '
       rHrmt=-One
-      If (lOMQ.and..Not.Primitive_Pass) Then
+      If (Allocated(OMQ_Center).and..Not.Primitive_Pass) Then
          Label='OMQ     '
          nComp = 9
          nOrdOp = 3
          Call Allocate_Auxiliary()
 *
-         Call dcopy_(nComp,[Work(ipOMQ  )],0,CoorO(1  ),3)
-         Call dcopy_(nComp,[Work(ipOMQ+1)],0,CoorO(1+1),3)
-         Call dcopy_(nComp,[Work(ipOMQ+2)],0,CoorO(1+2),3)
-         Call dcopy_(3,Work(ipOMQ),1,Ccoor,1)
+         Call dcopy_(nComp,[OMQ_Center(1)],0,CoorO(1  ),3)
+         Call dcopy_(nComp,[OMQ_Center(2)],0,CoorO(1+1),3)
+         Call dcopy_(nComp,[OMQ_Center(3)],0,CoorO(1+2),3)
+         Ccoor(:)=OMQ_Center(:)
 *
          ixyz=1
          iSymX = 2**IrrFnc(ixyz)
@@ -920,12 +931,9 @@ c           iPAMcount=iPAMcount+1
          iSymCz = iSymZ
          If (Ccoor(3).ne.Zero) iSymCz = iOr(iSymCz,1)
 *
-         iSymLx = iOr(MltLbl(iSymCy,iSymZ,nIrrep),
-     &                MltLbl(iSymCz,iSymY,nIrrep))
-         iSymLy = iOr(MltLbl(iSymCz,iSymX,nIrrep),
-     &                MltLbl(iSymCx,iSymZ,nIrrep))
-         iSymLz = iOr(MltLbl(iSymCx,iSymY,nIrrep),
-     &                MltLbl(iSymCy,iSymX,nIrrep))
+         iSymLx = iOr(MltLbl(iSymCy,iSymZ),MltLbl(iSymCz,iSymY))
+         iSymLy = iOr(MltLbl(iSymCz,iSymX),MltLbl(iSymCx,iSymZ))
+         iSymLz = iOr(MltLbl(iSymCx,iSymY),MltLbl(iSymCy,iSymX))
 *
 * Calculates M_ij = r_j*L_i + L_i*r_j = 2*r_j*L_i + i hbar E_ijk r_k
 * Since the i hbar is included outside we could do
@@ -933,7 +941,7 @@ c           iPAMcount=iPAMcount+1
 * We use all nine components even if we only need 6 of these later.
 *
 * Mxx
-         iSymxLx = MltLbl(iSymCx,iSymLx,nIrrep)
+         iSymxLx = MltLbl(iSymCx,iSymLx)
          iChOxx = iChBas(15)
          OperI(1  ) = iSymxLx
          OperC(1  ) = iChOxx
@@ -953,7 +961,7 @@ c           iPAMcount=iPAMcount+1
          OperI(1+3) = iSymyLx
          OperC(1+3) = iChOyx
 * Myy
-         iSymyLy = MltLbl(iSymCy,iSymLy,nIrrep)
+         iSymyLy = MltLbl(iSymCy,iSymLy)
          iChOyy = iChBas(15)
          OperI(1+4) = iSymyLy
          OperC(1+4) = iChOyy
@@ -973,7 +981,7 @@ c           iPAMcount=iPAMcount+1
          OperI(1+7) = iSymzLy
          OperC(1+7) = iChOzy
 * Mzz
-         iSymzLz = MltLbl(iSymCz,iSymLz,nIrrep)
+         iSymzLz = MltLbl(iSymCz,iSymLz)
          iChOzz = iChBas(15)
          OperI(1+8) = iSymzLz
          OperC(1+8) = iChOzz
@@ -1066,7 +1074,7 @@ c           iPAMcount=iPAMcount+1
          Write (Label,'(A,I2,I2)') 'DMS ',1,iDMS
          nComp = 9
          nOrdOp=2
-         Call dcopy_(3,Work(ipDMS+(iDMS-1)*3),1,Ccoor,1)
+         CCoor(:)=DMS_Centers(:,iDMS)
          Call Allocate_Auxiliary()
          iSymC = 1
          If (Ccoor(1).ne.Zero) iSymC = iOr(iSymC,iSymX)
@@ -1084,7 +1092,7 @@ c           iPAMcount=iPAMcount+1
          iComp = 0
          iC = 0
          Do 1510 ix = 1, 0, -1
-         Do 1510 iy = 1-ix, 0, -1
+         Do 1511 iy = 1-ix, 0, -1
             iz=1-ix-iy
             iC = iC + 1
             iChO1 = iChBas(iC+1)
@@ -1095,8 +1103,8 @@ c           iPAMcount=iPAMcount+1
             iSym = 2**IrrFnc(ixyz)
             If (Ccoor(iC).ne.Zero) iSym = iOr(iSym,1)
             iD = 0
-            Do 1511 jx = 1, 0, -1
-            Do 1511 jy = 1-jx, 0, -1
+            Do 1512 jx = 1, 0, -1
+            Do 1513 jy = 1-jx, 0, -1
                jz=1-jx-jy
                iD = iD + 1
                iChO2 = iChBas(iD+1)
@@ -1115,12 +1123,13 @@ c           iPAMcount=iPAMcount+1
                Else
                   iChO = iOr(iChO1,iChO2)
                End If
-               OperI(1+iComp) = MltLbl(iSymD,MltLbl(iSym,iSymC,
-     &                            nIrrep),nIrrep)
+               OperI(1+iComp) = MltLbl(iSymD,MltLbl(iSym,iSymC))
                OperC(1+iComp) = iChO
                Call dcopy_(3,Ccoor,1,CoorO(1+iComp*3),1)
                iComp = iComp + 1
- 1511       Continue
+ 1513       Continue
+ 1512       Continue
+ 1511    Continue
  1510    Continue
          Call dcopy_(3,Dxyz,1,CoorO(1+3),1)
 *
@@ -1161,8 +1170,8 @@ c           iPAMcount=iPAMcount+1
          OperI(1) = 1
          OperC(1) = iChBas(1)
          Do 1600 iWel = 1, nWel
-            r0   = Work(ipWel+(iWel-1)*3  )
-            ExpB = Work(ipWel+(iWel-1)*3+1)
+            r0   = Wel_Info(1,iWel)
+            ExpB = Wel_Info(2,iWel)
             Write (Label,'(A,I4)') 'Well',iWel
             Call OneEl(WelInt,WelMem,Label,ipList,OperI,nComp,
      &                 CoorO,iWel,[Zero],rHrmt,OperC,
@@ -1188,6 +1197,7 @@ c           iPAMcount=iPAMcount+1
      &                                 label='Emb_Int')
 #endif
          iOpt = 0
+         lOper = 0
          iRC = -1
          Label='Kinetic '
          Call RdOne(iRC,iOpt,Label,1,KnE_Int,lOper)
@@ -1198,6 +1208,7 @@ c           iPAMcount=iPAMcount+1
             Call Quit(_RC_IO_ERROR_READ_)
          End If
          Label='Attract '
+         lOper = 0
          iRC = -1
          Call RdOne(iRC,iOpt,Label,1,NA_Int,lOper)
          If (iRC.ne.0) then
@@ -1224,6 +1235,7 @@ c           iPAMcount=iPAMcount+1
            close(iunit)
           else
            Label='embpot  '
+           lOper = 0
            iRC=-1
            Call RdOne(iRC,iOpt,Label,1,Emb_Int,lOper)
            If (iRC.ne.0) then
@@ -1241,6 +1253,7 @@ c           iPAMcount=iPAMcount+1
 *
          If (lECPnp) Then
             Label='PrjInt  '
+            lOper = 0
             iRC = -1
             Call RdOne(iRC,iOpt,Label,1,KnE_Int,lOper)
             If (iRC.ne.0) then
@@ -1251,6 +1264,7 @@ c           iPAMcount=iPAMcount+1
             End If
             Call DaXpY_(n2Tri(1)+4,One,KnE_Int,1,NA_Int,1)
             Label='M1Int   '
+            lOper = 0
             iRC = -1
             Call RdOne(iRC,iOpt,Label,1,KnE_Int,lOper)
             If (iRC.ne.0) then
@@ -1261,6 +1275,7 @@ c           iPAMcount=iPAMcount+1
             End If
             Call DaXpY_(n2Tri(1)+4,One,KnE_Int,1,NA_Int,1)
             Label='M2Int   '
+            lOper = 0
             iRC = -1
             Call RdOne(iRC,iOpt,Label,1,KnE_Int,lOper)
             If (iRC.ne.0) then
@@ -1271,6 +1286,7 @@ c           iPAMcount=iPAMcount+1
             End If
             Call DaXpY_(n2Tri(1)+4,One,KnE_Int,1,NA_Int,1)
             Label='SROInt  '
+            lOper = 0
             iRC = -1
             Call RdOne(iRC,iOpt,Label,1,KnE_Int,lOper)
             If (iRC.ne.0) then
@@ -1286,6 +1302,7 @@ c           iPAMcount=iPAMcount+1
 *
          If (lPP) Then
             Label='PPInt   '
+            lOper = 0
             iRC = -1
             Call RdOne(iRC,iOpt,Label,1,KnE_Int,lOper)
             If (iRC.ne.0) then
@@ -1299,8 +1316,9 @@ c           iPAMcount=iPAMcount+1
 *
 *--------Add contributions from the external field
 *
-         If (lXF) Then
+         If (Allocated(XF)) Then
             Label='XFdInt  '
+            lOper = 0
             iRC = -1
             Call RdOne(iRC,iOpt,Label,1,KnE_Int,lOper)
             If (iRC.ne.0) then
@@ -1316,8 +1334,9 @@ c           iPAMcount=iPAMcount+1
 *
          If (nWel.ne.0) Then
             Do iWel = 1, nWel
-               Fact=Work(ipWel-1+(iWel-1)*3+3)
+               Fact=Wel_Info(3,iWel)
                Write (Label,'(A,I4)') 'Well',iWel
+               lOper = 0
                iRC = -1
                Call RdOne(iRC,iOpt,Label,1,KnE_Int,lOper)
                If (iRC.ne.0) then
@@ -1387,15 +1406,15 @@ c           iPAMcount=iPAMcount+1
 * Coded P-A Malmqvist, Garching, Nov 1996
       PLabel=' '
       rHrmt=-One
-      If (lAMP.and..Not.Primitive_Pass) Then
+      If (Allocated(AMP_Center).and..Not.Primitive_Pass) Then
          Label='AMProd  '
          nComp = 6
          nOrdOp = 2
          Call Allocate_Auxiliary()
-         Call dcopy_(nComp,[Work(ipAMP  )],0,CoorO(1  ),3)
-         Call dcopy_(nComp,[Work(ipAMP+1)],0,CoorO(1+1),3)
-         Call dcopy_(nComp,[Work(ipAMP+2)],0,CoorO(1+2),3)
-         Call dcopy_(3,Work(ipAMP),1,Ccoor,1)
+         Call dcopy_(nComp,[AMP_Center(1)],0,CoorO(1  ),3)
+         Call dcopy_(nComp,[AMP_Center(2)],0,CoorO(1+1),3)
+         Call dcopy_(nComp,[AMP_Center(3)],0,CoorO(1+2),3)
+         CCoor(:)=AMP_Center(:)
 C Symmetry labels iSymX  for operator d/dx, etc.
 C Symmetry labels iSymLx for operator Lx, etc.
 C Characters iChOx for operator Lx, etc.
@@ -1411,14 +1430,11 @@ C Characters iChOx for operator Lx, etc.
          If (Ccoor(2).ne.Zero) iSymCy = iOr(iSymCy,1)
          iSymCz = iSymZ
          If (Ccoor(3).ne.Zero) iSymCz = iOr(iSymCz,1)
-         iSymLx = iOr(MltLbl(iSymCy,iSymZ,nIrrep),
-     &                MltLbl(iSymCz,iSymY,nIrrep))
+         iSymLx = iOr(MltLbl(iSymCy,iSymZ),MltLbl(iSymCz,iSymY))
          iChOx = iChBas(3) + iChBas(4)
-         iSymLy = iOr(MltLbl(iSymCz,iSymX,nIrrep),
-     &                MltLbl(iSymCx,iSymZ,nIrrep))
+         iSymLy = iOr(MltLbl(iSymCz,iSymX),MltLbl(iSymCx,iSymZ))
          iChOy = iChBas(4) + iChBas(2)
-         iSymLz = iOr(MltLbl(iSymCx,iSymY,nIrrep),
-     &                MltLbl(iSymCy,iSymX,nIrrep))
+         iSymLz = iOr(MltLbl(iSymCx,iSymY),MltLbl(iSymCy,iSymX))
          iChOz = iChBas(2) + iChBas(3)
 
 C Symmetry labels and characters of products. Let G be the full
@@ -1428,12 +1444,12 @@ C decomposed into irreps of G.
 C Then symmetry label=packed array of bits, one for each irrep
 C of G. The bit is set, if that irrep is included in the
 C decomposition of the totally symmetric irrep of Gsub.
-         OperI(1  )=MltLbl(iSymLx,iSymLx,nIrrep)
-         OperI(1+1)=MltLbl(iSymLx,iSymLy,nIrrep)
-         OperI(1+2)=MltLbl(iSymLx,iSymLz,nIrrep)
-         OperI(1+3)=MltLbl(iSymLy,iSymLy,nIrrep)
-         OperI(1+4)=MltLbl(iSymLy,iSymLz,nIrrep)
-         OperI(1+5)=MltLbl(iSymLz,iSymLz,nIrrep)
+         OperI(1  )=MltLbl(iSymLx,iSymLx)
+         OperI(1+1)=MltLbl(iSymLx,iSymLy)
+         OperI(1+2)=MltLbl(iSymLx,iSymLz)
+         OperI(1+3)=MltLbl(iSymLy,iSymLy)
+         OperI(1+4)=MltLbl(iSymLy,iSymLz)
+         OperI(1+5)=MltLbl(iSymLz,iSymLz)
          OperC(1  )=0
          OperC(1+1)=iEOr(iChOx,iChOy)
          OperC(1+2)=iEOr(iChOx,iChOz)
@@ -1481,7 +1497,7 @@ C decomposition of the totally symmetric irrep of Gsub.
       nOrdOp = 1
       Do iCnt = 1, mCnt
          Write (Label,'(A,I5)') 'Cnt',iCnt
-         Call dcopy_(3,Work(ipEF+(iCnt-1)*3),1,Ccoor,1)
+         CCoor(:)=EF_Centers(:,iCnt)
          Call Allocate_Auxiliary()
 *
          iSymR(0) = 1
@@ -1616,7 +1632,7 @@ C     mMltpl=-1 ! Do only overlap.
 *              belong to. The lowest significant bit if set indicate that
 *              a particular irrep is included.
 *
-               iTemp = MltLbl(iSymX,MltLbl(iSymY,iSymZ,nIrrep),nIrrep)
+               iTemp = MltLbl(iSymX,MltLbl(iSymY,iSymZ))
 *
                iChO = Mod(ix,2)*iChBas(2)
      &              + Mod(iy,2)*iChBas(3)
@@ -1634,9 +1650,8 @@ C     mMltpl=-1 ! Do only overlap.
      &               + Mod(iy+1,2)*iChBas(3)
      &               + Mod(iz+1,2)*iChBas(4)
                OperC(1+(iB-1)*mComp+iComp) = iChOx
-               iSymBx = MltLbl(iSymRy,iSymRz,nIrrep)
-               OperI(1+(iB-1)*mComp+iComp) =
-     &            MltLbl(iTemp,iSymBx,nIrrep)
+               iSymBx = MltLbl(iSymRy,iSymRz)
+               OperI(1+(iB-1)*mComp+iComp) = MltLbl(iTemp,iSymBx)
                Call DCopy_(3,Coor_MPM(1,iMltpl+1),1,
      &                      CoorO(1+((iB-1)*mComp+iComp)*3),1)
 *
@@ -1645,9 +1660,8 @@ C     mMltpl=-1 ! Do only overlap.
      &               + Mod(iy  ,2)*iChBas(3)
      &               + Mod(iz+1,2)*iChBas(4)
                OperC(1+(iB-1)*mComp+iComp) = iChOy
-               iSymBy = MltLbl(iSymRz,iSymRx,nIrrep)
-               OperI(1+(iB-1)*mComp+iComp) =
-     &            MltLbl(iTemp,iSymBy,nIrrep)
+               iSymBy = MltLbl(iSymRz,iSymRx)
+               OperI(1+(iB-1)*mComp+iComp) = MltLbl(iTemp,iSymBy)
                Call DCopy_(3,Coor_MPM(1,iMltpl+1),1,
      &                      CoorO(1+((iB-1)*mComp+iComp)*3),1)
 *
@@ -1656,9 +1670,8 @@ C     mMltpl=-1 ! Do only overlap.
      &               + Mod(iy+1,2)*iChBas(3)
      &               + Mod(iz  ,2)*iChBas(4)
                OperC(1+(iB-1)*mComp+iComp) = iChOz
-               iSymBz = MltLbl(iSymRx,iSymRy,nIrrep)
-               OperI(1+(iB-1)*mComp+iComp) =
-     &            MltLbl(iTemp,iSymBz,nIrrep)
+               iSymBz = MltLbl(iSymRx,iSymRy)
+               OperI(1+(iB-1)*mComp+iComp) = MltLbl(iTemp,iSymBz)
                Call DCopy_(3,Coor_MPM(1,iMltpl+1),1,
      &                      CoorO(1+((iB-1)*mComp+iComp)*3),1)
 *
@@ -1699,31 +1712,38 @@ C     mMltpl=-1 ! Do only overlap.
          OperI(1+2)=2**IrrFnc(3)
          OperC(1+2)=iChBas(4)
 
-* BP - Turn off AMFI integrals for certain atom types
-*      as requested by the PAMF keyword
-c         write(6,*) "nPAMFI:", nPAMFI
-c         write(6,*) "iPAMFI:", iPAMFI(1:nPAMFI)
+* BP -   Turn off AMFI integrals for certain atom types
+*        as requested by the PAMF keyword
 
-         Do iAtm=1,nCnttp
-           iAtmNr2(iAtm) = iAtmNr(iAtm)
-           Charge2(iAtm) = Charge(iAtm)
+*        Note that Drv_AMFI will onluy process dbsc of valence typ.
+*        Hence the restriction on the loop.
 
-c           write(6,*) "iAtmNr2(iAtm)",iAtm, iAtmNr2(iAtm)
-c           write(6,*) "Charge(iAtm)", iAtm, Charge(iAtm)
+         Do i=1,nCnttp
+            If (dbsc(i)%ECP  .or.
+     &          dbsc(i)%Aux  .or.
+     &          dbsc(i)%Frag) Cycle
+            iAtmNr2(i) = dbsc(i)%AtmNr
+            Charge2(i) = dbsc(i)%Charge
 
-           do iPAM=1,nPAMFI
-             if(iAtmNr(iAtm).EQ.iPAMFI(iPAM)) then
-               write(6,*) "Disabling AMFI for atom type ",iAtmNr(iAtm)
-               iAtmNr2(iAtm) = 0
-               Charge2(iAtm) = 0.0d0
-             end if
-           end do
+c           write(6,*) "iAtmNr2(i)",i, iAtmNr2(i)
+c           write(6,*) "Charge(i)", i, dbsc(i)%Charge
+
+            iAtom_Number= dbsc(i)%AtmNr
+            If (iAtom_Number<0 .or. iAtom_Number>SIZE(No_AMFI)) Then
+               Write (6,*) 'Illegal atom number.'
+               Write (6,*) 'Atom number=',iAtom_Number
+               Call Abend()
+            End If
+            If (No_AMFI(iAtom_Number)) then
+               write(6,*) "Disabling AMFI for atom type ",
+     &                 dbsc(i)%AtmNr
+               iAtmNr2(i) = 0
+               Charge2(i) = 0.0d0
+            End if
          End do
 
-         Call Gen_RelPointers(-(Info-1))
-         Call Drv_AMFI(Label,ipList,OperI,nComp,rHrmt,
-     &                 OperC, iAtmNr2, Charge2,DInf,nDInf)
-         Call Gen_RelPointers(Info-1)
+         Call Drv_AMFI(Label,ipList,OperI,nComp,rHrmt,OperC,iAtmNr2,
+     &                 Charge2)
 
          Call Deallocate_Auxiliary()
       End If
@@ -1770,18 +1790,15 @@ c        Call DCopy_(3,Work(ipPSO),1,CoorO(1+(iComp-1)*3),1)
          iSymCz = iSymZ
          If (Ccoor(3).ne.Zero) iSymCz = iOr(iSymCz,1)
 *
-         iSymLx = iOr(MltLbl(iSymCy,iSymZ,nIrrep),
-     &                MltLbl(iSymCz,iSymY,nIrrep))
+         iSymLx = iOr(MltLbl(iSymCy,iSymZ),MltLbl(iSymCz,iSymY))
          iChOx = iChBas(3) + iChBas(4)
          OperI(1  ) = iSymLx
          OperC(1  ) = iChOx
-         iSymLy = iOr(MltLbl(iSymCz,iSymX,nIrrep),
-     &                MltLbl(iSymCx,iSymZ,nIrrep))
+         iSymLy = iOr(MltLbl(iSymCz,iSymX),MltLbl(iSymCx,iSymZ))
          iChOy = iChBas(4) + iChBas(2)
          OperI(1+1) = iSymLy
          OperC(1+1) = iChOy
-         iSymLz = iOr(MltLbl(iSymCx,iSymY,nIrrep),
-     &                MltLbl(iSymCy,iSymX,nIrrep))
+         iSymLz = iOr(MltLbl(iSymCx,iSymY),MltLbl(iSymCy,iSymX))
          iChOz = iChBas(2) + iChBas(3)
          OperI(1+2) = iSymLz
          OperC(1+2) = iChOz
@@ -1869,10 +1886,10 @@ c        Call DCopy_(3,Work(ipPSO),1,CoorO(1+(iComp-1)*3),1)
 *
          iEF = 0
          Do  iCnttp = 1, nCnttp
-            Do iCnt = 1, nCntr(iCnttp)
+            Do iCnt = 1, dbsc(iCnttp)%nCntr
                iEF=iEF+1
                Write (Label,'(A,I2)') 'dT/dmu',iEF
-               Call dcopy_(3,Work(ipCntr(iCnttp)+(iCnt-1)*3),1,Ccoor,1)
+               CCoor(1:3)=dbsc(iCnttp)%Coor(1:3,iCnt)
                Call Allocate_Auxiliary()
                iSymC = 1
                If (Ccoor(1).ne.Zero) iSymC = iOr(iSymC,iSymX)
@@ -1898,14 +1915,13 @@ c        Call DCopy_(3,Work(ipPSO),1,CoorO(1+(iComp-1)*3),1)
                      If (Mod(iz,2).ne.0) ixyz=iOr(ixyz,4)
                      iSym = 2**IrrFnc(ixyz)
                      If (Ccoor(iComp).ne.Zero ) iSym = iOr(iSym,1)
-                     OperI(1+(iComp-1)) = MltLbl(iSymC,iSym,nIrrep)
+                     OperI(1+(iComp-1)) = MltLbl(iSymC,iSym)
                      OperC(1+(iComp-1)) = iChBas(iComp+1)
                      Call dcopy_(3,Ccoor,1,CoorO(1+(iComp-1)*3),1)
                   End Do
                End Do
 *
-*              Call EFNuc(CoorO,Chrg,Centr,kCentr,
-*    &                    Nuc,nOrdOp)
+*              Call EFNuc(CoorO,Chrg,Centr,S%kCentr,Nuc,nOrdOp)
 *
 
                Call OneEl(dTdmu_Int,dTdmu_Mem,Label,ipList,
@@ -1925,7 +1941,6 @@ c        Call DCopy_(3,Work(ipPSO),1,CoorO(1+(iComp-1)*3),1)
 *                                                                      *
 ************************************************************************
 ************************************************************************
-      Call Gen_RelPointers(-(Info-1))
       PLabel=' '
       rHrmt=One
       nComp=1
@@ -1940,11 +1955,10 @@ c        Call DCopy_(3,Work(ipPSO),1,CoorO(1+(iComp-1)*3),1)
          Call Drv_Fck(Label,ipList,OperI,nComp,
      &                CoorO,nOrdOp,[Zero],rHrmt,OperC,
      &                dum,1,dum,idum,0,0,
-     &                dum,1,0,DInf,nDInf)
+     &                dum,1,0)
 *
          Call Deallocate_Auxiliary()
       End If
-      Call Gen_RelPointers(Info-1)
 *                                                                      *
 ************************************************************************
 *                                                                      *
@@ -2037,6 +2051,7 @@ c        Call DCopy_(3,Work(ipPSO),1,CoorO(1+(iComp-1)*3),1)
         Call Deallocate_Auxiliary()
 * add the results to the one-electron hamiltonian
         iOpt = 0
+        lOper = 0
         iRC = -1
         Call mma_allocate(FragP,n2Tri(1)+4,label='FragP')
         Call RdOne(iRC,iOpt,Label,1,FragP,lOper)
@@ -2047,6 +2062,7 @@ c        Call DCopy_(3,Work(ipPSO),1,CoorO(1+(iComp-1)*3),1)
            Call Quit(_RC_IO_ERROR_READ_)
         End If
         Label = 'OneHam  '
+        lOper = 0
         iRC = -1
         Call mma_allocate(OneHam,n2Tri(1)+4,label='OneHam')
         Call RdOne(iRC,iOpt,Label,1,OneHam,lOper)
@@ -2087,7 +2103,6 @@ c        Call DCopy_(3,Work(ipPSO),1,CoorO(1+(iComp-1)*3),1)
 *                                                                      *
 ************************************************************************
 *                                                                      *
-*     Call qExit('Drv1El')
       Return
 *
       Contains
