@@ -11,11 +11,11 @@
       Subroutine Convrg(iter,kIter, nInter, qInt, Shift, Grad,
      &                  Lbl,GNrm,Energy,Stat,MaxItr,Stop,iStop,ThrCons,
      &                  ThrEne, ThrGrd, MxItr, UpMeth, HUpMet, mIntEff,
-     &                  Baker, Cx,Gx,nAtom,mTtAtm,iOper,nSym,ed,iNeg,
+     &                  Baker, Cx,Gx,nAtom,mTtAtm,ed,iNeg,
      &                  GoOn,Step_Trunc,GrdMax,StpMax,GrdLbl,StpLbl,
      &                  Analytic_hessian,rMEP,MEP,nMEP,Numerical,
      &                  Just_Frequencies,FindTS,ipCoor,eMEPTest,nLambda,
-     &                  TSReg)
+     &                  TSReg,ThrMEP)
       Use Chkpnt
       Implicit Real*8 (a-h,o-z)
 #include "real.fh"
@@ -32,11 +32,13 @@
       Character*1 Step_Trunc
       Character*16 StdIn
       Character*80 Point_Desc
-      Integer   iOper(0:nSym-1), iNeg(2)
+      Character*16 MEP_Text
+      Integer   iNeg(2)
       Logical Stop, Conv1, Baker, GoOn,Analytic_hessian, MEP,
      &        Found, Terminate, Numerical, Last_Energy, rMEP,
      &        Just_Frequencies, Saddle, FindTS, eMEPTest, eTest,
-     &        IRCRestart, Conv2, ConvTmp, TSReg
+     &        IRCRestart, Conv2, ConvTmp, TSReg, BadConstraint,
+     &        TurnBack
       Character*8 Temp
 *
       Lu=6
@@ -51,7 +53,6 @@
          Call RecPrt('Convrg: Cx',' ',Cx,3*nAtom,iter+1)
          Call RecPrt('Convrg: Gx',' ',Gx,3*nAtom,iter+1)
       End If
-      Call QEnter('Convrg')
 *
       Call Get_iScalar('Saddle Iter',iter_S)
       If (iter_S.eq.0) Then
@@ -79,8 +80,8 @@
 *
       Call GetMem('x','Allo','Real',ipx,3*mTtAtm)
       Call GetMem('y','Allo','Real',ipy,3*mTtAtm)
-      Call AtmLst(Cx(1,iter  ),nAtom,Work(ipx),iOper,nSym,mTtAtm)
-      Call AtmLst(Cx(1,iter+1),nAtom,Work(ipy),iOper,nSym,mTtAtm)
+      Call AtmLst(Cx(1,iter  ),nAtom,Work(ipx),mTtAtm)
+      Call AtmLst(Cx(1,iter+1),nAtom,Work(ipy),mTtAtm)
       Call OptRMS_Slapaf(Work(ipx),Work(ipy),mTtAtm,RMS,RMSMax)
       Call GetMem('y','Free','Real',ipy,3*mTtAtm)
       Call GetMem('x','Free','Real',ipx,3*mTtAtm)
@@ -106,6 +107,7 @@
          End If
       End If
 *
+      eDiffMEP=Zero
       If (MEP.or.rMEP) Then
          Saddle=.False.
          iMEP=0
@@ -164,10 +166,10 @@
          Val2= RMSMax
          Thr2= ThrGrd
          If (Val2.lt.Thr2) Then
-            If (Step_Trunc.eq.' ') Then
-               ConLbl(2)=' Yes '
-            Else
+            If (Step_Trunc.eq.'*') Then
                ConLbl(2)=' No *'
+            Else
+               ConLbl(2)=' Yes '
             End If
          Else
             ConLbl(2)=' No  '
@@ -180,7 +182,7 @@
             ConLbl(3)=' No  '
          End If
          Conv1= Val1.lt.Thr1.and.kIter.gt.1
-         Conv1= Conv1.or. (Val2.lt.Thr2 .and. Step_Trunc.eq.' ')
+         Conv1= Conv1.or. (Val2.lt.Thr2 .and. Step_Trunc.ne.'*')
          Conv1= Conv1.and. Val3.lt.Thr3
       Else
          Val2=Abs(Fabs/Sqrt(DBLE(mIntEff)))
@@ -201,16 +203,16 @@
          Else
             ConLbl(4)=' No  '
          End If
-         Conv2= RMS.lt.ThrGrd*4.D0 .and. Step_Trunc.eq.' '
+         Conv2= RMS.lt.ThrGrd*4.D0 .and. Step_Trunc.ne.'*'
          Val1=RMS
          Thr1=ThrGrd*4.0D0
          ConvTmp=Val1.lt.Thr1
-         Conv2=ConvTmp .and. Step_Trunc.eq.' '
+         Conv2=ConvTmp .and. Step_Trunc.ne.'*'
          If (ConvTmp) Then
-            If (Step_Trunc.eq.' ') Then
-               ConLbl(1)=' Yes '
-            Else
+            If (Step_Trunc.eq.'*') Then
                ConLbl(1)=' No *'
+            Else
+               ConLbl(1)=' Yes '
             End If
          Else
             ConLbl(1)=' No  '
@@ -219,11 +221,11 @@
          Thr3=ThrGrd*6.0D0
          ConvTmp=Val3.lt.Thr3
          Conv2=Conv2.and.ConvTmp
-         If (Conv2) Then
-            If (Step_Trunc.eq.' ') Then
-               ConLbl(3)=' Yes '
-            Else
+         If (ConvTmp) Then
+            If (Step_Trunc.eq.'*') Then
                ConLbl(3)=' No *'
+            Else
+               ConLbl(3)=' Yes '
             End If
          Else
             ConLbl(3)=' No  '
@@ -686,7 +688,9 @@ C              Write (6,*) 'SubProject=.Prod'
          IRC=0
       End If
 *
-      If (Conv1.and.(MEP.or.rMEP)) Then
+      TurnBack=.False.
+      If (MEP.or.rMEP) Then
+       If (Conv1) Then
 *
 *        Is this the first iteration or not?
 *
@@ -725,83 +729,191 @@ C              Write (6,*) 'SubProject=.Prod'
          Call Intergeo('MD_MEP',Work(ipE),Work(ipC),Work(ipG),nAtom,
      &                 iMEP+1)
 *
+*        Compute energy difference and RMS between last two structures
+*
+         eDiffMEP=Work(ipE+(iMEP))-Work(ipE+(iMEP-1))
+         Call GetMem('x','Allo','Real',ipx,3*mTtAtm)
+         Call GetMem('y','Allo','Real',ipy,3*mTtAtm)
+         Call AtmLst(Work(ipC+(iMEP-1)*3*nAtom),nAtom,Work(ipx),mTtAtm)
+         Call AtmLst(Work(ipC+(iMEP  )*3*nAtom),nAtom,Work(ipy),mTtAtm)
+         Call OptRMS_Slapaf(Work(ipx),Work(ipy),mTtAtm,RMS,RMSMax)
+         Call GetMem('x','Free','Real',ipx,3*mTtAtm)
+         Call GetMem('y','Free','Real',ipy,3*mTtAtm)
+*
+         Call Free_Work(ipE)
+         Call Free_Work(ipG)
+         Call Free_Work(ipC)
+*
+       Else
+*
+*        Test for "turn back", i.e. when the trial structure
+*        is getting too close to the previous converged structure,
+*        this may be an indication of an ill-behaved constraint
+         If (iMEP.ge.1) Then
+            Call Allocate_Work(ipC,3*nAtom*(nMEP+1))
+            Call Allocate_Work(ipTmp,3*nAtom)
+            Call Get_dArray('MEP-Coor',Work(ipC),3*nAtom*(nMEP+1))
+            ipPrev=ipC+iMEP*3*nAtom
+*           Using hypersphere measure, even with "transverse" MEPs,
+*           this should not be a problem
+            Call SphInt(Cx(1,iter),nAtom,ip_Dummy,refDist,Work(ipTmp),
+     &         .False.,.False.,'dummy   ',Work(ip_Dummy),.False.)
+            Call SphInt(Cx(1,iter),nAtom,ipPrev,prevDist,Work(ipTmp),
+     &         .False.,.False.,'dummy   ',Work(ip_Dummy),.False.)
+            If (prevDist.lt.Half*refDist) Then
+               TurnBack=.True.
+               Conv1=.True.
+               Stop=.True.
+               iStop=0
+               Terminate=.True.
+            End If
+            Call Free_Work(ipC)
+            Call Free_Work(ipTmp)
+         End If
+*
+       End If
+      End If
+*                                                                      *
+************************************************************************
+*                                                                      *
+*-----List internal coordinates and gradients
+*
+      kkIter=iter+1
+      If (iPrint.ge.8) Then
+         Call List(' Internal coordinates ',Lbl,qInt,nInter,kkIter)
+         Call List(' Internal forces    ',Lbl,Grad,nInter,iter)
+      End If
+*                                                                      *
+************************************************************************
+*                                                                      *
+*     Put out the new reference structure and the new starting
+*     structure to be used for the next MEP point.
+*     For rMEP keep the reference structure!
+*     Note that this is done in weighted Cartesian coordinates!
+*
+      If ((Conv1.or.(iter.eq.1)).and.(MEP.or.rMEP)) Then
+         If ((iMEP.ge.1).and.(iPrint.ge.5)) Then
+            Write (6,*)
+            Call CollapseOutput(1,'IRC/Minimum Energy Path Information')
+         End If
+*
+         ResGrad=Huge(ResGrad)
+         If (.Not.Terminate) Then
+            BadConstraint=.False.
+            Call MEP_Dir(Cx,Gx,nAtom,iMEP,iOff_iter,iPrint,IRCRestart,
+     &                   ResGrad,BadConstraint)
+            Call dCopy_(3*nAtom,Cx(1,iter+1),1,Work(ipCoor),1)
+            Call Put_iScalar('iOff_Iter',iter)
+         End If
+*
+         If (MEP) Then
+            If (IRC.eq.0) Then
+               MEP_Text='MEP'
+            Else If (IRC.eq.1) Then
+               MEP_Text='IRC(forward)'
+            Else
+               MEP_Text='IRC(backward)'
+            End If
+         Else If (rMEP) Then
+            MEP_Text='rMEP'
+         Else
+            MEP_Text=''
+         End If
+*
 *        Should we terminate or not? Not done on the first iteration.
 *
          If (iMEP.gt.0) Then
 *
-*           Test if the energy increase (optionally disabled).
-            If (eMEPTest) Then
-               eTest= Work(ipE+(iMEP  )).gt.Work(ipE+(iMEP-1))
-            Else
-               eTest=.FALSE.
-            End If
-            If ( MEP .and. eTest) Then
+*           Test for energy increase (optionally disabled).
+            eTest=eMEPTest.and.(eDiffMEP.gt.Zero)
+            If ((MEP.and.eTest).and.(.not.Terminate)) Then
                Terminate=.True.
                If (iPrint.ge.5) Then
                   Write (6,*)
-                  If (IRC.eq.0) Then
-                     Write (6,'(A)')
-     &                     ' MEP-search terminated'//
-     &                     ' due to energy increase!'
-                  Else If (IRC.eq.1) Then
-                     Write (6,'(A)')
-     &                     ' IRC(forward)-search terminated'//
-     &                     ' due to energy increase!'
-                  Else
-                     Write (6,'(A)')
-     &                     ' IRC(backward)-search terminated'//
-     &                     ' due to energy increase!'
-                  End If
+                  Write (6,'(A)') ' '//Trim(MEP_Text)//'-search'//
+     &               ' terminated due to energy increase!'
                   Write (6,*)
                End If
             End If
 *
-*           Test if the energy decrease (optionally disabled).
-            If (eMEPTest) Then
-               eTest= Work(ipE+(iMEP  )).lt.Work(ipE+(iMEP-1))
-            Else
-               eTest=.FALSE.
-            End If
-            If (rMEP .and. eTest) Then
+*           Test for energy decrease (optionally disabled).
+            eTest=eMEPTest.and.(eDiffMEP.lt.Zero)
+            If ((rMEP.and.eTest).and.(.not.Terminate)) Then
                Terminate=.True.
                If (iPrint.ge.5) Then
                   Write (6,*)
-                  Write (6,'(A)')
-     &                  ' rMEP-search terminated'//
-     &                  ' due to energy decrease!'
+                  Write (6,'(A)') ' '//Trim(MEP_Text)//'-search'//
+     &               ' terminated due to energy decrease!'
                   Write (6,*)
                End If
             End If
-         End If
 *
-*        Test on max number of points.
-         If ((iMEP.ge.nMEP).and.(.not.Terminate)) Then
-            Terminate=.True.
-            If (iPrint.ge.5) Then
-               Write (6,*)
-               If (MEP) Then
-                  If (IRC.eq.0) Then
-                     Write (6,'(A)') ' MEP-search '//
-     &                   'terminated due to max number of path points!'
-                  Else If (IRC.eq.1) Then
-                     Write (6,'(A)') ' IRC(forward)-search '//
-     &                   'terminated due to max number of path points!'
-                  Else
-                     Write (6,'(A)') ' IRC(backward)-search '//
-     &                   'terminated due to max number of path points!'
-                  End If
-               Else If (rMEP) Then
-                  Write (6,'(A)') ' rMEP-search '//
-     &                'terminated due to max number of path points!'
-               End If
-               Write (6,*)
+*           Test for small gradient.
+            If ((iMEP.gt.1).or.(IRC.eq.0)) Then
+              If ((ResGrad.lt.ThrMEP).and.(.not.Terminate)) Then
+                 Terminate=.True.
+                 If (iPrint.ge.5) Then
+                    Write (6,*)
+                    Write (6,'(A)') ' '//Trim(MEP_Text)//'-search'//
+     &               ' terminated due to small gradient!'
+                    Write (6,*)
+                 End If
+              End If
             End If
+*
+*           Test for small step.
+            If ((RMS.lt.ThrGrd*4.D0).and.(.not.Terminate)) Then
+               Terminate=.True.
+               If (iPrint.ge.5) Then
+                  Write (6,*)
+                  Write (6,'(A)') ' '//Trim(MEP_Text)//'-search'//
+     &               ' terminated due to small geometry change!'
+                  Write (6,*)
+               End If
+            End If
+*
+*           Test for max number of points.
+            If ((iMEP.ge.nMEP).and.(.not.Terminate)) Then
+               Terminate=.True.
+               If (iPrint.ge.5) Then
+                  Write (6,*)
+                  Write (6,'(A)') ' '//Trim(MEP_Text)//'-search'//
+     &               ' terminated due to max number of path points!'
+                  Write (6,*)
+               End If
+            End If
+*
+*           Test for constraint misbehavior.
+            If ((BadConstraint.and.(.not.Terminate)).or.TurnBack) Then
+               Terminate=.True.
+               If (iPrint.ge.5) Then
+                  Write (6,*)
+                  Write (6,'(A)') ' '//Trim(MEP_Text)//'-search'//
+     &               ' terminated due to problematic constraint!'
+                  Write (6,*)
+               End If
+            End If
+*
+*           If IRC reset for backward IRC search.
+*
+            If (Terminate) Then
+               If (IRC.eq.1) Then
+                  IRCRestart=.True.
+               End If
+            End If
+*
          End If
 *
-*        If IRC reset for backward IRC search.
+         If (Conv1) Call Chkpnt_update_MEP(IRCRestart)
 *
-         If (Terminate) Then
+         If (Conv1.and.Terminate) Then
             If (IRC.ne.0) Then
+               Call Allocate_Work(ipE,nMEP+1)
+               Call Allocate_Work(ipC,3*nAtom*(nMEP+1))
+               Call Allocate_Work(ipG,3*nAtom*(nMEP+1))
+               Call Get_dArray('MEP-Energies',Work(ipE),nMEP+1)
+               Call Get_dArray('MEP-Coor',Work(ipC),3*nAtom*(nMEP+1))
+               Call Get_dArray('MEP-Grad',Work(ipG),3*nAtom*(nMEP+1))
                If (IRC.eq.1) Then
                   IRCRestart=.True.
                   IRC=-1
@@ -845,19 +957,14 @@ C              Write (6,*) 'SubProject=.Prod'
      &                          Work(ipG_IRC+(j-1)*3*nAtom),1)
                   End Do
 *
-                  Call Get_dArray('IRC-Energies',Work(ipE),nForward)
-                  Call Get_dArray('IRC-Coor',Work(ipC),3*nAtom*nForward)
-                  Call Get_dArray('IRC-Grad',Work(ipG),3*nAtom*nForward)
-*
-                  call dcopy_(nForward,
-     &                       Work(ipE),1,
-     &                       Work(ipE_IRC+(nBackward-1)),1)
-                  call dcopy_(nForward*3*nAtom,
-     &                       Work(ipC),1,
-     &                       Work(ipC_IRC+(nBackward-1)*3*nAtom),1)
-                  call dcopy_(nForward*3*nAtom,
-     &                       Work(ipG),1,
-     &                       Work(ipG_IRC+(nBackward-1)*3*nAtom),1)
+                  Call Get_dArray('IRC-Energies',
+     &                            Work(ipE_IRC+(nBackward-1)),nForward)
+                  Call Get_dArray('IRC-Coor',
+     &                            Work(ipC_IRC+(nBackward-1)*3*nAtom),
+     &                            nForward*3*nAtom)
+                  Call Get_dArray('IRC-Grad',
+     &                            Work(ipG_IRC+(nBackward-1)*3*nAtom),
+     &                            nForward*3*nAtom)
 *
                   Call Intergeo('MD_IRC',Work(ipE_IRC),Work(ipC_IRC),
      &                          Work(ipG_IRC),nAtom,nIRC)
@@ -866,48 +973,16 @@ C              Write (6,*) 'SubProject=.Prod'
                   Call Free_Work(ipC_IRC)
                   Call Free_Work(ipE_IRC)
                End If
+               Call Free_Work(ipG)
+               Call Free_Work(ipC)
+               Call Free_Work(ipE)
             End If
-*
          End If
 *
-         Call Chkpnt_update_MEP(IRCRestart)
-*
-         Call Free_Work(ipE)
-         Call Free_Work(ipG)
-         Call Free_Work(ipC)
-*
-      End If
-*                                                                      *
-************************************************************************
-*                                                                      *
-*-----List internal coordinates and gradients
-*
-      kkIter=iter+1
-      If (iPrint.ge.8) Then
-         Call List(' Internal coordinates ',Lbl,qInt,nInter,kkIter)
-         Call List(' Internal forces    ',Lbl,Grad,nInter,iter)
-      End If
-*                                                                      *
-************************************************************************
-*                                                                      *
-*     Put out the new reference structure and the new starting
-*     structure to be used for the next MEP point.
-*     For rMEP keep the reference structure!
-*     Note that this is done in weighted Cartesian coordinates!
-*
-      If ((Conv1.or.(iter.eq.1)).and.(MEP.or.rMEP)) Then
          If (.Not.Terminate) Then
            iStop=1
            Stop=.False.
          End If
-*
-         If ((iMEP.ge.1).and.(iPrint.ge.5)) Then
-            Write (6,*)
-            Call CollapseOutput(1,'IRC/Minimum Energy Path Information')
-         End If
-*
-         Call MEP_Dir(Cx,Gx,nAtom,iMEP,iOff_iter,iPrint,IRCRestart)
-         Call Put_iScalar('iOff_Iter',iter)
 *
 *        Print out the path so far
 *
@@ -1006,6 +1081,5 @@ C              Write (6,*) 'SubProject=.Prod'
 *                                                                      *
 ************************************************************************
 *                                                                      *
-      Call QExit('Convrg')
       Return
       End
