@@ -10,6 +10,7 @@
 ************************************************************************
       Subroutine RlxCtl(iStop)
       Use Chkpnt
+      Use kriging_mod, only: Kriging, nspAI
       Implicit Real*8 (a-h,o-z)
 ************************************************************************
 *     Program for determination of the new molecular geometry          *
@@ -22,14 +23,16 @@
 #include "weighting.fh"
 #include "db.fh"
 #include "print.fh"
+#include "stdalloc.fh"
       Logical Numerical, GoOn, PrQ, TSReg,
      &        Do_ESPF, Just_Frequencies, Found
       Character*8 GrdLbl, StpLbl, Labels(nLabels), Lbl(nLbl)
       Character*1 Step_trunc
       Integer AixRm, iNeg(2)
+      Integer nGB
+      Real*8, Allocatable:: GB(:)
 *
       Lu=6
-      Call QEnter('RlxCtl')
       iRout = 32
       iPrint=nPrint(iRout)
       StpLbl=' '
@@ -89,8 +92,7 @@
 *                                                                      *
       If (lCtoF .AND. PrQ) Call Def_CtoF(.False.,Work(ipCM),
      &                                   nsAtom,AtomLbl,
-     &                                   Work(ipCoor),nSym,iOper,
-     &                                   jStab,nStab)
+     &                                   Work(ipCoor),jStab,nStab)
 *                                                                      *
 ************************************************************************
 *                                                                      *
@@ -124,9 +126,10 @@
       Numerical = lNmHss .and.iter.le.NmIter .and.iter.ne.1
 *
       If (Numerical) nWndw=NmIter
+      iRef=0
       Call BMtrx(iRow,nBVec,ipB,nsAtom,mInt,ipqInt,Lbl,
-     &           Work(ipCoor),nDimBC,Work(ipCM),AtomLbl,nSym,
-     &           iOper,Smmtrc,Degen,BSet,HSet,iter,ipdqInt,ipShf,
+     &           Work(ipCoor),nDimBC,Work(ipCM),AtomLbl,
+     &           Smmtrc,Degen,BSet,HSet,iter,ipdqInt,ipShf,
      &           Work(ipGx),Work(ipCx),mTtAtm,iWork(ipANr),iOptH,
      &           User_Def,nStab,jStab,Curvilinear,Numerical,
      &           DDV_Schlegel,HWRS,Analytic_Hessian,iOptC,PrQ,mxdc,
@@ -154,7 +157,7 @@
 *                                                                      *
 ************************************************************************
 *                                                                      *
-      Call Reset_ThrGrd(nsAtom,nDimBC,Work(ipCM),nSym,iOper,Smmtrc,
+      Call Reset_ThrGrd(nsAtom,nDimBC,Work(ipCM),Smmtrc,
      &                  Degen,Iter,Work(ipCx),mTtAtm,iWork(ipANr),
      &                  DDV_Schlegel,iOptC,rHidden,ThrGrd)
 *                                                                      *
@@ -209,6 +212,7 @@
       nPrint( 54)=nPrint( 54)-1
       Write (6,*) ' Accumulate the gradient for selected '//
      &            'numerical differentiation.'
+      Write (6,'(1x,i5,1x,a,1x,i5)') iter,'of',NmIter
       Ed=Zero
       Step_Trunc=' '
          Go To 666
@@ -222,21 +226,46 @@
       Step_Trunc=' '
       ed=zero
       If (lRowH.or.lNmHss) kIter = iter - (NmIter-1)
+*define UNIT_MM
+#ifdef UNIT_MM
+      Call Setup_UpdMask(Curvilinear, Redundant, nsAtom, nInter)
+#endif
 *
 *     Update geometry
 *
-      Call Update_sl(Iter,NmIter,iInt,nFix,nQQ,Work(ipqInt),
-     &               Work(ipShf),Work(ipdqInt),iOptC,Beta,
+      If (Kriging .and. Iter.ge.nspAI) Then
+         Call Update_Kriging(
+     &               Iter,MaxItr,NmIter,iInt,nFix,nQQ,Work(ipqInt),
+     &               Work(ipShf),Work(ipdqInt),iOptC,Beta,Beta_Disp,
      &               Lbl,Work(ipGNrm),Work(ipEner),UpMeth,
      &               ed,Line_Search,Step_Trunc,nLambda,iRow_c,nsAtom,
-     &               AtomLbl,nSym,iOper,mxdc,jStab,nStab,Work(ipB),
-     &               Smmtrc,nDimBC,Work(ipL),ipCx,GrdMax,
-     &               StpMax,GrdLbl,StpLbl,iNeg,nLbl,
+     &               AtomLbl,mxdc,jStab,nStab,Work(ipB),
+     &               Smmtrc,nDimBC,Work(ipL),Work(ipCx),Work(ipGx),
+     &               GrdMax,StpMax,GrdLbl,StpLbl,iNeg,nLbl,
      &               Labels,nLabels,FindTS,TSConstraints,nRowH,
-     &               nWndw,Mode,ipMF,
+     &               nWndw,Mode,Work(ipMF),
      &               iOptH,HUpMet,kIter,GNrm_Threshold,
      &               IRC,Work(ipCM),HrmFrq_Show,
-     &               CnstWght,Curvilinear,Redundant,Degen)
+     &               CnstWght,Curvilinear,Degen,ThrEne,ThrGrd)
+      Else
+         Call Update_sl(
+     &               Iter,MaxItr,NmIter,iInt,nFix,nQQ,Work(ipqInt),
+     &               Work(ipShf),Work(ipdqInt),iOptC,Beta,Beta_Disp,
+     &               Lbl,Work(ipGNrm),Work(ipEner),UpMeth,
+     &               ed,Line_Search,Step_Trunc,nLambda,iRow_c,nsAtom,
+     &               AtomLbl,mxdc,jStab,nStab,Work(ipB),
+     &               Smmtrc,nDimBC,Work(ipL),Work(ipCx),GrdMax,
+     &               StpMax,GrdLbl,StpLbl,iNeg,nLbl,
+     &               Labels,nLabels,FindTS,TSConstraints,nRowH,
+     &               nWndw,Mode,Work(ipMF),
+     &               iOptH,HUpMet,kIter,GNrm_Threshold,
+     &               IRC,Work(ipCM),HrmFrq_Show,
+     &               CnstWght,Curvilinear,Degen)
+      End If
+*
+#ifdef UNIT_MM
+      Call Free_UpdMask()
+#endif
 *
  666  Continue
 *                                                                      *
@@ -244,22 +273,26 @@
 ************************************************************************
 *                                                                      *
 *-----Transform the new internal coordinates to Cartesians
+*     (if not already done by Kriging)
 *
-      Call GetMem(' DCF  ', 'Allo','Real',ipDCF, 3*nsAtom)
-      Call GetMem(' dss  ', 'Allo','Real',ipdss, nQQ)
-      Call GetMem(' qTemp', 'Allo','Real',ipTmp, nQQ)
-      PrQ=.False.
-      Call NewCar(Iter,nBVec,iRow,nsAtom,nDimBC,nQQ,Work(ipCoor),
-     &            ipB,Work(ipCM),Lbl,Work(ipShf),ipqInt,
-     &            ipdqInt,Work(ipDCF),Work(ipdss),Work(ipTmp),
-     &            Stop,AtomLbl,iOper,nSym,iSym,Smmtrc,Degen,
-     &            Work(ipGx),Work(ipCx),mTtAtm,iWork(ipANr),iOptH,
-     &            User_Def,nStab,jStab,Curvilinear,Numerical,
-     &            DDV_Schlegel,HWRS,Analytic_Hessian,iOptC,PrQ,mxdc,
-     &            iCoSet,rHidden,ipRef,Redundant,nqInt,MaxItr)
-      Call GetMem(' qTemp', 'Free','Real',ipTmp, nQQ)
-      Call GetMem(' dss  ', 'Free','Real',ipdss, nQQ)
-      Call GetMem(' DCF  ', 'Free','Real',ipDCF, 3*nsAtom)
+      If (.not.(Kriging .and. Iter.ge.nspAI)) Then
+         Call GetMem(' DFC  ', 'Allo','Real',ipDFC, 3*nsAtom)
+         Call GetMem(' dss  ', 'Allo','Real',ipdss, nQQ)
+         Call GetMem(' qTemp', 'Allo','Real',ipTmp, nQQ)
+         PrQ=.False.
+         iRef=0
+         Call NewCar(Iter,nBVec,iRow,nsAtom,nDimBC,nQQ,Work(ipCoor),
+     &               ipB,Work(ipCM),Lbl,Work(ipShf),ipqInt,
+     &               ipdqInt,Work(ipDFC),Work(ipdss),Work(ipTmp),
+     &               AtomLbl,iSym,Smmtrc,Degen,
+     &               Work(ipGx),Work(ipCx),mTtAtm,iWork(ipANr),iOptH,
+     &               User_Def,nStab,jStab,Curvilinear,Numerical,
+     &               DDV_Schlegel,HWRS,Analytic_Hessian,iOptC,PrQ,mxdc,
+     &               iCoSet,rHidden,ipRef,Redundant,nqInt,MaxItr,iRef)
+         Call GetMem(' qTemp', 'Free','Real',ipTmp, nQQ)
+         Call GetMem(' dss  ', 'Free','Real',ipdss, nQQ)
+         Call GetMem(' DFC  ', 'Free','Real',ipDFC, 3*nsAtom)
+      End If
 *                                                                      *
 ************************************************************************
 ************************************************************************
@@ -270,7 +303,7 @@
       Do_ESPF = .False.
       Call DecideOnESPF(Do_ESPF)
       If (Do_ESPF) Then
-       Call LA_Morok(nsAtom,ipCoor,2)
+       Call LA_Morok(nsAtom,work(ipCoor),2)
        call dcopy_(3*nsAtom,Work(ipCoor),1,Work(ipCx+3*nsAtom*Iter),1)
       End If
 *                                                                      *
@@ -309,12 +342,12 @@
      &            Work(ipdqInt),Lbl,Work(ipGNrm),
      &            Work(ipEner),Stat,MaxItr,Stop,iStop,ThrCons,
      &            ThrEne,ThrGrd,MxItr,UpMeth,HUpMet,mIntEff,Baker,
-     &            Work(ipCx),Work(ipGx),nsAtom,mTtAtm,iOper,nSym,ed,
+     &            Work(ipCx),Work(ipGx),nsAtom,mTtAtm,ed,
      &            iNeg,GoOn,Step_Trunc,GrdMax,StpMax,GrdLbl,StpLbl,
      &            Analytic_Hessian,rMEP,MEP,nMEP,
      &            (lNmHss.or.lRowH).and.iter.le.NmIter,
      &            Just_Frequencies,FindTS,ipCoor,eMEPTest,nLambda,
-     &            TSReg)
+     &            TSReg,ThrMEP)
       Call Free_Work(ipShf)
 *
 ************************************************************************
@@ -328,7 +361,7 @@
       Call DstInf(iStop,Just_Frequencies,
      &            (lNmHss.or.lRowH) .and.iter.le.NmIter)
       If (lCtoF) Call Def_CtoF(.True.,Work(ipCM),
-     &         nsAtom,AtomLbl,Work(ipCoor),nSym,iOper,jStab,nStab)
+     &         nsAtom,AtomLbl,Work(ipCoor),jStab,nStab)
       If (.Not.User_Def .and.
      &   ((lNmHss.and.iter.ge.NmIter).or..Not.lNmHss)) Call cp_SpcInt
 *
@@ -339,7 +372,9 @@
          Call f_Inquire('RUNBACK',Found)
          If (Found) Then
 *           Read data
-            Call Get_Grad(ipGB,nGB)
+            nGB=3*nsAtom
+            Call mma_allocate(GB,nGB,Label='GB')
+            Call Get_Grad(GB,nGB)
             Call Qpg_dArray('Hss_X',Found,nHX)
             Call GetMem('HssX','Allo','Real',ipHX,nHX)
             Call Get_dArray('Hss_X',Work(ipHX),nHX)
@@ -352,7 +387,7 @@
             Call Get_iScalar('No of Internal coordinates',nIntCoor)
 *           Write data in backup file
             Call NameRun('RUNBACK')
-            Call Put_Grad(Work(ipGB),nGB)
+            Call Put_Grad(GB,nGB)
             Call Put_dArray('Hss_X',Work(ipHX),nHX)
             Call Put_dArray('Hss_Q',Work(ipHQ),nHQ)
             Call Put_dArray('Hss_upd',Work(ip_Dummy),0)
@@ -370,7 +405,7 @@
             End Do
             Call Put_AnalHess(Work(ipHX),iOff)
             Call NameRun('#Pop')
-            Call GetMem('Grad','Free','Real',ipGB,nGB)
+            Call mma_deallocate(GB)
             Call GetMem('HssX','Free','Real',ipHX,nHX)
             Call GetMem('HssQ','Free','Real',ipHQ,nHQ)
             Call GetMem('KtB','Free','Real',ipKtB,nKtB)
@@ -425,7 +460,6 @@
 *
 *-----Terminate the calculations.
 *
-      Call QExit('RlxCtl')
 *
       Return
       End
