@@ -10,14 +10,15 @@
 ************************************************************************
       Subroutine Angle_List(
      &                 nq,
-     &                 nAtoms,iIter,nIter,Cx,iOper,nSym,jStab,
+     &                 nAtoms,iIter,nIter,Cx,jStab,
      &                 nStab,nDim,Smmtrc,Process,Value,
      &                 nB,iANr,qLbl,iRef,
      &                 fconst,rMult,LuIC,Name,Indq,
      &                 Grad_all,iGlow,iGhi,iPrv,Proc_dB,
      &                 iTabBonds,nBonds,iTabAI,mAtoms,iTabAtoms,nMax,
      &                 mB_Tot,mdB_Tot,
-     &                 BM,dBM,iBM,idBM,nB_Tot,ndB_Tot,nqB)
+     &                 BM,dBM,iBM,idBM,nB_Tot,ndB_Tot,nqB,Thr_small)
+      use Symmetry_Info, only: nIrrep, iOper
       Implicit Real*8 (a-h,o-z)
 #include "real.fh"
 #include "print.fh"
@@ -29,8 +30,8 @@
      &       Grad_Ref(9), Axis(3), Perp_Axis(3,2), Grad(mB),
      &       Grad_all(9,iGlow:iGhi,nIter),
      &       BM(nB_Tot), dBM(ndB_Tot)
-      Integer   nStab(nAtoms), iOper(0:nSym-1), iANr(nAtoms),
-     &          iDCRR(0:7), jStab(0:7,nAtoms), iPhase(3,0:7),
+      Integer   nStab(nAtoms), iANr(nAtoms),
+     &          iDCRR(0:7), jStab(0:7,nAtoms),
      &          iStabM(0:7), Ind(3), iDCR(3), iDCRT(0:7),
      &          iStabN(0:7), iChOp(0:7), Indq(3,nB), nqB(nB),
      &          iTabBonds(3,nBonds), iTabAI(2,mAtoms),
@@ -45,29 +46,26 @@
 #define _FMIN_
 #include "ddvdt.fh"
 #include "ddvdt_bend.fh"
-      Data iPhase/ 1, 1, 1,   -1, 1, 1,   1,-1, 1,  -1,-1, 1,
-     &             1, 1,-1,   -1, 1,-1,   1,-1,-1,  -1,-1,-1/
       Data ChOp/'E  ','X ','Y ','XY ','Z  ','XZ ','YZ ','XYZ'/
       Data iChOp/1,1,1,2,1,2,2,3/
 #include "constants.fh"
 *                                                                      *
 ************************************************************************
 *                                                                      *
-*define _DEBUG_
+*define _DEBUGPRINT_
 *                                                                      *
 ************************************************************************
 *                                                                      *
       If (nBonds.lt.2) Return
       iRout=150
       iPrint=nPrint(iRout)
-#ifdef _DEBUG_
+#ifdef _DEBUGPRINT_
       iPrint=99
 #endif
-      Call QEnter('Bends')
 *
       nqA=0
       PSPrint=.False.
-#ifdef _DEBUG_
+#ifdef _DEBUGPRINT_
       If (iPrint.ge.99) PSPrint=.True.
       If (PSPrint) Write (6,*) ' Enter Bends.'
 #endif
@@ -83,7 +81,7 @@
          Fact=One
       End If
       nCent=3
-*     Write (*,*)
+*     Write (6,*)
 *
       Do mAtom_ = 1, mAtoms
          mAtom = iTabAI(1,mAtom_)
@@ -112,9 +110,9 @@
 *
             iBond = iTabAtoms(2,iNeighbor,mAtom_)
             iBondType=iTabBonds(3,iBond)
-            If (iBondType.eq.vdW_Bond) Go To 200
-            If (iBondType.gt.Magic_Bond) Go To 200
-#ifdef _DEBUG_
+            If (iBondType.eq.vdW_Bond.or.
+     &          iBondType.gt.Magic_Bond) Go To 200
+#ifdef _DEBUGPRINT_
             Write (6,*)
             Write (6,*) 'iAtom,mAtom=',iAtom,mAtom
             Write (6,*) 'iBond,iBondType=',iBond,iBondType
@@ -149,9 +147,9 @@
 *
                jBond = iTabAtoms(2,jNeighbor,mAtom_)
                jBondType=iTabBonds(3,jBond)
-               If (jBondType.eq.vdW_Bond) Go To 300
-               If (jBondType.gt.Magic_Bond) Go To 300
-#ifdef _DEBUG_
+               If (jBondType.eq.vdW_Bond.or.
+     &             jBondType.gt.Magic_Bond) Go To 300
+#ifdef _DEBUGPRINT_
                Write (6,*)
                Write (6,*) 'jAtom,mAtom=',jAtom,mAtom
                Write (6,*) 'jBond,jBondType=',jBond,jBondType
@@ -161,7 +159,7 @@
                Write (Label,'(A,I2,A,I2,A,I2,A)')
      &                'A(',iAtom,',',mAtom,',',jAtom,')'
 *
-#ifdef _DEBUG_
+#ifdef _DEBUGPRINT_
                If (PSPrint) Then
                   Call RecPrt('A',' ',Cx(1,iAtom,iIter),1,3)
                   Call RecPrt('B',' ',Cx(1,mAtom,iIter),1,3)
@@ -171,16 +169,16 @@
 *
 *------------- Form double coset representatives for (iAtom,jAtom)
 *
-               Call DCR(Lambda,iOper,nSym,
+               Call DCR(Lambda,
      &                  jStab(0,iAtom),nStab(iAtom),
      &                  jStab(0,jAtom),nStab(jAtom),iDCRT,nDCRT)
-#ifdef _DEBUG_
+#ifdef _DEBUGPRINT_
                Write (6,'(10A)') 'T={',
      &               (ChOp(iDCRT(i)),i=0,nDCRT-1),'}  '
 #endif
                kDCRT=iDCR(3)
 *
-#ifdef _DEBUG_
+#ifdef _DEBUGPRINT_
                If (PSPrint) Then
                   Write (6,'(10A)') 'U={',
      &                  (ChOp(jStab(i,iAtom)),i=0,nStab(iAtom)-1),'}  '
@@ -192,15 +190,9 @@
                End If
 #endif
 *
-               A(1,3)   = DBLE(iPhase(1,kDCRT))*Cx(1,jAtom,iIter)
-               A(2,3)   = DBLE(iPhase(2,kDCRT))*Cx(2,jAtom,iIter)
-               A(3,3)   = DBLE(iPhase(3,kDCRT))*Cx(3,jAtom,iIter)
-               Ref(1,3) = DBLE(iPhase(1,kDCRT))*Cx(1,jAtom,iRef )
-               Ref(2,3) = DBLE(iPhase(2,kDCRT))*Cx(2,jAtom,iRef )
-               Ref(3,3) = DBLE(iPhase(3,kDCRT))*Cx(3,jAtom,iRef )
-               Prv(1,3) = DBLE(iPhase(1,kDCRT))*Cx(1,jAtom,iPrv )
-               Prv(2,3) = DBLE(iPhase(2,kDCRT))*Cx(2,jAtom,iPrv )
-               Prv(3,3) = DBLE(iPhase(3,kDCRT))*Cx(3,jAtom,iPrv )
+               Call OA(kDCRT,Cx(1:3,jAtom,iIter),  A(1:3,3))
+               Call OA(kDCRT,Cx(1:3,jAtom,iRef ),Ref(1:3,3))
+               Call OA(kDCRT,Cx(1:3,jAtom,iPrv ),Prv(1:3,3))
 *
 *------------- Form the stabilizer for (iAtom,jAtom)
 *
@@ -214,7 +206,7 @@
      &                          iStabN,nStabN)
                End If
 *
-#ifdef _DEBUG_
+#ifdef _DEBUGPRINT_
                If (PSPrint) Then
                   Write (6,'(10A)') 'N={',
      &                  (ChOp(iStabN(i)),i=0,nStabN-1),'}  '
@@ -224,12 +216,12 @@
 *------------- Form double coset representatives for
 *              ((iAtom,mAtom),jAtom)
 *
-               Call DCR(Lambda,iOper,nSym,
+               Call DCR(Lambda,
      &                  jStab(0,mAtom),nStab(mAtom),
      &                  iStabN,nStabN,iDCRR,nDCRR)
                kDCRR = iDCR(2)
 *
-#ifdef _DEBUG_
+#ifdef _DEBUGPRINT_
                If (PSPrint) Then
                   Write (6,'(10A)') 'R={',
      &                  (ChOp(iDCRR(i)),i=0,nDCRR-1),'}  '
@@ -237,15 +229,9 @@
                End If
 #endif
 *
-               A(1,2)   = DBLE(iPhase(1,kDCRR))*Cx(1,mAtom,iIter)
-               A(2,2)   = DBLE(iPhase(2,kDCRR))*Cx(2,mAtom,iIter)
-               A(3,2)   = DBLE(iPhase(3,kDCRR))*Cx(3,mAtom,iIter)
-               Ref(1,2) = DBLE(iPhase(1,kDCRR))*Cx(1,mAtom,iRef )
-               Ref(2,2) = DBLE(iPhase(2,kDCRR))*Cx(2,mAtom,iRef )
-               Ref(3,2) = DBLE(iPhase(3,kDCRR))*Cx(3,mAtom,iRef )
-               Prv(1,2) = DBLE(iPhase(1,kDCRR))*Cx(1,mAtom,iPrv )
-               Prv(2,2) = DBLE(iPhase(2,kDCRR))*Cx(2,mAtom,iPrv )
-               Prv(3,2) = DBLE(iPhase(3,kDCRR))*Cx(3,mAtom,iPrv )
+               Call OA(kDCRR,Cx(1:3,mAtom,iIter),  A(1:3,2))
+               Call OA(kDCRR,Cx(1:3,mAtom,iRef ),Ref(1:3,2))
+               Call OA(kDCRR,Cx(1:3,mAtom,iPrv ),Prv(1:3,2))
 *
 *------------- Form the stabilizer for ((iAtom,mAtom),jAtom)
 *
@@ -253,7 +239,7 @@
      &                    iStabN,nStabN,
      &                    iStabM,nStabM)
 *
-#ifdef _DEBUG_
+#ifdef _DEBUGPRINT_
                If (PSPrint) Then
                   Write (6,'(10A)') 'M={',
      &                  (ChOp(iStabM(i)),i=0,nStabM-1),'}  '
@@ -262,10 +248,10 @@
 *
 *------------- Compute the degeneracy of the angle
 *
-               ideg=nSym/nStabM
+               ideg=nIrrep/nStabM
                Deg=Sqrt(DBLE(iDeg))
-#ifdef _DEBUG_
-               If (PSPrint) Write (6,*)' nSym,nStabM=',nSym,nStabM
+#ifdef _DEBUGPRINT_
+               If (PSPrint) Write (6,*)' nIrrep,nStabM=',nIrrep,nStabM
 #endif
 *
 *------------- Test if coordinate should be included
@@ -317,7 +303,7 @@
                If (f_Const_Ref.lt.f_Const_Min .and.
      &             iBondType.ne.Fragments_Bond .and.
      &             jBondType.ne.Fragments_Bond ) Go To 300
-#ifdef _DEBUG_
+#ifdef _DEBUGPRINT_
                Write (6,*) ' A Force Constant:',f_Const
                Write (6,*) iAtom,mAtom,jAtom, f_Const
 #endif
@@ -329,7 +315,6 @@
 *
 *------------- Skip cases with a too small angle.
 *
-               Thr_Small=(30.D00/180.D00)*Pi
                If (Abs(Val_Ref).lt.Thr_Small .and.
      &             iBondType.ne.Fragments_Bond .and.
      &             jBondType.ne.Fragments_Bond) Go To 300
@@ -337,18 +322,33 @@
 *                                                                      *
 ************************************************************************
 *                                                                      *
+*              We'd like to avoid the problem with angles that have the
+*              value Pi. We introduce "linear" angles under two
+*              conditions.
+*              (1) the reference angle is within delta of Pi.
+*              (2) the actual angle is within 1.0D-11 of Pi.(?)
+*              Delta is set to 1.0D-11 if there are 3 atoms.(?)
+*
                delta=(45.0D0/180.0D0)*Pi
-               If (mAtoms.eq.3) delta=1.0D-11
-               If (Abs(Val_Ref-Pi).lt.Delta .or.
-     &             Abs(Val-Pi).lt.1.0D-11) Then
+*              If (mAtoms.eq.3) delta=1.0D-11 ! I do not understand
+*              although it is probably me who introduced it!
+*
+               If ( (Abs(Val_Ref-Pi).lt.Delta .or.
+     &               Abs(Val-Pi).lt.1.0D-11) .and.
+     &            .NOT.(
+     &                  (iBondType.eq.Fragments_Bond .or.
+     &                   jBondType.eq.Fragments_Bond)
+     &                   .and. mAtoms.le.4
+     &                  )
+     &            ) Then
 *
 *---------------- Reference is linear(a) or
 *---------------- reference is NOT linear but the new structure is(b).
 *
                   If (Abs(Val-Pi).lt.1.0D-11 .and.
      &                .Not.(Abs(Val_Ref-Pi).lt.Delta)) Then
-*                   Case b
-                    nk=1
+*                    Case b
+                     nk=1
                   Else
 *                    Case a
                      nk=2
@@ -394,7 +394,7 @@ C                 Do k = 1, 2
      &                          Lbls(1)(iF1:iE1),
      &                      ' ',Lbls(2)(iF2:iE2),
      &                      ' ',Lbls(3)(iF3:iE3)
-#ifdef _DEBUG_
+#ifdef _DEBUGPRINT_
                      If (iPrint.ge.49)
      &               Write (6,'(A,I3.3,A,I1.1,6A)')
      &                      'a',nqA,' = LAngle(',k,') ',
@@ -408,20 +408,18 @@ C                 Do k = 1, 2
 *
                      If (Process) Then
 *
-                        Call LBend1(A,nCent,Val,
-     &                              Grad_all(1,nq,iIter),
-     &                              .False.,.False.,
-     &                              '        ',Hess,Proc_dB,Axis,
-     &                              Perp_Axis(1,k))
+                        Call LBend(A,nCent,Val,
+     &                             Grad_all(1,nq,iIter),
+     &                             .False.,.False.,
+     &                             '        ',Hess,Proc_dB,Axis,
+     &                             Perp_Axis(1,k),(k.eq.2))
 *
 *---------------------- Flip Angle value and gradient if needed!
 *
-                        BB=DDot_(9,Grad_all(1,nq,iPrv),1,
-     &                            Grad_all(1,nq,iIter),1)
+                        BB=DDot_(9,Grad_all(1,nq, iPrv),1,
+     &                             Grad_all(1,nq,iIter),1)
                         If (BB.lt.Zero) Then
-*                          Write (*,*) 'BB=',BB
-*                          Write (*,*) ' Angle flips, corrected!'
-*                          Write (*,*) ' iPrv,iIter=', iPrv,iIter
+*                          Write (6,*) ' Angle flips, corrected!'
                            Val=Two*Pi-Val
                            Call DScal_(9,-One,
      &                                Grad_all(1,nq,iIter),1)
@@ -495,14 +493,13 @@ C                 Do k = 1, 2
      &                       Lbls(1)(iF1:iE1),
      &                   ' ',Lbls(2)(iF2:iE2),
      &                   ' ',Lbls(3)(iF3:iE3)
-#ifdef _DEBUG_
+#ifdef _DEBUGPRINT_
                   If (iPrint.ge.49)
      &            Write (6,'(A,I3.3,6A)')
      &                   'a',nqA,' = Angle ',
      &                       Lbls(1)(iF1:iE1),
      &                   ' ',Lbls(2)(iF2:iE2),
      &                   ' ',Lbls(3)(iF3:iE3)
-*                 Write (*,*) 'iDeg=',iDeg
 #endif
                   Label=' '
                   Write (Label,'(A,I3.3)') 'a',nqA
@@ -566,6 +563,5 @@ C                 Do k = 1, 2
 *                                                                      *
 ************************************************************************
 *                                                                      *
-      Call QExit ('Bends')
       Return
       End
