@@ -17,13 +17,12 @@
       Integer   iANr(nAtoms+nHidden), iTabBonds(3,nBonds),
      &          iTabAtoms(2,0:nMax,nAtoms+nHidden)
       Logical Schlegel
-      Call QEnter('ddV')
 *
 *  Temporary big hessian
 *
 ************************************************************************
 *                                                                      *
-*define _DEBUG_
+*#define _DEBUGPRINT_
 *                                                                      *
 ************************************************************************
       If (nHidden.gt.0) Then
@@ -39,7 +38,7 @@
          iSBS = iOr(iSBS,2**7)
          iSBS = iOr(iSBS,2**8)
          Call dCopy_((3*nAtoms)*(3*nAtoms+1)/2,Work(ipHBig),1,Hess,1)
-#ifdef _DEBUG_
+#ifdef _DEBUGPRINT_
          write(6,*) 'DDV: Improved Hessian'
          Call RecPrt('Coord (with hidden atoms):',' ',Cart,3,nTot)
          Call TriPrt('Hessian (hidden atoms):',' ',Work(ipHBig),3*nTot)
@@ -50,11 +49,11 @@
          Call ddV_(Cart,nAtoms,Hess,iANr,Schlegel,iOptC,iTabBonds,
      &             iTabAtoms,nBonds,nMax,nHidden)
       End If
-      Call QExit('ddV')
       End
 *
       Subroutine ddV_(Cart,nAtoms,Hess,iANr,Schlegel,iOptC,iTabBonds,
      &               iTabAtoms,nBonds,nMax,nHidden)
+      use Symmetry_Info, only: nIrrep, iOper
       Implicit Real*8 (a-h,o-z)
 #include "real.fh"
 #include "print.fh"
@@ -66,7 +65,7 @@
      &       xyz(3,4), C(3,4), Dum(1),
      &       ril(3), rik(3)
       Integer   iANr(nAtoms), iTabBonds(3,nBonds),
-     &          iTabAtoms(2,0:nMax,nAtoms), iOper(0:7)
+     &          iTabAtoms(2,0:nMax,nAtoms)
       Logical Schlegel, MinBas, Help, TransVar, RotVar, Torsion_Check,
      &        Invariant(3)
 *
@@ -87,7 +86,7 @@
 *                                                                      *
 ************************************************************************
 *                                                                      *
-#ifdef _DEBUG_
+#ifdef _DEBUGPRINT_
       Write (6,*) 'ddV: nBonds=',nBonds
       nqR=0
       nqB=0
@@ -104,7 +103,6 @@
 *                                                                      *
       iRout=140
       iPrint=nPrint(iRout)
-      Call QEnter('ddV_')
 *
       f_const_min_=f_const_min * 1.0D-1
       f_const=0.0D0
@@ -120,7 +118,7 @@
       n3=3*nAtoms
 *
       call dcopy_((n3*(n3+1)/2),[Zero],0,Hess,1)
-#ifdef _DEBUG_
+#ifdef _DEBUGPRINT_
       Call TriPrt(' In LNM: Hessian at start','(12f8.3)',
      &               Hess,n3)
       Call DiagMtrx_T(Hess,n3,iNeg)
@@ -131,8 +129,6 @@
       TransVar=iAnd(iSBS,2**7).eq. 2**7
       RotVar  =iAnd(iSBS,2**8).eq. 2**8
 *
-      Call Get_iScalar('NSYM',nSym)
-      Call Get_iArray('Symmetry operations',iOper,nSym)
       Call Allocate_Work(ip_xMass,nAtoms)
       Call Get_Mass_All(Work(ip_xMass),nAtoms-nHidden)
       Do iAtom=nAtoms-nHidden+1,nAtoms
@@ -148,7 +144,7 @@
       Do ixyz = 1, 3
          Invariant(ixyz)=.False.
          iTest=2**(ixyz-1)
-         Do iSym = 0, nSym-1
+         Do iSym = 0, nIrrep-1
             If (iOper(iSym).eq.iTest) Invariant(ixyz)=.True.
          End Do
       End Do
@@ -189,7 +185,7 @@
      &   Hess(LHR(3,iAtom,3,iAtom))=Hess(LHR(3,iAtom,3,iAtom))+gmm
 *
       End Do
-#ifdef _DEBUG_
+#ifdef _DEBUGPRINT_
       Call TriPrt(' In LNM: Hessian after Translation','(6f12.7)',
      &               Hess,n3)
       Call DiagMtrx_T(Hess,n3,iNeg)
@@ -211,7 +207,7 @@
          Else
             iTest=3
          End If
-         Do iSym = 0, nSym-1
+         Do iSym = 0, nIrrep-1
             If (iOper(iSym).eq.iTest) Invariant(ixyz)=.True.
          End Do
       End Do
@@ -368,7 +364,7 @@ c     End If
 *
       End Do
       Call Free_Work(ip_Grad)
-#ifdef _DEBUG_
+#ifdef _DEBUGPRINT_
       Call TriPrt(' In LNM: Hessian after Rotation','(12f12.7)',
      &               Hess,n3)
       Call DiagMtrx_T(Hess,n3,iNeg)
@@ -417,7 +413,7 @@ C        If (iBondType.gt.Magic_Bond) Go To 10
          End If
 *
          f_const = Max(gmm,f_const_Min_)
-#ifdef _DEBUG_
+#ifdef _DEBUGPRINT_
          nqR=nqR+1
          Write (6,*) 'ddV: bonds: kAtom,lAtom=',kAtom,LAtom
          Write (6,*) '          : Bondtype=',iBondType
@@ -457,7 +453,7 @@ C        If (iBondType.gt.Magic_Bond) Go To 10
 *
 C10      Continue
       End Do
-#ifdef _DEBUG_
+#ifdef _DEBUGPRINT_
       Call TriPrt(' In LNM: Hessian after tension','(12f12.7)',
      &               Hess,n3)
       Call DiagMtrx_T(Hess,n3,iNeg)
@@ -559,7 +555,7 @@ chjw modified
               rL=sqrt(rL2)
             end if
             gij=Max(gij,f_const_Min_)
-#ifdef _DEBUG_
+#ifdef _DEBUGPRINT_
             Write (6,*) 'iAtom,mAtom,jAtom=',iAtom,mAtom,jAtom
             Write (6,*) 'gij=',gij
             Write (6,*) 'rmj=',rmj
@@ -569,7 +565,7 @@ chjw modified
 *
             if ((rmj.gt.rZero).and.(rmi.gt.rZero).and.
      &                                (rrij.gt.rZero)) Then
-#ifdef _DEBUG_
+#ifdef _DEBUGPRINT_
               nqB=nqB+1
 #endif
               SinPhi=rL/(rmj*rmi)
@@ -656,7 +652,7 @@ chjw modified
                    y(2)=One
                    z(2)=Zero
                 End If
-#ifdef _DEBUG_
+#ifdef _DEBUGPRINT_
                 nqB=nqB+2
 #endif
                 Do i=1,2
@@ -728,7 +724,7 @@ chjw modified
        End Do
  20    Continue
       End Do
-#ifdef _DEBUG_
+#ifdef _DEBUGPRINT_
       Call TriPrt(' In LNM: Hessian after bending','(12f12.7)',
      &               Hess,n3)
       Call DiagMtrx_T(Hess,n3,iNeg)
@@ -745,7 +741,7 @@ chjw modified
          iBondType =iTabBonds(3,iBond)
          Fact = One
          If (iBondType.gt.Magic_Bond) Fact=Two
-#ifdef _DEBUG_
+#ifdef _DEBUGPRINT_
          Write (6,*)
          Write (6,*) '*',jAtom,kAtom,' *'
          Write (6,*)
@@ -769,7 +765,7 @@ C        If (iBondType.eq.vdW_Bond) Go To 444
 *
          Do jNeighbor = 1, nNeighbor_j
             iAtom = iTabAtoms(1,jNeighbor,jAtom)
-#ifdef _DEBUG_
+#ifdef _DEBUGPRINT_
 *           Write (6,*)
 *           Write (6,*) iAtom,jAtom,kAtom,' *'
 *           Write (6,*)
@@ -826,7 +822,7 @@ C              If (kBondType.eq.vdW_Bond) Go To 222
                CosFi3=(rkl(1)*rjk(1)+rkl(2)*rjk(2)+rkl(3)*rjk(3))
      &               /Sqrt(rkl2*rjk2)
                If (Abs(CosFi3).gt.CosFi_Max) Go To 222
-#ifdef _DEBUG_
+#ifdef _DEBUGPRINT_
                Write (6,*) 'CosFi2,CosFi3=',CosFi2,CosFi3
                Write (6,*) 'rij=',rij,rij2
                Write (6,*) 'rjk=',rjk,rjk2
@@ -885,7 +881,7 @@ C              If (kBondType.eq.vdW_Bond) Go To 222
      &                           nMax,nAtoms) )Then
                   tij = Max(tij,10.0D0*f_const_Min_)
                End If
-#ifdef _DEBUG_
+#ifdef _DEBUGPRINT_
                nqT=nqT+1
                Write (6,*)
                Write (6,*) iAtom,jAtom,kAtom,lAtom
@@ -898,7 +894,7 @@ C              If (kBondType.eq.vdW_Bond) Go To 222
                call dcopy_(3,C(1,2),1,sj,1)
                call dcopy_(3,C(1,3),1,sk,1)
                call dcopy_(3,C(1,4),1,sl,1)
-#ifdef _DEBUG_
+#ifdef _DEBUGPRINT_
 *              Call RecPrt('C',' ',C,3,4)
 #endif
 *
@@ -955,7 +951,7 @@ C              If (kBondType.eq.vdW_Bond) Go To 222
          End Do             ! iNeighbor_j
  444     Continue
       End Do                ! iBonds
-#ifdef _DEBUG_
+#ifdef _DEBUGPRINT_
       Call TriPrt(' In LNM: Hessian after torsion','(12f12.7)',
      &               Hess,n3)
       Call DiagMtrx_T(Hess,n3,iNeg)
@@ -1048,20 +1044,22 @@ C                 Write (*,*) 'Help=',Help
                   rik2=rik(1)**2+rik(2)**2+rik(3)**2
                   ril2=ril(1)**2+ril(2)**2+ril(3)**2
 *
+                  ThrFi1=Cos(90.0D0*Pi/(180.0D0))
+                  ThrFi2=Cos(150.0D0*Pi/(180.0D0))
                   CosFi2=(rij(1)*rik(1)+rij(2)*rik(2)+rij(3)*rik(3))
      &                  /Sqrt(rij2*rik2)
-                  If (Abs(Abs(CosFi2)-One).lt.1.0D-1) Go To 224
+                  If (CosFi2.gt.ThrFi1 .or. CosFi2.lt.ThrFi2) Go To 224
 *
                   CosFi3=(rij(1)*ril(1)+rij(2)*ril(2)+rij(3)*ril(3))
      &                  /Sqrt(rij2*ril2)
-                  If (Abs(Abs(CosFi3)-One).lt.1.0D-1) Go To 224
+                  If (CosFi3.gt.ThrFi1 .or. CosFi3.lt.ThrFi2) Go To 224
 *
                   CosFi4=(rik(1)*ril(1)+rik(2)*ril(2)+rik(3)*ril(3))
      &                  /Sqrt(rik2*ril2)
-                  If (Abs(Abs(CosFi4)-One).lt.1.0D-1) Go To 224
-#ifdef _DEBUG_
-*                 Write (6,*) 'CosFi2,CosFi3,CosFi4=',
-*    &                        CosFi2,CosFi3,CosFi4
+                  If (CosFi4.gt.ThrFi1 .or. CosFi4.lt.ThrFi2) Go To 224
+#ifdef _DEBUGPRINT_
+                  Write (6,*) 'CosFi2,CosFi3,CosFi4=',
+     &                        CosFi2,CosFi3,CosFi4
 #endif
 *
                   If (Schlegel.or.Help) Then
@@ -1078,8 +1076,8 @@ C                 tij=Max(tij,f_const_Min_)
 *
                   Call OutofP(xyz,4,Tau,C,.False.,.False.,'        ',
      &                        Dum,.False.)
-                  If (Abs(Tau).gt.45.0D0*(Pi/180.D0)) Go To 224
-#ifdef _DEBUG_
+                  If (Abs(Tau).gt.25.0D0*(Pi/180.D0)) Go To 224
+#ifdef _DEBUGPRINT_
                   nqO=nqO+1
 #endif
 *
@@ -1087,10 +1085,10 @@ C                 tij=Max(tij,f_const_Min_)
                   call dcopy_(3,C(1,1),1,sj,1)
                   call dcopy_(3,C(1,2),1,sk,1)
                   call dcopy_(3,C(1,3),1,sl,1)
-#ifdef _DEBUG_
+#ifdef _DEBUGPRINT_
                   Write (6,*) 'iAtoms=',
      &                         iAtom,jAtom,kAtom,lAtom
-                  Write(6,*) 'tij=',tij
+                  Write(6,*) 'tij,Tau=',tij,Tau
 *                 Call RecPrt('si',' ',si,1,3)
 *                 Call RecPrt('sj',' ',sj,1,3)
 *                 Call RecPrt('sk',' ',sk,1,3)
@@ -1152,7 +1150,7 @@ C                 tij=Max(tij,f_const_Min_)
          End Do             ! iCase
  446     Continue
       End Do               ! iBond
-#ifdef _DEBUG_
+#ifdef _DEBUGPRINT_
       Call TriPrt(' In LNM: Hessian after out-of-plane','(12f12.7)',
      &               Hess,n3)
       Call DiagMtrx_T(Hess,n3,iNeg)
@@ -1161,13 +1159,12 @@ C                 tij=Max(tij,f_const_Min_)
 ************************************************************************
 *                                                                      *
  999  Continue
-#ifdef _DEBUG_
+#ifdef _DEBUGPRINT_
       Write (6,*) 'ddV: nqR, nqB, nqT, nqO=',nqR, nqB, nqT, nqO
 #endif
-      Call QExit('ddV_')
       Return
       End
-#ifdef _DEBUG_
+#ifdef _DEBUGPRINT_
       Subroutine DiagMtrx_T(H,nH,iNeg)
       Implicit Real*8 (a-h,o-z)
 #include "real.fh"
@@ -1177,11 +1174,9 @@ C                 tij=Max(tij,f_const_Min_)
       Real*8 H(*)
       Logical Exist
 *
-      Call QEnter('DiagMtrx')
       Lu=6
       iRout=22
       iprint=nPrint(iRout)
-      iPrint=99
 *
       Call GetMem('EVal','Allo','Real',ipEVal,nH*(nH+1)/2)
       Call GetMem('EVec','Allo','Real',ipEVec,nH*nH)
@@ -1264,7 +1259,6 @@ c         Open(luTmp,File=filnam,Form='unformatted',Status='unknown')
       Call GetMem('EVec','Free','Real',ipEVec,nH*nH)
       Call GetMem('EVal','Free','Real',ipEVal,nH*(nH+1)/2)
 *
-      Call QExit('DiagMtrx')
       Return
       End
 #endif
