@@ -9,6 +9,7 @@
 * LICENSE or in <http://www.gnu.org/licenses/>.                        *
 ************************************************************************
       Subroutine Init_SlapAf(iRow)
+      use Symmetry_Info, only: nIrrep, iOper
       Implicit Real*8 (a-h,o-z)
 #include "real.fh"
 #include "WrkSpc.fh"
@@ -31,7 +32,6 @@
 *
       iPrmt(i,j) = jPrmt(iAnd(i,j))
 *
-      Call QEnter('Init')
 ************************************************************************
 ************************** StartUp section   ***************************
 ************************************************************************
@@ -115,7 +115,7 @@
 *   9  iOptC           (512) set: RS-I-RFO, unset: RS-P-RFO
 *  10  iOptC          (1024) HMF augmented with weak interactions
 *  11  iOptC          (2048) augmented HMF used for selection of
-*                           internal coordinates
+*                            internal coordinates
 *  12  iOptC          (4096) set if FindTS
 *  13  iOptC          (8192) set if FindTS and in TS regime
 *
@@ -163,7 +163,10 @@
 *
       Cubic  = .False.
       PDH    = .True.
+*     The threshold for restricted step optimization.
       Beta = 0.30D0
+*     The threshold for restricted variance optimization.
+      Beta_Disp=0.30D0
       GNrm_Threshold=0.2D0
       CnstWght=1.0D0
       Call DecideOnESPF(Do_ESPF)
@@ -176,6 +179,7 @@
          ThrEne = 1.0D-6
          Line_Search=.True.
       End If
+      ThrMEP = ThrGrd
       ThrCons = 1.0D10
       Delta  = 1.0D-2
       nWndw = 5
@@ -224,23 +228,12 @@
 *
       Call Get_cArray('Seward Title',Header,144)
 *
-*...  Read the number of irreps
-*
-      Call Get_iScalar('nSym',nSym)
-      nIrrep=nSym
-*
 *...  Read number of atoms, charges, coordinates, gradients and
 *     atom labels
 *
       Call Get_Molecule(ipCM,ipCoor,ipGrd,AtomLbl,nsAtom,mxdc)
 *                                                                      *
 ************************************************************************
-*                                                                      *
-*...  Read the symmetry operators
-*
-      Call Get_iArray('Symmetry operations',iOper,nSym)
-*                                                                      *
-************************************************************************
 *                                                                      *
       ipNADC=ip_Dummy
       NADC=.False.
@@ -336,7 +329,7 @@ C           NADC= .False. ! for debugging
 *---  Set up of symmetry and degeneracy
 *
       Call ICopy(3,[0],0,iSym,1)
-      Do 600 iIrrep = 1, Min(4,nSym-1)
+      Do 600 iIrrep = 1, Min(4,nIrrep-1)
          jIrrep = iIrrep
          If (iIrrep.eq.3) jIrrep = 4
          Do 601 k = 1, 3
@@ -356,14 +349,14 @@ C           NADC= .False. ! for debugging
          iChxyz=0
          Do i = 1, 3
             If (Work(iAdr+i).ne.Zero) Then
-               Do iIrrep= 0, nSym-1
+               Do iIrrep= 0, nIrrep-1
                   If (iAnd(2**(i-1),iOper(iIrrep)).ne.0)
      &               iChxyz=iOr(iChxyz,2**(i-1))
                End Do
             End If
          End Do
          nStb = 0
-         Do iIrrep = 0, nSym-1
+         Do iIrrep = 0, nIrrep-1
             If (iAnd(iChxyz,iOper(iIrrep)).eq.0) Then
                jStab(nStb,isAtom)=iOper(iIrrep)
                nStb = nStb + 1
@@ -373,7 +366,7 @@ C           NADC= .False. ! for debugging
 *...     Find the coset representatives
          iCoSet(0,nsAtom) = 0      ! Put in the unit operator
          nCoSet = 1
-         Do iIrrep = 1, nSym-1
+         Do iIrrep = 1, nIrrep-1
             itest=iAnd(iChxyz,iOper(iIrrep))
             Same=.False.
             Do jCoSet = 0, nCoSet-1
@@ -387,14 +380,14 @@ C           NADC= .False. ! for debugging
                iCoSet(nCoSet-1,isAtom) = iOper(iIrrep)
             End If
          End Do
-         If (nSym/nStb.ne.nCoSet) Then
+         If (nIrrep/nStb.ne.nCoSet) Then
             Call WarningMessage(2,' Error while doing cosets.')
             Call Abend()
          End If
          Do 611 i = 1, 3
             iComp = 2**(i-1)
             Call ICopy(nCoSet,[0],0,iAdd,1)
-            Do 640 iIrrep = 0, nSym-1
+            Do 640 iIrrep = 0, nIrrep-1
 *...           find the stabilizer index
                iTest=iAnd(iChxyz,iOper(iIrrep))
                n=-1
@@ -450,8 +443,8 @@ C           NADC= .False. ! for debugging
       mTtAtm=0
       Do 4100 isAtom = 1, nsAtom
          iOff = 3*(isAtom-1) + ipCoor
-         mTtAtm=mTtAtm+iDeg(Work(iOff),iOper,nSym)
-         tmp = DBLE(iDeg(Work(iOff),iOper,nSym))
+         mTtAtm=mTtAtm+iDeg(Work(iOff))
+         tmp = DBLE(iDeg(Work(iOff)))
          i=(isAtom-1)*3+1
          Degen(i)=tmp
          i=(isAtom-1)*3+2
@@ -479,8 +472,7 @@ C           NADC= .False. ! for debugging
      &                   AtomLbl,nsAtom,Work(ipCoor),3,nsAtom)
       LWrite = .False.
       If (jPrint.ge.99) lWrite=.True.
-      Call CofMss(Work(ipCoor),Work(ipCM),iOper,nSym,
-     &            nsAtom,LWrite,cMass,iSym)
+      Call CofMss(Work(ipCoor),Work(ipCM),nsAtom,LWrite,cMass,iSym)
       LWrite = .False.
       If (jPrint.ge.99) Call
      &     PrList('Symmetry Distinct Nuclear Forces / au',
@@ -496,9 +488,9 @@ C           NADC= .False. ! for debugging
       mB_Tot=0
       mdB_Tot=0
       mq=0
+      Force_dB=.False.
 *                                                                      *
 ************************************************************************
 *                                                                      *
-      Call QExit('Init')
       Return
       End
