@@ -28,6 +28,7 @@
 *> @param[in] lDisp Number of displacements per irrep
 ************************************************************************
       Subroutine Print_Mode_Components(Modes,Freq,nModes,lModes,lDisp)
+      use Symmetry_Info, only: nIrrep
       Implicit None
 #include "backup_info.fh"
 #include "print.fh"
@@ -37,7 +38,7 @@
       Real*8 :: Modes(*), Freq(*), Mx, MinComp
       Integer :: LuInput, iRow, iInt, nFix, iRout,
      &           iPrint, nX, i, j, nB, iq, nAll_Atoms, nUnique_Atoms,
-     &           iB, lDisp(nSym), nModes, lModes, LuIC, ii, im, nK,
+     &           iB, lDisp(nIrrep), nModes, lModes, LuIC, ii, im, nK,
      &           iErr, PLback
       Real*8, Dimension(:,:), Allocatable :: KMtrx, KTrsp, KKtB, IntMod,
      &                                       NMod
@@ -47,16 +48,14 @@
       Logical :: Cartesian, Numerical, PrQ, Found
       Character(Len=8) :: Lbl(nLbl),Filename
       Character(Len=16) :: StdIn
-      Character(Len=24) :: Label(nLbl)
+      Character(Len=24), Allocatable :: Label(:)
       Character(Len=180), External :: Get_Ln_EOF
       Real*8, External :: DDot_
 *
-      Call QEnter('Print_Mode_Components')
 *
 *---- Ugly hack: backup all "global" slapaf variables in case this is
 *                called from inside slapaf
 *
-      Bk_iOper(0:7)=iOper(0:7)
       Bk_iSym(:)=iSym(:)
       Bk_iCoSet(0:7,:)=iCoSet(0:7,:)
       Bk_nStab(:)=nStab(:)
@@ -118,7 +117,6 @@
       Bk_ipCoor=ipCoor
       Bk_mTtAtm=mTtAtm
       Bk_nsAtom=nsAtom
-      Bk_nSym=nSym
       Bk_MEPnum=MEPnum
       Bk_RootMap(:)=RootMap(:)
       Bk_Smmtrc(:)=Smmtrc(:)
@@ -176,6 +174,7 @@
       Bk_CnstWght=CnstWght
       Bk_dMEPStep=dMEPStep
       Bk_rFuzz=rFuzz
+      Bk_ThrMEP=ThrMEP
       Bk_lTherm=lTherm
       Bk_lDoubleIso=lDoubleIso
       Bk_nUserPT=nUserPT
@@ -258,8 +257,9 @@
       PrQ=.False.
       nFix=0
       nWndw=iter
+      iRef=0
       Call BMtrx(iRow,nBVec,ipB,nsAtom,mInt,ipqInt,Lbl,
-     &           Work(ipCoor),nDimBC,Work(ipCM),AtomLbl,nSym,iOper,
+     &           Work(ipCoor),nDimBC,Work(ipCM),AtomLbl,
      &           Smmtrc,Degen,BSet,HSet,iter,ipdqInt,ipShf,
      &           Work(ipGx),Work(ipCx),mTtAtm,iWork(ipANr),iOptH,
      &           User_Def,nStab,jStab,Curvilinear,Numerical,
@@ -329,6 +329,7 @@
 *
 *---- Print the overlaps
 *
+      Call mma_allocate(Label,nLbl,label='Label')
       Filename='INTCOR'
       LuIC=21
       LuIC=IsFreeUnit(LuIC)
@@ -380,6 +381,7 @@
 *
 *---- Clean up
 *
+      Call mma_deallocate(Label)
       Call mma_deallocate(IntMod)
       Call mma_deallocate(Sort)
       Call GetMem('BM','Free','Real',ip_B,mB_Tot)
@@ -412,7 +414,6 @@
       If (iErr.ne.0) Call Abend()
       If (AixRm('RUNBCK2').ne.0) Call Abend
 *
-      iOper(0:7)=Bk_iOper(0:7)
       iSym(:)=Bk_iSym(:)
       iCoSet(0:7,:)=Bk_iCoSet(0:7,:)
       nStab(:)=Bk_nStab(:)
@@ -474,7 +475,6 @@
       ipCoor=Bk_ipCoor
       mTtAtm=Bk_mTtAtm
       nsAtom=Bk_nsAtom
-      nSym=Bk_nSym
       MEPnum=Bk_MEPnum
       RootMap(:)=Bk_RootMap(:)
       Smmtrc(:)=Bk_Smmtrc(:)
@@ -532,6 +532,7 @@
       CnstWght=Bk_CnstWght
       dMEPStep=Bk_dMEPStep
       rFuzz=Bk_rFuzz
+      ThrMEP=Bk_ThrMEP
       lTherm=Bk_lTherm
       lDoubleIso=Bk_lDoubleIso
       nUserPT=Bk_nUserPT
@@ -566,6 +567,5 @@
       ipNADC=Bk_ipNADC
       iState(:)=Bk_iState(:)
 *
-      Call QExit('Print_Mode_Components')
 *
       End Subroutine
